@@ -509,7 +509,7 @@ public interface HttpServletRequest extends ServletRequest {
      * @since Servlet 3.1
      */
     <T extends HttpUpgradeHandler> T upgrade(Class<T> httpUpgradeHandlerClass)
-            throws java.io.IOException, ServletException;
+            throws IOException, ServletException;
 
     /**
      * Obtain a Map of the trailer fields that is not backed by the request object.
@@ -518,7 +518,7 @@ public interface HttpServletRequest extends ServletRequest {
      *
      * @since Servlet 4.0
      */
-    default Map<String, String> getTrailerFields() {
+    default Map<String,String> getTrailerFields() {
         return Collections.emptyMap();
     }
 
