@@ -50,22 +50,6 @@ public final class Globals {
     public static final String NAMED_DISPATCHER_ATTR = "org.apache.catalina.NAMED";
 
 
-    /**
-     * The request attribute used to expose the current connection ID associated
-     * with the request, if any. Used with multiplexing protocols such as
-     * HTTTP/2.
-     */
-    public static final String CONNECTION_ID = "org.apache.coyote.connectionID";
-
-
-    /**
-     * The request attribute used to expose the current stream ID associated
-     * with the request, if any. Used with multiplexing protocols such as
-     * HTTTP/2.
-     */
-    public static final String STREAM_ID = "org.apache.coyote.streamID";
-
-
     /**
      * The request attribute that is set to {@code Boolean.TRUE} if some request
      * parameters have been ignored during request parameters parsing. It can
@@ -111,10 +95,17 @@ public final class Globals {
     public static final String SENDFILE_SUPPORTED_ATTR = org.apache.coyote.Constants.SENDFILE_SUPPORTED_ATTR;
 
 
+    /**
+     * The request attribute that is set to the value of {@code Boolean.TRUE}
+     * if {@link org.apache.catalina.filters.RemoteIpFilter} determines
+     * that this request was submitted via a secure channel.
+     */
+    public static final String REMOTE_IP_FILTER_SECURE = "org.apache.catalina.filters.RemoteIpFilter.secure";
+
     /**
      * The request attribute that can be used by a servlet to pass
      * to the connector the name of the file that is to be served
-     * by sendfile. The value should be {@code java.lang.String}
+     * by sendfile. The value should be {@code String}
      * that is {@code File.getCanonicalPath()} of the file to be served.
      *
      * Duplicated here for neater code in the catalina packages.
@@ -126,7 +117,7 @@ public final class Globals {
      * The request attribute that can be used by a servlet to pass
      * to the connector the start offset of the part of a file
      * that is to be served by sendfile. The value should be
-     * {@code java.lang.Long}. To serve complete file
+     * {@code Long}. To serve complete file
      * the value should be {@code Long.valueOf(0)}.
      *
      * Duplicated here for neater code in the catalina packages.
@@ -156,22 +147,21 @@ public final class Globals {
 
     /**
      * The request attribute under which we store the name of the cipher suite
-     * being used on an SSL connection (as an object of type
-     * java.lang.String).
+     * being used on an SSL connection (as an object of type {@link String}).
      */
     public static final String CIPHER_SUITE_ATTR = "jakarta.servlet.request.cipher_suite";
 
 
     /**
      * The request attribute under which we store the key size being used for
-     * this SSL connection (as an object of type java.lang.Integer).
+     * this SSL connection (as an object of type {@link Integer}).
      */
     public static final String KEY_SIZE_ATTR = "jakarta.servlet.request.key_size";
 
 
     /**
      * The request attribute under which we store the session id being used
-     * for this SSL connection (as an object of type java.lang.String).
+     * for this SSL connection (as an object of type {@link String}).
      */
     public static final String SSL_SESSION_ID_ATTR = "jakarta.servlet.request.ssl_session_id";
 
@@ -275,7 +265,7 @@ public final class Globals {
      * this flag to {@code true} will change the defaults for other settings.
      */
     public static final boolean STRICT_SERVLET_COMPLIANCE =
-            Boolean.parseBoolean(System.getProperty("org.apache.catalina.STRICT_SERVLET_COMPLIANCE", "false"));
+            Boolean.getBoolean("org.apache.catalina.STRICT_SERVLET_COMPLIANCE");
 
 
     /**
