@@ -65,8 +65,8 @@ public interface Realm extends Contained {
      * Try to authenticate with the specified username.
      *
      * @param username Username of the Principal to look up
-     * @return the associated principal, or <code>null</code> if none is
-     *         associated.
+     *
+     * @return the associated principal, or {@code null} if none is associated.
      */
     Principal authenticate(String username);
 
@@ -78,7 +78,8 @@ public interface Realm extends Contained {
      * @param username Username of the Principal to look up
      * @param credentials Password or other credentials to use in
      * authenticating this username
-     * @return the associated principal, or <code>null</code> if there is none
+     *
+     * @return the associated principal, or {@code null} if there is none
      */
     Principal authenticate(String username, String credentials);
 
@@ -94,32 +95,72 @@ public interface Realm extends Contained {
      * for this request
      * @param nc the nonce counter
      * @param cnonce the client chosen nonce
-     * @param qop the "quality of protection" (<code>nc</code> and <code>cnonce</code>
-     *        will only be used, if <code>qop</code> is not <code>null</code>).
+     * @param qop the "quality of protection" ({@code nc} and {@code cnonce}
+     *        will only be used, if {@code qop} is not {@code null}).
      * @param realm Realm name
-     * @param md5a2 Second MD5 digest used to calculate the digest :
-     * MD5(Method + ":" + uri)
-     * @return the associated principal, or <code>null</code> if there is none.
+     * @param digestA2 Second digest calculated as digest(Method + ":" + uri)
+     *
+     * @return the associated principal, or {@code null} if there is none.
+     *
+     * @deprecated Unused. Use {@link #authenticate(String, String, String,
+     * String, String, String, String, String, String)}. Will be removed in
+     * Tomcat 11.
      */
+    @Deprecated
     Principal authenticate(String username, String digest,
                                   String nonce, String nc, String cnonce,
                                   String qop, String realm,
-                                  String md5a2);
+                                  String digestA2);
 
 
     /**
-     * Try to authenticate using a {@link GSSContext}
+     * Try to authenticate with the specified username, which
+     * matches the digest calculated using the given parameters using the
+     * method described in RFC 7616.
+     * <p>
+     * The default implementation calls {@link #authenticate(String, String,
+     * String, String, String, String, String, String)} for backwards
+     * compatibility which effectively forces the use of MD5 regardless of the
+     * algorithm specified in the call to this method.
+     * <p>
+     * Implementations are expected to override the default implementation and
+     * take account of the algorithm parameter.
+     *
+     * @param username Username of the Principal to look up
+     * @param digest Digest which has been submitted by the client
+     * @param nonce Unique (or supposedly unique) token which has been used
+     * for this request
+     * @param nc the nonce counter
+     * @param cnonce the client chosen nonce
+     * @param qop the "quality of protection" ({@code nc} and {@code cnonce}
+     *        will only be used, if {@code qop} is not {@code null}).
+     * @param realm Realm name
+     * @param digestA2 Second digest calculated as digest(Method + ":" + uri)
+     * @param algorithm The message digest algorithm to use
+     *
+     * @return the associated principal, or {@code null} if there is none.
+     */
+    default Principal authenticate(String username, String digest,
+                                  String nonce, String nc, String cnonce,
+                                  String qop, String realm,
+                                  String digestA2, String algorithm) {
+        return authenticate(username, digest, nonce, nc, cnonce, qop, realm, digestA2);
+    }
+
+
+    /**
+     * Try to authenticate using a {@link GSSContext}.
      *
      * @param gssContext The gssContext processed by the {@link Authenticator}.
      * @param storeCreds Should the realm attempt to store the delegated
      *                   credentials in the returned Principal?
-     * @return the associated principal, or <code>null</code> if there is none
+     * @return the associated principal, or {@code null} if there is none
      */
     Principal authenticate(GSSContext gssContext, boolean storeCreds);
 
 
     /**
-     * Try to authenticate using a {@link GSSName}
+     * Try to authenticate using a {@link GSSName}.
      *
      * @param gssName The {@link GSSName} of the principal to look up
      * @param gssCredential The {@link GSSCredential} of the principal, may be
@@ -130,11 +171,12 @@ public interface Realm extends Contained {
 
 
     /**
-     * Try to authenticate using {@link X509Certificate}s
+     * Try to authenticate using a chain of {@link X509Certificate}s.
      *
      * @param certs Array of client certificates, with the first one in
      *  the array being the certificate of the client itself.
-     * @return the associated principal, or <code>null</code> if there is none
+     *
+     * @return the associated principal, or {@code null} if there is none
      */
     Principal authenticate(X509Certificate certs[]);
 
@@ -152,9 +194,10 @@ public interface Realm extends Contained {
      * this request.
      *
      * @param request Request we are processing
-     * @param context {@link Context} for this request
-     * @return the configured {@link SecurityConstraint}, of <code>null</code>
-     *         if there is none
+     * @param context Context the Request is mapped to
+     *
+     * @return the configured {@link SecurityConstraint}, or {@code null} if
+     *         there is none
      */
     SecurityConstraint [] findSecurityConstraints(Request request,
                                                      Context context);
@@ -167,8 +210,9 @@ public interface Realm extends Contained {
      * @param response Response we are creating
      * @param constraint Security constraint we are enforcing
      * @param context The Context to which client of this class is attached.
-     * @return <code>true</code> if this constraint is satisfied and processing
-     *         should continue, or <code>false</code> otherwise
+     *
+     * @return {@code true} if this constraint is satisfied and processing
+     *         should continue, or {@code false} otherwise
      *
      * @exception IOException if an input/output error occurs
      */
@@ -186,9 +230,10 @@ public interface Realm extends Contained {
      * @param wrapper wrapper context for evaluating role
      * @param principal Principal for whom the role is to be checked
      * @param role Security role to be checked
-     * @return <code>true</code> if the specified Principal has the specified
+     *
+     * @return {@code true} if the specified Principal has the specified
      *         security role, within the context of this Realm; otherwise return
-     *         <code>false</code>.
+     *         {@code false}.
      */
     boolean hasRole(Wrapper wrapper, Principal principal, String role);
 
@@ -200,8 +245,9 @@ public interface Realm extends Contained {
      * @param request Request we are processing
      * @param response Response we are creating
      * @param constraint Security constraint being checked
-     * @return <code>true</code> if this constraint
-     *         was not violated and processing should continue, or <code>false</code>
+     *
+     * @return {@code true} if this constraint
+     *         was not violated and processing should continue, or {@code false}
      *         if we have created a response already.
      *
      * @exception IOException if an input/output error occurs
@@ -222,7 +268,7 @@ public interface Realm extends Contained {
 
     /**
      * Return the availability of the realm for authentication.
-     * @return <code>true</code> if the realm is able to perform authentication
+     * @return {@code true} if the realm is able to perform authentication
      */
     default boolean isAvailable() {
         return true;
