@@ -20,12 +20,15 @@ package org.apache.catalina;
 import java.security.Principal;
 import java.util.Iterator;
 
-import javax.servlet.http.HttpSession;
+import jakarta.servlet.http.HttpSession;
 
 
 /**
- * A <b>Session</b> is the Catalina-internal facade for an <code>HttpSession</code> that is used to maintain state
- * information between requests for a particular user of a web application.
+ * A <b>Session</b> is the Catalina-internal facade for an
+ * <code>HttpSession</code> that is used to maintain state information
+ * between requests for a particular user of a web application.
+ *
+ * @author Craig R. McClanahan
  */
 public interface Session {
 
@@ -56,22 +59,20 @@ public interface Session {
      */
     String SESSION_PASSIVATED_EVENT = "passivateSession";
 
-    /**
-     * The SessionEvent event type when a session changes its sessionId.
-     */
-    String SESSION_CHANGED_ID_EVENT = "changeSessionId";
 
     // ------------------------------------------------------------- Properties
 
 
     /**
-     * @return the authentication type used to authenticate our cached Principal, if any.
+     * @return the authentication type used to authenticate our cached
+     * Principal, if any.
      */
     String getAuthType();
 
 
     /**
-     * Set the authentication type used to authenticate our cached Principal, if any.
+     * Set the authentication type used to authenticate our cached
+     * Principal, if any.
      *
      * @param authType The new cached authentication type
      */
@@ -85,14 +86,15 @@ public interface Session {
 
 
     /**
-     * @return the creation time for this session, bypassing the session validity checks.
+     * @return the creation time for this session, bypassing the session validity
+     * checks.
      */
     long getCreationTimeInternal();
 
 
     /**
-     * Set the creation time for this session. This method is called by the Manager when an existing Session instance is
-     * reused.
+     * Set the creation time for this session.  This method is called by the
+     * Manager when an existing Session instance is reused.
      *
      * @param time The new creation time
      */
@@ -112,8 +114,8 @@ public interface Session {
 
 
     /**
-     * Set the session identifier for this session and notifies any associated listeners that a new session has been
-     * created.
+     * Set the session identifier for this session and notifies any associated
+     * listeners that a new session has been created.
      *
      * @param id The new session identifier
      */
@@ -121,41 +123,42 @@ public interface Session {
 
 
     /**
-     * Set the session identifier for this session and optionally notifies any associated listeners that a new session
-     * has been created.
+     * Set the session identifier for this session and optionally notifies any
+     * associated listeners that a new session has been created.
      *
-     * @param id     The new session identifier
-     * @param notify Should any associated listeners be notified that a new session has been created?
+     * @param id        The new session identifier
+     * @param notify    Should any associated listeners be notified that a new
+     *                      session has been created?
      */
     void setId(String id, boolean notify);
 
 
     /**
-     * @return the last time the client sent a request associated with this session, as the number of milliseconds since
-     *             midnight, January 1, 1970 GMT. Actions that your application takes, such as getting or setting a
-     *             value associated with the session, do not affect the access time. This one gets updated whenever a
-     *             request starts.
+     * @return the last time the client sent a request associated with this
+     * session, as the number of milliseconds since midnight, January 1, 1970
+     * GMT.  Actions that your application takes, such as getting or setting
+     * a value associated with the session, do not affect the access time.
+     * This one gets updated whenever a request starts.
      */
     long getThisAccessedTime();
 
     /**
      * @return the last client access time without invalidation check
-     *
      * @see #getThisAccessedTime()
      */
     long getThisAccessedTimeInternal();
 
     /**
-     * @return the last time the client sent a request associated with this session, as the number of milliseconds since
-     *             midnight, January 1, 1970 GMT. Actions that your application takes, such as getting or setting a
-     *             value associated with the session, do not affect the access time. This one gets updated whenever a
-     *             request finishes.
+     * @return the last time the client sent a request associated with this
+     * session, as the number of milliseconds since midnight, January 1, 1970
+     * GMT.  Actions that your application takes, such as getting or setting
+     * a value associated with the session, do not affect the access time.
+     * This one gets updated whenever a request finishes.
      */
     long getLastAccessedTime();
 
     /**
      * @return the last client access time without invalidation check
-     *
      * @see #getLastAccessedTime()
      */
     long getLastAccessedTimeInternal();
@@ -167,7 +170,6 @@ public interface Session {
 
     /**
      * @return the idle time from last client access time without invalidation check
-     *
      * @see #getIdleTime()
      */
     long getIdleTimeInternal();
@@ -187,15 +189,17 @@ public interface Session {
 
 
     /**
-     * @return the maximum time interval, in seconds, between client requests before the servlet container will
-     *             invalidate the session. A negative time indicates that the session should never time out.
+     * @return the maximum time interval, in seconds, between client requests
+     * before the servlet container will invalidate the session.  A negative
+     * time indicates that the session should never time out.
      */
     int getMaxInactiveInterval();
 
 
     /**
-     * Set the maximum time interval, in seconds, between client requests before the servlet container will invalidate
-     * the session. A negative time indicates that the session should never time out.
+     * Set the maximum time interval, in seconds, between client requests
+     * before the servlet container will invalidate the session.  A negative
+     * time indicates that the session should never time out.
      *
      * @param interval The new maximum interval
      */
@@ -211,17 +215,19 @@ public interface Session {
 
 
     /**
-     * @return the authenticated Principal that is associated with this Session. This provides an
-     *             <code>Authenticator</code> with a means to cache a previously authenticated Principal, and avoid
-     *             potentially expensive <code>Realm.authenticate()</code> calls on every request. If there is no
-     *             current associated Principal, return <code>null</code>.
+     * @return the authenticated Principal that is associated with this Session.
+     * This provides an <code>Authenticator</code> with a means to cache a
+     * previously authenticated Principal, and avoid potentially expensive
+     * <code>Realm.authenticate()</code> calls on every request.  If there
+     * is no current associated Principal, return <code>null</code>.
      */
     Principal getPrincipal();
 
 
     /**
-     * Set the authenticated Principal that is associated with this Session. This provides an <code>Authenticator</code>
-     * with a means to cache a previously authenticated Principal, and avoid potentially expensive
+     * Set the authenticated Principal that is associated with this Session.
+     * This provides an <code>Authenticator</code> with a means to cache a
+     * previously authenticated Principal, and avoid potentially expensive
      * <code>Realm.authenticate()</code> calls on every request.
      *
      * @param principal The new Principal, or <code>null</code> if none
@@ -230,7 +236,8 @@ public interface Session {
 
 
     /**
-     * @return the <code>HttpSession</code> for which this object is the facade.
+     * @return the <code>HttpSession</code> for which this object
+     * is the facade.
      */
     HttpSession getSession();
 
@@ -253,8 +260,9 @@ public interface Session {
 
 
     /**
-     * Update the accessed time information for this session. This method should be called by the context when a request
-     * comes in for a particular session, even if the application does not reference it.
+     * Update the accessed time information for this session.  This method
+     * should be called by the context when a request comes in for a particular
+     * session, even if the application does not reference it.
      */
     void access();
 
@@ -262,7 +270,8 @@ public interface Session {
     /**
      * Add a session event listener to this component.
      *
-     * @param listener the SessionListener instance that should be notified for session events
+     * @param listener the SessionListener instance that should be notified
+     *   for session events
      */
     void addSessionListener(SessionListener listener);
 
@@ -274,15 +283,15 @@ public interface Session {
 
 
     /**
-     * Perform the internal processing required to invalidate this session, without triggering an exception if the
-     * session has already expired.
+     * Perform the internal processing required to invalidate this session,
+     * without triggering an exception if the session has already expired.
      */
     void expire();
 
 
     /**
-     * @return the object bound with the specified name to the internal notes for this session, or <code>null</code> if
-     *             no such binding exists.
+     * @return the object bound with the specified name to the internal notes
+     * for this session, or <code>null</code> if no such binding exists.
      *
      * @param name Name of the note to be returned
      */
@@ -290,19 +299,22 @@ public interface Session {
 
 
     /**
-     * @return an Iterator containing the String names of all notes bindings that exist for this session.
+     * @return an Iterator containing the String names of all notes bindings
+     * that exist for this session.
      */
     Iterator<String> getNoteNames();
 
 
     /**
-     * Release all object references, and initialize instance variables, in preparation for reuse of this object.
+     * Release all object references, and initialize instance variables, in
+     * preparation for reuse of this object.
      */
     void recycle();
 
 
     /**
-     * Remove any object bound to the specified name in the internal notes for this session.
+     * Remove any object bound to the specified name in the internal notes
+     * for this session.
      *
      * @param name Name of the note to be removed
      */
@@ -312,16 +324,17 @@ public interface Session {
     /**
      * Remove a session event listener from this component.
      *
-     * @param listener remove the session listener, which will no longer be notified
+     * @param listener remove the session listener, which will no longer be
+     *     notified
      */
     void removeSessionListener(SessionListener listener);
 
 
     /**
-     * Bind an object to a specified name in the internal notes associated with this session, replacing any existing
-     * binding for this name.
+     * Bind an object to a specified name in the internal notes associated
+     * with this session, replacing any existing binding for this name.
      *
-     * @param name  Name to which the object should be bound
+     * @param name Name to which the object should be bound
      * @param value Object to be bound to the specified name
      */
     void setNote(String name, Object value);
@@ -330,24 +343,27 @@ public interface Session {
     /**
      * Inform the listeners about the change session ID.
      *
-     * @param newId                    new session ID
-     * @param oldId                    old session ID
-     * @param notifySessionListeners   Should any associated sessionListeners be notified that session ID has been
-     *                                     changed?
-     * @param notifyContainerListeners Should any associated ContainerListeners be notified that session ID has been
-     *                                     changed?
+     * @param newId  new session ID
+     * @param oldId  old session ID
+     * @param notifySessionListeners  Should any associated sessionListeners be
+     *        notified that session ID has been changed?
+     * @param notifyContainerListeners  Should any associated ContainerListeners
+     *        be notified that session ID has been changed?
      */
-    void tellChangedSessionId(String newId, String oldId, boolean notifySessionListeners,
-            boolean notifyContainerListeners);
+    void tellChangedSessionId(String newId, String oldId,
+            boolean notifySessionListeners, boolean notifyContainerListeners);
 
 
     /**
-     * Does the session implementation support the distributing of the given attribute? If the Manager is marked as
-     * distributable, then this method must be used to check attributes before adding them to a session and an
-     * {@link IllegalArgumentException} thrown if the proposed attribute is not distributable.
+     * Does the session implementation support the distributing of the given
+     * attribute? If the Manager is marked as distributable, then this method
+     * must be used to check attributes before adding them to a session and
+     * an {@link IllegalArgumentException} thrown if the proposed attribute is
+     * not distributable.
      * <p>
-     * Note that the {@link Manager} implementation may further restrict which attributes are distributed but a
-     * {@link Manager} level restriction should not trigger an {@link IllegalArgumentException} in
+     * Note that the {@link Manager} implementation may further restrict which
+     * attributes are distributed but a {@link Manager} level restriction should
+     * not trigger an {@link IllegalArgumentException} in
      * {@link HttpSession#setAttribute(String, Object)}
      *
      * @param name  The attribute name
