@@ -17,7 +17,6 @@
 package org.apache.catalina;
 
 import java.security.Principal;
-import java.util.Collections;
 import java.util.Enumeration;
 
 import org.ietf.jgss.GSSCredential;
@@ -84,9 +83,7 @@ public interface TomcatPrincipal extends Principal {
      *         <code>null</code> if the attribute does not exist, or if
      *         <code>null</code> has been specified as the attribute's name
      */
-    default Object getAttribute(String name) {
-        return null;
-    }
+    Object getAttribute(String name);
 
     /**
      * Returns an <code>Enumeration</code> containing the names of the
@@ -97,7 +94,5 @@ public interface TomcatPrincipal extends Principal {
      * @return an <code>Enumeration</code> of strings containing the names of
      *         the Principal's attributes
      */
-    default Enumeration<String> getAttributeNames() {
-        return Collections.emptyEnumeration();
-    }
+    Enumeration<String> getAttributeNames();
 }
