@@ -17,25 +17,28 @@
 package org.apache.catalina;
 
 
-import javax.servlet.MultipartConfigElement;
-import javax.servlet.Servlet;
-import javax.servlet.ServletException;
-import javax.servlet.UnavailableException;
+import jakarta.servlet.MultipartConfigElement;
+import jakarta.servlet.Servlet;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.UnavailableException;
 
 
 /**
- * A <b>Wrapper</b> is a Container that represents an individual servlet definition from the deployment descriptor of
- * the web application. It provides a convenient mechanism to use Interceptors that see every single request to the
- * servlet represented by this definition.
+ * A <b>Wrapper</b> is a Container that represents an individual servlet
+ * definition from the deployment descriptor of the web application.  It
+ * provides a convenient mechanism to use Interceptors that see every single
+ * request to the servlet represented by this definition.
  * <p>
- * Implementations of Wrapper are responsible for managing the servlet life cycle for their underlying servlet class,
- * including calling init() and destroy() at appropriate times, as well as respecting the existence of the
- * SingleThreadModel declaration on the servlet class itself.
+ * Implementations of Wrapper are responsible for managing the servlet life
+ * cycle for their underlying servlet class, including calling init() and
+ * destroy() at appropriate times.
  * <p>
- * The parent Container attached to a Wrapper will generally be an implementation of Context, representing the servlet
- * context (and therefore the web application) within which this servlet executes.
+ * The parent Container attached to a Wrapper will generally be an
+ * implementation of Context, representing the servlet context (and
+ * therefore the web application) within which this servlet executes.
  * <p>
- * Child Containers are not allowed on Wrapper implementations, so the <code>addChild()</code> method should throw an
+ * Child Containers are not allowed on Wrapper implementations, so the
+ * <code>addChild()</code> method should throw an
  * <code>IllegalArgumentException</code>.
  *
  * @author Craig R. McClanahan
@@ -56,18 +59,20 @@ public interface Wrapper extends Container {
 
 
     /**
-     * @return the available date/time for this servlet, in milliseconds since the epoch. If this date/time is in the
-     *             future, any request for this servlet will return an SC_SERVICE_UNAVAILABLE error. If it is zero, the
-     *             servlet is currently available. A value equal to Long.MAX_VALUE is considered to mean that
-     *             unavailability is permanent.
+     * @return the available date/time for this servlet, in milliseconds since
+     * the epoch.  If this date/time is in the future, any request for this
+     * servlet will return an SC_SERVICE_UNAVAILABLE error.  If it is zero,
+     * the servlet is currently available.  A value equal to Long.MAX_VALUE
+     * is considered to mean that unavailability is permanent.
      */
     long getAvailable();
 
 
     /**
-     * Set the available date/time for this servlet, in milliseconds since the epoch. If this date/time is in the
-     * future, any request for this servlet will return an SC_SERVICE_UNAVAILABLE error. A value equal to Long.MAX_VALUE
-     * is considered to mean that unavailability is permanent.
+     * Set the available date/time for this servlet, in milliseconds since the
+     * epoch.  If this date/time is in the future, any request for this servlet
+     * will return an SC_SERVICE_UNAVAILABLE error.  A value equal to
+     * Long.MAX_VALUE is considered to mean that unavailability is permanent.
      *
      * @param available The new available date/time
      */
@@ -75,13 +80,15 @@ public interface Wrapper extends Container {
 
 
     /**
-     * @return the load-on-startup order value (negative value means load on first call).
+     * @return the load-on-startup order value (negative value means
+     * load on first call).
      */
     int getLoadOnStartup();
 
 
     /**
-     * Set the load-on-startup order value (negative value means load on first call).
+     * Set the load-on-startup order value (negative value means
+     * load on first call).
      *
      * @param value New load-on-startup value
      */
@@ -117,10 +124,14 @@ public interface Wrapper extends Container {
 
 
     /**
-     * Gets the names of the methods supported by the underlying servlet. This is the same set of methods included in
-     * the Allow response header in response to an OPTIONS request method processed by the underlying servlet.
+     * Gets the names of the methods supported by the underlying servlet.
      *
-     * @return Array of names of the methods supported by the underlying servlet
+     * This is the same set of methods included in the Allow response header
+     * in response to an OPTIONS request method processed by the underlying
+     * servlet.
+     *
+     * @return Array of names of the methods supported by the underlying
+     *         servlet
      *
      * @throws ServletException If the target servlet cannot be loaded
      */
@@ -152,7 +163,7 @@ public interface Wrapper extends Container {
     /**
      * Add a new servlet initialization parameter for this servlet.
      *
-     * @param name  Name of this initialization parameter to add
+     * @param name Name of this initialization parameter to add
      * @param value Value of this initialization parameter to add
      */
     void addInitParameter(String name, String value);
@@ -167,7 +178,8 @@ public interface Wrapper extends Container {
 
 
     /**
-     * Add a new security role reference record to the set of records for this servlet.
+     * Add a new security role reference record to the set of records for
+     * this servlet.
      *
      * @param name Role name used within this servlet
      * @param link Role name used within the web application
@@ -176,23 +188,20 @@ public interface Wrapper extends Container {
 
 
     /**
-     * Allocate an initialized instance of this Servlet that is ready to have its <code>service()</code> method called.
-     * If the Servlet class does not implement <code>SingleThreadModel</code>, the (only) initialized instance may be
-     * returned immediately. If the Servlet class implements <code>SingleThreadModel</code>, the Wrapper implementation
-     * must ensure that this instance is not allocated again until it is deallocated by a call to
-     * <code>deallocate()</code>.
+     * Allocate an initialized instance of this Servlet that is ready to have
+     * its <code>service()</code> method called.  The previously initialized
+     * instance may be returned immediately.
      *
-     * @exception ServletException if the Servlet init() method threw an exception
+     * @exception ServletException if the Servlet init() method threw
+     *  an exception
      * @exception ServletException if a loading error occurs
-     *
      * @return a new Servlet instance
      */
     Servlet allocate() throws ServletException;
 
 
     /**
-     * Return this previously allocated servlet to the pool of available instances. If this servlet class does not
-     * implement SingleThreadModel, no action is actually required.
+     * Decrement the allocation count for the servlet instance.
      *
      * @param servlet The servlet to be returned
      *
@@ -202,7 +211,8 @@ public interface Wrapper extends Container {
 
 
     /**
-     * @return the value for the specified initialization parameter name, if any; otherwise return <code>null</code>.
+     * @return the value for the specified initialization parameter name,
+     * if any; otherwise return <code>null</code>.
      *
      * @param name Name of the requested initialization parameter
      */
@@ -210,7 +220,8 @@ public interface Wrapper extends Container {
 
 
     /**
-     * @return the names of all defined initialization parameters for this servlet.
+     * @return the names of all defined initialization parameters for this
+     * servlet.
      */
     String[] findInitParameters();
 
@@ -222,8 +233,8 @@ public interface Wrapper extends Container {
 
 
     /**
-     * @return the security role link for the specified security role reference name, if any; otherwise return
-     *             <code>null</code>.
+     * @return the security role link for the specified security role
+     * reference name, if any; otherwise return <code>null</code>.
      *
      * @param name Security role reference used within this servlet
      */
@@ -231,8 +242,8 @@ public interface Wrapper extends Container {
 
 
     /**
-     * @return the set of security role reference names associated with this servlet, if any; otherwise return a
-     *             zero-length array.
+     * @return the set of security role reference names associated with
+     * this servlet, if any; otherwise return a zero-length array.
      */
     String[] findSecurityReferences();
 
@@ -244,12 +255,13 @@ public interface Wrapper extends Container {
 
 
     /**
-     * Load and initialize an instance of this Servlet, if there is not already at least one initialized instance. This
-     * can be used, for example, to load Servlets that are marked in the deployment descriptor to be loaded at server
-     * startup time.
+     * Load and initialize an instance of this Servlet, if there is not already
+     * at least one initialized instance.  This can be used, for example, to
+     * load Servlets that are marked in the deployment descriptor to be loaded
+     * at server startup time.
      *
-     * @exception ServletException if the Servlet init() method threw an exception or if some other loading problem
-     *                                 occurs
+     * @exception ServletException if the Servlet init() method threw
+     *  an exception or if some other loading problem occurs
      */
     void load() throws ServletException;
 
@@ -279,18 +291,21 @@ public interface Wrapper extends Container {
 
 
     /**
-     * Process an UnavailableException, marking this Servlet as unavailable for the specified amount of time.
+     * Process an UnavailableException, marking this Servlet as unavailable
+     * for the specified amount of time.
      *
-     * @param unavailable The exception that occurred, or <code>null</code> to mark this Servlet as permanently
-     *                        unavailable
+     * @param unavailable The exception that occurred, or <code>null</code>
+     *  to mark this Servlet as permanently unavailable
      */
     void unavailable(UnavailableException unavailable);
 
 
     /**
-     * Unload all initialized instances of this servlet, after calling the <code>destroy()</code> method for each
-     * instance. This can be used, for example, prior to shutting down the entire servlet engine, or prior to reloading
-     * all of the classes from the Loader associated with our Loader's repository.
+     * Unload all initialized instances of this servlet, after calling the
+     * <code>destroy()</code> method for each instance.  This can be used,
+     * for example, prior to shutting down the entire servlet engine, or
+     * prior to reloading all of the classes from the Loader associated with
+     * our Loader's repository.
      *
      * @exception ServletException if an unload error occurs
      */
@@ -298,22 +313,25 @@ public interface Wrapper extends Container {
 
 
     /**
-     * @return the multi-part configuration for the associated Servlet. If no multi-part configuration has been defined,
-     *             then <code>null</code> will be returned.
+     * @return the multi-part configuration for the associated Servlet. If no
+     * multi-part configuration has been defined, then <code>null</code> will be
+     * returned.
      */
     MultipartConfigElement getMultipartConfigElement();
 
 
     /**
-     * Set the multi-part configuration for the associated Servlet. To clear the multi-part configuration specify
-     * <code>null</code> as the new value.
+     * Set the multi-part configuration for the associated Servlet. To clear the
+     * multi-part configuration specify <code>null</code> as the new value.
      *
      * @param multipartConfig The configuration associated with the Servlet
      */
-    void setMultipartConfigElement(MultipartConfigElement multipartConfig);
+    void setMultipartConfigElement(
+            MultipartConfigElement multipartConfig);
 
     /**
-     * Does the associated Servlet support async processing? Defaults to <code>false</code>.
+     * Does the associated Servlet support async processing? Defaults to
+     * <code>false</code>.
      *
      * @return <code>true</code> if the Servlet supports async
      */
