@@ -263,29 +263,18 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
         this.cache = cache;
     }
 
-    /**
-     * Return the Container to which this Valve is attached.
-     */
     @Override
     public Container getContainer() {
         return this.context;
     }
 
-    /**
-     * Set the Container to which this Valve is attached.
-     *
-     * @param container The container to which we are attached
-     */
     @Override
     public void setContainer(Container container) {
-
         if (container != null && !(container instanceof Context)) {
             throw new IllegalArgumentException(sm.getString("authenticator.notContext"));
         }
-
         super.setContainer(container);
         this.context = (Context) container;
-
     }
 
     /**
@@ -623,8 +612,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
                 String originHeader = request.getHeader(CorsFilter.REQUEST_HEADER_ORIGIN);
                 if (originHeader != null && !originHeader.isEmpty() && RequestUtil.isValidOrigin(originHeader) &&
                         !RequestUtil.isSameOrigin(request, originHeader)) {
-                    String accessControlRequestMethodHeader = request
-                            .getHeader(CorsFilter.REQUEST_HEADER_ACCESS_CONTROL_REQUEST_METHOD);
+                    String accessControlRequestMethodHeader =
+                            request.getHeader(CorsFilter.REQUEST_HEADER_ACCESS_CONTROL_REQUEST_METHOD);
                     if (accessControlRequestMethodHeader != null && !accessControlRequestMethodHeader.isEmpty()) {
                         // This appears to be a CORS Preflight request
                         if (allowCorsPreflight == AllowCorsPreflight.ALWAYS) {
@@ -710,8 +699,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
 
         try {
             CallbackHandler callbackHandler = getCallbackHandler();
-            ServerAuthConfig serverAuthConfig = jaspicProvider.getServerAuthConfig("HttpServlet", jaspicAppContextID,
-                    callbackHandler);
+            ServerAuthConfig serverAuthConfig =
+                    jaspicProvider.getServerAuthConfig("HttpServlet", jaspicAppContextID, callbackHandler);
             String authContextID = serverAuthConfig.getAuthContextID(jaspicState.messageInfo);
             jaspicState.serverAuthContext = serverAuthConfig.getAuthContext(authContextID, null, null);
         } catch (AuthException e) {
@@ -1147,6 +1136,11 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
         register(request, request.getResponse(), principal, getAuthMethod(), username, password);
     }
 
+    /**
+     * Return the authentication method, which is vendor-specific and not defined by HttpServletRequest.
+     *
+     * @return the authentication method, which is vendor-specific and not defined by HttpServletRequest.
+     */
     protected abstract String getAuthMethod();
 
     /**
@@ -1177,8 +1171,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
             if (client != null) {
                 ServerAuthContext serverAuthContext;
                 try {
-                    ServerAuthConfig serverAuthConfig = provider.getServerAuthConfig("HttpServlet", jaspicAppContextID,
-                            getCallbackHandler());
+                    ServerAuthConfig serverAuthConfig =
+                            provider.getServerAuthConfig("HttpServlet", jaspicAppContextID, getCallbackHandler());
                     String authContextID = serverAuthConfig.getAuthContextID(messageInfo);
                     serverAuthContext = serverAuthConfig.getAuthContext(authContextID, null, null);
                     serverAuthContext.cleanSubject(messageInfo, client);
@@ -1202,13 +1196,6 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
     }
 
 
-    /**
-     * Start this component and implement the requirements of
-     * {@link org.apache.catalina.util.LifecycleBase#startInternal()}.
-     *
-     * @exception LifecycleException if this component detects a fatal error that prevents this component from being
-     *                                   used
-     */
     @Override
     protected synchronized void startInternal() throws LifecycleException {
         ServletContext servletContext = context.getServletContext();
@@ -1246,18 +1233,9 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
     }
 
 
-    /**
-     * Stop this component and implement the requirements of
-     * {@link org.apache.catalina.util.LifecycleBase#stopInternal()}.
-     *
-     * @exception LifecycleException if this component detects a fatal error that prevents this component from being
-     *                                   used
-     */
     @Override
     protected synchronized void stopInternal() throws LifecycleException {
-
         super.stopInternal();
-
         sso = null;
     }
 
@@ -1309,6 +1287,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
 
 
     protected enum AllowCorsPreflight {
-        NEVER, FILTER, ALWAYS
+        NEVER,
+        FILTER,
+        ALWAYS
     }
 }
