@@ -23,13 +23,12 @@ import java.util.Enumeration;
 import java.util.Iterator;
 import java.util.Locale;
 
-import javax.servlet.RequestDispatcher;
-import javax.servlet.http.Cookie;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpSession;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.http.Cookie;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpSession;
 
-import org.apache.catalina.Globals;
 import org.apache.catalina.Realm;
 import org.apache.catalina.Session;
 import org.apache.catalina.connector.Request;
@@ -81,7 +80,7 @@ public class FormAuthenticator extends AuthenticatorBase {
     // ------------------------------------------------------------- Properties
 
     /**
-     * Return the character encoding to use to read the username and password.
+     * Return the character encoding to use to read the user name and password.
      *
      * @return The name of the character encoding
      */
@@ -91,7 +90,7 @@ public class FormAuthenticator extends AuthenticatorBase {
 
 
     /**
-     * Set the character encoding to be used to read the username and password.
+     * Set the character encoding to be used to read the user name and password.
      *
      * @param encoding The name of the encoding to use
      */
@@ -136,7 +135,7 @@ public class FormAuthenticator extends AuthenticatorBase {
      * Configures the maximum session timeout to be used during authentication if the authentication process creates a
      * session.
      *
-     * @param authenticationSessionTimeout The maximum session timeout to use during authentication if the
+     * @param authenticationSessionTimeout The maximum session timeout to use duriing authentication if the
      *                                         authentication process creates a session
      */
     public void setAuthenticationSessionTimeout(int authenticationSessionTimeout) {
@@ -161,19 +160,19 @@ public class FormAuthenticator extends AuthenticatorBase {
 
         // References to objects we will need later
         Session session = null;
-        Principal principal;
+        Principal principal = null;
 
         // Have we authenticated this user before but have caching disabled?
         if (!cache) {
             session = request.getSessionInternal(true);
-            if (log.isTraceEnabled()) {
-                log.trace("Checking for reauthenticate in session " + session);
+            if (log.isDebugEnabled()) {
+                log.debug("Checking for reauthenticate in session " + session);
             }
             String username = (String) session.getNote(Constants.SESS_USERNAME_NOTE);
             String password = (String) session.getNote(Constants.SESS_PASSWORD_NOTE);
             if (username != null && password != null) {
-                if (log.isTraceEnabled()) {
-                    log.trace("Reauthenticating username '" + username + "'");
+                if (log.isDebugEnabled()) {
+                    log.debug("Reauthenticating username '" + username + "'");
                 }
                 principal = context.getRealm().authenticate(username, password);
                 if (principal != null) {
@@ -183,7 +182,7 @@ public class FormAuthenticator extends AuthenticatorBase {
                     }
                 }
                 if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("formAuthenticator.reauthFailed"));
+                    log.debug("Reauthentication failed, proceed normally");
                 }
             }
         }
@@ -192,17 +191,17 @@ public class FormAuthenticator extends AuthenticatorBase {
         // authentication? If so, forward the *original* request instead.
         if (matchRequest(request)) {
             session = request.getSessionInternal(true);
-            if (log.isTraceEnabled()) {
-                log.trace("Restore request from session '" + session.getIdInternal() + "'");
+            if (log.isDebugEnabled()) {
+                log.debug("Restore request from session '" + session.getIdInternal() + "'");
             }
             if (restoreRequest(request, session)) {
-                if (log.isTraceEnabled()) {
-                    log.trace("Proceed to restored request");
+                if (log.isDebugEnabled()) {
+                    log.debug("Proceed to restored request");
                 }
                 return true;
             } else {
                 if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("formAuthenticator.restoreFailed"));
+                    log.debug("Restore of original request failed");
                 }
                 response.sendError(HttpServletResponse.SC_BAD_REQUEST);
                 return false;
@@ -227,9 +226,9 @@ public class FormAuthenticator extends AuthenticatorBase {
         // No -- Save this request and redirect to the form login page
         if (!loginAction) {
             // If this request was to the root of the context without a trailing
-            // '/', need to redirect to add it else the submission of the login form
+            // '/', need to redirect to add it else the submit of the login form
             // may not go to the correct web application
-            if (request.getServletPath().isEmpty() && request.getPathInfo() == null) {
+            if (request.getServletPath().length() == 0 && request.getPathInfo() == null) {
                 StringBuilder location = new StringBuilder(requestURI);
                 location.append('/');
                 if (request.getQueryString() != null) {
@@ -241,13 +240,13 @@ public class FormAuthenticator extends AuthenticatorBase {
             }
 
             session = request.getSessionInternal(true);
-            if (log.isTraceEnabled()) {
-                log.trace("Save request in session '" + session.getIdInternal() + "'");
+            if (log.isDebugEnabled()) {
+                log.debug("Save request in session '" + session.getIdInternal() + "'");
             }
             try {
                 saveRequest(request, session);
             } catch (IOException ioe) {
-                log.debug(sm.getString("authenticator.requestBodyTooBig"));
+                log.debug("Request body too big to save during authentication");
                 response.sendError(HttpServletResponse.SC_FORBIDDEN, sm.getString("authenticator.requestBodyTooBig"));
                 return false;
             }
@@ -264,8 +263,8 @@ public class FormAuthenticator extends AuthenticatorBase {
         }
         String username = request.getParameter(Constants.FORM_USERNAME);
         String password = request.getParameter(Constants.FORM_PASSWORD);
-        if (log.isTraceEnabled()) {
-            log.trace("Authenticating username '" + username + "'");
+        if (log.isDebugEnabled()) {
+            log.debug("Authenticating username '" + username + "'");
         }
         principal = realm.authenticate(username, password);
         if (principal == null) {
@@ -273,8 +272,8 @@ public class FormAuthenticator extends AuthenticatorBase {
             return false;
         }
 
-        if (log.isTraceEnabled()) {
-            log.trace("Authentication of '" + username + "' was successful");
+        if (log.isDebugEnabled()) {
+            log.debug("Authentication of '" + username + "' was successful");
         }
 
         if (session == null) {
@@ -293,7 +292,7 @@ public class FormAuthenticator extends AuthenticatorBase {
         }
         if (session == null) {
             if (containerLog.isDebugEnabled()) {
-                containerLog.debug(sm.getString("formAuthenticator.sessionExpired"));
+                containerLog.debug("User took so long to log on the session expired");
             }
             if (landingPage == null) {
                 response.sendError(HttpServletResponse.SC_REQUEST_TIMEOUT,
@@ -317,8 +316,8 @@ public class FormAuthenticator extends AuthenticatorBase {
         // Redirect the user to the original request URI (which will cause
         // the original request to be restored)
         requestURI = savedRequestURL(session);
-        if (log.isTraceEnabled()) {
-            log.trace("Redirecting to original '" + requestURI + "'");
+        if (log.isDebugEnabled()) {
+            log.debug("Redirecting to original '" + requestURI + "'");
         }
         if (requestURI == null) {
             if (landingPage == null) {
@@ -369,7 +368,9 @@ public class FormAuthenticator extends AuthenticatorBase {
         Session session = request.getSessionInternal(false);
         if (session != null) {
             SavedRequest savedRequest = (SavedRequest) session.getNote(Constants.FORM_REQUEST_NOTE);
-            return savedRequest != null && decodedRequestURI.equals(savedRequest.getDecodedRequestURI());
+            if (savedRequest != null && decodedRequestURI.equals(savedRequest.getDecodedRequestURI())) {
+                return true;
+            }
         }
 
         return false;
@@ -427,7 +428,7 @@ public class FormAuthenticator extends AuthenticatorBase {
         }
 
         String loginPage = config.getLoginPage();
-        if (loginPage == null || loginPage.isEmpty()) {
+        if (loginPage == null || loginPage.length() == 0) {
             String msg = sm.getString("formAuthenticator.noLoginPage", context.getName());
             log.warn(msg);
             response.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR, msg);
@@ -483,7 +484,7 @@ public class FormAuthenticator extends AuthenticatorBase {
             throws IOException {
 
         String errorPage = config.getErrorPage();
-        if (errorPage == null || errorPage.isEmpty()) {
+        if (errorPage == null || errorPage.length() == 0) {
             String msg = sm.getString("formAuthenticator.noErrorPage", context.getName());
             log.warn(msg);
             response.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR, msg);
@@ -508,7 +509,7 @@ public class FormAuthenticator extends AuthenticatorBase {
 
     /**
      * Does this request match the saved one (so that it must be the redirect we signaled after successful
-     * authentication?)
+     * authentication?
      *
      * @param request The request to be verified
      *
@@ -625,7 +626,7 @@ public class FormAuthenticator extends AuthenticatorBase {
             // If no content type specified, use default for POST
             String savedContentType = saved.getContentType();
             if (savedContentType == null && "POST".equalsIgnoreCase(method)) {
-                savedContentType = Globals.CONTENT_TYPE_FORM_URL_ENCODING;
+                savedContentType = "application/x-www-form-urlencoded";
             }
 
             contentType.setString(savedContentType);
@@ -640,14 +641,14 @@ public class FormAuthenticator extends AuthenticatorBase {
         // HttpInputBuffer. Processing the saved request body will overwrite
         // these bytes. Configuring the HttpInputBuffer to retain these bytes as
         // it would in a normal request would require some invasive API changes.
-        // Therefore, force the conversion to String now so the correct values
+        // Therefore force the conversion to String now so the correct values
         // are presented if the application requests them.
-        request.getCoyoteRequest().requestURI().toStringType();
-        request.getCoyoteRequest().queryString().toStringType();
-        request.getCoyoteRequest().protocol().toStringType();
+        request.getRequestURI();
+        request.getQueryString();
+        request.getProtocol();
 
-        if (saved.getOriginalMaxInactiveIntervalOptional() != null) {
-            session.setMaxInactiveInterval(saved.getOriginalMaxInactiveIntervalOptional().intValue());
+        if (saved.getOriginalMaxInactiveInterval() > 0) {
+            session.setMaxInactiveInterval(saved.getOriginalMaxInactiveInterval());
         }
 
         return true;
@@ -666,7 +667,7 @@ public class FormAuthenticator extends AuthenticatorBase {
 
         // Create and populate a SavedRequest object for this request
         SavedRequest saved = new SavedRequest();
-        Cookie[] cookies = request.getCookies();
+        Cookie cookies[] = request.getCookies();
         if (cookies != null) {
             for (Cookie cookie : cookies) {
                 saved.addCookie(cookie);
@@ -719,19 +720,17 @@ public class FormAuthenticator extends AuthenticatorBase {
         if (session instanceof HttpSession) {
             if (((HttpSession) session).isNew()) {
                 int originalMaxInactiveInterval = session.getMaxInactiveInterval();
-                if (originalMaxInactiveInterval > getAuthenticationSessionTimeout() || originalMaxInactiveInterval <= 0) {
+                if (originalMaxInactiveInterval > getAuthenticationSessionTimeout()) {
                     saved.setOriginalMaxInactiveInterval(originalMaxInactiveInterval);
                     session.setMaxInactiveInterval(getAuthenticationSessionTimeout());
                 }
-            } else if (previousSavedRequest != null &&
-                    previousSavedRequest.getOriginalMaxInactiveIntervalOptional() != null) {
+            } else if (previousSavedRequest != null && previousSavedRequest.getOriginalMaxInactiveInterval() > 0) {
                 /*
                  * The user may have refreshed the browser page during authentication. Transfer the original max inactive
                  * interval from previous saved request to current one else, once authentication is completed, the session
-                 * will retain the shorter authentication session timeout
+                 * will retain the the shorter authentication session timeout
                  */
-                saved.setOriginalMaxInactiveInterval(
-                        previousSavedRequest.getOriginalMaxInactiveIntervalOptional().intValue());
+                saved.setOriginalMaxInactiveInterval(previousSavedRequest.getOriginalMaxInactiveInterval());
             }
         }
 
