@@ -290,7 +290,7 @@ public class Response implements HttpServletResponse {
     /**
      * @return the Request with which this Response is associated.
      */
-    public org.apache.catalina.connector.Request getRequest() {
+    public Request getRequest() {
         return this.request;
     }
 
@@ -299,7 +299,7 @@ public class Response implements HttpServletResponse {
      *
      * @param request The new associated request
      */
-    public void setRequest(org.apache.catalina.connector.Request request) {
+    public void setRequest(Request request) {
         this.request = request;
     }
 
@@ -377,7 +377,10 @@ public class Response implements HttpServletResponse {
      * Set the error flag.
      *
      * @return <code>false</code> if the error flag was already set
+     *
+     * @deprecated This method will be changed to return void in Tomcat 11 onwards
      */
+    @Deprecated
     public boolean setError() {
         return getCoyoteResponse().setError();
     }
@@ -1688,7 +1691,7 @@ public class Response implements HttpServletResponse {
      * @return the encoded URL
      */
     protected String toEncoded(String url, String sessionId) {
-        if ((url == null) || (sessionId == null)) {
+        if (url == null || sessionId == null) {
             return url;
         }
 
