@@ -173,29 +173,24 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public ServletOutputStream getOutputStream() throws IOException {
-        checkFacade();
-        ServletOutputStream sos = response.getOutputStream();
         if (isFinished()) {
             response.setSuspended(true);
         }
-        return sos;
+        return response.getOutputStream();
     }
 
 
     @Override
     public PrintWriter getWriter() throws IOException {
-        checkFacade();
-        PrintWriter writer = response.getWriter();
         if (isFinished()) {
             response.setSuspended(true);
         }
-        return writer;
+        return response.getWriter();
     }
 
 
     @Override
     public void setContentLength(int len) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -205,7 +200,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void setContentLengthLong(long length) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -215,7 +209,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void setContentType(String type) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -244,7 +237,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void flushBuffer() throws IOException {
-        checkFacade();
         if (isFinished()) {
             return;
         }
@@ -288,7 +280,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void setLocale(Locale loc) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -305,7 +296,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void addCookie(Cookie cookie) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -360,7 +350,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void setDateHeader(String name, long date) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -375,7 +364,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void addDateHeader(String name, long date) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -390,7 +378,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void setHeader(String name, String value) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -400,7 +387,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void addHeader(String name, String value) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -410,7 +396,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void setIntHeader(String name, int value) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -420,7 +405,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void addIntHeader(String name, int value) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -430,7 +414,6 @@ public class ResponseFacade implements HttpServletResponse {
 
     @Override
     public void setStatus(int sc) {
-        checkFacade();
         if (isCommitted()) {
             return;
         }
@@ -498,7 +481,6 @@ public class ResponseFacade implements HttpServletResponse {
 
 
     private void checkCommitted(String messageKey) {
-        checkFacade();
         if (isCommitted()) {
             throw new IllegalStateException(sm.getString(messageKey));
         }
