@@ -16,7 +16,6 @@
  */
 package org.apache.catalina.core;
 
-
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
@@ -25,6 +24,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Enumeration;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.NoSuchElementException;
@@ -54,7 +54,6 @@ import org.apache.tomcat.util.buf.MessageBytes;
 import org.apache.tomcat.util.http.Parameters;
 import org.apache.tomcat.util.res.StringManager;
 
-
 /**
  * Wrapper around a <code>jakarta.servlet.http.HttpServletRequest</code> that transforms an application request object
  * (which might be the original one passed to a servlet, or might be based on the 2.3
@@ -82,31 +81,19 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
                     RequestDispatcher.FORWARD_REQUEST_URI, RequestDispatcher.FORWARD_CONTEXT_PATH,
                     RequestDispatcher.FORWARD_SERVLET_PATH, RequestDispatcher.FORWARD_PATH_INFO,
                     RequestDispatcher.FORWARD_QUERY_STRING, RequestDispatcher.FORWARD_MAPPING };
-
-    private static final int SPECIALS_FIRST_FORWARD_INDEX = 6;
-
-
-    // ----------------------------------------------------------- Constructors
-
-
-    /**
-     * Construct a new wrapped request around the specified servlet request.
-     *
-     * @param request      The servlet request being wrapped
-     * @param context      The target context for the wrapped request
-     * @param crossContext {@code true} if the wrapped request will be a cross-context request, otherwise {@code false}
+    /*
+     * This duplicates specials to some extent but has been added to improve the performance of [get|set|is]Special().
+     * It may be possible to remove specials but that will require changes to AttributeNamesEnumerator.
      */
-    ApplicationHttpRequest(HttpServletRequest request, Context context, boolean crossContext) {
-
-        super(request);
-        this.context = context;
-        this.crossContext = crossContext;
-        setRequest(request);
-
+    private static final Map<String,Integer> specialsMap = new HashMap<>();
+    static {
+        for (int i = 0; i < specials.length; i++) {
+            specialsMap.put(specials[i], Integer.valueOf(i));
+        }
     }
 
 
-    // ----------------------------------------------------- Instance Variables
+    private static final int SPECIALS_FIRST_FORWARD_INDEX = 6;
 
 
     /**
@@ -199,6 +186,21 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
     protected final Object[] specialAttributes = new Object[specials.length];
 
 
+    /**
+     * Construct a new wrapped request around the specified servlet request.
+     *
+     * @param request      The servlet request being wrapped
+     * @param context      The target context for the wrapped request
+     * @param crossContext {@code true} if the wrapped request will be a cross-context request, otherwise {@code false}
+     */
+    ApplicationHttpRequest(HttpServletRequest request, Context context, boolean crossContext) {
+        super(request);
+        this.context = context;
+        this.crossContext = crossContext;
+        setRequest(request);
+    }
+
+
     // ------------------------------------------------- ServletRequest Methods
 
     @Override
@@ -242,7 +244,6 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
                 return specialAttributes[pos];
             }
         }
-
     }
 
 
@@ -262,11 +263,9 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      */
     @Override
     public void removeAttribute(String name) {
-
         if (!removeSpecial(name)) {
             getRequest().removeAttribute(name);
         }
-
     }
 
 
@@ -290,7 +289,6 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
         if (!setSpecial(name, value)) {
             getRequest().setAttribute(name, value);
         }
-
     }
 
 
@@ -355,7 +353,6 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
         }
 
         return context.getServletContext().getRequestDispatcher(relative);
-
     }
 
 
@@ -370,7 +367,6 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
 
     // --------------------------------------------- HttpServletRequest Methods
 
-
     /**
      * Override the <code>getContextPath()</code> method of the wrapped request.
      */
@@ -553,7 +549,6 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
         } else {
             return super.getSession(create);
         }
-
     }
 
 
@@ -635,9 +630,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @param contextPath The new context path
      */
     void setContextPath(String contextPath) {
-
         this.contextPath = contextPath;
-
     }
 
 
@@ -647,9 +640,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @param pathInfo The new path info
      */
     void setPathInfo(String pathInfo) {
-
         this.pathInfo = pathInfo;
-
     }
 
 
@@ -659,9 +650,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @param queryString The new query string
      */
     void setQueryString(String queryString) {
-
         this.queryString = queryString;
-
     }
 
 
@@ -694,9 +683,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @param requestURI The new request URI
      */
     void setRequestURI(String requestURI) {
-
         this.requestURI = requestURI;
-
     }
 
 
@@ -706,9 +693,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @param servletPath The new servlet path
      */
     void setServletPath(String servletPath) {
-
         this.servletPath = servletPath;
-
     }
 
 
@@ -753,14 +738,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @param name Attribute name to be tested
      */
     protected boolean isSpecial(String name) {
-
-        for (String special : specials) {
-            if (special.equals(name)) {
-                return true;
-            }
-        }
-        return false;
-
+        return specialsMap.containsKey(name);
     }
 
 
@@ -770,12 +748,11 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @return the special attribute pos, or -1 if it is not a special attribute
      */
     protected int getSpecial(String name) {
-        for (int i = 0; i < specials.length; i++) {
-            if (specials[i].equals(name)) {
-                return i;
-            }
+        Integer index = specialsMap.get(name);
+        if (index == null) {
+            return -1;
         }
-        return -1;
+        return index.intValue();
     }
 
 
@@ -785,13 +762,12 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @return true if the attribute was a special attribute, false otherwise
      */
     protected boolean setSpecial(String name, Object value) {
-        for (int i = 0; i < specials.length; i++) {
-            if (specials[i].equals(name)) {
-                specialAttributes[i] = value;
-                return true;
-            }
+        Integer index = specialsMap.get(name);
+        if (index == null) {
+            return false;
         }
-        return false;
+        specialAttributes[index.intValue()] = value;
+        return true;
     }
 
 
@@ -801,13 +777,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @return true if the attribute was a special attribute, false otherwise
      */
     protected boolean removeSpecial(String name) {
-        for (int i = 0; i < specials.length; i++) {
-            if (specials[i].equals(name)) {
-                specialAttributes[i] = null;
-                return true;
-            }
-        }
-        return false;
+        return setSpecial(name, null);
     }
 
 
@@ -839,7 +809,6 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
 
     // ------------------------------------------------------ Private Methods
 
-
     /**
      * Merge the parameters from the saved query parameter string (if any), and the parameters already present on this
      * request (if any), such that the parameter values from the query string show up first if there are duplicate
@@ -895,7 +864,6 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
 
     // ----------------------------------- AttributeNamesEnumerator Inner Class
 
-
     /**
      * Utility class used to expose the special attributes as being available as request attributes.
      */
@@ -952,8 +920,5 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
             }
             return result;
         }
-
     }
-
-
 }
