@@ -16,16 +16,17 @@
  */
 package org.apache.catalina.core;
 
-
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Set;
 
 import jakarta.servlet.RequestDispatcher;
 import jakarta.servlet.ServletRequest;
 import jakarta.servlet.ServletRequestWrapper;
 
-
 /**
  * Wrapper around a <code>jakarta.servlet.ServletRequest</code> that transforms an application request object (which
  * might be the original one passed to a servlet, or might be based on the 2.3
@@ -40,24 +41,29 @@ import jakarta.servlet.ServletRequestWrapper;
  */
 class ApplicationRequest extends ServletRequestWrapper {
 
-
-    // ------------------------------------------------------- Static Variables
+    /**
+     * The set of attribute names that are special for request dispatchers.
+     *
+     * @deprecated Will be removed without replacement in Tomcat 11 onwards.
+     */
+    @Deprecated
+    protected static final String specials[] =
+            { RequestDispatcher.INCLUDE_REQUEST_URI, RequestDispatcher.INCLUDE_CONTEXT_PATH,
+                    RequestDispatcher.INCLUDE_SERVLET_PATH, RequestDispatcher.INCLUDE_PATH_INFO,
+                    RequestDispatcher.INCLUDE_QUERY_STRING, RequestDispatcher.INCLUDE_MAPPING,
+                    RequestDispatcher.FORWARD_REQUEST_URI, RequestDispatcher.FORWARD_CONTEXT_PATH,
+                    RequestDispatcher.FORWARD_SERVLET_PATH, RequestDispatcher.FORWARD_PATH_INFO,
+                    RequestDispatcher.FORWARD_QUERY_STRING, RequestDispatcher.FORWARD_MAPPING };
+    /*
+     * This duplicates specials but has been added to improve the performance of isSpecial().
+     */
+    private static final Set<String> specialsSet = new HashSet<>(Arrays.asList(specials));
 
 
     /**
-     * The set of attribute names that are special for request dispatchers.
+     * The request attributes for this request. This is initialized from the wrapped request, but updates are allowed.
      */
-    protected static final String specials[] = { RequestDispatcher.INCLUDE_REQUEST_URI,
-            RequestDispatcher.INCLUDE_CONTEXT_PATH, RequestDispatcher.INCLUDE_SERVLET_PATH,
-            RequestDispatcher.INCLUDE_PATH_INFO, RequestDispatcher.INCLUDE_QUERY_STRING,
-            RequestDispatcher.INCLUDE_MAPPING, RequestDispatcher.FORWARD_REQUEST_URI,
-            RequestDispatcher.FORWARD_CONTEXT_PATH, RequestDispatcher.FORWARD_SERVLET_PATH,
-            RequestDispatcher.FORWARD_PATH_INFO, RequestDispatcher.FORWARD_QUERY_STRING,
-            RequestDispatcher.FORWARD_MAPPING };
-
-
-    // ----------------------------------------------------------- Constructors
-
+    protected final HashMap<String,Object> attributes = new HashMap<>();
 
     /**
      * Construct a new wrapped request around the specified servlet request.
@@ -65,25 +71,13 @@ class ApplicationRequest extends ServletRequestWrapper {
      * @param request The servlet request being wrapped
      */
     ApplicationRequest(ServletRequest request) {
-
         super(request);
         setRequest(request);
-
     }
 
 
-    // ----------------------------------------------------- Instance Variables
-
-
-    /**
-     * The request attributes for this request. This is initialized from the wrapped request, but updates are allowed.
-     */
-    protected final HashMap<String, Object> attributes = new HashMap<>();
-
-
     // ------------------------------------------------- ServletRequest Methods
 
-
     /**
      * Override the <code>getAttribute()</code> method of the wrapped request.
      *
@@ -91,11 +85,9 @@ class ApplicationRequest extends ServletRequestWrapper {
      */
     @Override
     public Object getAttribute(String name) {
-
         synchronized (attributes) {
             return attributes.get(name);
         }
-
     }
 
 
@@ -104,11 +96,9 @@ class ApplicationRequest extends ServletRequestWrapper {
      */
     @Override
     public Enumeration<String> getAttributeNames() {
-
         synchronized (attributes) {
             return Collections.enumeration(attributes.keySet());
         }
-
     }
 
 
@@ -119,14 +109,12 @@ class ApplicationRequest extends ServletRequestWrapper {
      */
     @Override
     public void removeAttribute(String name) {
-
         synchronized (attributes) {
             attributes.remove(name);
             if (!isSpecial(name)) {
                 getRequest().removeAttribute(name);
             }
         }
-
     }
 
 
@@ -138,20 +126,17 @@ class ApplicationRequest extends ServletRequestWrapper {
      */
     @Override
     public void setAttribute(String name, Object value) {
-
         synchronized (attributes) {
             attributes.put(name, value);
             if (!isSpecial(name)) {
                 getRequest().setAttribute(name, value);
             }
         }
-
     }
 
 
     // ------------------------------------------ ServletRequestWrapper Methods
 
-
     /**
      * Set the request that we are wrapping.
      *
@@ -159,7 +144,6 @@ class ApplicationRequest extends ServletRequestWrapper {
      */
     @Override
     public void setRequest(ServletRequest request) {
-
         super.setRequest(request);
 
         // Initialize the attributes for this request
@@ -172,28 +156,20 @@ class ApplicationRequest extends ServletRequestWrapper {
                 attributes.put(name, value);
             }
         }
-
     }
 
 
     // ------------------------------------------------------ Protected Methods
 
-
     /**
      * Is this attribute name one of the special ones that is added only for included servlets?
      *
      * @param name Attribute name to be tested
+     *
+     * @deprecated Will be removed without replacement in Tomcat 11 onwards.
      */
+    @Deprecated
     protected boolean isSpecial(String name) {
-
-        for (String special : specials) {
-            if (special.equals(name)) {
-                return true;
-            }
-        }
-        return false;
-
+        return specialsSet.contains(name);
     }
-
-
 }
