@@ -16,12 +16,17 @@
  */
 package org.apache.catalina.core;
 
-import javax.servlet.SessionCookieConfig;
-import javax.servlet.http.Cookie;
+import java.util.Collections;
+import java.util.Map;
+import java.util.TreeMap;
+
+import jakarta.servlet.SessionCookieConfig;
+import jakarta.servlet.http.Cookie;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.LifecycleState;
 import org.apache.catalina.util.SessionConfig;
+import org.apache.tomcat.util.descriptor.web.Constants;
 import org.apache.tomcat.util.res.StringManager;
 
 public class ApplicationSessionCookieConfig implements SessionCookieConfig {
@@ -31,13 +36,13 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
      */
     private static final StringManager sm = StringManager.getManager(ApplicationSessionCookieConfig.class);
 
-    private boolean httpOnly;
-    private boolean secure;
-    private int maxAge = -1;
-    private String comment;
-    private String domain;
+    private static final int DEFAULT_MAX_AGE = -1;
+    private static final boolean DEFAULT_HTTP_ONLY = false;
+    private static final boolean DEFAULT_SECURE = false;
+
+    private final Map<String,String> attributes = new TreeMap<>(String.CASE_INSENSITIVE_ORDER);
+
     private String name;
-    private String path;
     private StandardContext context;
 
     public ApplicationSessionCookieConfig(StandardContext context) {
@@ -46,17 +51,21 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
 
     @Override
     public String getComment() {
-        return comment;
+        return null;
     }
 
     @Override
     public String getDomain() {
-        return domain;
+        return getAttribute(Constants.COOKIE_DOMAIN_ATTR);
     }
 
     @Override
     public int getMaxAge() {
-        return maxAge;
+        String maxAge = getAttribute(Constants.COOKIE_MAX_AGE_ATTR);
+        if (maxAge == null) {
+            return DEFAULT_MAX_AGE;
+        }
+        return Integer.parseInt(maxAge);
     }
 
     @Override
@@ -66,17 +75,25 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
 
     @Override
     public String getPath() {
-        return path;
+        return getAttribute(Constants.COOKIE_PATH_ATTR);
     }
 
     @Override
     public boolean isHttpOnly() {
-        return httpOnly;
+        String httpOnly = getAttribute(Constants.COOKIE_HTTP_ONLY_ATTR);
+        if (httpOnly == null) {
+            return DEFAULT_HTTP_ONLY;
+        }
+        return Boolean.parseBoolean(httpOnly);
     }
 
     @Override
     public boolean isSecure() {
-        return secure;
+        String secure = getAttribute(Constants.COOKIE_SECURE_ATTR);
+        if (secure == null) {
+            return DEFAULT_SECURE;
+        }
+        return Boolean.parseBoolean(secure);
     }
 
     @Override
@@ -85,7 +102,6 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
             throw new IllegalStateException(
                     sm.getString("applicationSessionCookieConfig.ise", "comment", context.getPath()));
         }
-        this.comment = comment;
     }
 
     @Override
@@ -94,7 +110,7 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
             throw new IllegalStateException(
                     sm.getString("applicationSessionCookieConfig.ise", "domain name", context.getPath()));
         }
-        this.domain = domain;
+        setAttribute(Constants.COOKIE_DOMAIN_ATTR, domain);
     }
 
     @Override
@@ -103,7 +119,7 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
             throw new IllegalStateException(
                     sm.getString("applicationSessionCookieConfig.ise", "HttpOnly", context.getPath()));
         }
-        this.httpOnly = httpOnly;
+        setAttribute(Constants.COOKIE_HTTP_ONLY_ATTR, Boolean.toString(httpOnly));
     }
 
     @Override
@@ -112,7 +128,7 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
             throw new IllegalStateException(
                     sm.getString("applicationSessionCookieConfig.ise", "max age", context.getPath()));
         }
-        this.maxAge = maxAge;
+        setAttribute(Constants.COOKIE_MAX_AGE_ATTR, Integer.toString(maxAge));
     }
 
     @Override
@@ -130,7 +146,7 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
             throw new IllegalStateException(
                     sm.getString("applicationSessionCookieConfig.ise", "path", context.getPath()));
         }
-        this.path = path;
+        setAttribute(Constants.COOKIE_PATH_ATTR, path);
     }
 
     @Override
@@ -139,7 +155,28 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
             throw new IllegalStateException(
                     sm.getString("applicationSessionCookieConfig.ise", "secure", context.getPath()));
         }
-        this.secure = secure;
+        setAttribute(Constants.COOKIE_SECURE_ATTR, Boolean.toString(secure));
+    }
+
+
+    @Override
+    public void setAttribute(String name, String value) {
+        if (!context.getState().equals(LifecycleState.STARTING_PREP)) {
+            throw new IllegalStateException(
+                    sm.getString("applicationSessionCookieConfig.ise", name, context.getPath()));
+        }
+        attributes.put(name, value);
+    }
+
+    @Override
+    public String getAttribute(String name) {
+        return attributes.get(name);
+    }
+
+
+    @Override
+    public Map<String,String> getAttributes() {
+        return Collections.unmodifiableMap(attributes);
     }
 
     /**
@@ -164,7 +201,6 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
 
         // Just apply the defaults.
         cookie.setMaxAge(scc.getMaxAge());
-        cookie.setComment(scc.getComment());
 
         if (context.getSessionCookieDomain() == null) {
             // Avoid possible NPE
@@ -187,6 +223,23 @@ public class ApplicationSessionCookieConfig implements SessionCookieConfig {
 
         cookie.setPath(SessionConfig.getSessionCookiePath(context));
 
+        // Other attributes
+        for (Map.Entry<String,String> attribute : scc.getAttributes().entrySet()) {
+            switch (attribute.getKey()) {
+                case Constants.COOKIE_COMMENT_ATTR:
+                case Constants.COOKIE_DOMAIN_ATTR:
+                case Constants.COOKIE_MAX_AGE_ATTR:
+                case Constants.COOKIE_PATH_ATTR:
+                case Constants.COOKIE_SECURE_ATTR:
+                case Constants.COOKIE_HTTP_ONLY_ATTR:
+                    // Handled above so NO-OP
+                    break;
+                default: {
+                    cookie.setAttribute(attribute.getKey(), attribute.getValue());
+                }
+            }
+        }
+
         return cookie;
     }
 }
