@@ -16,6 +16,7 @@
  */
 package org.apache.catalina.core;
 
+import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.List;
@@ -33,15 +34,13 @@ import org.apache.tomcat.util.ExceptionUtils;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Implementation of <code>LifecycleListener</code> that will init and destroy APR.
+ * Implementation of <code>LifecycleListener</code> that will init and and destroy APR.
  * <p>
  * This listener must only be nested within {@link Server} elements.
  * <p>
- * Only one instance of the APR/Native library may be loaded per JVM. Loading multiple instances will trigger a JVM
- * crash - typically when the Connectors are destroyed. This listener utilises reference counting to ensure that only
- * one instance of the APR/Native library is loaded at any one time.
- * <p>
- * If multiple listener configurations are found, only the first one initialised will be used.
+ * <strong>Note</strong>: If you are running Tomcat in an embedded fashion and have more than one Server instance per
+ * JVM, this listener <em>must not</em> be added to the {@code Server} instances, but handled outside by the calling
+ * code which is bootstrapping the embedded Tomcat instances. Not doing so will lead to JVM crashes.
  *
  * @since 4.1
  */
@@ -65,10 +64,10 @@ public class AprLifecycleListener implements LifecycleListener {
 
     protected static final int TCN_REQUIRED_MAJOR = 1;
     protected static final int TCN_REQUIRED_MINOR = 2;
-    protected static final int TCN_REQUIRED_PATCH = 14;
-    protected static final int TCN_RECOMMENDED_MAJOR = 1;
-    protected static final int TCN_RECOMMENDED_MINOR = 3;
-    protected static final int TCN_RECOMMENDED_PV = 0;
+    protected static final int TCN_REQUIRED_PATCH = 34;
+    protected static final int TCN_RECOMMENDED_MAJOR = 2;
+    protected static final int TCN_RECOMMENDED_MINOR = 0;
+    protected static final int TCN_RECOMMENDED_PV = 5;
 
 
     // ---------------------------------------------- Properties
@@ -101,11 +100,6 @@ public class AprLifecycleListener implements LifecycleListener {
 
     protected static final Object lock = new Object();
 
-    // Guarded by lock
-    private static int referenceCount = 0;
-    private boolean instanceInitialized = false;
-
-
     public static boolean isAprAvailable() {
         // https://bz.apache.org/bugzilla/show_bug.cgi?id=48613
         if (AprStatus.isInstanceCreated()) {
@@ -132,14 +126,9 @@ public class AprLifecycleListener implements LifecycleListener {
 
         if (Lifecycle.BEFORE_INIT_EVENT.equals(event.getType())) {
             synchronized (lock) {
-                instanceInitialized = true;
                 if (!(event.getLifecycle() instanceof Server)) {
                     log.warn(sm.getString("listener.notServer", event.getLifecycle().getClass().getSimpleName()));
                 }
-                if (referenceCount++ != 0) {
-                    // Already loaded (note test is performed before reference count is incremented)
-                    return;
-                }
                 init();
                 for (String msg : initInfoLogMessages) {
                     log.info(msg);
@@ -149,55 +138,48 @@ public class AprLifecycleListener implements LifecycleListener {
                     try {
                         initializeSSL();
                     } catch (Throwable t) {
-                        Throwable throwable = ExceptionUtils.unwrapInvocationTargetException(t);
-                        ExceptionUtils.handleThrowable(throwable);
-                        log.error(sm.getString("aprListener.sslInit"), throwable);
+                        t = ExceptionUtils.unwrapInvocationTargetException(t);
+                        ExceptionUtils.handleThrowable(t);
+                        log.error(sm.getString("aprListener.sslInit"), t);
                     }
                 }
                 // Failure to initialize FIPS mode is fatal
                 if (!(null == FIPSMode || "off".equalsIgnoreCase(FIPSMode)) && !isFIPSModeActive()) {
-                    Error e = new Error(sm.getString("aprListener.initializeFIPSFailed"));
+                    String errorMessage = sm.getString("aprListener.initializeFIPSFailed");
+                    Error e = new Error(errorMessage);
                     // Log here, because thrown error might be not logged
-                    log.fatal(e.getMessage(), e);
+                    log.fatal(errorMessage, e);
                     throw e;
                 }
             }
         } else if (Lifecycle.AFTER_DESTROY_EVENT.equals(event.getType())) {
             synchronized (lock) {
-                // Instance may get destroyed without ever being initialized
-                if (instanceInitialized) {
-                    referenceCount--;
-                }
-                if (referenceCount != 0) {
-                    // Still being used
-                    return;
-                }
                 if (!AprStatus.isAprAvailable()) {
                     return;
                 }
                 try {
                     terminateAPR();
                 } catch (Throwable t) {
-                    Throwable throwable = ExceptionUtils.unwrapInvocationTargetException(t);
-                    ExceptionUtils.handleThrowable(throwable);
-                    log.warn(sm.getString("aprListener.aprDestroy"), throwable);
+                    t = ExceptionUtils.unwrapInvocationTargetException(t);
+                    ExceptionUtils.handleThrowable(t);
+                    log.info(sm.getString("aprListener.aprDestroy"));
                 }
             }
         }
 
     }
 
-    private static void terminateAPR() {
-        AprStatus.setAprInitialized(false);
+    private static void terminateAPR()
+            throws ClassNotFoundException, NoSuchMethodException, IllegalAccessException, InvocationTargetException {
+        String methodName = "terminate";
+        Method method = Class.forName("org.apache.tomcat.jni.Library").getMethod(methodName, (Class[]) null);
+        method.invoke(null, (Object[]) null);
         AprStatus.setAprAvailable(false);
-        fipsModeActive = false;
+        AprStatus.setAprInitialized(false);
         sslInitialized = false; // Well we cleaned the pool in terminate.
-        // There could be unreferenced SSL_CTX still waiting for GC
-        System.gc();
-        Library.threadSafeTerminate();
+        fipsModeActive = false;
     }
 
-    @SuppressWarnings("deprecation")
     private static void init() {
         int rqver = TCN_REQUIRED_MAJOR * 1000 + TCN_REQUIRED_MINOR * 100 + TCN_REQUIRED_PATCH;
         int rcver = TCN_RECOMMENDED_MAJOR * 1000 + TCN_RECOMMENDED_MINOR * 100 + TCN_RECOMMENDED_PV;
@@ -223,9 +205,9 @@ public class AprLifecycleListener implements LifecycleListener {
             return;
         } catch (Throwable t) {
             // Library present but failed to load
-            Throwable throwable = ExceptionUtils.unwrapInvocationTargetException(t);
-            ExceptionUtils.handleThrowable(throwable);
-            log.warn(sm.getString("aprListener.aprInitError", throwable.getMessage()), throwable);
+            t = ExceptionUtils.unwrapInvocationTargetException(t);
+            ExceptionUtils.handleThrowable(t);
+            log.warn(sm.getString("aprListener.aprInitError", t.getMessage()), t);
             return;
         }
         if (tcnMajor > 1 && "off".equalsIgnoreCase(SSLEngine)) {
@@ -234,8 +216,8 @@ public class AprLifecycleListener implements LifecycleListener {
                 // Tomcat Native 2.x onwards requires SSL
                 terminateAPR();
             } catch (Throwable t) {
-                Throwable throwable = ExceptionUtils.unwrapInvocationTargetException(t);
-                ExceptionUtils.handleThrowable(throwable);
+                t = ExceptionUtils.unwrapInvocationTargetException(t);
+                ExceptionUtils.handleThrowable(t);
             }
             return;
         }
@@ -247,8 +229,8 @@ public class AprLifecycleListener implements LifecycleListener {
                 // is below required.
                 terminateAPR();
             } catch (Throwable t) {
-                Throwable throwable = ExceptionUtils.unwrapInvocationTargetException(t);
-                ExceptionUtils.handleThrowable(throwable);
+                t = ExceptionUtils.unwrapInvocationTargetException(t);
+                ExceptionUtils.handleThrowable(t);
             }
             return;
         }
@@ -260,14 +242,6 @@ public class AprLifecycleListener implements LifecycleListener {
         initInfoLogMessages
                 .add(sm.getString("aprListener.tcnValid", Library.versionString(), Library.aprVersionString()));
 
-        // Log APR flags
-        initInfoLogMessages.add(sm.getString("aprListener.flags", Boolean.valueOf(Library.APR_HAVE_IPV6),
-                Boolean.valueOf(Library.APR_HAS_SENDFILE), Boolean.valueOf(Library.APR_HAS_SO_ACCEPTFILTER),
-                Boolean.valueOf(Library.APR_HAS_RANDOM), Boolean.valueOf(Library.APR_HAVE_UNIX)));
-
-        initInfoLogMessages.add(sm.getString("aprListener.config", Boolean.valueOf(AprStatus.getUseAprConnector()),
-                Boolean.valueOf(AprStatus.getUseOpenSSL())));
-
         AprStatus.setAprAvailable(true);
     }
 
@@ -284,9 +258,9 @@ public class AprLifecycleListener implements LifecycleListener {
         sslInitialized = true;
 
         String methodName = "randSet";
-        Class<?>[] paramTypes = new Class[1];
+        Class<?> paramTypes[] = new Class[1];
         paramTypes[0] = String.class;
-        Object[] paramValues = new Object[1];
+        Object paramValues[] = new Object[1];
         paramValues[0] = SSLRandomSeed;
         Class<?> clazz = Class.forName("org.apache.tomcat.jni.SSL");
         Method method = clazz.getMethod(methodName, paramTypes);
@@ -298,7 +272,6 @@ public class AprLifecycleListener implements LifecycleListener {
         method = clazz.getMethod(methodName, paramTypes);
         method.invoke(null, paramValues);
 
-        AprStatus.setOpenSSLVersion(SSL.version());
         // OpenSSL 3 onwards uses providers
         boolean usingProviders = tcnMajor > 1 || (tcnVersion > 1233 && (SSL.version() & 0xF0000000L) > 0x20000000);
 
@@ -437,16 +410,6 @@ public class AprLifecycleListener implements LifecycleListener {
         return fipsModeActive;
     }
 
-    public void setUseAprConnector(boolean useAprConnector) {
-        if (useAprConnector != AprStatus.getUseAprConnector()) {
-            AprStatus.setUseAprConnector(useAprConnector);
-        }
-    }
-
-    public static boolean getUseAprConnector() {
-        return AprStatus.getUseAprConnector();
-    }
-
     public void setUseOpenSSL(boolean useOpenSSL) {
         if (useOpenSSL != AprStatus.getUseOpenSSL()) {
             AprStatus.setUseOpenSSL(useOpenSSL);
