@@ -151,7 +151,7 @@ public abstract class ContainerBase extends LifecycleMBeanBase implements Contai
     /**
      * The child Containers belonging to this Container, keyed by name.
      */
-    protected final HashMap<String, Container> children = new HashMap<>();
+    protected final HashMap<String,Container> children = new HashMap<>();
 
 
     /**
@@ -1095,7 +1095,7 @@ public abstract class ContainerBase extends LifecycleMBeanBase implements Contai
             }
             current = current.getNext();
         }
-        fireLifecycleEvent(Lifecycle.PERIODIC_EVENT, null);
+        fireLifecycleEvent(PERIODIC_EVENT, null);
     }
 
 
@@ -1196,11 +1196,15 @@ public abstract class ContainerBase extends LifecycleMBeanBase implements Contai
         return keyProperties.toString();
     }
 
+
     public ObjectName[] getChildren() {
-        List<ObjectName> names = new ArrayList<>(children.size());
-        for (Container next : children.values()) {
-            if (next instanceof ContainerBase) {
-                names.add(next.getObjectName());
+        List<ObjectName> names;
+        synchronized (children) {
+            names = new ArrayList<>(children.size());
+            for (Container next : children.values()) {
+                if (next instanceof ContainerBase) {
+                    names.add(next.getObjectName());
+                }
             }
         }
         return names.toArray(new ObjectName[0]);
