@@ -136,7 +136,7 @@ public class NamingContextListener implements LifecycleListener, PropertyChangeL
     /**
      * Objectnames Map.
      */
-    protected HashMap<String, ObjectName> objectNames = new HashMap<>();
+    protected HashMap<String,ObjectName> objectNames = new HashMap<>();
 
 
     /**
@@ -222,7 +222,7 @@ public class NamingContextListener implements LifecycleListener, PropertyChangeL
             }
 
             try {
-                Hashtable<String, Object> contextEnv = new Hashtable<>();
+                Hashtable<String,Object> contextEnv = new Hashtable<>();
                 namingContext = new NamingContext(contextEnv, getName());
                 ContextAccessController.setSecurityToken(getName(), token);
                 ContextAccessController.setSecurityToken(container, token);
@@ -258,7 +258,7 @@ public class NamingContextListener implements LifecycleListener, PropertyChangeL
                 }
 
                 if (container instanceof Server) {
-                    org.apache.naming.factory.ResourceLinkFactory.setGlobalContext(namingContext);
+                    ResourceLinkFactory.setGlobalContext(namingContext);
                     try {
                         ContextBindings.bindClassLoader(container, token, this.getClass().getClassLoader());
                     } catch (NamingException e) {
@@ -848,8 +848,8 @@ public class NamingContextListener implements LifecycleListener, PropertyChangeL
                 }
                 if (jaxrpcURL == null) {
                     try {
-                        jaxrpcURL = ((Context) container).getServletContext()
-                                .getResource(service.getJaxrpcmappingfile());
+                        jaxrpcURL =
+                                ((Context) container).getServletContext().getResource(service.getJaxrpcmappingfile());
                     } catch (MalformedURLException e) {
                         // Ignore and carry on
                     }
@@ -1021,8 +1021,8 @@ public class NamingContextListener implements LifecycleListener, PropertyChangeL
     public void addResourceLink(ContextResourceLink resourceLink) {
 
         // Create a reference to the resource.
-        Reference ref = new ResourceLinkRef(resourceLink.getType(), resourceLink.getGlobal(), resourceLink.getFactory(),
-                null);
+        Reference ref =
+                new ResourceLinkRef(resourceLink.getType(), resourceLink.getGlobal(), resourceLink.getFactory(), null);
         Iterator<String> i = resourceLink.listProperties();
         while (i.hasNext()) {
             String key = i.next();
