@@ -35,7 +35,6 @@ import org.apache.catalina.Engine;
 import org.apache.catalina.Globals;
 import org.apache.catalina.Host;
 import org.apache.catalina.JmxEnabled;
-import org.apache.catalina.Lifecycle;
 import org.apache.catalina.LifecycleEvent;
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.LifecycleListener;
@@ -171,7 +170,7 @@ public class StandardHost extends ContainerBase implements Host {
     /**
      * Track the class loaders for the child web applications so memory leaks can be detected.
      */
-    private final Map<ClassLoader, String> childClassLoaders = new WeakHashMap<>();
+    private final Map<ClassLoader,String> childClassLoaders = new WeakHashMap<>();
 
 
     /**
@@ -722,7 +721,7 @@ public class StandardHost extends ContainerBase implements Host {
     private class MemoryLeakTrackingListener implements LifecycleListener {
         @Override
         public void lifecycleEvent(LifecycleEvent event) {
-            if (event.getType().equals(Lifecycle.AFTER_START_EVENT)) {
+            if (event.getType().equals(AFTER_START_EVENT)) {
                 if (event.getSource() instanceof Context) {
                     Context context = ((Context) event.getSource());
                     childClassLoaders.put(context.getLoader().getClassLoader(),
@@ -746,7 +745,7 @@ public class StandardHost extends ContainerBase implements Host {
 
         List<String> result = new ArrayList<>();
 
-        for (Map.Entry<ClassLoader, String> entry : childClassLoaders.entrySet()) {
+        for (Map.Entry<ClassLoader,String> entry : childClassLoaders.entrySet()) {
             ClassLoader cl = entry.getKey();
             if (cl instanceof WebappClassLoaderBase) {
                 if (!((WebappClassLoaderBase) cl).getState().isAvailable()) {
@@ -834,8 +833,8 @@ public class StandardHost extends ContainerBase implements Host {
                     }
                 }
                 if (!found) {
-                    Valve valve = ErrorReportValve.class.getName().equals(errorValve) ? new ErrorReportValve()
-                            : (Valve) Class.forName(errorValve).getConstructor().newInstance();
+                    Valve valve = ErrorReportValve.class.getName().equals(errorValve) ? new ErrorReportValve() :
+                            (Valve) Class.forName(errorValve).getConstructor().newInstance();
                     getPipeline().addValve(valve);
                 }
             } catch (Throwable t) {
