@@ -19,11 +19,11 @@ package org.apache.catalina.core;
 import java.io.IOException;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import javax.servlet.DispatcherType;
-import javax.servlet.RequestDispatcher;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.DispatcherType;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.Globals;
@@ -57,21 +57,6 @@ final class StandardHostValve extends ValveBase {
     // minor one) in a profiler.
     private static final ClassLoader MY_CLASSLOADER = StandardHostValve.class.getClassLoader();
 
-    static final boolean STRICT_SERVLET_COMPLIANCE;
-
-    static final boolean ACCESS_SESSION;
-
-    static {
-        STRICT_SERVLET_COMPLIANCE = Globals.STRICT_SERVLET_COMPLIANCE;
-
-        String accessSession = System.getProperty("org.apache.catalina.core.StandardHostValve.ACCESS_SESSION");
-        if (accessSession == null) {
-            ACCESS_SESSION = STRICT_SERVLET_COMPLIANCE;
-        } else {
-            ACCESS_SESSION = Boolean.parseBoolean(accessSession);
-        }
-    }
-
     // ------------------------------------------------------ Constructor
 
     StandardHostValve() {
@@ -131,7 +116,7 @@ final class StandardHostValve extends ValveBase {
                 }
             } catch (Throwable t) {
                 ExceptionUtils.handleThrowable(t);
-                container.getLogger().error(sm.getString("standardHostValve.exception", request.getRequestURI()), t);
+                container.getLogger().error("Exception Processing " + request.getRequestURI(), t);
                 // If a new error occurred while trying to report a previous
                 // error allow the original error to be reported.
                 if (!response.isErrorReportRequired()) {
@@ -174,7 +159,7 @@ final class StandardHostValve extends ValveBase {
         } finally {
             // Access a session (if present) to update last accessed time, based
             // on a strict interpretation of the specification
-            if (ACCESS_SESSION) {
+            if (context.getAlwaysAccessSession()) {
                 request.getSession(false);
             }
 
@@ -218,8 +203,22 @@ final class StandardHostValve extends ValveBase {
         }
         if (errorPage != null && response.isErrorReportRequired()) {
             response.setAppCommitted(false);
-            setRequestErrorAttributes(request, statusCode, null, response.getMessage(), null, errorPage.getLocation());
+            request.setAttribute(RequestDispatcher.ERROR_STATUS_CODE, Integer.valueOf(statusCode));
 
+            String message = response.getMessage();
+            if (message == null) {
+                message = "";
+            }
+            request.setAttribute(RequestDispatcher.ERROR_MESSAGE, message);
+            request.setAttribute(Globals.DISPATCHER_REQUEST_PATH_ATTR, errorPage.getLocation());
+            request.setAttribute(Globals.DISPATCHER_TYPE_ATTR, DispatcherType.ERROR);
+
+
+            Wrapper wrapper = request.getWrapper();
+            if (wrapper != null) {
+                request.setAttribute(RequestDispatcher.ERROR_SERVLET_NAME, wrapper.getName());
+            }
+            request.setAttribute(RequestDispatcher.ERROR_REQUEST_URI, request.getRequestURI());
             if (custom(request, response, errorPage)) {
                 response.setErrorReported();
                 try {
@@ -227,7 +226,7 @@ final class StandardHostValve extends ValveBase {
                 } catch (ClientAbortException e) {
                     // Ignore
                 } catch (IOException e) {
-                    container.getLogger().warn(sm.getString("standardHostValve.exception", errorPage), e);
+                    container.getLogger().warn("Exception Processing " + errorPage, e);
                 }
             }
         }
@@ -274,22 +273,31 @@ final class StandardHostValve extends ValveBase {
         if (errorPage != null) {
             if (response.setErrorReported()) {
                 response.setAppCommitted(false);
-                setRequestErrorAttributes(request, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, realError.getClass(),
-                        throwable.getMessage(), realError, errorPage.getLocation());
-
+                request.setAttribute(Globals.DISPATCHER_REQUEST_PATH_ATTR, errorPage.getLocation());
+                request.setAttribute(Globals.DISPATCHER_TYPE_ATTR, DispatcherType.ERROR);
+                request.setAttribute(RequestDispatcher.ERROR_STATUS_CODE,
+                        Integer.valueOf(HttpServletResponse.SC_INTERNAL_SERVER_ERROR));
+                request.setAttribute(RequestDispatcher.ERROR_MESSAGE, throwable.getMessage());
+                request.setAttribute(RequestDispatcher.ERROR_EXCEPTION, realError);
+                Wrapper wrapper = request.getWrapper();
+                if (wrapper != null) {
+                    request.setAttribute(RequestDispatcher.ERROR_SERVLET_NAME, wrapper.getName());
+                }
+                request.setAttribute(RequestDispatcher.ERROR_REQUEST_URI, request.getRequestURI());
+                request.setAttribute(RequestDispatcher.ERROR_EXCEPTION_TYPE, realError.getClass());
                 if (custom(request, response, errorPage)) {
                     try {
                         response.finishResponse();
                     } catch (IOException e) {
-                        container.getLogger().warn(sm.getString("standardHostValve.exception", errorPage), e);
+                        container.getLogger().warn("Exception Processing " + errorPage, e);
                     }
                 }
             }
         } else {
             /*
-             * A custom error-page has not been defined for the exception that was thrown during request processing. Set
-             * the status to 500 if an error status has not already been set and check for custom error-page for the
-             * status.
+             *  A custom error-page has not been defined for the exception that was thrown during request processing.
+             *  Set the status to 500 if an error status has not already been set and check for custom error-page for
+             *  the status.
              */
             if (response.getStatus() < HttpServletResponse.SC_BAD_REQUEST) {
                 response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
@@ -302,47 +310,6 @@ final class StandardHostValve extends ValveBase {
     }
 
 
-    private void setRequestErrorAttributes(Request request, int statusCode, Class<?> exceptionType, String message,
-            Throwable exception, String location) {
-        /*
-         * Generally, don't set attributes to null as that will trigger an unnecessary (in this case) call to
-         * removeAttribute().
-         */
-
-        request.setAttribute(RequestDispatcher.ERROR_STATUS_CODE, Integer.valueOf(statusCode));
-
-        if (exceptionType != null) {
-            request.setAttribute(RequestDispatcher.ERROR_EXCEPTION_TYPE, exceptionType);
-        }
-
-        /*
-         * https://bz.apache.org/bugzilla/show_bug.cgi?id=69444
-         *
-         * Need to ensure message attribute is set even if there is no message (e.g. if error was triggered by an
-         * exception with a null message).
-         */
-        if (message == null) {
-            request.setAttribute(RequestDispatcher.ERROR_MESSAGE, "");
-        } else {
-            request.setAttribute(RequestDispatcher.ERROR_MESSAGE, message);
-        }
-
-        if (exception != null) {
-            request.setAttribute(RequestDispatcher.ERROR_EXCEPTION, exception);
-        }
-
-        request.setAttribute(RequestDispatcher.ERROR_REQUEST_URI, request.getRequestURI());
-
-        Wrapper wrapper = request.getWrapper();
-        if (wrapper != null) {
-            request.setAttribute(RequestDispatcher.ERROR_SERVLET_NAME, wrapper.getName());
-        }
-
-        request.setAttribute(Globals.DISPATCHER_REQUEST_PATH_ATTR, location);
-        request.setAttribute(Globals.DISPATCHER_TYPE_ATTR, DispatcherType.ERROR);
-    }
-
-
     /**
      * Handle an HTTP status code or Java exception by forwarding control to the location included in the specified
      * errorPage object. It is assumed that the caller has already recorded any request attributes that are to be
@@ -355,8 +322,8 @@ final class StandardHostValve extends ValveBase {
      */
     private boolean custom(Request request, Response response, ErrorPage errorPage) {
 
-        if (container.getLogger().isTraceEnabled()) {
-            container.getLogger().trace("Processing " + errorPage);
+        if (container.getLogger().isDebugEnabled()) {
+            container.getLogger().debug("Processing " + errorPage);
         }
 
         try {
@@ -366,7 +333,7 @@ final class StandardHostValve extends ValveBase {
 
             if (rd == null) {
                 container.getLogger()
-                        .error(sm.getString("standardHostValve.customStatusFailed", errorPage.getLocation()));
+                        .error(sm.getString("standardHostValue.customStatusFailed", errorPage.getLocation()));
                 return false;
             }
 
@@ -404,7 +371,7 @@ final class StandardHostValve extends ValveBase {
         } catch (Throwable t) {
             ExceptionUtils.handleThrowable(t);
             // Report our failure to process this custom page
-            container.getLogger().error(sm.getString("standardHostValve.exception", errorPage), t);
+            container.getLogger().error("Exception Processing " + errorPage, t);
             return false;
         }
     }
