@@ -60,8 +60,9 @@ import org.apache.tomcat.util.res.StringManager;
 
 
 /**
- * Holds and manages the naming resources defined in the J2EE Enterprise Naming Context and their associated JNDI
- * context.
+ * Holds and manages the naming resources defined in the Jakarta EE Naming Context and their associated JNDI context.
+ *
+ * @author Remy Maucherat
  */
 public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializable, NamingResources {
 
@@ -162,6 +163,9 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
     // ------------------------------------------------------------- Properties
 
 
+    /**
+     * @return the container with which the naming resources are associated.
+     */
     @Override
     public Object getContainer() {
         return container;
@@ -207,7 +211,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
         String ejbLink = ejb.getLink();
         String lookupName = ejb.getLookupName();
 
-        if (ejbLink != null && !ejbLink.isEmpty() && lookupName != null && !lookupName.isEmpty()) {
+        if (ejbLink != null && ejbLink.length() > 0 && lookupName != null && lookupName.length() > 0) {
             throw new IllegalArgumentException(sm.getString("namingResources.ejbLookupLink", ejb.getName()));
         }
 
@@ -226,6 +230,11 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
     }
 
 
+    /**
+     * Add an environment entry for this web application.
+     *
+     * @param environment New environment entry
+     */
     @Override
     public void addEnvironment(ContextEnvironment environment) {
 
@@ -259,12 +268,12 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
         String lookupName = environment.getLookupName();
 
         // Entries with injection targets but no value are effectively ignored
-        if (injectionTargets != null && !injectionTargets.isEmpty() && (value == null || value.isEmpty())) {
+        if (injectionTargets != null && injectionTargets.size() > 0 && (value == null || value.length() == 0)) {
             return;
         }
 
         // Entries with lookup-name and value are an error (EE.5.4.1.3)
-        if (value != null && !value.isEmpty() && lookupName != null && !lookupName.isEmpty()) {
+        if (value != null && value.length() > 0 && lookupName != null && lookupName.length() > 0) {
             throw new IllegalArgumentException(
                     sm.getString("namingResources.envEntryLookupValue", environment.getName()));
         }
@@ -366,6 +375,11 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
     }
 
 
+    /**
+     * Add a resource reference for this web application.
+     *
+     * @param resource New resource reference
+     */
     @Override
     public void addResource(ContextResource resource) {
 
@@ -422,6 +436,11 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
     }
 
 
+    /**
+     * Add a resource link for this web application.
+     *
+     * @param resourceLink New resource link
+     */
     @Override
     public void addResourceLink(ContextResourceLink resourceLink) {
 
@@ -512,8 +531,8 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
 
 
     /**
-     * @return the array of defined environment entries for this web application. If none have been defined, a
-     *             zero-length array is returned.
+     * @return the set of defined environment entries for this web application. If none have been defined, a zero-length
+     *             array is returned.
      */
     public ContextEnvironment[] findEnvironments() {
 
@@ -648,8 +667,8 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
 
 
     /**
-     * @return the array of resource environment reference names for this web application. If none have been specified,
-     *             a zero-length array is returned.
+     * @return the set of resource environment reference names for this web application. If none have been specified, a
+     *             zero-length array is returned.
      */
     public ContextResourceEnvRef[] findResourceEnvRefs() {
 
@@ -696,7 +715,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
 
         entries.remove(name);
 
-        ContextEjb ejb;
+        ContextEjb ejb = null;
         synchronized (ejbs) {
             ejb = ejbs.remove(name);
         }
@@ -708,12 +727,17 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
     }
 
 
+    /**
+     * Remove any environment entry with the specified name.
+     *
+     * @param name Name of the environment entry to remove
+     */
     @Override
     public void removeEnvironment(String name) {
 
         entries.remove(name);
 
-        ContextEnvironment environment;
+        ContextEnvironment environment = null;
         synchronized (envs) {
             environment = envs.remove(name);
         }
@@ -741,7 +765,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
 
         entries.remove(name);
 
-        ContextLocalEjb localEjb;
+        ContextLocalEjb localEjb = null;
         synchronized (localEjbs) {
             localEjb = localEjbs.remove(name);
         }
@@ -762,7 +786,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
 
         entries.remove(name);
 
-        MessageDestinationRef mdr;
+        MessageDestinationRef mdr = null;
         synchronized (mdrs) {
             mdr = mdrs.remove(name);
         }
@@ -786,12 +810,17 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
     }
 
 
+    /**
+     * Remove any resource reference with the specified name.
+     *
+     * @param name Name of the resource reference to remove
+     */
     @Override
     public void removeResource(String name) {
 
         entries.remove(name);
 
-        ContextResource resource;
+        ContextResource resource = null;
         synchronized (resources) {
             resource = resources.remove(name);
         }
@@ -819,7 +848,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
 
         entries.remove(name);
 
-        ContextResourceEnvRef resourceEnvRef;
+        ContextResourceEnvRef resourceEnvRef = null;
         synchronized (resourceEnvRefs) {
             resourceEnvRef = resourceEnvRefs.remove(name);
         }
@@ -831,12 +860,17 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
     }
 
 
+    /**
+     * Remove any resource link with the specified name.
+     *
+     * @param name Name of the resource link to remove
+     */
     @Override
     public void removeResourceLink(String name) {
 
         entries.remove(name);
 
-        ContextResourceLink resourceLink;
+        ContextResourceLink resourceLink = null;
         synchronized (resourceLinks) {
             resourceLink = resourceLinks.remove(name);
         }
@@ -864,7 +898,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
 
         entries.remove(name);
 
-        ContextService service;
+        ContextService service = null;
         synchronized (services) {
             service = services.remove(name);
         }
@@ -930,7 +964,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
      * Close those resources that an explicit close may help clean-up faster.
      */
     private void cleanUp() {
-        if (resources.isEmpty()) {
+        if (resources.size() == 0) {
             return;
         }
         javax.naming.Context ctxt;
@@ -948,7 +982,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
         for (ContextResource cr : resources.values()) {
             if (cr.getSingleton()) {
                 String closeMethod = cr.getCloseMethod();
-                if (closeMethod != null && !closeMethod.isEmpty()) {
+                if (closeMethod != null && closeMethod.length() > 0) {
                     String name = cr.getName();
                     Object resource;
                     try {
@@ -972,14 +1006,14 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
      */
     private void cleanUp(Object resource, String name, String closeMethod) {
         // Look for a zero-arg close() method
-        Method m;
+        Method m = null;
         try {
             m = resource.getClass().getMethod(closeMethod, (Class<?>[]) null);
         } catch (SecurityException e) {
-            log.debug(sm.getString("namingResources.cleanupCloseSecurity", closeMethod, name, container), e);
+            log.debug(sm.getString("namingResources.cleanupCloseSecurity", closeMethod, name, container));
             return;
         } catch (NoSuchMethodException e) {
-            log.debug(sm.getString("namingResources.cleanupNoClose", name, container, closeMethod), e);
+            log.debug(sm.getString("namingResources.cleanupNoClose", name, container, closeMethod));
             return;
         }
         try {
@@ -1068,7 +1102,7 @@ public class NamingResourcesImpl extends LifecycleMBeanBase implements Serializa
             return true;
         }
 
-        if (resource.getInjectionTargets() == null || resource.getInjectionTargets().isEmpty()) {
+        if (resource.getInjectionTargets() == null || resource.getInjectionTargets().size() == 0) {
             // No injection targets so use the defined type for the resource
             return true;
         }
