@@ -27,25 +27,23 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Set;
 
-import javax.servlet.FilterChain;
-import javax.servlet.GenericFilter;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.GenericFilter;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
-import org.apache.catalina.Globals;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.http.RequestUtil;
 import org.apache.tomcat.util.http.ResponseUtil;
-import org.apache.tomcat.util.http.parser.MediaType;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
  * <p>
- * A {@link javax.servlet.Filter} that enable client-side cross-origin requests by implementing W3C's CORS
+ * A {@link jakarta.servlet.Filter} that enable client-side cross-origin requests by implementing W3C's CORS
  * (<b>C</b>ross-<b>O</b>rigin <b>R</b>esource <b>S</b>haring) specification for resources. Each
  * {@link HttpServletRequest} request is inspected as per specification, and appropriate response headers are added to
  * {@link HttpServletResponse}.
@@ -352,7 +350,16 @@ public class CorsFilter extends GenericFilter {
         response.resetBuffer();
 
         if (log.isDebugEnabled()) {
-            log.debug(sm.getString("corsFilter.invalidRequest", origin, method, accessControlRequestHeaders));
+            // Debug so no need for i18n
+            StringBuilder message = new StringBuilder("Invalid CORS request; Origin=");
+            message.append(origin);
+            message.append(";Method=");
+            message.append(method);
+            if (accessControlRequestHeaders != null) {
+                message.append(";Access-Control-Request-Headers=");
+                message.append(accessControlRequestHeaders);
+            }
+            log.debug(message.toString());
         }
     }
 
@@ -402,14 +409,14 @@ public class CorsFilter extends GenericFilter {
         // Local copy to avoid concurrency issues if getExposedHeaders()
         // is overridden.
         Collection<String> exposedHeaders = getExposedHeaders();
-        if (exposedHeaders != null && !exposedHeaders.isEmpty()) {
+        if (exposedHeaders != null && exposedHeaders.size() > 0) {
             String exposedHeadersString = join(exposedHeaders, ",");
             response.addHeader(RESPONSE_HEADER_ACCESS_CONTROL_EXPOSE_HEADERS, exposedHeadersString);
         }
 
         if ("OPTIONS".equals(method)) {
             // For an OPTIONS request, the response will vary based on the
-            // value or absence of the following headers. Hence, they need to be
+            // value or absence of the following headers. Hence they need be be
             // included in the Vary header.
             ResponseUtil.addVaryFieldName(response, REQUEST_HEADER_ACCESS_CONTROL_REQUEST_METHOD);
             ResponseUtil.addVaryFieldName(response, REQUEST_HEADER_ACCESS_CONTROL_REQUEST_HEADERS);
@@ -538,44 +545,71 @@ public class CorsFilter extends GenericFilter {
      * @return the CORS type
      */
     protected CORSRequestType checkRequestType(final HttpServletRequest request) {
+        CORSRequestType requestType = CORSRequestType.INVALID_CORS;
         if (request == null) {
             throw new IllegalArgumentException(sm.getString("corsFilter.nullRequest"));
         }
         String originHeader = request.getHeader(REQUEST_HEADER_ORIGIN);
-        if (originHeader == null) {
-            return CORSRequestType.NOT_CORS;
-        }
-        if (originHeader.isEmpty() || !RequestUtil.isValidOrigin(originHeader)) {
-            return CORSRequestType.INVALID_CORS;
-        }
-        if(RequestUtil.isSameOrigin(request, originHeader)) {
-            return CORSRequestType.NOT_CORS;
-        }
-        String method = request.getMethod();
-        if (method == null) {
-            return CORSRequestType.INVALID_CORS;
-        }
-        switch (method) {
-            case "OPTIONS":
-                String accessControlRequestMethodHeader = request.getHeader(REQUEST_HEADER_ACCESS_CONTROL_REQUEST_METHOD);
-                if (accessControlRequestMethodHeader != null) {
-                    if (accessControlRequestMethodHeader.isEmpty()) {
-                        return CORSRequestType.INVALID_CORS;
+        // Section 6.1.1 and Section 6.2.1
+        if (originHeader != null) {
+            if (originHeader.isEmpty()) {
+                requestType = CORSRequestType.INVALID_CORS;
+            } else if (!RequestUtil.isValidOrigin(originHeader)) {
+                requestType = CORSRequestType.INVALID_CORS;
+            } else if (RequestUtil.isSameOrigin(request, originHeader)) {
+                return CORSRequestType.NOT_CORS;
+            } else {
+                String method = request.getMethod();
+                if (method != null) {
+                    if ("OPTIONS".equals(method)) {
+                        String accessControlRequestMethodHeader =
+                                request.getHeader(REQUEST_HEADER_ACCESS_CONTROL_REQUEST_METHOD);
+                        if (accessControlRequestMethodHeader != null && !accessControlRequestMethodHeader.isEmpty()) {
+                            requestType = CORSRequestType.PRE_FLIGHT;
+                        } else if (accessControlRequestMethodHeader != null &&
+                                accessControlRequestMethodHeader.isEmpty()) {
+                            requestType = CORSRequestType.INVALID_CORS;
+                        } else {
+                            requestType = CORSRequestType.ACTUAL;
+                        }
+                    } else if ("GET".equals(method) || "HEAD".equals(method)) {
+                        requestType = CORSRequestType.SIMPLE;
+                    } else if ("POST".equals(method)) {
+                        String mediaType = getMediaType(request.getContentType());
+                        if (mediaType != null) {
+                            if (SIMPLE_HTTP_REQUEST_CONTENT_TYPE_VALUES.contains(mediaType)) {
+                                requestType = CORSRequestType.SIMPLE;
+                            } else {
+                                requestType = CORSRequestType.ACTUAL;
+                            }
+                        }
+                    } else {
+                        requestType = CORSRequestType.ACTUAL;
                     }
-                    return CORSRequestType.PRE_FLIGHT;
                 }
-                return CORSRequestType.ACTUAL;
-            case "GET":
-            case "HEAD":
-                return CORSRequestType.SIMPLE;
-            case "POST":
-                String mediaType = MediaType.parseMediaTypeOnly(request.getContentType());
-                if (mediaType == null || SIMPLE_HTTP_REQUEST_CONTENT_TYPE_VALUES.contains(mediaType)) {
-                    return CORSRequestType.SIMPLE;
-                }
-                break;
+            }
+        } else {
+            requestType = CORSRequestType.NOT_CORS;
         }
-        return CORSRequestType.ACTUAL;
+
+        return requestType;
+    }
+
+
+    /**
+     * Return the lower case, trimmed value of the media type from the content type.
+     */
+    private String getMediaType(String contentType) {
+        if (contentType == null) {
+            return null;
+        }
+        String result = contentType.toLowerCase(Locale.ENGLISH);
+        int firstSemiColonIndex = result.indexOf(';');
+        if (firstSemiColonIndex > -1) {
+            result = result.substring(0, firstSemiColonIndex);
+        }
+        result = result.trim();
+        return result;
     }
 
     /**
@@ -670,43 +704,23 @@ public class CorsFilter extends GenericFilter {
     private Set<String> parseStringToSet(final String data) {
         String[] splits;
 
-        if (data != null && !data.isEmpty()) {
+        if (data != null && data.length() > 0) {
             splits = data.split(",");
         } else {
             splits = new String[] {};
         }
 
         Set<String> set = new HashSet<>();
-        for (String split : splits) {
-            set.add(split.trim());
+        if (splits.length > 0) {
+            for (String split : splits) {
+                set.add(split.trim());
+            }
         }
 
         return set;
     }
 
 
-    /**
-     * Checks if a given origin is valid or not. Criteria:
-     * <ul>
-     * <li>If an encoded character is present in origin, it's not valid.</li>
-     * <li>If origin is "null", it's valid.</li>
-     * <li>Origin should be a valid URI</li>
-     * </ul>
-     *
-     * @param origin The origin URI
-     *
-     * @return <code>true</code> if the origin was valid
-     *
-     * @see <a href="http://tools.ietf.org/html/rfc952">RFC952</a>
-     *
-     * @deprecated This will be removed in Tomcat 10 Use {@link RequestUtil#isValidOrigin(String)}
-     */
-    @Deprecated
-    protected static boolean isValidOrigin(String origin) {
-        return RequestUtil.isValidOrigin(origin);
-    }
-
-
     /**
      * Determines if any origin is allowed to make CORS request.
      *
@@ -838,14 +852,6 @@ public class CorsFilter extends GenericFilter {
 
     // -------------------------------------------------- CORS Request Headers
 
-    /**
-     * The Vary header indicates allows disabling proxy caching by indicating the the response depends on the origin.
-     *
-     * @deprecated Unused. Will be removed in Tomcat 10
-     */
-    @Deprecated
-    public static final String REQUEST_HEADER_VARY = "Vary";
-
     /**
      * The Origin header indicates where the cross-origin request or preflight request originates from.
      */
@@ -924,7 +930,7 @@ public class CorsFilter extends GenericFilter {
      * @see <a href="http://www.w3.org/TR/cors/#terminology" >http://www.w3.org/TR/cors/#terminology</a>
      */
     public static final Collection<String> SIMPLE_HTTP_REQUEST_CONTENT_TYPE_VALUES = Collections.unmodifiableSet(
-            new HashSet<>(Arrays.asList(Globals.CONTENT_TYPE_FORM_URL_ENCODING, "multipart/form-data", "text/plain")));
+            new HashSet<>(Arrays.asList("application/x-www-form-urlencoded", "multipart/form-data", "text/plain")));
 
     // ------------------------------------------------ Configuration Defaults
     /**
@@ -966,32 +972,32 @@ public class CorsFilter extends GenericFilter {
 
     // ----------------------------------------Filter Config Init param-name(s)
     /**
-     * Key to retrieve allowed origins from {@link javax.servlet.FilterConfig}.
+     * Key to retrieve allowed origins from {@link jakarta.servlet.FilterConfig}.
      */
     public static final String PARAM_CORS_ALLOWED_ORIGINS = "cors.allowed.origins";
 
     /**
-     * Key to retrieve support credentials from {@link javax.servlet.FilterConfig}.
+     * Key to retrieve support credentials from {@link jakarta.servlet.FilterConfig}.
      */
     public static final String PARAM_CORS_SUPPORT_CREDENTIALS = "cors.support.credentials";
 
     /**
-     * Key to retrieve exposed headers from {@link javax.servlet.FilterConfig}.
+     * Key to retrieve exposed headers from {@link jakarta.servlet.FilterConfig}.
      */
     public static final String PARAM_CORS_EXPOSED_HEADERS = "cors.exposed.headers";
 
     /**
-     * Key to retrieve allowed headers from {@link javax.servlet.FilterConfig}.
+     * Key to retrieve allowed headers from {@link jakarta.servlet.FilterConfig}.
      */
     public static final String PARAM_CORS_ALLOWED_HEADERS = "cors.allowed.headers";
 
     /**
-     * Key to retrieve allowed methods from {@link javax.servlet.FilterConfig}.
+     * Key to retrieve allowed methods from {@link jakarta.servlet.FilterConfig}.
      */
     public static final String PARAM_CORS_ALLOWED_METHODS = "cors.allowed.methods";
 
     /**
-     * Key to retrieve preflight max age from {@link javax.servlet.FilterConfig}.
+     * Key to retrieve preflight max age from {@link jakarta.servlet.FilterConfig}.
      */
     public static final String PARAM_CORS_PREFLIGHT_MAXAGE = "cors.preflight.maxage";
 
