@@ -462,7 +462,7 @@ public class RemoteIpFilter extends GenericFilter {
 
     public static class XForwardedRequest extends HttpServletRequestWrapper {
 
-        protected final Map<String, List<String>> headers;
+        protected final Map<String,List<String>> headers;
 
         protected String localName;
 
@@ -513,15 +513,15 @@ public class RemoteIpFilter extends GenericFilter {
 
         @Override
         public String getHeader(String name) {
-            Map.Entry<String, List<String>> header = getHeaderEntry(name);
+            Map.Entry<String,List<String>> header = getHeaderEntry(name);
             if (header == null || header.getValue() == null || header.getValue().isEmpty()) {
                 return null;
             }
             return header.getValue().get(0);
         }
 
-        protected Map.Entry<String, List<String>> getHeaderEntry(String name) {
-            for (Map.Entry<String, List<String>> entry : headers.entrySet()) {
+        protected Map.Entry<String,List<String>> getHeaderEntry(String name) {
+            for (Map.Entry<String,List<String>> entry : headers.entrySet()) {
                 if (entry.getKey().equalsIgnoreCase(name)) {
                     return entry;
                 }
@@ -536,7 +536,7 @@ public class RemoteIpFilter extends GenericFilter {
 
         @Override
         public Enumeration<String> getHeaders(String name) {
-            Map.Entry<String, List<String>> header = getHeaderEntry(name);
+            Map.Entry<String,List<String>> header = getHeaderEntry(name);
             if (header == null || header.getValue() == null) {
                 return Collections.enumeration(Collections.<String>emptyList());
             }
@@ -588,7 +588,7 @@ public class RemoteIpFilter extends GenericFilter {
         }
 
         public void removeHeader(String name) {
-            Map.Entry<String, List<String>> header = getHeaderEntry(name);
+            Map.Entry<String,List<String>> header = getHeaderEntry(name);
             if (header != null) {
                 headers.remove(header.getKey());
             }
@@ -596,7 +596,7 @@ public class RemoteIpFilter extends GenericFilter {
 
         public void setHeader(String name, String value) {
             List<String> values = Collections.singletonList(value);
-            Map.Entry<String, List<String>> header = getHeaderEntry(name);
+            Map.Entry<String,List<String>> header = getHeaderEntry(name);
             if (header == null) {
                 headers.put(name, values);
             } else {
@@ -701,8 +701,8 @@ public class RemoteIpFilter extends GenericFilter {
      * @return array of patterns (non <code>null</code>)
      */
     protected static String[] commaDelimitedListToStringArray(String commaDelimitedStrings) {
-        return (commaDelimitedStrings == null || commaDelimitedStrings.length() == 0) ? new String[0]
-                : commaSeparatedValuesPattern.split(commaDelimitedStrings);
+        return (commaDelimitedStrings == null || commaDelimitedStrings.length() == 0) ? new String[0] :
+                commaSeparatedValuesPattern.split(commaDelimitedStrings);
     }
 
     /**
@@ -745,8 +745,8 @@ public class RemoteIpFilter extends GenericFilter {
     /**
      * @see #setInternalProxies(String)
      */
-    private Pattern internalProxies = Pattern
-            .compile("10\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}|" + "192\\.168\\.\\d{1,3}\\.\\d{1,3}|" +
+    private Pattern internalProxies =
+            Pattern.compile("10\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}|" + "192\\.168\\.\\d{1,3}\\.\\d{1,3}|" +
                     "169\\.254\\.\\d{1,3}\\.\\d{1,3}|" + "127\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}|" +
                     "100\\.6[4-9]{1}\\.\\d{1,3}\\.\\d{1,3}|" + "100\\.[7-9]{1}\\d{1}\\.\\d{1,3}\\.\\d{1,3}|" +
                     "100\\.1[0-1]{1}\\d{1}\\.\\d{1,3}\\.\\d{1,3}|" + "100\\.12[0-7]{1}\\.\\d{1,3}\\.\\d{1,3}|" +
