@@ -18,13 +18,13 @@ package org.apache.catalina.filters;
 
 import java.io.IOException;
 
-import javax.servlet.FilterChain;
-import javax.servlet.GenericFilter;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.GenericFilter;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.tomcat.util.res.StringManager;
 
@@ -51,11 +51,7 @@ import org.apache.tomcat.util.res.StringManager;
  * <li>Only connects to port 80</li>
  * <li>Unknown issue means it doesn't work</li>
  * </ul>
- *
- * @deprecated This will be removed in Tomcat 11 onwards. This filter is no longer required. The WebDAV client in
- *             Windows 10 / Windows Server 2012 onwards works correctly without this filter.
  */
-@Deprecated
 public class WebdavFixFilter extends GenericFilter {
 
     private static final long serialVersionUID = 1L;
