@@ -20,8 +20,8 @@ import org.apache.catalina.ha.ClusterMessageBase;
 import org.apache.catalina.tribes.Member;
 
 /**
- * Contains the data for a file being transferred over TCP, this is
- * essentially a fragment of a file, read and written by the FileMessageFactory.
+ * Contains the data for a file being transferred over TCP, this is essentially a fragment of a file, read and written
+ * by the FileMessageFactory.
  */
 
 public class FileMessage extends ClusterMessageBase {
@@ -35,33 +35,37 @@ public class FileMessage extends ClusterMessageBase {
     private final String fileName;
     private final String contextName;
 
-    public FileMessage(Member source,
-                       String fileName,
-                       String contextName) {
-        this.address=source;
-        this.fileName=fileName;
-        this.contextName=contextName;
+    public FileMessage(Member source, String fileName, String contextName) {
+        this.address = source;
+        this.fileName = fileName;
+        this.contextName = contextName;
     }
 
     public int getMessageNumber() {
         return messageNumber;
     }
+
     public void setMessageNumber(int messageNumber) {
         this.messageNumber = messageNumber;
     }
+
     public long getTotalNrOfMsgs() {
         return totalNrOfMsgs;
     }
+
     public void setTotalNrOfMsgs(long totalNrOfMsgs) {
         this.totalNrOfMsgs = totalNrOfMsgs;
     }
+
     public byte[] getData() {
         return data;
     }
+
     public void setData(byte[] data, int length) {
         this.data = data;
         this.dataLength = length;
     }
+
     public int getDataLength() {
         return dataLength;
     }
@@ -80,6 +84,7 @@ public class FileMessage extends ClusterMessageBase {
     public String getFileName() {
         return fileName;
     }
+
     public String getContextName() {
         return contextName;
     }
