@@ -31,13 +31,10 @@ import org.apache.tomcat.util.buf.HexUtils;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * This factory is used to read files and write files by splitting them up into
- * smaller messages. So that entire files don't have to be read into memory.
- * <BR>
- * The factory can be used as a reader or writer but not both at the same time.
- * When done reading or writing the factory will close the input or output
- * streams and mark the factory as closed. It is not possible to use it after
- * that. <BR>
+ * This factory is used to read files and write files by splitting them up into smaller messages. So that entire files
+ * don't have to be read into memory. <BR>
+ * The factory can be used as a reader or writer but not both at the same time. When done reading or writing the factory
+ * will close the input or output streams and mark the factory as closed. It is not possible to use it after that. <BR>
  * To force a cleanup, call cleanup() from the calling object. <BR>
  * This class is not thread safe.
  */
@@ -49,7 +46,7 @@ public class FileMessageFactory {
     /**
      * The number of bytes that we read from file
      */
-    public static final int READ_SIZE = 1024 * 10; //10kb
+    public static final int READ_SIZE = 1024 * 10; // 10 KiB
 
     /**
      * The file that we are reading/writing
@@ -57,8 +54,7 @@ public class FileMessageFactory {
     protected final File file;
 
     /**
-     * True means that we are writing with this factory. False means that we are
-     * reading with this factory
+     * True means that we are writing with this factory. False means that we are reading with this factory
      */
     protected final boolean openForWrite;
 
@@ -98,11 +94,10 @@ public class FileMessageFactory {
     protected AtomicLong lastMessageProcessed = new AtomicLong(0);
 
     /**
-     * Messages received out of order are held in the buffer until required. If
-     * everything is worked as expected, messages will spend very little time in
-     * the buffer.
+     * Messages received out of order are held in the buffer until required. If everything is worked as expected,
+     * messages will spend very little time in the buffer.
      */
-    protected final Map<Long, FileMessage> msgBuffer = new ConcurrentHashMap<>();
+    protected final Map<Long,FileMessage> msgBuffer = new ConcurrentHashMap<>();
 
     /**
      * The bytes that we hold the data in, not thread safe.
@@ -110,41 +105,42 @@ public class FileMessageFactory {
     protected byte[] data = new byte[READ_SIZE];
 
     /**
-     * Flag that indicates if a thread is writing messages to disk. Access to
-     * this flag must be synchronised.
+     * Flag that indicates if a thread is writing messages to disk. Access to this flag must be synchronised.
      */
     protected boolean isWriting = false;
 
     /**
      * The time this instance was created. (in milliseconds)
+     *
+     * @deprecated Unused. This will be removed in Tomcat 11.
      */
+    @Deprecated
     protected long creationTime = 0;
 
+
     /**
-     * The maximum valid time(in seconds) from creationTime.
+     * The time this instance was last modified.
+     */
+    protected long lastModified = 0;
+
+    /**
+     * The maximum time (in seconds) this instance will be allowed to exist from lastModifiedTime.
      */
     protected int maxValidTime = -1;
 
     /**
      * Private constructor, either instantiates a factory to read or write. <BR>
-     * When openForWrite==true, then a the file, f, will be created and an
-     * output stream is opened to write to it. <BR>
-     * When openForWrite==false, an input stream is opened, the file has to
-     * exist.
+     * When openForWrite==true, then a the file, f, will be created and an output stream is opened to write to it. <BR>
+     * When openForWrite==false, an input stream is opened, the file has to exist.
      *
-     * @param f
-     *            File - the file to be read/written
-     * @param openForWrite
-     *            boolean - true means we are writing to the file, false means
-     *            we are reading from the file
-     * @throws FileNotFoundException -
-     *             if the file to be read doesn't exist
-     * @throws IOException -
-     *             if the system fails to open input/output streams to the file
-     *             or if it fails to create the file to be written to.
+     * @param f            File - the file to be read/written
+     * @param openForWrite boolean - true means we are writing to the file, false means we are reading from the file
+     *
+     * @throws FileNotFoundException - if the file to be read doesn't exist
+     * @throws IOException           - if the system fails to open input/output streams to the file or if it fails to
+     *                                   create the file to be written to.
      */
-    private FileMessageFactory(File f, boolean openForWrite)
-            throws FileNotFoundException, IOException {
+    private FileMessageFactory(File f, boolean openForWrite) throws FileNotFoundException, IOException {
         this.file = f;
         this.openForWrite = openForWrite;
         if (log.isDebugEnabled()) {
@@ -161,24 +157,21 @@ public class FileMessageFactory {
             size = file.length();
             totalNrOfMessages = (size / READ_SIZE) + 1;
             in = new FileInputStream(f);
-        }//end if
+        } // end if
         creationTime = System.currentTimeMillis();
+        lastModified = System.currentTimeMillis();
     }
 
     /**
-     * Creates a factory to read or write from a file. When opening for read,
-     * the readMessage can be invoked, and when opening for write the
-     * writeMessage can be invoked.
+     * Creates a factory to read or write from a file. When opening for read, the readMessage can be invoked, and when
+     * opening for write the writeMessage can be invoked.
+     *
+     * @param f            File - the file to be read or written
+     * @param openForWrite boolean - true, means we are writing to the file, false means we are reading from it
+     *
+     * @throws FileNotFoundException - if the file to be read doesn't exist
+     * @throws IOException           - if it fails to create the file that is to be written
      *
-     * @param f
-     *            File - the file to be read or written
-     * @param openForWrite
-     *            boolean - true, means we are writing to the file, false means
-     *            we are reading from it
-     * @throws FileNotFoundException -
-     *             if the file to be read doesn't exist
-     * @throws IOException -
-     *             if it fails to create the file that is to be written
      * @return FileMessageFactory
      */
     public static FileMessageFactory getInstance(File f, boolean openForWrite)
@@ -187,25 +180,19 @@ public class FileMessageFactory {
     }
 
     /**
-     * Reads file data into the file message and sets the size, totalLength,
-     * totalNrOfMsgs and the message number <BR>
-     * If EOF is reached, the factory returns null, and closes itself, otherwise
-     * the same message is returned as was passed in. This makes sure that not
-     * more memory is ever used. To remember, neither the file message or the
-     * factory are thread safe. Don't hand off the message to one thread and
-     * read the same with another.
+     * Reads file data into the file message and sets the size, totalLength, totalNrOfMsgs and the message number <BR>
+     * If EOF is reached, the factory returns null, and closes itself, otherwise the same message is returned as was
+     * passed in. This makes sure that not more memory is ever used. To remember, neither the file message or the
+     * factory are thread safe. Don't hand off the message to one thread and read the same with another.
      *
-     * @param f
-     *            FileMessage - the message to be populated with file data
-     * @throws IllegalArgumentException -
-     *             if the factory is for writing or is closed
-     * @throws IOException -
-     *             if a file read exception occurs
-     * @return FileMessage - returns the same message passed in as a parameter,
-     *         or null if EOF
+     * @param f FileMessage - the message to be populated with file data
+     *
+     * @throws IllegalArgumentException - if the factory is for writing or is closed
+     * @throws IOException              - if a file read exception occurs
+     *
+     * @return FileMessage - returns the same message passed in as a parameter, or null if EOF
      */
-    public FileMessage readMessage(FileMessage f)
-            throws IllegalArgumentException, IOException {
+    public FileMessage readMessage(FileMessage f) throws IllegalArgumentException, IOException {
         checkState(false);
         int length = in.read(data);
         if (length == -1) {
@@ -216,30 +203,27 @@ public class FileMessageFactory {
             f.setTotalNrOfMsgs(totalNrOfMessages);
             f.setMessageNumber(++nrOfMessagesProcessed);
             return f;
-        }//end if
+        } // end if
     }
 
     /**
-     * Writes a message to file. If (msg.getMessageNumber() ==
-     * msg.getTotalNrOfMsgs()) the output stream will be closed after writing.
+     * Writes a message to file. If (msg.getMessageNumber() == msg.getTotalNrOfMsgs()) the output stream will be closed
+     * after writing.
      *
-     * @param msg
-     *            FileMessage - message containing data to be written
-     * @throws IllegalArgumentException -
-     *             if the factory is opened for read or closed
-     * @throws IOException -
-     *             if a file write error occurs
-     * @return returns true if the file is complete and outputstream is closed,
-     *         false otherwise.
+     * @param msg FileMessage - message containing data to be written
+     *
+     * @throws IllegalArgumentException - if the factory is opened for read or closed
+     * @throws IOException              - if a file write error occurs
+     *
+     * @return returns true if the file is complete and outputstream is closed, false otherwise.
      */
-    public boolean writeMessage(FileMessage msg)
-            throws IllegalArgumentException, IOException {
+    public boolean writeMessage(FileMessage msg) throws IllegalArgumentException, IOException {
         if (!openForWrite) {
             throw new IllegalArgumentException(sm.getString("fileMessageFactory.cannotWrite"));
         }
         if (log.isDebugEnabled()) {
-            log.debug("Message " + msg + " data " + HexUtils.toHexString(msg.getData())
-                    + " data length " + msg.getDataLength() + " out " + out);
+            log.debug("Message " + msg + " data " + HexUtils.toHexString(msg.getData()) + " data length " +
+                    msg.getDataLength() + " out " + out);
         }
 
         if (msg.getMessageNumber() <= lastMessageProcessed.get()) {
@@ -249,8 +233,7 @@ public class FileMessageFactory {
             return false;
         }
 
-        FileMessage previous =
-            msgBuffer.put(Long.valueOf(msg.getMessageNumber()), msg);
+        FileMessage previous = msgBuffer.put(Long.valueOf(msg.getMessageNumber()), msg);
         if (previous != null) {
             // Duplicate of message not yet processed
             log.warn(sm.getString("fileMessageFactory.duplicateMessage", msg.getContextName(), msg.getFileName(),
@@ -258,6 +241,9 @@ public class FileMessageFactory {
             return false;
         }
 
+        // Have received a new message. Update the last modified time (even if the message is being buffered for now).
+        lastModified = System.currentTimeMillis();
+
         FileMessage next = null;
         synchronized (this) {
             if (!isWriting) {
@@ -281,9 +267,8 @@ public class FileMessageFactory {
                 cleanup();
                 return true;
             }
-            synchronized(this) {
-                next =
-                    msgBuffer.get(Long.valueOf(lastMessageProcessed.get() + 1));
+            synchronized (this) {
+                next = msgBuffer.get(Long.valueOf(lastMessageProcessed.get() + 1));
                 if (next == null) {
                     isWriting = false;
                 }
@@ -291,7 +276,7 @@ public class FileMessageFactory {
         }
 
         return false;
-    }//writeMessage
+    }// writeMessage
 
     /**
      * Closes the factory, its streams and sets all its references to null
@@ -321,15 +306,14 @@ public class FileMessageFactory {
     }
 
     /**
-     * Check to make sure the factory is able to perform the function it is
-     * asked to do. Invoked by readMessage/writeMessage before those methods
-     * proceed.
+     * Check to make sure the factory is able to perform the function it is asked to do. Invoked by
+     * readMessage/writeMessage before those methods proceed.
      *
      * @param openForWrite The value to check
+     *
      * @throws IllegalArgumentException if the state is not the expected one
      */
-    protected void checkState(boolean openForWrite)
-            throws IllegalArgumentException {
+    protected void checkState(boolean openForWrite) throws IllegalArgumentException {
         if (this.openForWrite != openForWrite) {
             cleanup();
             if (openForWrite) {
@@ -351,11 +335,15 @@ public class FileMessageFactory {
     public boolean isValid() {
         if (maxValidTime > 0) {
             long timeNow = System.currentTimeMillis();
-            int timeIdle = (int) ((timeNow - creationTime) / 1000L);
+            long timeIdle = (timeNow - lastModified) / 1000L;
             if (timeIdle > maxValidTime) {
                 cleanup();
-                if (file.exists() && !file.delete()) {
-                    log.warn(sm.getString("fileMessageFactory.deleteFail", file));
+                if (file.exists()) {
+                    if (file.delete()) {
+                        log.warn(sm.getString("fileMessageFactory.delete", file, Long.toString(maxValidTime)));
+                    } else {
+                        log.warn(sm.getString("fileMessageFactory.deleteFail", file));
+                    }
                 }
                 return false;
             }
