@@ -132,7 +132,7 @@ public class BackupManager extends ClusterManagerBase implements MapOwner, Distr
      *                                   used
      */
     @Override
-    protected void startInternal() throws LifecycleException {
+    protected synchronized void startInternal() throws LifecycleException {
 
         super.startInternal();
 
@@ -154,8 +154,8 @@ public class BackupManager extends ClusterManagerBase implements MapOwner, Distr
 
     public String getMapName() {
         String name = cluster.getManagerName(getName(), this) + "-" + "map";
-        if (log.isTraceEnabled()) {
-            log.trace("Backup manager, Setting map name to:" + name);
+        if (log.isDebugEnabled()) {
+            log.debug("Backup manager, Setting map name to:" + name);
         }
         return name;
     }
@@ -170,10 +170,10 @@ public class BackupManager extends ClusterManagerBase implements MapOwner, Distr
      *                                   used
      */
     @Override
-    protected void stopInternal() throws LifecycleException {
+    protected synchronized void stopInternal() throws LifecycleException {
 
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("backupManager.stopped", getName()));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("backupManager.stopped", getName()));
         }
 
         setState(LifecycleState.STOPPING);
