@@ -51,7 +51,7 @@ public abstract class ClusterManagerBase extends ManagerBase implements ClusterM
     /**
      * cached replication valve cluster container!
      */
-    private volatile ReplicationValve replicationValve = null ;
+    private volatile ReplicationValve replicationValve = null;
 
     /**
      * send all actions of session attributes.
@@ -106,9 +106,9 @@ public abstract class ClusterManagerBase extends ManagerBase implements ClusterM
             classLoader = tccl;
         }
         if (classLoader == tccl) {
-            return new ClassLoader[] {classLoader};
+            return new ClassLoader[] { classLoader };
         } else {
-            return new ClassLoader[] {classLoader, tccl};
+            return new ClassLoader[] { classLoader, tccl };
         }
     }
 
@@ -119,7 +119,7 @@ public abstract class ClusterManagerBase extends ManagerBase implements ClusterM
 
     @Override
     public ReplicationStream getReplicationStream(byte[] data) throws IOException {
-        return getReplicationStream(data,0,data.length);
+        return getReplicationStream(data, 0, data.length);
     }
 
     @Override
@@ -129,11 +129,11 @@ public abstract class ClusterManagerBase extends ManagerBase implements ClusterM
     }
 
 
-    //  ---------------------------------------------------- persistence handler
+    // ---------------------------------------------------- persistence handler
 
     /**
-     * {@link org.apache.catalina.Manager} implementations that also implement
-     * {@link ClusterManager} do not support local session persistence.
+     * {@link org.apache.catalina.Manager} implementations that also implement {@link ClusterManager} do not support
+     * local session persistence.
      */
     @Override
     public void load() {
@@ -141,8 +141,8 @@ public abstract class ClusterManagerBase extends ManagerBase implements ClusterM
     }
 
     /**
-     * {@link org.apache.catalina.Manager} implementations that also implement
-     * {@link ClusterManager} do not support local session persistence.
+     * {@link org.apache.catalina.Manager} implementations that also implement {@link ClusterManager} do not support
+     * local session persistence.
      */
     @Override
     public void unload() {
@@ -175,26 +175,28 @@ public abstract class ClusterManagerBase extends ManagerBase implements ClusterM
 
     /**
      * Register cross context session at replication valve thread local
+     *
      * @param session cross context session
      */
     protected void registerSessionAtReplicationValve(DeltaSession session) {
-        if(replicationValve == null) {
-            CatalinaCluster cluster = getCluster() ;
-            if(cluster != null) {
+        if (replicationValve == null) {
+            CatalinaCluster cluster = getCluster();
+            if (cluster != null) {
                 Valve[] valves = cluster.getValves();
-                if(valves != null && valves.length > 0) {
-                    for(int i=0; replicationValve == null && i < valves.length ; i++ ){
-                        if(valves[i] instanceof ReplicationValve) replicationValve =
-                                (ReplicationValve)valves[i] ;
-                    }//for
+                if (valves != null && valves.length > 0) {
+                    for (int i = 0; replicationValve == null && i < valves.length; i++) {
+                        if (valves[i] instanceof ReplicationValve) {
+                            replicationValve = (ReplicationValve) valves[i];
+                        }
+                    } // for
 
-                    if(replicationValve == null && log.isDebugEnabled()) {
+                    if (replicationValve == null && log.isDebugEnabled()) {
                         log.debug("no ReplicationValve found for CrossContext Support");
-                    }//endif
-                }//end if
-            }//endif
-        }//end if
-        if(replicationValve != null) {
+                    } // endif
+                } // end if
+            } // endif
+        } // end if
+        if (replicationValve != null) {
             replicationValve.registerReplicationSession(session);
         }
     }
@@ -205,15 +207,19 @@ public abstract class ClusterManagerBase extends ManagerBase implements ClusterM
         if (getCluster() == null) {
             Cluster cluster = getContext().getCluster();
             if (cluster instanceof CatalinaCluster) {
-                setCluster((CatalinaCluster)cluster);
+                setCluster((CatalinaCluster) cluster);
             }
         }
-        if (cluster != null) cluster.registerManager(this);
+        if (cluster != null) {
+            cluster.registerManager(this);
+        }
     }
 
     @Override
     protected void stopInternal() throws LifecycleException {
-        if (cluster != null) cluster.removeManager(this);
+        if (cluster != null) {
+            cluster.removeManager(this);
+        }
         replicationValve = null;
         super.stopInternal();
     }
