@@ -49,10 +49,9 @@ import org.apache.tomcat.util.collections.SynchronizedStack;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Similar to the StandardSession except that this session will keep
- * track of deltas during a request.
+ * Similar to the StandardSession except that this session will keep track of deltas during a request.
  */
-public class DeltaSession extends StandardSession implements Externalizable,ClusterSession,ReplicatedMapEntry {
+public class DeltaSession extends StandardSession implements Externalizable, ClusterSession, ReplicatedMapEntry {
 
     public static final Log log = LogFactory.getLog(DeltaSession.class);
 
@@ -64,22 +63,19 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     // ----------------------------------------------------- Instance Variables
 
     /**
-     * only the primary session will expire, or be able to expire due to
-     * inactivity. This is set to false as soon as I receive this session over
-     * the wire in a session message. That means that someone else has made a
-     * request on another server.
+     * only the primary session will expire, or be able to expire due to inactivity. This is set to false as soon as I
+     * receive this session over the wire in a session message. That means that someone else has made a request on
+     * another server.
      */
     private transient boolean isPrimarySession = true;
 
     /**
      * The delta request contains all the action info
-     *
      */
     private transient DeltaRequest deltaRequest = null;
 
     /**
-     * Last time the session was replicated, used for distributed expiring of
-     * session
+     * Last time the session was replicated, used for distributed expiring of session
      */
     private transient long lastTimeReplicated = System.currentTimeMillis();
 
@@ -97,13 +93,12 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     /**
      * Construct a new Session associated with the specified Manager.
      *
-     * @param manager
-     *            The manager with which this Session is associated
+     * @param manager The manager with which this Session is associated
      */
     public DeltaSession(Manager manager) {
         super(manager);
-        boolean recordAllActions = manager instanceof ClusterManagerBase &&
-                ((ClusterManagerBase)manager).isRecordAllActions();
+        boolean recordAllActions =
+                manager instanceof ClusterManagerBase && ((ClusterManagerBase) manager).isRecordAllActions();
         deltaRequest = createRequest(getIdInternal(), recordAllActions);
     }
 
@@ -112,9 +107,8 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     }
 
     /*
-     * DeltaRequest instances are created via this protected method to enable
-     * sub-classes to over-ride the method to use custom DeltaRequest
-     * implementations.
+     * DeltaRequest instances are created via this protected method to enable sub-classes to over-ride the method to use
+     * custom DeltaRequest implementations.
      */
     protected DeltaRequest createRequest(String sessionId, boolean recordAllActions) {
         return new DeltaRequest(sessionId, recordAllActions);
@@ -123,18 +117,19 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     // ----------------------------------------------------- ReplicatedMapEntry
 
     /**
-     * Has the object changed since last replication
-     * and is not in a locked state
+     * Has the object changed since last replication and is not in a locked state
+     *
      * @return boolean
      */
     @Override
     public boolean isDirty() {
-        return getDeltaRequest().getSize()>0;
+        return deltaRequest.getSize() > 0;
     }
 
     /**
-     * If this returns true, the map will extract the diff using getDiff()
-     * Otherwise it will serialize the entire object.
+     * If this returns true, the map will extract the diff using getDiff() Otherwise it will serialize the entire
+     * object.
+     *
      * @return boolean
      */
     @Override
@@ -144,7 +139,9 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     /**
      * Returns a diff and sets the dirty map to false
+     *
      * @return a serialized view of the difference
+     *
      * @throws IOException IO error serializing
      */
     @Override
@@ -178,9 +175,9 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     public ClassLoader[] getClassLoaders() {
         if (manager instanceof ClusterManagerBase) {
-            return ((ClusterManagerBase)manager).getClassLoaders();
+            return ((ClusterManagerBase) manager).getClassLoaders();
         } else if (manager instanceof ManagerBase) {
-            ManagerBase mb = (ManagerBase)manager;
+            ManagerBase mb = (ManagerBase) manager;
             return ClusterManagerBase.getClassLoaders(mb.getContext());
         }
         return null;
@@ -188,29 +185,28 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     /**
      * Applies a diff to an existing object.
-     * @param diff Serialized diff data
+     *
+     * @param diff   Serialized diff data
      * @param offset Array offset
      * @param length Array length
+     *
      * @throws IOException IO error deserializing
      */
     @Override
     public void applyDiff(byte[] diff, int offset, int length) throws IOException, ClassNotFoundException {
+        Thread currentThread = Thread.currentThread();
+        ClassLoader contextLoader = currentThread.getContextClassLoader();
         lockInternal();
         try (ObjectInputStream stream = ((ClusterManager) getManager()).getReplicationStream(diff, offset, length)) {
-            Thread currentThread = Thread.currentThread();
-            ClassLoader contextLoader = currentThread.getContextClassLoader();
-            try {
-                ClassLoader[] loaders = getClassLoaders();
-                if (loaders != null && loaders.length > 0) {
-                    currentThread.setContextClassLoader(loaders[0]);
-                }
-                getDeltaRequest().readExternal(stream);
-                getDeltaRequest().execute(this, ((ClusterManager)getManager()).isNotifyListenersOnReplication());
-            } finally {
-                currentThread.setContextClassLoader(contextLoader);
+            ClassLoader[] loaders = getClassLoaders();
+            if (loaders != null && loaders.length > 0) {
+                currentThread.setContextClassLoader(loaders[0]);
             }
+            deltaRequest.readExternal(stream);
+            deltaRequest.execute(this, ((ClusterManager) getManager()).isNotifyListenersOnReplication());
         } finally {
             unlockInternal();
+            currentThread.setContextClassLoader(contextLoader);
         }
     }
 
@@ -227,8 +223,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     /**
      * {@inheritDoc}
      * <p>
-     * This implementation is a NO-OP. Any required locking takes place in the
-     * methods that make modifications.
+     * This implementation is a NO-OP. Any required locking takes place in the methods that make modifications.
      */
     @Override
     public void lock() {
@@ -238,8 +233,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     /**
      * {@inheritDoc}
      * <p>
-     * This implementation is a NO-OP. Any required unlocking takes place in the
-     * methods that make modifications.
+     * This implementation is a NO-OP. Any required unlocking takes place in the methods that make modifications.
      */
     @Override
     public void unlock() {
@@ -262,8 +256,8 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     @Override
     public void setOwner(Object owner) {
-        if ( owner instanceof ClusterManager && getManager()==null) {
-            ClusterManager cm = (ClusterManager)owner;
+        if (owner instanceof ClusterManager && getManager() == null) {
+            ClusterManager cm = (ClusterManager) owner;
             this.setManager(cm);
             this.setValid(true);
             this.setPrimarySession(false);
@@ -275,12 +269,13 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     /**
      * If this returns true, to replicate that an object has been accessed
+     *
      * @return boolean
      */
     @Override
     public boolean isAccessReplicate() {
         long replDelta = System.currentTimeMillis() - getLastTimeReplicated();
-        if (maxInactiveInterval >=0 && replDelta > (maxInactiveInterval * 1000L)) {
+        if (maxInactiveInterval >= 0 && replDelta > (maxInactiveInterval * 1000L)) {
             return true;
         }
         return false;
@@ -299,8 +294,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     // ----------------------------------------------------- Session Properties
 
     /**
-     * returns true if this session is the primary session, if that is the case,
-     * the manager can expire it upon timeout.
+     * returns true if this session is the primary session, if that is the case, the manager can expire it upon timeout.
      */
     @Override
     public boolean isPrimarySession() {
@@ -310,8 +304,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     /**
      * Sets whether this is the primary session or not.
      *
-     * @param primarySession
-     *            Flag value
+     * @param primarySession Flag value
      */
     @Override
     public void setPrimarySession(boolean primarySession) {
@@ -319,16 +312,13 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setId(String id, boolean notify) {
         super.setId(id, notify);
         lockInternal();
         try {
             deltaRequest.setSessionId(getIdInternal());
-        } finally{
+        } finally {
             unlockInternal();
         }
     }
@@ -337,8 +327,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     /**
      * Set the session identifier for this session.
      *
-     * @param id
-     *            The new session identifier
+     * @param id The new session identifier
      */
     @Override
     public void setId(String id) {
@@ -348,7 +337,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     @Override
     public void setMaxInactiveInterval(int interval) {
-        this.setMaxInactiveInterval(interval,true);
+        this.setMaxInactiveInterval(interval, true);
     }
 
 
@@ -367,8 +356,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     /**
      * Set the <code>isNew</code> flag for this session.
      *
-     * @param isNew
-     *            The new value for the <code>isNew</code> flag
+     * @param isNew The new value for the <code>isNew</code> flag
      */
     @Override
     public void setNew(boolean isNew) {
@@ -377,7 +365,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     public void setNew(boolean isNew, boolean addDeltaRequest) {
         super.setNew(isNew);
-        if (addDeltaRequest){
+        if (addDeltaRequest) {
             lockInternal();
             try {
                 deltaRequest.setNew(isNew);
@@ -388,13 +376,11 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     }
 
     /**
-     * Set the authenticated Principal that is associated with this Session.
-     * This provides an <code>Authenticator</code> with a means to cache a
-     * previously authenticated Principal, and avoid potentially expensive
+     * Set the authenticated Principal that is associated with this Session. This provides an <code>Authenticator</code>
+     * with a means to cache a previously authenticated Principal, and avoid potentially expensive
      * <code>Realm.authenticate()</code> calls on every request.
      *
-     * @param principal
-     *            The new Principal, or <code>null</code> if none
+     * @param principal The new Principal, or <code>null</code> if none
      */
     @Override
     public void setPrincipal(Principal principal) {
@@ -414,8 +400,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     }
 
     /**
-     * Set the authentication type used to authenticate our cached
-     * Principal, if any.
+     * Set the authentication type used to authenticate our cached Principal, if any.
      *
      * @param authType The new cached authentication type
      */
@@ -458,10 +443,10 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
                 }
             } else {
                 if (timeIdle >= (2 * maxInactiveInterval)) {
-                    //if the session has been idle twice as long as allowed,
-                    //the primary session has probably crashed, and no other
-                    //requests are coming in. that is why we do this. otherwise
-                    //we would have a memory leak
+                    // if the session has been idle twice as long as allowed,
+                    // the primary session has probably crashed, and no other
+                    // requests are coming in. that is why we do this. otherwise
+                    // we would have a memory leak
                     expire(true, false);
                 }
             }
@@ -475,20 +460,19 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
      */
     @Override
     public void endAccess() {
-        super.endAccess() ;
-        if(manager instanceof ClusterManagerBase) {
-            ((ClusterManagerBase)manager).registerSessionAtReplicationValve(this);
+        super.endAccess();
+        if (manager instanceof ClusterManagerBase) {
+            ((ClusterManagerBase) manager).registerSessionAtReplicationValve(this);
         }
     }
 
     // ------------------------------------------------- Session Public Methods
 
     /**
-     * Perform the internal processing required to invalidate this session,
-     * without triggering an exception if the session has already expired.
+     * Perform the internal processing required to invalidate this session, without triggering an exception if the
+     * session has already expired.
      *
-     * @param notify
-     *            Should we notify listeners about the demise of this session?
+     * @param notify Should we notify listeners about the demise of this session?
      */
     @Override
     public void expire(boolean notify) {
@@ -517,9 +501,8 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
             String expiredId = getIdInternal();
 
-            if(notifyCluster && expiredId != null &&
-                    manager instanceof DeltaManager) {
-                DeltaManager dmanager = (DeltaManager)manager;
+            if (notifyCluster && expiredId != null && manager instanceof DeltaManager) {
+                DeltaManager dmanager = (DeltaManager) manager;
                 CatalinaCluster cluster = dmanager.getCluster();
                 ClusterMessage msg = dmanager.requestCompleted(expiredId, true);
                 if (msg != null) {
@@ -531,21 +514,18 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
             if (notifyCluster) {
                 if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("deltaSession.notifying",
-                                           ((ClusterManager)manager).getName(),
-                                           Boolean.valueOf(isPrimarySession()),
-                                           expiredId));
+                    log.debug(sm.getString("deltaSession.notifying", ((ClusterManager) manager).getName(),
+                            Boolean.valueOf(isPrimarySession()), expiredId));
                 }
-                if ( manager instanceof DeltaManager ) {
-                    ( (DeltaManager) manager).sessionExpired(expiredId);
+                if (manager instanceof DeltaManager) {
+                    ((DeltaManager) manager).sessionExpired(expiredId);
                 }
             }
         }
     }
 
     /**
-     * Release all object references, and initialize instance variables, in
-     * preparation for reuse of this object.
+     * Release all object references, and initialize instance variables, in preparation for reuse of this object.
      */
     @Override
     public void recycle() {
@@ -609,7 +589,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     // ------------------------------------------------ Session Package Methods
 
     @Override
-    public void readExternal(ObjectInput in) throws IOException,ClassNotFoundException {
+    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
         lockInternal();
         try {
             readObjectData(in);
@@ -620,41 +600,36 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
 
     /**
-     * Read a serialized version of the contents of this session object from the
-     * specified object input stream, without requiring that the StandardSession
-     * itself have been serialized.
+     * Read a serialized version of the contents of this session object from the specified object input stream, without
+     * requiring that the StandardSession itself have been serialized.
      *
-     * @param stream
-     *            The object input stream to read from
+     * @param stream The object input stream to read from
      *
-     * @exception ClassNotFoundException
-     *                if an unknown class is specified
-     * @exception IOException
-     *                if an input/output error occurs
+     * @exception ClassNotFoundException if an unknown class is specified
+     * @exception IOException            if an input/output error occurs
      */
     @Override
     public void readObjectData(ObjectInputStream stream) throws ClassNotFoundException, IOException {
-        doReadObject((ObjectInput)stream);
+        doReadObject((ObjectInput) stream);
     }
+
     public void readObjectData(ObjectInput stream) throws ClassNotFoundException, IOException {
         doReadObject(stream);
     }
 
     /**
-     * Write a serialized version of the contents of this session object to the
-     * specified object output stream, without requiring that the
-     * StandardSession itself have been serialized.
+     * Write a serialized version of the contents of this session object to the specified object output stream, without
+     * requiring that the StandardSession itself have been serialized.
      *
-     * @param stream
-     *            The object output stream to write to
+     * @param stream The object output stream to write to
      *
-     * @exception IOException
-     *                if an input/output error occurs
+     * @exception IOException if an input/output error occurs
      */
     @Override
     public void writeObjectData(ObjectOutputStream stream) throws IOException {
-        writeObjectData((ObjectOutput)stream);
+        writeObjectData((ObjectOutput) stream);
     }
+
     public void writeObjectData(ObjectOutput stream) throws IOException {
         doWriteObject(stream);
     }
@@ -664,11 +639,17 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
         try {
             deltaRequest.reset();
             deltaRequest.setSessionId(getIdInternal());
-        } finally{
+        } finally {
             unlockInternal();
         }
     }
 
+    /**
+     * Get the request.
+     * @return the request
+     * @deprecated Unused. This method will be removed in Tomcat 12.
+     */
+    @Deprecated
     public DeltaRequest getDeltaRequest() {
         return deltaRequest;
     }
@@ -676,8 +657,8 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     /**
      * Replace the existing deltaRequest with the provided replacement.
      *
-     * @param deltaRequest The new deltaRequest. Expected to be either a newly
-     *                     created object or an instance that has been reset.
+     * @param deltaRequest The new deltaRequest. Expected to be either a newly created object or an instance that has
+     *                         been reset.
      *
      * @return The old deltaRequest
      */
@@ -696,8 +677,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     protected void deserializeAndExecuteDeltaRequest(byte[] delta) throws IOException, ClassNotFoundException {
         if (manager instanceof ClusterManagerBase) {
-            SynchronizedStack<DeltaRequest> deltaRequestPool =
-                    ((ClusterManagerBase) manager).getDeltaRequestPool();
+            SynchronizedStack<DeltaRequest> deltaRequestPool = ((ClusterManagerBase) manager).getDeltaRequestPool();
 
             DeltaRequest newDeltaRequest = deltaRequestPool.pop();
             if (newDeltaRequest == null) {
@@ -728,29 +708,23 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     // ----------------------------------------------HttpSession Public Methods
 
     /**
-     * Remove the object bound with the specified name from this session. If the
-     * session does not have an object bound with this name, this method does
-     * nothing.
+     * Remove the object bound with the specified name from this session. If the session does not have an object bound
+     * with this name, this method does nothing.
      * <p>
-     * After this method executes, and if the object implements
-     * <code>HttpSessionBindingListener</code>, the container calls
-     * <code>valueUnbound()</code> on the object.
+     * After this method executes, and if the object implements <code>HttpSessionBindingListener</code>, the container
+     * calls <code>valueUnbound()</code> on the object.
      *
-     * @param name
-     *            Name of the object to remove from this session.
-     * @param notify
-     *            Should we notify interested listeners that this attribute is
-     *            being removed?
+     * @param name   Name of the object to remove from this session.
+     * @param notify Should we notify interested listeners that this attribute is being removed?
      *
-     * @exception IllegalStateException
-     *                if this method is called on an invalidated session
+     * @exception IllegalStateException if this method is called on an invalidated session
      */
     @Override
     public void removeAttribute(String name, boolean notify) {
         removeAttribute(name, notify, true);
     }
 
-    public void removeAttribute(String name, boolean notify,boolean addDeltaRequest) {
+    public void removeAttribute(String name, boolean notify, boolean addDeltaRequest) {
         // Validate our current state
         if (!isValid()) {
             throw new IllegalStateException(sm.getString("standardSession.removeAttribute.ise"));
@@ -759,30 +733,25 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     }
 
     /**
-     * Bind an object to this session, using the specified name. If an object of
-     * the same name is already bound to this session, the object is replaced.
+     * Bind an object to this session, using the specified name. If an object of the same name is already bound to this
+     * session, the object is replaced.
      * <p>
-     * After this method executes, and if the object implements
-     * <code>HttpSessionBindingListener</code>, the container calls
-     * <code>valueBound()</code> on the object.
+     * After this method executes, and if the object implements <code>HttpSessionBindingListener</code>, the container
+     * calls <code>valueBound()</code> on the object.
      *
-     * @param name
-     *            Name to which the object is bound, cannot be null
-     * @param value
-     *            Object to be bound, cannot be null
+     * @param name  Name to which the object is bound, cannot be null
+     * @param value Object to be bound, cannot be null
      *
-     * @exception IllegalArgumentException
-     *                if an attempt is made to add a non-serializable object in
-     *                an environment marked distributable.
-     * @exception IllegalStateException
-     *                if this method is called on an invalidated session
+     * @exception IllegalArgumentException if an attempt is made to add a non-serializable object in an environment
+     *                                         marked distributable.
+     * @exception IllegalStateException    if this method is called on an invalidated session
      */
     @Override
     public void setAttribute(String name, Object value) {
         setAttribute(name, value, true, true);
     }
 
-    public void setAttribute(String name, Object value, boolean notify,boolean addDeltaRequest) {
+    public void setAttribute(String name, Object value, boolean notify, boolean addDeltaRequest) {
 
         // Name cannot be null
         if (name == null) {
@@ -797,7 +766,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
         lockInternal();
         try {
-            super.setAttribute(name,value, notify);
+            super.setAttribute(name, value, notify);
             if (addDeltaRequest && !exclude(name, value)) {
                 deltaRequest.setAttribute(name, value);
             }
@@ -852,36 +821,32 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     // -------------------------------------------- HttpSession Private Methods
 
     /**
-     * Read a serialized version of this session object from the specified
-     * object input stream.
+     * Read a serialized version of this session object from the specified object input stream.
      * <p>
-     * <b>IMPLEMENTATION NOTE </b>: The reference to the owning Manager is not
-     * restored by this method, and must be set explicitly.
+     * <b>IMPLEMENTATION NOTE </b>: The reference to the owning Manager is not restored by this method, and must be set
+     * explicitly.
      *
-     * @param stream
-     *            The input stream to read from
+     * @param stream The input stream to read from
      *
-     * @exception ClassNotFoundException
-     *                if an unknown class is specified
-     * @exception IOException
-     *                if an input/output error occurs
+     * @exception ClassNotFoundException if an unknown class is specified
+     * @exception IOException            if an input/output error occurs
      */
     @Override
     protected void doReadObject(ObjectInputStream stream) throws ClassNotFoundException, IOException {
-        doReadObject((ObjectInput)stream);
+        doReadObject((ObjectInput) stream);
     }
 
     private void doReadObject(ObjectInput stream) throws ClassNotFoundException, IOException {
 
         // Deserialize the scalar instance variables (except Manager)
         authType = null; // Transient only
-        creationTime = ( (Long) stream.readObject()).longValue();
-        lastAccessedTime = ( (Long) stream.readObject()).longValue();
-        maxInactiveInterval = ( (Integer) stream.readObject()).intValue();
-        isNew = ( (Boolean) stream.readObject()).booleanValue();
-        isValid = ( (Boolean) stream.readObject()).booleanValue();
-        thisAccessedTime = ( (Long) stream.readObject()).longValue();
-        version = ( (Long) stream.readObject()).longValue();
+        creationTime = ((Long) stream.readObject()).longValue();
+        lastAccessedTime = ((Long) stream.readObject()).longValue();
+        maxInactiveInterval = ((Integer) stream.readObject()).intValue();
+        isNew = ((Boolean) stream.readObject()).booleanValue();
+        isValid = ((Boolean) stream.readObject()).booleanValue();
+        thisAccessedTime = ((Long) stream.readObject()).longValue();
+        version = ((Long) stream.readObject()).longValue();
         boolean hasPrincipal = stream.readBoolean();
         principal = null;
         if (hasPrincipal) {
@@ -937,7 +902,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
                 continue;
             }
             // ConcurrentHashMap does not allow null keys or values
-            if(null != value) {
+            if (null != value) {
                 attributes.put(name, value);
             }
         }
@@ -960,7 +925,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
     }
 
     @Override
-    public void writeExternal(ObjectOutput out ) throws java.io.IOException {
+    public void writeExternal(ObjectOutput out) throws IOException {
         lockInternal();
         try {
             doWriteObject(out);
@@ -971,29 +936,22 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
 
     /**
-     * Write a serialized version of this session object to the specified object
-     * output stream.
+     * Write a serialized version of this session object to the specified object output stream.
      * <p>
-     * <b>IMPLEMENTATION NOTE </b>: The owning Manager will not be stored in the
-     * serialized representation of this Session. After calling
-     * <code>readObject()</code>, you must set the associated Manager
-     * explicitly.
+     * <b>IMPLEMENTATION NOTE </b>: The owning Manager will not be stored in the serialized representation of this
+     * Session. After calling <code>readObject()</code>, you must set the associated Manager explicitly.
      * <p>
-     * <b>IMPLEMENTATION NOTE </b>: Any attribute that is not Serializable will
-     * be unbound from the session, with appropriate actions if it implements
-     * HttpSessionBindingListener. If you do not want any such attributes, be
-     * sure the <code>distributable</code> property of the associated Manager
-     * is set to <code>true</code>.
+     * <b>IMPLEMENTATION NOTE </b>: Any attribute that is not Serializable will be unbound from the session, with
+     * appropriate actions if it implements HttpSessionBindingListener. If you do not want any such attributes, be sure
+     * the <code>distributable</code> property of the associated Manager is set to <code>true</code>.
      *
-     * @param stream
-     *            The output stream to write to
+     * @param stream The output stream to write to
      *
-     * @exception IOException
-     *                if an input/output error occurs
+     * @exception IOException if an input/output error occurs
      */
     @Override
     protected void doWriteObject(ObjectOutputStream stream) throws IOException {
-        doWriteObject((ObjectOutput)stream);
+        doWriteObject((ObjectOutput) stream);
     }
 
     private void doWriteObject(ObjectOutput stream) throws IOException {
@@ -1028,8 +986,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
         for (String key : keys) {
             Object value = null;
             value = attributes.get(key);
-            if (value != null && !exclude(key, value) &&
-                    isAttributeDistributable(key, value)) {
+            if (value != null && !exclude(key, value) && isAttributeDistributable(key, value)) {
                 saveNames.add(key);
                 saveValues.add(value);
             }
@@ -1039,7 +996,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
         int n = saveNames.size();
         stream.writeObject(Integer.valueOf(n));
         for (int i = 0; i < n; i++) {
-            stream.writeObject( saveNames.get(i));
+            stream.writeObject(saveNames.get(i));
             try {
                 stream.writeObject(saveValues.get(i));
             } catch (NotSerializableException e) {
@@ -1063,8 +1020,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
 
     // -------------------------------------------------------- Private Methods
 
-    protected void removeAttributeInternal(String name, boolean notify,
-                                           boolean addDeltaRequest) {
+    protected void removeAttributeInternal(String name, boolean notify, boolean addDeltaRequest) {
         lockInternal();
         try {
             // Remove this attribute from our collection
@@ -1073,7 +1029,7 @@ public class DeltaSession extends StandardSession implements Externalizable,Clus
                 return;
             }
 
-            super.removeAttributeInternal(name,notify);
+            super.removeAttributeInternal(name, notify);
             if (addDeltaRequest && !exclude(name, null)) {
                 deltaRequest.removeAttribute(name);
             }
