@@ -84,31 +84,42 @@ public class SessionMessageImpl extends ClusterMessageBase implements SessionMes
         uniqueId = uniqueID;
     }
 
+    /**
+     * returns the event type
+     *
+     * @return one of the event types EVT_XXXX
+     */
     @Override
     public int getEventType() {
         return mEvtType;
     }
 
+    /**
+     * @return the serialized data for the session
+     */
     @Override
     public byte[] getSession() {
         return mSession;
     }
 
+    /**
+     * @return the session ID for the session
+     */
     @Override
     public String getSessionID() {
         return mSessionID;
     }
 
     /**
-     * Set message send time but only the first setting works (one shot)
-     *
-     * @param time the timestamp
+     * set message send time but only the first setting works (one shot)
      */
     @Override
     public void setTimestamp(long time) {
-        if (!timestampSet) {
-            serializationTimestamp = time;
-            timestampSet = true;
+        synchronized (this) {
+            if (!timestampSet) {
+                serializationTimestamp = time;
+                timestampSet = true;
+            }
         }
     }
 
@@ -117,6 +128,11 @@ public class SessionMessageImpl extends ClusterMessageBase implements SessionMes
         return serializationTimestamp;
     }
 
+    /**
+     * clear text event type name (for logging purpose only)
+     *
+     * @return the event type in a string representation, useful for debugging
+     */
     @Override
     public String getEventTypeString() {
         switch (mEvtType) {
