@@ -20,6 +20,8 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicLong;
+import java.util.concurrent.atomic.LongAdder;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
@@ -46,23 +48,23 @@ import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * <p>Implementation of a Valve that logs interesting contents from the
- * specified Request (before processing) and the corresponding Response
- * (after processing).  It is especially useful in debugging problems
- * related to headers and cookies.</p>
- *
- * <p>This Valve may be attached to any Container, depending on the granularity
- * of the logging you wish to perform.</p>
- *
- * <p>primaryIndicator=true, then the request attribute <i>org.apache.catalina.ha.tcp.isPrimarySession.</i>
- * is set true, when request processing is at sessions primary node.
+ * <p>
+ * Implementation of a Valve that logs interesting contents from the specified Request (before processing) and the
+ * corresponding Response (after processing). It is especially useful in debugging problems related to headers and
+ * cookies.
+ * </p>
+ * <p>
+ * This Valve may be attached to any Container, depending on the granularity of the logging you wish to perform.
+ * </p>
+ * <p>
+ * primaryIndicator=true, then the request attribute <i>org.apache.catalina.ha.tcp.isPrimarySession.</i> is set true,
+ * when request processing is at sessions primary node.
  * </p>
  *
  * @author Craig R. McClanahan
  * @author Peter Rossbach
  */
-public class ReplicationValve
-    extends ValveBase implements ClusterValve {
+public class ReplicationValve extends ValveBase implements ClusterValve {
 
     private static final Log log = LogFactory.getLog(ReplicationValve.class);
 
@@ -71,10 +73,9 @@ public class ReplicationValve
     /**
      * The StringManager for this package.
      */
-    protected static final StringManager sm =
-        StringManager.getManager(Constants.Package);
+    protected static final StringManager sm = StringManager.getManager(Constants.Package);
 
-    private CatalinaCluster cluster = null ;
+    private CatalinaCluster cluster = null;
 
     /**
      * Filter expression
@@ -84,34 +85,25 @@ public class ReplicationValve
     /**
      * crossContext session container
      */
-    protected final ThreadLocal<ArrayList<DeltaSession>> crossContextSessions =
-        new ThreadLocal<>() ;
+    protected final ThreadLocal<ArrayList<DeltaSession>> crossContextSessions = new ThreadLocal<>();
 
     /**
      * doProcessingStats (default = off)
      */
     protected boolean doProcessingStats = false;
 
-    /*
-     * Note: The statistics are volatile to ensure the concurrent updates do not
-     *       corrupt them but it is still possible that:
-     *       - some updates may be lost;
-     *       - the individual statistics may not be consistent which each other.
-     *       This is a deliberate design choice to reduce the requirement for
-     *       synchronization.
-     */
-    protected volatile long totalRequestTime = 0;
-    protected volatile long totalSendTime = 0;
-    protected volatile long nrOfRequests = 0;
-    protected volatile long lastSendTime = 0;
-    protected volatile long nrOfFilterRequests = 0;
-    protected volatile long nrOfSendRequests = 0;
-    protected volatile long nrOfCrossContextSendRequests = 0;
+    protected LongAdder totalRequestTime = new LongAdder();
+    protected LongAdder totalSendTime = new LongAdder();
+    protected LongAdder nrOfRequests = new LongAdder();
+    protected AtomicLong lastSendTime = new AtomicLong();
+    protected LongAdder nrOfFilterRequests = new LongAdder();
+    protected LongAdder nrOfSendRequests = new LongAdder();
+    protected LongAdder nrOfCrossContextSendRequests = new LongAdder();
 
     /**
      * must primary change indicator set
      */
-    protected boolean primaryIndicator = false ;
+    protected boolean primaryIndicator = false;
 
     /**
      * Name of primary change indicator as request attribute
@@ -144,17 +136,18 @@ public class ReplicationValve
      * @return the filter
      */
     public String getFilter() {
-       if (filter == null) {
-           return null;
-       }
-       return filter.toString();
+        if (filter == null) {
+            return null;
+        }
+        return filter.toString();
     }
 
     /**
      * compile filter string to regular expression
-     * @see Pattern#compile(java.lang.String)
-     * @param filter
-     *            The filter to set.
+     *
+     * @see Pattern#compile(String)
+     *
+     * @param filter The filter to set.
      */
     public void setFilter(String filter) {
         if (log.isDebugEnabled()) {
@@ -167,8 +160,7 @@ public class ReplicationValve
             try {
                 this.filter = Pattern.compile(filter);
             } catch (PatternSyntaxException pse) {
-                log.error(sm.getString("ReplicationValve.filter.failure",
-                        filter), pse);
+                log.error(sm.getString("ReplicationValve.filter.failure", filter), pse);
             }
         }
     }
@@ -203,6 +195,7 @@ public class ReplicationValve
 
     /**
      * Calc processing stats
+     *
      * @return <code>true</code> if statistics are enabled
      */
     public boolean doStatistics() {
@@ -213,6 +206,7 @@ public class ReplicationValve
      * Set Calc processing stats
      *
      * @param doProcessingStats New flag value
+     *
      * @see #resetStatistics()
      */
     public void setStatistics(boolean doProcessingStats) {
@@ -223,68 +217,66 @@ public class ReplicationValve
      * @return the lastSendTime.
      */
     public long getLastSendTime() {
-        return lastSendTime;
+        return lastSendTime.longValue();
     }
 
     /**
      * @return the nrOfRequests.
      */
     public long getNrOfRequests() {
-        return nrOfRequests;
+        return nrOfRequests.longValue();
     }
 
     /**
      * @return the nrOfFilterRequests.
      */
     public long getNrOfFilterRequests() {
-        return nrOfFilterRequests;
+        return nrOfFilterRequests.longValue();
     }
 
     /**
      * @return the nrOfCrossContextSendRequests.
      */
     public long getNrOfCrossContextSendRequests() {
-        return nrOfCrossContextSendRequests;
+        return nrOfCrossContextSendRequests.longValue();
     }
 
     /**
      * @return the nrOfSendRequests.
      */
     public long getNrOfSendRequests() {
-        return nrOfSendRequests;
+        return nrOfSendRequests.longValue();
     }
 
     /**
      * @return the totalRequestTime.
      */
     public long getTotalRequestTime() {
-        return totalRequestTime;
+        return totalRequestTime.longValue();
     }
 
     /**
      * @return the totalSendTime.
      */
     public long getTotalSendTime() {
-        return totalSendTime;
+        return totalSendTime.longValue();
     }
 
     // --------------------------------------------------------- Public Methods
 
     /**
-     * Register all cross context sessions inside endAccess.
-     * Use a list with contains check, that the Portlet API can include a lot of fragments from same or
-     * different applications with session changes.
+     * Register all cross context sessions inside endAccess. Use a list with contains check, that the Portlet API can
+     * include a lot of fragments from same or different applications with session changes.
      *
      * @param session cross context session
      */
     public void registerReplicationSession(DeltaSession session) {
         List<DeltaSession> sessions = crossContextSessions.get();
-        if(sessions != null) {
-            if(!sessions.contains(session)) {
-                if(log.isDebugEnabled()) {
-                    log.debug(sm.getString("ReplicationValve.crossContext.registerSession",
-                        session.getIdInternal(),
-                        session.getManager().getContext().getName()));
+        if (sessions != null) {
+            if (!sessions.contains(session)) {
+                if (log.isDebugEnabled()) {
+                    log.debug(sm.getString("ReplicationValve.crossContext.registerSession", session.getIdInternal(),
+                            session.getManager().getContext().getName()));
                 }
                 sessions.add(session);
             }
@@ -292,61 +284,56 @@ public class ReplicationValve
     }
 
     /**
-     * Log the interesting request parameters, invoke the next Valve in the
-     * sequence, and log the interesting response parameters.
+     * Log the interesting request parameters, invoke the next Valve in the sequence, and log the interesting response
+     * parameters.
      *
-     * @param request The servlet request to be processed
+     * @param request  The servlet request to be processed
      * @param response The servlet response to be created
      *
-     * @exception IOException if an input/output error occurs
+     * @exception IOException      if an input/output error occurs
      * @exception ServletException if a servlet error occurs
      */
     @Override
-    public void invoke(Request request, Response response)
-        throws IOException, ServletException
-    {
+    public void invoke(Request request, Response response) throws IOException, ServletException {
         long totalstart = 0;
 
-        //this happens before the request
-        if(doStatistics()) {
+        // this happens before the request
+        if (doStatistics()) {
             totalstart = System.currentTimeMillis();
         }
         if (primaryIndicator) {
-            createPrimaryIndicator(request) ;
+            createPrimaryIndicator(request);
         }
         Context context = request.getContext();
-        boolean isCrossContext = context != null
-                && context instanceof StandardContext
-                && context.getCrossContext();
+        boolean isCrossContext = context != null && context instanceof StandardContext && context.getCrossContext();
         try {
-            if(isCrossContext) {
-                if(log.isDebugEnabled()) {
+            if (isCrossContext) {
+                if (log.isDebugEnabled()) {
                     log.debug(sm.getString("ReplicationValve.crossContext.add"));
                 }
-                //FIXME add Pool of Arraylists
+                // FIXME add Pool of Arraylists
                 crossContextSessions.set(new ArrayList<>());
             }
             getNext().invoke(request, response);
-            if(context != null && cluster != null
-                    && context.getManager() instanceof ClusterManager) {
+            if (context != null && cluster != null && context.getManager() instanceof ClusterManager) {
                 ClusterManager clusterManager = (ClusterManager) context.getManager();
 
                 // valve cluster can access manager - other cluster handle replication
                 // at host level - hopefully!
-                if(cluster.getManager(clusterManager.getName()) == null) {
-                    return ;
+                if (cluster.getManager(clusterManager.getName()) == null) {
+                    return;
                 }
-                if(cluster.hasMembers()) {
+                if (cluster.hasMembers()) {
                     sendReplicationMessage(request, totalstart, isCrossContext, clusterManager);
                 } else {
-                    resetReplicationRequest(request,isCrossContext);
+                    resetReplicationRequest(request, isCrossContext);
                 }
             }
         } finally {
             // Array must be remove: Current master request send endAccess at recycle.
             // Don't register this request session again!
             if (isCrossContext) {
-                if(log.isDebugEnabled()) {
+                if (log.isDebugEnabled()) {
                     log.debug(sm.getString("ReplicationValve.crossContext.remove"));
                 }
                 crossContextSessions.remove();
@@ -359,28 +346,28 @@ public class ReplicationValve
      * reset the active statistics
      */
     public void resetStatistics() {
-        totalRequestTime = 0;
-        totalSendTime = 0;
-        lastSendTime = 0;
-        nrOfFilterRequests = 0;
-        nrOfRequests = 0;
-        nrOfSendRequests = 0;
-        nrOfCrossContextSendRequests = 0;
+        totalRequestTime.reset();
+        totalSendTime.reset();
+        lastSendTime.set(0);
+        nrOfFilterRequests.reset();
+        nrOfRequests.reset();
+        nrOfSendRequests.reset();
+        nrOfCrossContextSendRequests.reset();
     }
 
     /**
-     * Start this component and implement the requirements
-     * of {@link org.apache.catalina.util.LifecycleBase#startInternal()}.
+     * Start this component and implement the requirements of
+     * {@link org.apache.catalina.util.LifecycleBase#startInternal()}.
      *
-     * @exception LifecycleException if this component detects a fatal error
-     *  that prevents this component from being used
+     * @exception LifecycleException if this component detects a fatal error that prevents this component from being
+     *                                   used
      */
     @Override
     protected synchronized void startInternal() throws LifecycleException {
         if (cluster == null) {
             Cluster containerCluster = getContainer().getCluster();
             if (containerCluster instanceof CatalinaCluster) {
-                setCluster((CatalinaCluster)containerCluster);
+                setCluster((CatalinaCluster) containerCluster);
             } else {
                 if (log.isWarnEnabled()) {
                     log.warn(sm.getString("ReplicationValve.nocluster"));
@@ -393,10 +380,11 @@ public class ReplicationValve
 
     // --------------------------------------------------------- Protected Methods
 
-    protected void sendReplicationMessage(Request request, long totalstart, boolean isCrossContext, ClusterManager clusterManager) {
-        //this happens after the request
+    protected void sendReplicationMessage(Request request, long totalstart, boolean isCrossContext,
+            ClusterManager clusterManager) {
+        // this happens after the request
         long start = 0;
-        if(doStatistics()) {
+        if (doStatistics()) {
             start = System.currentTimeMillis();
         }
         try {
@@ -407,16 +395,15 @@ public class ReplicationValve
             }
             // send replication
             sendSessionReplicationMessage(request, clusterManager);
-            if(isCrossContext) {
+            if (isCrossContext) {
                 sendCrossContextSession();
             }
         } catch (Exception x) {
             // FIXME we have a lot of sends, but the trouble with one node stops the correct replication to other nodes!
             log.error(sm.getString("ReplicationValve.send.failure"), x);
         } finally {
-            // FIXME this stats update are not cheap!!
-            if(doStatistics()) {
-                updateStats(totalstart,start);
+            if (doStatistics()) {
+                updateStats(totalstart, start);
             }
         }
     }
@@ -426,15 +413,15 @@ public class ReplicationValve
      */
     protected void sendCrossContextSession() {
         List<DeltaSession> sessions = crossContextSessions.get();
-        if(sessions != null && sessions.size() >0) {
+        if (sessions != null && sessions.size() > 0) {
             for (DeltaSession session : sessions) {
-                if(log.isDebugEnabled()) {
+                if (log.isDebugEnabled()) {
                     log.debug(sm.getString("ReplicationValve.crossContext.sendDelta",
-                            session.getManager().getContext().getName() ));
+                            session.getManager().getContext().getName()));
                 }
-                sendMessage(session,(ClusterManager)session.getManager());
-                if(doStatistics()) {
-                    nrOfCrossContextSendRequests++;
+                sendMessage(session, (ClusterManager) session.getManager());
+                if (doStatistics()) {
+                    nrOfCrossContextSendRequests.increment();
                 }
             }
         }
@@ -442,24 +429,25 @@ public class ReplicationValve
 
     /**
      * Fix memory leak for long sessions with many changes, when no backup member exists!
-     * @param request current request after response is generated
+     *
+     * @param request        current request after response is generated
      * @param isCrossContext check crosscontext threadlocal
      */
     protected void resetReplicationRequest(Request request, boolean isCrossContext) {
         Session contextSession = request.getSessionInternal(false);
-        if(contextSession instanceof DeltaSession){
+        if (contextSession instanceof DeltaSession) {
             resetDeltaRequest(contextSession);
-            ((DeltaSession)contextSession).setPrimarySession(true);
+            ((DeltaSession) contextSession).setPrimarySession(true);
         }
-        if(isCrossContext) {
+        if (isCrossContext) {
             List<DeltaSession> sessions = crossContextSessions.get();
-            if(sessions != null && sessions.size() >0) {
+            if (sessions != null && sessions.size() > 0) {
                 Iterator<DeltaSession> iter = sessions.iterator();
-                for(; iter.hasNext() ;) {
+                for (; iter.hasNext();) {
                     Session session = iter.next();
                     resetDeltaRequest(session);
-                    if(session instanceof DeltaSession) {
-                        ((DeltaSession)contextSession).setPrimarySession(true);
+                    if (session instanceof DeltaSession) {
+                        ((DeltaSession) contextSession).setPrimarySession(true);
                     }
 
                 }
@@ -469,23 +457,23 @@ public class ReplicationValve
 
     /**
      * Reset DeltaRequest from session
+     *
      * @param session HttpSession from current request or cross context session
      */
     protected void resetDeltaRequest(Session session) {
-        if(log.isDebugEnabled()) {
-            log.debug(sm.getString("ReplicationValve.resetDeltaRequest" ,
-                session.getManager().getContext().getName() ));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("ReplicationValve.resetDeltaRequest", session.getManager().getContext().getName()));
         }
-        ((DeltaSession)session).resetDeltaRequest();
+        ((DeltaSession) session).resetDeltaRequest();
     }
 
     /**
      * Send Cluster Replication Request
+     *
      * @param request current request
      * @param manager session manager
      */
-    protected void sendSessionReplicationMessage(Request request,
-            ClusterManager manager) {
+    protected void sendSessionReplicationMessage(Request request, ClusterManager manager) {
         Session session = request.getSessionInternal(false);
         if (session != null) {
             String uri = request.getDecodedRequestURI();
@@ -494,22 +482,21 @@ public class ReplicationValve
                 if (log.isDebugEnabled()) {
                     log.debug(sm.getString("ReplicationValve.invoke.uri", uri));
                 }
-                sendMessage(session,manager);
-            } else
-                if(doStatistics()) {
-                    nrOfFilterRequests++;
-                }
+                sendMessage(session, manager);
+            } else if (doStatistics()) {
+                nrOfFilterRequests.increment();
+            }
         }
 
     }
 
-   /**
-    * Send message delta message from request session
-    * @param session current session
-    * @param manager session manager
-    */
-    protected void sendMessage(Session session,
-             ClusterManager manager) {
+    /**
+     * Send message delta message from request session
+     *
+     * @param session current session
+     * @param manager session manager
+     */
+    protected void sendMessage(Session session, ClusterManager manager) {
         String id = session.getIdInternal();
         if (id != null) {
             send(manager, id);
@@ -518,8 +505,10 @@ public class ReplicationValve
 
     /**
      * send manager requestCompleted message to cluster
-     * @param manager SessionManager
+     *
+     * @param manager   SessionManager
      * @param sessionId sessionid from the manager
+     *
      * @see DeltaManager#requestCompleted(String)
      * @see SimpleTcpCluster#send(ClusterMessage)
      */
@@ -527,19 +516,20 @@ public class ReplicationValve
         ClusterMessage msg = manager.requestCompleted(sessionId);
         if (msg != null && cluster != null) {
             cluster.send(msg);
-            if(doStatistics()) {
-                nrOfSendRequests++;
+            if (doStatistics()) {
+                nrOfSendRequests.increment();
             }
         }
     }
 
     /**
      * check for session invalidations
+     *
      * @param manager Associated manager
      */
     protected void sendInvalidSessions(ClusterManager manager) {
-        String[] invalidIds=manager.getInvalidatedSessions();
-        if ( invalidIds.length > 0 ) {
+        String[] invalidIds = manager.getInvalidatedSessions();
+        if (invalidIds.length > 0) {
             for (String invalidId : invalidIds) {
                 try {
                     send(manager, invalidId);
@@ -552,7 +542,9 @@ public class ReplicationValve
 
     /**
      * is request without possible session change
+     *
      * @param uri The request uri
+     *
      * @return True if no session change
      */
     protected boolean isRequestWithoutSessionChange(String uri) {
@@ -562,39 +554,36 @@ public class ReplicationValve
 
     /**
      * Protocol cluster replications stats
+     *
      * @param requestTime Request time
      * @param clusterTime Cluster time
      */
-    protected  void updateStats(long requestTime, long clusterTime) {
+    protected void updateStats(long requestTime, long clusterTime) {
         // TODO: Async requests may trigger multiple replication requests. How,
-        //       if at all, should the stats handle this?
+        // if at all, should the stats handle this?
         long currentTime = System.currentTimeMillis();
-        lastSendTime = currentTime;
-        totalSendTime += currentTime - clusterTime;
-        totalRequestTime += currentTime - requestTime;
-        nrOfRequests++;
-        if(log.isInfoEnabled()) {
-            if ( (nrOfRequests % 100) == 0 ) {
-                 log.info(sm.getString("ReplicationValve.stats",
-                     new Object[]{
-                         Long.valueOf(totalRequestTime/nrOfRequests),
-                         Long.valueOf(totalSendTime/nrOfRequests),
-                         Long.valueOf(nrOfRequests),
-                         Long.valueOf(nrOfSendRequests),
-                         Long.valueOf(nrOfCrossContextSendRequests),
-                         Long.valueOf(nrOfFilterRequests),
-                         Long.valueOf(totalRequestTime),
-                         Long.valueOf(totalSendTime)}));
-             }
+        lastSendTime.set(currentTime);
+        totalSendTime.add(currentTime - clusterTime);
+        totalRequestTime.add(currentTime - requestTime);
+        nrOfRequests.increment();
+        if (log.isInfoEnabled()) {
+            if ((nrOfRequests.longValue() % 100) == 0) {
+                log.info(sm.getString("ReplicationValve.stats",
+                        new Object[] { Long.valueOf(totalRequestTime.longValue() / nrOfRequests.longValue()),
+                                Long.valueOf(totalSendTime.longValue() / nrOfRequests.longValue()), Long.valueOf(nrOfRequests.longValue()),
+                                Long.valueOf(nrOfSendRequests.longValue()), Long.valueOf(nrOfCrossContextSendRequests.longValue()),
+                                Long.valueOf(nrOfFilterRequests.longValue()), Long.valueOf(totalRequestTime.longValue()),
+                                Long.valueOf(totalSendTime.longValue()) }));
+            }
         }
     }
 
 
     /**
-     * Mark Request that processed at primary node with attribute
-     * primaryIndicatorName
+     * Mark Request that processed at primary node with attribute primaryIndicatorName
      *
      * @param request The Servlet request
+     *
      * @throws IOException IO error finding session
      */
     protected void createPrimaryIndicator(Request request) throws IOException {
@@ -605,20 +594,16 @@ public class ReplicationValve
             if (session instanceof ClusterSession) {
                 ClusterSession cses = (ClusterSession) session;
                 if (log.isDebugEnabled()) {
-                    log.debug(sm.getString(
-                            "ReplicationValve.session.indicator", request.getContext().getName(),id,
-                            primaryIndicatorName,
-                            Boolean.valueOf(cses.isPrimarySession())));
+                    log.debug(sm.getString("ReplicationValve.session.indicator", request.getContext().getName(), id,
+                            primaryIndicatorName, Boolean.valueOf(cses.isPrimarySession())));
                 }
-                request.setAttribute(primaryIndicatorName, cses.isPrimarySession()?Boolean.TRUE:Boolean.FALSE);
+                request.setAttribute(primaryIndicatorName, cses.isPrimarySession() ? Boolean.TRUE : Boolean.FALSE);
             } else {
                 if (log.isDebugEnabled()) {
                     if (session != null) {
-                        log.debug(sm.getString(
-                                "ReplicationValve.session.found", request.getContext().getName(),id));
+                        log.debug(sm.getString("ReplicationValve.session.found", request.getContext().getName(), id));
                     } else {
-                        log.debug(sm.getString(
-                                "ReplicationValve.session.invalid", request.getContext().getName(),id));
+                        log.debug(sm.getString("ReplicationValve.session.invalid", request.getContext().getName(), id));
                     }
                 }
             }
