@@ -49,17 +49,13 @@ import org.apache.tomcat.util.modeler.Registry;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Classloader implementation which is specialized for handling web
- * applications in the most efficient way, while being Catalina aware (all
- * accesses to resources are made through
- * {@link org.apache.catalina.WebResourceRoot}).
- * This class loader supports detection of modified
- * Java classes, which can be used to implement auto-reload support.
+ * Classloader implementation which is specialized for handling web applications in the most efficient way, while being
+ * Catalina aware (all accesses to resources are made through {@link org.apache.catalina.WebResourceRoot}). This class
+ * loader supports detection of modified Java classes, which can be used to implement auto-reload support.
  * <p>
- * This class loader is configured via the Resources children of its Context
- * prior to calling <code>start()</code>.  When a new class is required,
- * these Resources will be consulted first to locate the class.  If it
- * is not present, the system class loader will be used instead.
+ * This class loader is configured via the Resources children of its Context prior to calling <code>start()</code>. When
+ * a new class is required, these Resources will be consulted first to locate the class. If it is not present, the
+ * system class loader will be used instead.
  *
  * @author Craig R. McClanahan
  * @author Remy Maucherat
@@ -83,24 +79,21 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /**
-     * The "follow standard delegation model" flag that will be used to
-     * configure our ClassLoader.
+     * The "follow standard delegation model" flag that will be used to configure our ClassLoader.
      */
     private boolean delegate = false;
 
 
     /**
-     * The profile name which will be used by the converter, or null if not used.
-     * Any invalid profile value will default to the TOMCAT profile, which
-     * converts all packages used by Tomcat.
+     * The profile name which will be used by the converter, or null if not used. Any invalid profile value will default
+     * to the TOMCAT profile, which converts all packages used by Tomcat.
      */
     private String jakartaConverter = null;
 
 
     /**
-     * The Java class name of the ClassLoader implementation to be used.
-     * This class should extend WebappClassLoaderBase, otherwise, a different
-     * loader implementation must be used.
+     * The Java class name of the ClassLoader implementation to be used. This class should extend WebappClassLoaderBase,
+     * otherwise, a different loader implementation must be used.
      */
     private String loaderClass = ParallelWebappClassLoader.class.getName();
 
@@ -159,8 +152,7 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /**
-     * Return the "follow standard delegation model" flag used to configure
-     * our ClassLoader.
+     * Return the "follow standard delegation model" flag used to configure our ClassLoader.
      */
     @Override
     public boolean getDelegate() {
@@ -169,8 +161,7 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /**
-     * Set the "follow standard delegation model" flag used to configure
-     * our ClassLoader.
+     * Set the "follow standard delegation model" flag used to configure our ClassLoader.
      *
      * @param delegate The new flag
      */
@@ -178,15 +169,13 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
     public void setDelegate(boolean delegate) {
         boolean oldDelegate = this.delegate;
         this.delegate = delegate;
-        support.firePropertyChange("delegate", Boolean.valueOf(oldDelegate),
-                                   Boolean.valueOf(this.delegate));
+        support.firePropertyChange("delegate", Boolean.valueOf(oldDelegate), Boolean.valueOf(this.delegate));
     }
 
 
     /**
-     * @return a non null String if the loader will attempt to use the
-     *  Jakarta converter. The String is the name of the profile
-     *  used for conversion.
+     * @return a non null String if the loader will attempt to use the Jakarta converter. The String is the name of the
+     *             profile used for conversion.
      */
     public String getJakartaConverter() {
         return jakartaConverter;
@@ -196,16 +185,13 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
     /**
      * Set the Jakarta converter.
      *
-     * @param jakartaConverter The profile name which will be used by the converter
-     *   Any invalid profile value will default to the TOMCAT profile, which
-     *   converts all packages used by Tomcat.
+     * @param jakartaConverter The profile name which will be used by the converter Any invalid profile value will
+     *                             default to the TOMCAT profile, which converts all packages used by Tomcat.
      */
     public void setJakartaConverter(String jakartaConverter) {
         String oldJakartaConverter = this.jakartaConverter;
         this.jakartaConverter = jakartaConverter;
-        support.firePropertyChange("jakartaConverter",
-                oldJakartaConverter,
-                this.jakartaConverter);
+        support.firePropertyChange("jakartaConverter", oldJakartaConverter, this.jakartaConverter);
     }
 
 
@@ -227,9 +213,8 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
     }
 
     /**
-     * Set the ClassLoader instance, without relying on reflection
-     * This method will also invoke {@link #setLoaderClass(String)} with
-     * {@code loaderInstance.getClass().getName()} as an argument
+     * Set the ClassLoader instance, without relying on reflection This method will also invoke
+     * {@link #setLoaderClass(String)} with {@code loaderInstance.getClass().getName()} as an argument
      *
      * @param loaderInstance The new ClassLoader instance to use
      */
@@ -254,9 +239,8 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /**
-     * Execute a periodic task, such as reloading, etc. This method will be
-     * invoked inside the classloading context of this container. Unexpected
-     * throwables will be caught and logged.
+     * Execute a periodic task, such as reloading, etc. This method will be invoked inside the classloading context of
+     * this container. Unexpected throwables will be caught and logged.
      */
     @Override
     public void backgroundProcess() {
@@ -289,8 +273,8 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
     }
 
     public String getLoaderRepositoriesString() {
-        String repositories[]=getLoaderRepositories();
-        StringBuilder sb=new StringBuilder();
+        String repositories[] = getLoaderRepositories();
+        StringBuilder sb = new StringBuilder();
         for (String repository : repositories) {
             sb.append(repository).append(':');
         }
@@ -299,8 +283,7 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /**
-     * Classpath, as set in org.apache.catalina.jsp_classpath context
-     * property
+     * Classpath, as set in org.apache.catalina.jsp_classpath context property
      *
      * @return The classpath
      */
@@ -310,12 +293,12 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /**
-     * Has the internal repository associated with this Loader been modified,
-     * such that the loaded classes should be reloaded?
+     * Has the internal repository associated with this Loader been modified, such that the loaded classes should be
+     * reloaded?
      */
     @Override
     public boolean modified() {
-        return classLoader != null ? classLoader.modified() : false ;
+        return classLoader != null ? classLoader.modified() : false;
     }
 
 
@@ -340,11 +323,11 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /**
-     * Start associated {@link ClassLoader} and implement the requirements
-     * of {@link org.apache.catalina.util.LifecycleBase#startInternal()}.
+     * Start associated {@link ClassLoader} and implement the requirements of
+     * {@link org.apache.catalina.util.LifecycleBase#startInternal()}.
      *
-     * @exception LifecycleException if this component detects a fatal error
-     *  that prevents this component from being used
+     * @exception LifecycleException if this component detects a fatal error that prevents this component from being
+     *                                   used
      */
     @Override
     protected void startInternal() throws LifecycleException {
@@ -382,11 +365,10 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
             if (!contextName.startsWith("/")) {
                 contextName = "/" + contextName;
             }
-            ObjectName cloname = new ObjectName(context.getDomain() + ":type=" +
-                    classLoader.getClass().getSimpleName() + ",host=" +
-                    context.getParent().getName() + ",context=" + contextName);
-            Registry.getRegistry(null, null)
-                .registerComponent(classLoader, cloname, null);
+            ObjectName cloname =
+                    new ObjectName(context.getDomain() + ":type=" + classLoader.getClass().getSimpleName() + ",host=" +
+                            context.getParent().getName() + ",context=" + contextName);
+            Registry.getRegistry(null, null).registerComponent(classLoader, cloname, null);
 
         } catch (Throwable t) {
             t = ExceptionUtils.unwrapInvocationTargetException(t);
@@ -399,11 +381,11 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /**
-     * Stop associated {@link ClassLoader} and implement the requirements
-     * of {@link org.apache.catalina.util.LifecycleBase#stopInternal()}.
+     * Stop associated {@link ClassLoader} and implement the requirements of
+     * {@link org.apache.catalina.util.LifecycleBase#stopInternal()}.
      *
-     * @exception LifecycleException if this component detects a fatal error
-     *  that prevents this component from being used
+     * @exception LifecycleException if this component detects a fatal error that prevents this component from being
+     *                                   used
      */
     @Override
     protected void stopInternal() throws LifecycleException {
@@ -432,9 +414,9 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
                 if (!contextName.startsWith("/")) {
                     contextName = "/" + contextName;
                 }
-                ObjectName cloname = new ObjectName(context.getDomain() + ":type=" +
-                        classLoader.getClass().getSimpleName() + ",host=" +
-                        context.getParent().getName() + ",context=" + contextName);
+                ObjectName cloname =
+                        new ObjectName(context.getDomain() + ":type=" + classLoader.getClass().getSimpleName() +
+                                ",host=" + context.getParent().getName() + ",context=" + contextName);
                 Registry.getRegistry(null, null).unregisterComponent(cloname);
             } catch (Exception e) {
                 log.warn(sm.getString("webappLoader.stopError"), e);
@@ -451,8 +433,7 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
     /**
      * Create associated classLoader.
      */
-    private WebappClassLoaderBase createClassLoader()
-        throws Exception {
+    private WebappClassLoaderBase createClassLoader() throws Exception {
 
         if (classLoader != null) {
             return classLoader;
@@ -492,30 +473,25 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
         ServletContext servletContext = context.getServletContext();
 
         // Assigning permissions for the work directory
-        File workDir =
-            (File) servletContext.getAttribute(ServletContext.TEMPDIR);
+        File workDir = (File) servletContext.getAttribute(ServletContext.TEMPDIR);
         if (workDir != null) {
             try {
                 String workDirPath = workDir.getCanonicalPath();
-                classLoader.addPermission
-                    (new FilePermission(workDirPath, "read,write"));
-                classLoader.addPermission
-                    (new FilePermission(workDirPath + File.separator + "-",
-                                        "read,write,delete"));
+                classLoader.addPermission(new FilePermission(workDirPath, "read,write"));
+                classLoader.addPermission(new FilePermission(workDirPath + File.separator + "-", "read,write,delete"));
             } catch (IOException e) {
                 // Ignore
             }
         }
 
         for (URL url : context.getResources().getBaseUrls()) {
-           classLoader.addPermission(url);
+            classLoader.addPermission(url);
         }
     }
 
 
     /**
-     * Set the appropriate context attribute for our class path.  This
-     * is required only because Jasper depends on it.
+     * Set the appropriate context attribute for our class path. This is required only because Jasper depends on it.
      */
     private void setClassPath() {
 
@@ -580,7 +556,7 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
                 }
                 classpath.append(repository);
             }
-        } else if (loader == ClassLoader.getSystemClassLoader()){
+        } else if (loader == ClassLoader.getSystemClassLoader()) {
             // From Java 9 the internal class loaders no longer extend
             // URLCLassLoader
             String cp = System.getProperty("java.class.path");
@@ -628,9 +604,8 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
 
 
     /*
-     * Implemented in a sub-class so EESpecProfile and EESpecProfiles are not
-     * loaded unless a profile is configured. Otherwise, tomcat-embed-core.jar
-     * has a runtime dependency on the migration tool whether it is used or not.
+     * Implemented in a sub-class so EESpecProfile and EESpecProfiles are not loaded unless a profile is configured.
+     * Otherwise, tomcat-embed-core.jar has a runtime dependency on the migration tool whether it is used or not.
      */
     private static class MigrationUtil {
 
@@ -642,7 +617,7 @@ public class WebappLoader extends LifecycleMBeanBase implements Loader {
                 // Use default value
                 log.warn(sm.getString("webappLoader.unknownProfile", profileName));
             }
-            webappClassLoader.addTransformer((profile != null) ? new ClassConverter(profile) : new ClassConverter());
+            webappClassLoader.addTransformer(profile != null ? new ClassConverter(profile) : new ClassConverter());
         }
     }
 }
