@@ -38,13 +38,14 @@ import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
 import javax.naming.Binding;
 import javax.naming.NamingEnumeration;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.ServletInputStream;
-import javax.servlet.UnavailableException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletInputStream;
+import jakarta.servlet.UnavailableException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.catalina.Container;
 import org.apache.catalina.ContainerServlet;
@@ -144,6 +145,9 @@ import org.apache.tomcat.util.security.Escape;
  * <li><b>debug</b> - The debugging detail level that controls the amount of information that is logged by this servlet.
  * Default is zero.
  * </ul>
+ *
+ * @author Craig R. McClanahan
+ * @author Remy Maucherat
  */
 public class ManagerServlet extends HttpServlet implements ContainerServlet {
 
@@ -215,12 +219,20 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     // ----------------------------------------------- ContainerServlet Methods
 
 
+    /**
+     * Return the Wrapper with which we are associated.
+     */
     @Override
     public Wrapper getWrapper() {
         return this.wrapper;
     }
 
 
+    /**
+     * Set the Wrapper with which we are associated.
+     *
+     * @param wrapper The new wrapper
+     */
     @Override
     public void setWrapper(Wrapper wrapper) {
 
@@ -242,7 +254,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
         }
 
         // Retrieve the MBean server
-        mBeanServer = Registry.getRegistry(null).getMBeanServer();
+        mBeanServer = Registry.getRegistry(null, null).getMBeanServer();
 
     }
 
@@ -250,6 +262,9 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     // --------------------------------------------------------- Public Methods
 
 
+    /**
+     * Finalize this servlet.
+     */
     @Override
     public void destroy() {
 
@@ -258,6 +273,15 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     }
 
 
+    /**
+     * Process a GET request for the specified resource.
+     *
+     * @param request  The servlet request we are processing
+     * @param response The servlet response we are creating
+     *
+     * @exception IOException      if an input/output error occurs
+     * @exception ServletException if a servlet-specified error occurs
+     */
     @Override
     public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
 
@@ -283,10 +307,16 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
 
         String type = request.getParameter("type");
         String tag = request.getParameter("tag");
-        boolean update = request.getParameter("update") != null && request.getParameter("update").equals("true");
+        boolean update = false;
+        if (request.getParameter("update") != null && request.getParameter("update").equals("true")) {
+            update = true;
+        }
         String tlsHostName = request.getParameter("tlsHostName");
 
-        boolean statusLine = "true".equals(request.getParameter("statusLine"));
+        boolean statusLine = false;
+        if ("true".equals(request.getParameter("statusLine"))) {
+            statusLine = true;
+        }
 
         // Prepare our output writer to generate the response message
         response.setContentType("text/plain; charset=" + Constants.CHARSET);
@@ -352,6 +382,15 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     }
 
 
+    /**
+     * Process a PUT request for the specified resource.
+     *
+     * @param request  The servlet request we are processing
+     * @param response The servlet response we are creating
+     *
+     * @exception IOException      if an input/output error occurs
+     * @exception ServletException if a servlet-specified error occurs
+     */
     @Override
     public void doPut(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
 
@@ -369,7 +408,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
         }
         String config = request.getParameter("config");
         String tag = request.getParameter("tag");
-        boolean update = request.getParameter("update") != null && request.getParameter("update").equals("true");
+        boolean update = false;
+        if (request.getParameter("update") != null && request.getParameter("update").equals("true")) {
+            update = true;
+        }
 
         // Prepare our output writer to generate the response message
         response.setContentType("text/plain;charset=" + Constants.CHARSET);
@@ -395,6 +437,9 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     }
 
 
+    /**
+     * Initialize this servlet.
+     */
     @Override
     public void init() throws ServletException {
 
@@ -404,7 +449,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
         }
 
         // Set our properties from the initialization parameters
-        String value;
+        String value = null;
         try {
             value = getServletConfig().getInitParameter("debug");
             debug = Integer.parseInt(value);
@@ -489,21 +534,21 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
 
 
     protected void sslReload(PrintWriter writer, String tlsHostName, StringManager smClient) {
-        Connector[] connectors = getConnectors();
+        Connector connectors[] = getConnectors();
         boolean found = false;
         for (Connector connector : connectors) {
             if (Boolean.TRUE.equals(connector.getProperty("SSLEnabled"))) {
                 ProtocolHandler protocol = connector.getProtocolHandler();
                 if (protocol instanceof AbstractHttp11Protocol<?>) {
                     AbstractHttp11Protocol<?> http11Protoocol = (AbstractHttp11Protocol<?>) protocol;
-                    if (tlsHostName == null || tlsHostName.isEmpty()) {
+                    if (tlsHostName == null || tlsHostName.length() == 0) {
                         found = true;
                         http11Protoocol.reloadSslHostConfigs();
                     } else {
                         SSLHostConfig[] sslHostConfigs = http11Protoocol.findSslHostConfigs();
                         for (SSLHostConfig sslHostConfig : sslHostConfigs) {
-                            // tlsHostName is as provided by the user so use a case-insensitive
-                            // comparison as host names are case-insensitive.
+                            // tlsHostName is as provided by the user so use a case insensitive
+                            // comparison as host names are case insensitive.
                             if (sslHostConfig.getHostName().equalsIgnoreCase(tlsHostName)) {
                                 found = true;
                                 http11Protoocol.reloadSslHostConfig(tlsHostName);
@@ -514,7 +559,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
             }
         }
         if (found) {
-            if (tlsHostName == null || tlsHostName.isEmpty()) {
+            if (tlsHostName == null || tlsHostName.length() == 0) {
                 writer.println(smClient.getString("managerServlet.sslReloadAll"));
             } else {
                 writer.println(smClient.getString("managerServlet.sslReload", tlsHostName));
@@ -612,7 +657,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
             return;
         }
 
-        if (path == null || !path.startsWith("/")) {
+        if (path == null || path.length() == 0 || !path.startsWith("/")) {
             try {
                 mBeanServer.invoke(storeConfigOname, "storeConfig", null, null);
                 writer.println(smClient.getString("managerServlet.saved"));
@@ -660,7 +705,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected void deploy(PrintWriter writer, String config, ContextName cn, String tag, boolean update,
             HttpServletRequest request, StringManager smClient) {
 
-        if (config != null && config.isEmpty()) {
+        if (config != null && config.length() == 0) {
             config = null;
         }
 
@@ -729,10 +774,8 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                             writer.println(smClient.getString("managerServlet.mkdirFail", configBase));
                             return;
                         }
-                        if (!ExpandWar.copy(new File(config), new File(configBase, baseName + ".xml"))) {
-                            writer.println(smClient.getString("managerServlet.copyFail", new File(config),
-                                    new File(configBase, baseName + ".xml")));
-                            return;
+                        if (ExpandWar.copy(new File(config), new File(configBase, baseName + ".xml")) == false) {
+                            throw new Exception(sm.getString("managerServlet.copyError", config));
                         }
                     }
                     // Upload WAR
@@ -750,10 +793,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                     }
                     if (tag != null) {
                         // Copy WAR to the host's appBase
-                        if (!ExpandWar.copy(uploadedWar, deployedWar)) {
-                            writer.println(smClient.getString("managerServlet.copyFail", uploadedWar, deployedWar));
-                            return;
-                        }
+                        ExpandWar.copy(uploadedWar, deployedWar);
                     }
                 } finally {
                     removeServiced(name);
@@ -807,10 +847,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                         writer.println(smClient.getString("managerServlet.deleteFail", deployedWar));
                         return;
                     }
-                    if (!ExpandWar.copy(localWar, deployedWar)) {
-                        writer.println(smClient.getString("managerServlet.copyFail", localWar, deployedWar));
-                        return;
-                    }
+                    ExpandWar.copy(localWar, deployedWar);
                 } finally {
                     removeServiced(name);
                 }
@@ -842,10 +879,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected void deploy(PrintWriter writer, String config, ContextName cn, String war, boolean update,
             StringManager smClient) {
 
-        if (config != null && config.isEmpty()) {
+        if (config != null && config.length() == 0) {
             config = null;
         }
-        if (war != null && war.isEmpty()) {
+        if (war != null && war.length() == 0) {
             war = null;
         }
 
@@ -904,11 +941,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                                 writer.println(smClient.getString("managerServlet.deleteFail", localConfigFile));
                                 return;
                             }
-                            if (!ExpandWar.copy(configFile, localConfigFile)) {
-                                writer.println(
-                                        smClient.getString("managerServlet.copyFail", configFile, localConfigFile));
-                                return;
-                            }
+                            ExpandWar.copy(configFile, localConfigFile);
                         }
                     }
                     if (war != null) {
@@ -919,19 +952,13 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                             localWarFile = new File(host.getAppBaseFile(), baseName);
                         }
                         File warFile = new File(war);
-                        if (!warFile.isAbsolute()) {
-                            warFile = new File(host.getAppBaseFile(), war);
-                        }
                         // Skip delete and copy if source == destination
                         if (!warFile.getCanonicalPath().equals(localWarFile.getCanonicalPath())) {
                             if (localWarFile.exists() && !ExpandWar.delete(localWarFile)) {
                                 writer.println(smClient.getString("managerServlet.deleteFail", localWarFile));
                                 return;
                             }
-                            if (!ExpandWar.copy(warFile, localWarFile)) {
-                                writer.println(smClient.getString("managerServlet.copyFail", warFile, localWarFile));
-                                return;
-                            }
+                            ExpandWar.copy(warFile, localWarFile);
                         }
                     }
                 } finally {
@@ -983,10 +1010,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
             Context context = (Context) container;
             if (context != null) {
                 String displayPath = context.getPath();
-                if (displayPath.isEmpty()) {
+                if (displayPath.equals("")) {
                     displayPath = "/";
                 }
-                List<String> parts;
+                List<String> parts = null;
                 if (context.getState().isAvailable()) {
                     parts = Arrays.asList(displayPath, "running", "" + context.getManager().findSessions().length,
                             context.getDocBase());
@@ -1075,27 +1102,6 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     }
 
 
-    /**
-     * List the resources of the given context.
-     *
-     * @param writer        Writer to render to
-     * @param prefix        Path for recursion
-     * @param namingContext The naming context for lookups
-     * @param type          Fully qualified class name of the resource type of interest, or <code>null</code> to list
-     *                          resources of all types
-     * @param clazz         Unused
-     * @param smClient      i18n support for current client's locale
-     *
-     * @deprecated Use {@link #printResources(PrintWriter, String, javax.naming.Context, String, StringManager)} This
-     *                 method will be removed in Tomcat 10.x onwards
-     */
-    @Deprecated
-    protected void printResources(PrintWriter writer, String prefix, javax.naming.Context namingContext, String type,
-            Class<?> clazz, StringManager smClient) {
-        printResources(writer, prefix, namingContext, type, smClient);
-    }
-
-
     /**
      * List the resources of the given context.
      *
@@ -1469,43 +1475,6 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     }
 
 
-    /**
-     * Invoke the isServiced method on the deployer.
-     *
-     * @param name The webapp name
-     *
-     * @return <code>true</code> if a webapp with that name is being serviced
-     *
-     * @throws Exception Propagate JMX invocation error
-     *
-     * @deprecated Unused. Will be removed in Tomcat 10.1.x onwards.
-     */
-    @Deprecated
-    protected boolean isServiced(String name) throws Exception {
-        String[] params = { name };
-        String[] signature = { "java.lang.String" };
-        Boolean result = (Boolean) mBeanServer.invoke(oname, "isServiced", params, signature);
-        return result.booleanValue();
-    }
-
-
-    /**
-     * Invoke the addServiced method on the deployer.
-     *
-     * @param name The webapp name
-     *
-     * @throws Exception Propagate JMX invocation error
-     *
-     * @deprecated Unused. Will be removed in Tomcat 10.1.x onwards. Use {@link #tryAddServiced}
-     */
-    @Deprecated
-    protected void addServiced(String name) throws Exception {
-        String[] params = { name };
-        String[] signature = { "java.lang.String" };
-        mBeanServer.invoke(oname, "addServiced", params, signature);
-    }
-
-
     /**
      * Attempt to mark a context as being serviced
      *
@@ -1558,11 +1527,11 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
 
         try (ServletInputStream istream = request.getInputStream(); OutputStream ostream = new FileOutputStream(war)) {
             IOTools.flow(istream, ostream);
-        } catch (IOException ioe) {
+        } catch (IOException e) {
             if (war.exists() && !war.delete()) {
                 writer.println(smClient.getString("managerServlet.deleteFail", war));
             }
-            throw ioe;
+            throw e;
         }
     }
 
@@ -1571,7 +1540,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
 
         // ContextName should be non-null with a path that is empty or starts
         // with /
-        if (cn != null && (cn.getPath().startsWith("/") || cn.getPath().isEmpty())) {
+        if (cn != null && (cn.getPath().startsWith("/") || cn.getPath().equals(""))) {
             return true;
         }
 
@@ -1586,7 +1555,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected Map<String,List<String>> getConnectorCiphers(StringManager smClient) {
         Map<String,List<String>> result = new HashMap<>();
 
-        Connector[] connectors = getConnectors();
+        Connector connectors[] = getConnectors();
         for (Connector connector : connectors) {
             if (Boolean.TRUE.equals(connector.getProperty("SSLEnabled"))) {
                 SSLHostConfig[] sslHostConfigs = connector.getProtocolHandler().findSslHostConfigs();
@@ -1609,24 +1578,23 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected Map<String,List<String>> getConnectorCerts(StringManager smClient) {
         Map<String,List<String>> result = new HashMap<>();
 
-        Connector[] connectors = getConnectors();
+        Connector connectors[] = getConnectors();
         for (Connector connector : connectors) {
             if (Boolean.TRUE.equals(connector.getProperty("SSLEnabled"))) {
                 SSLHostConfig[] sslHostConfigs = connector.getProtocolHandler().findSslHostConfigs();
                 for (SSLHostConfig sslHostConfig : sslHostConfigs) {
-                    Set<SSLHostConfigCertificate> sslHostConfigCerts = sslHostConfig.getCertificates();
-                    for (SSLHostConfigCertificate sslHostConfigCert : sslHostConfigCerts) {
-                        String name = connector.toString() + "-" + sslHostConfig.getHostName() + "-" +
-                                sslHostConfigCert.getType();
-                        List<String> certList = new ArrayList<>();
-                        SSLContext sslContext = sslHostConfigCert.getSslContext();
-                        String alias = sslHostConfigCert.getCertificateKeyAlias();
-                        if (alias == null) {
-                            alias = SSLUtilBase.DEFAULT_KEY_ALIAS;
-                        }
-                        if (sslContext == null) {
-                            certList.add(smClient.getString("managerServlet.certsNotLoaded"));
-                        } else {
+                    if (sslHostConfig.getOpenSslContext().longValue() == 0) {
+                        // Not set. Must be JSSE based.
+                        Set<SSLHostConfigCertificate> sslHostConfigCerts = sslHostConfig.getCertificates();
+                        for (SSLHostConfigCertificate sslHostConfigCert : sslHostConfigCerts) {
+                            String name = connector.toString() + "-" + sslHostConfig.getHostName() + "-" +
+                                    sslHostConfigCert.getType();
+                            List<String> certList = new ArrayList<>();
+                            SSLContext sslContext = sslHostConfigCert.getSslContext();
+                            String alias = sslHostConfigCert.getCertificateKeyAlias();
+                            if (alias == null) {
+                                alias = SSLUtilBase.DEFAULT_KEY_ALIAS;
+                            }
                             X509Certificate[] certs = sslContext.getCertificateChain(alias);
                             if (certs == null) {
                                 certList.add(smClient.getString("managerServlet.certsNotAvailable"));
@@ -1635,7 +1603,12 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                                     certList.add(cert.toString());
                                 }
                             }
+                            result.put(name, certList);
                         }
+                    } else {
+                        List<String> certList = new ArrayList<>();
+                        certList.add(smClient.getString("managerServlet.certsNotAvailable"));
+                        String name = connector.toString() + "-" + sslHostConfig.getHostName();
                         result.put(name, certList);
                     }
                 }
@@ -1653,17 +1626,16 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected Map<String,List<String>> getConnectorTrustedCerts(StringManager smClient) {
         Map<String,List<String>> result = new HashMap<>();
 
-        Connector[] connectors = getConnectors();
+        Connector connectors[] = getConnectors();
         for (Connector connector : connectors) {
             if (Boolean.TRUE.equals(connector.getProperty("SSLEnabled"))) {
                 SSLHostConfig[] sslHostConfigs = connector.getProtocolHandler().findSslHostConfigs();
                 for (SSLHostConfig sslHostConfig : sslHostConfigs) {
                     String name = connector.toString() + "-" + sslHostConfig.getHostName();
                     List<String> certList = new ArrayList<>();
-                    SSLContext sslContext = sslHostConfig.getCertificates().iterator().next().getSslContext();
-                    if (sslContext == null) {
-                        certList.add(smClient.getString("managerServlet.certsNotLoaded"));
-                    } else {
+                    if (sslHostConfig.getOpenSslContext().longValue() == 0) {
+                        // Not set. Must be JSSE based.
+                        SSLContext sslContext = sslHostConfig.getCertificates().iterator().next().getSslContext();
                         X509Certificate[] certs = sslContext.getAcceptedIssuers();
                         if (certs == null) {
                             certList.add(smClient.getString("managerServlet.certsNotAvailable"));
@@ -1674,6 +1646,8 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                                 certList.add(cert.toString());
                             }
                         }
+                    } else {
+                        certList.add(smClient.getString("managerServlet.certsNotAvailable"));
                     }
                     result.put(name, certList);
                 }
