@@ -20,9 +20,11 @@ import java.io.IOException;
 import java.io.PrintWriter;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
+import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Set;
-import java.util.Vector;
 
 import javax.management.MBeanServer;
 import javax.management.MBeanServerNotification;
@@ -30,10 +32,11 @@ import javax.management.Notification;
 import javax.management.NotificationListener;
 import javax.management.ObjectInstance;
 import javax.management.ObjectName;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.catalina.util.ServerInfo;
 import org.apache.tomcat.util.modeler.Registry;
@@ -55,31 +58,22 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
     protected MBeanServer mBeanServer = null;
 
 
-    /**
-     * Vector of protocol handlers object names.
-     *
-     * @deprecated Unused. Will be removed in Tomcat 10.1.x
-     */
-    @Deprecated
-    protected final Vector<ObjectName> protocolHandlers = new Vector<>();
-
-
     /**
      * Vector of thread pools object names.
      */
-    protected final Vector<ObjectName> threadPools = new Vector<>();
+    protected final List<ObjectName> threadPools = Collections.synchronizedList(new ArrayList<>());
 
 
     /**
      * Vector of request processors object names.
      */
-    protected final Vector<ObjectName> requestProcessors = new Vector<>();
+    protected final List<ObjectName> requestProcessors = Collections.synchronizedList(new ArrayList<>());
 
 
     /**
      * Vector of global request processors object names.
      */
-    protected final Vector<ObjectName> globalRequestProcessors = new Vector<>();
+    protected final List<ObjectName> globalRequestProcessors = Collections.synchronizedList(new ArrayList<>());
 
 
     /**
@@ -90,32 +84,25 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
 
     // --------------------------------------------------------- Public Methods
 
+    /**
+     * Initialize this servlet.
+     */
     @Override
     public void init() throws ServletException {
 
         // Retrieve the MBean server
-        mBeanServer = Registry.getRegistry(null).getMBeanServer();
+        mBeanServer = Registry.getRegistry(null, null).getMBeanServer();
 
         try {
 
-            // Query protocol handlers
-            String onStr = "*:type=ProtocolHandler,*";
+            // Query Thread Pools
+            String onStr = "*:type=ThreadPool,*";
             ObjectName objectName = new ObjectName(onStr);
             Set<ObjectInstance> set = mBeanServer.queryMBeans(objectName, null);
             Iterator<ObjectInstance> iterator = set.iterator();
             while (iterator.hasNext()) {
                 ObjectInstance oi = iterator.next();
-                protocolHandlers.addElement(oi.getObjectName());
-            }
-
-            // Query Thread Pools
-            onStr = "*:type=ThreadPool,*";
-            objectName = new ObjectName(onStr);
-            set = mBeanServer.queryMBeans(objectName, null);
-            iterator = set.iterator();
-            while (iterator.hasNext()) {
-                ObjectInstance oi = iterator.next();
-                threadPools.addElement(oi.getObjectName());
+                threadPools.add(oi.getObjectName());
             }
 
             // Query Global Request Processors
@@ -125,7 +112,7 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
             iterator = set.iterator();
             while (iterator.hasNext()) {
                 ObjectInstance oi = iterator.next();
-                globalRequestProcessors.addElement(oi.getObjectName());
+                globalRequestProcessors.add(oi.getObjectName());
             }
 
             // Query Request Processors
@@ -135,7 +122,7 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
             iterator = set.iterator();
             while (iterator.hasNext()) {
                 ObjectInstance oi = iterator.next();
-                requestProcessors.addElement(oi.getObjectName());
+                requestProcessors.add(oi.getObjectName());
             }
 
             // Register with MBean server
@@ -150,6 +137,9 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
     }
 
 
+    /**
+     * Finalize this servlet.
+     */
     @Override
     public void destroy() {
 
@@ -166,6 +156,15 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
     }
 
 
+    /**
+     * Process a GET request for the specified resource.
+     *
+     * @param request  The servlet request we are processing
+     * @param response The servlet response we are creating
+     *
+     * @exception IOException      if an input/output error occurs
+     * @exception ServletException if a servlet-specified error occurs
+     */
     @Override
     public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
 
@@ -185,8 +184,10 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
 
         PrintWriter writer = response.getWriter();
 
-        boolean completeStatus = request.getPathInfo() != null && request.getPathInfo().equals("/all");
-
+        boolean completeStatus = false;
+        if (request.getPathInfo() != null && request.getPathInfo().equals("/all")) {
+            completeStatus = true;
+        }
         // use StatusTransformer to output status
         Object[] args = new Object[1];
         args[0] = getServletContext().getContextPath();
@@ -260,17 +261,6 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
 
         try {
 
-            // Display operating system statistics using APR if available
-            args = new Object[7];
-            args[0] = smClient.getString("htmlManagerServlet.osPhysicalMemory");
-            args[1] = smClient.getString("htmlManagerServlet.osAvailableMemory");
-            args[2] = smClient.getString("htmlManagerServlet.osTotalPageFile");
-            args[3] = smClient.getString("htmlManagerServlet.osFreePageFile");
-            args[4] = smClient.getString("htmlManagerServlet.osMemoryLoad");
-            args[5] = smClient.getString("htmlManagerServlet.osKernelTime");
-            args[6] = smClient.getString("htmlManagerServlet.osUserTime");
-            StatusTransformer.writeOSState(writer, mode, args);
-
             // Display virtual machine statistics
             args = new Object[9];
             args[0] = smClient.getString("htmlManagerServlet.jvmFreeMemory");
@@ -333,27 +323,23 @@ public class StatusManagerServlet extends HttpServlet implements NotificationLis
             if (notification.getType().equals(MBeanServerNotification.REGISTRATION_NOTIFICATION)) {
                 String type = objectName.getKeyProperty("type");
                 if (type != null) {
-                    if (type.equals("ProtocolHandler")) {
-                        protocolHandlers.addElement(objectName);
-                    } else if (type.equals("ThreadPool")) {
-                        threadPools.addElement(objectName);
+                    if (type.equals("ThreadPool")) {
+                        threadPools.add(objectName);
                     } else if (type.equals("GlobalRequestProcessor")) {
-                        globalRequestProcessors.addElement(objectName);
+                        globalRequestProcessors.add(objectName);
                     } else if (type.equals("RequestProcessor")) {
-                        requestProcessors.addElement(objectName);
+                        requestProcessors.add(objectName);
                     }
                 }
             } else if (notification.getType().equals(MBeanServerNotification.UNREGISTRATION_NOTIFICATION)) {
                 String type = objectName.getKeyProperty("type");
                 if (type != null) {
-                    if (type.equals("ProtocolHandler")) {
-                        protocolHandlers.removeElement(objectName);
-                    } else if (type.equals("ThreadPool")) {
-                        threadPools.removeElement(objectName);
+                    if (type.equals("ThreadPool")) {
+                        threadPools.remove(objectName);
                     } else if (type.equals("GlobalRequestProcessor")) {
-                        globalRequestProcessors.removeElement(objectName);
+                        globalRequestProcessors.remove(objectName);
                     } else if (type.equals("RequestProcessor")) {
-                        requestProcessors.removeElement(objectName);
+                        requestProcessors.remove(objectName);
                     }
                 }
             }
