@@ -20,27 +20,28 @@ import java.io.PrintWriter;
 import java.lang.management.ManagementFactory;
 import java.lang.management.MemoryPoolMXBean;
 import java.lang.management.MemoryUsage;
-import java.lang.reflect.Method;
 import java.text.MessageFormat;
 import java.util.Date;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
-import java.util.Vector;
 
 import javax.management.MBeanServer;
 import javax.management.ObjectInstance;
 import javax.management.ObjectName;
-import javax.servlet.http.HttpServletResponse;
 
-import org.apache.tomcat.util.ExceptionUtils;
+import jakarta.servlet.http.HttpServletResponse;
+
 import org.apache.tomcat.util.json.JSONFilter;
 import org.apache.tomcat.util.security.Escape;
 
 /**
  * This is a refactoring of the servlet to externalize the output into a simple class. Although we could use XSLT, that
  * is unnecessarily complex.
+ *
+ * @author Peter Lin
  */
 public class StatusTransformer {
 
@@ -132,71 +133,6 @@ public class StatusTransformer {
     }
 
 
-    /**
-     * Write the OS state.
-     *
-     * @param writer The output writer
-     * @param mode   Mode <code>0</code> will generate HTML. Mode <code>1</code> will generate XML.
-     * @param args   I18n labels for the OS state values
-     */
-    public static void writeOSState(PrintWriter writer, int mode, Object[] args) {
-        long[] result = new long[16];
-        boolean ok = false;
-        try {
-            String methodName = "info";
-            Class<?> paramTypes[] = new Class[1];
-            paramTypes[0] = result.getClass();
-            Object paramValues[] = new Object[1];
-            paramValues[0] = result;
-            Method method = Class.forName("org.apache.tomcat.jni.OS").getMethod(methodName, paramTypes);
-            method.invoke(null, paramValues);
-            ok = true;
-        } catch (Throwable t) {
-            t = ExceptionUtils.unwrapInvocationTargetException(t);
-            ExceptionUtils.handleThrowable(t);
-        }
-
-        if (ok) {
-            if (mode == 0) {
-                writer.print("<h1>OS</h1>");
-
-                writer.print("<p>");
-                writer.print(args[0]);
-                writer.print(' ');
-                writer.print(formatSize(Long.valueOf(result[0]), true));
-                writer.print(' ');
-                writer.print(args[1]);
-                writer.print(' ');
-                writer.print(formatSize(Long.valueOf(result[1]), true));
-                writer.print(' ');
-                writer.print(args[2]);
-                writer.print(' ');
-                writer.print(formatSize(Long.valueOf(result[2]), true));
-                writer.print(' ');
-                writer.print(args[3]);
-                writer.print(' ');
-                writer.print(formatSize(Long.valueOf(result[3]), true));
-                writer.print(' ');
-                writer.print(args[4]);
-                writer.print(' ');
-                writer.print(Long.valueOf(result[6]));
-                writer.print("<br>");
-                writer.print(args[5]);
-                writer.print(' ');
-                writer.print(formatTime(Long.valueOf(result[11] / 1000), true));
-                writer.print(' ');
-                writer.print(args[6]);
-                writer.print(' ');
-                writer.print(formatTime(Long.valueOf(result[12] / 1000), true));
-                writer.print("</p>");
-            } else if (mode == 1) {
-                // NO-OP
-            }
-        }
-
-    }
-
-
     /**
      * Write the VM state.
      *
@@ -275,57 +211,42 @@ public class StatusTransformer {
 
             writer.write("</jvm>");
         } else if (mode == 2) {
-            indent(writer, 1).append('"').append("jvm").append('"').append(':').append('{').println();
+            writer.append('"').append("jvm").append('"').append(':').append('{').println();
 
-            indent(writer, 2).append('"').append("memory").append('"').append(':').append('{');
-            appendJSonValue(writer, "free", Long.valueOf(Runtime.getRuntime().freeMemory())).append(',');
-            appendJSonValue(writer, "total", Long.valueOf(Runtime.getRuntime().totalMemory())).append(',');
-            appendJSonValue(writer, "max", Long.valueOf(Runtime.getRuntime().maxMemory()));
+            writer.append('"').append("memory").append('"').append(':').append('{');
+            appendJSonValue(writer, "free", Long.toString(Runtime.getRuntime().freeMemory())).append(',');
+            appendJSonValue(writer, "total", Long.toString(Runtime.getRuntime().totalMemory())).append(',');
+            appendJSonValue(writer, "max", Long.toString(Runtime.getRuntime().maxMemory()));
             writer.append('}').append(',').println();
 
-            indent(writer, 2).append('"').append("memorypool").append('"').append(':').append('[');
+            writer.append('"').append("memorypool").append('"').append(':').append('[');
             boolean first = true;
             for (MemoryPoolMXBean memoryPoolMBean : memoryPoolMBeans.values()) {
                 MemoryUsage usage = memoryPoolMBean.getUsage();
                 if (first) {
                     first = false;
-                    writer.println();
                 } else {
                     writer.append(',').println();
                 }
-                indent(writer, 3).append('{');
+                writer.append('{');
                 appendJSonValue(writer, "name", JSONFilter.escape(memoryPoolMBean.getName())).append(',');
                 appendJSonValue(writer, "type", memoryPoolMBean.getType().toString()).append(',');
-                appendJSonValue(writer, "usageInit", Long.valueOf(usage.getInit())).append(',');
-                appendJSonValue(writer, "usageCommitted", Long.valueOf(usage.getCommitted())).append(',');
-                appendJSonValue(writer, "usageMax", Long.valueOf(usage.getMax())).append(',');
-                appendJSonValue(writer, "usageUsed", Long.valueOf(usage.getUsed()));
+                appendJSonValue(writer, "usageInit", Long.toString(usage.getInit())).append(',');
+                appendJSonValue(writer, "usageCommitted", Long.toString(usage.getCommitted())).append(',');
+                appendJSonValue(writer, "usageMax", Long.toString(usage.getMax())).append(',');
+                appendJSonValue(writer, "usageUsed", Long.toString(usage.getUsed()));
                 writer.append('}');
             }
-            writer.println();
-            indent(writer, 2).append(']').println();
+            writer.append(']').println();
 
-            indent(writer, 1).append('}');
+            writer.append('}');
         }
 
     }
 
 
-    private static PrintWriter appendJSonValue(PrintWriter writer, String name, Object value) {
-        writer.append('"').append(name).append('"').append(':');
-        if (value instanceof Number) {
-            return writer.append(value.toString());
-        } else {
-            return writer.append('"').append(value.toString()).append('"');
-        }
-    }
-
-
-    private static PrintWriter indent(PrintWriter writer, int count) {
-        for (int i = 0; i < count; i++) {
-            writer.append(' ').append(' ');
-        }
-        return writer;
+    private static PrintWriter appendJSonValue(PrintWriter writer, String name, String value) {
+        return writer.append('"').append(name).append('"').append(':').append('"').append(value).append('"');
     }
 
 
@@ -342,12 +263,13 @@ public class StatusTransformer {
      *
      * @throws Exception Propagated JMX error
      */
-    public static void writeConnectorsState(PrintWriter writer, MBeanServer mBeanServer, Vector<ObjectName> threadPools,
-            Vector<ObjectName> globalRequestProcessors, Vector<ObjectName> requestProcessors, int mode, Object[] args)
+    public static void writeConnectorsState(PrintWriter writer, MBeanServer mBeanServer,
+            List<ObjectName> threadPools,
+            List<ObjectName> globalRequestProcessors, List<ObjectName> requestProcessors, int mode, Object[] args)
             throws Exception {
         if (mode == 2) {
             writer.append(',').println();
-            indent(writer, 1).append('"').append("connector").append('"').append(':').append('[').println();
+            writer.append('"').append("connector").append('"').append(':').append('[').println();
         }
         boolean first = true;
         for (ObjectName objectName : threadPools) {
@@ -360,11 +282,11 @@ public class StatusTransformer {
             }
             String name = objectName.getKeyProperty("name");
             // use StatusTransformer to output status
-            writeConnectorState(writer, objectName, name, mBeanServer, globalRequestProcessors, requestProcessors, mode,
-                    args);
+            writeConnectorState(
+                    writer, objectName, name, mBeanServer, globalRequestProcessors, requestProcessors, mode, args);
         }
         if (mode == 2) {
-            writer.append(']');
+            writer.append(']').println();
         }
     }
 
@@ -384,7 +306,7 @@ public class StatusTransformer {
      * @throws Exception Propagated JMX error
      */
     public static void writeConnectorState(PrintWriter writer, ObjectName tpName, String name, MBeanServer mBeanServer,
-            Vector<ObjectName> globalRequestProcessors, Vector<ObjectName> requestProcessors, int mode, Object[] args)
+            List<ObjectName> globalRequestProcessors, List<ObjectName> requestProcessors, int mode, Object[] args)
             throws Exception {
 
         if (mode == 0) {
@@ -454,7 +376,7 @@ public class StatusTransformer {
                     "</th><th>" + args[17] + "</th></tr>");
 
             for (ObjectName objectName : requestProcessors) {
-                if (name.equals(getConnectorName(objectName.getKeyProperty("worker")))) {
+                if (name.equals(objectName.getKeyProperty("worker"))) {
                     writer.print("<tr>");
                     writeProcessorState(writer, objectName, mBeanServer, mode);
                     writer.print("</tr>");
@@ -497,7 +419,7 @@ public class StatusTransformer {
 
                 writer.write("<workers>");
                 for (ObjectName objectName : requestProcessors) {
-                    if (name.equals(getConnectorName(objectName.getKeyProperty("worker")))) {
+                    if (name.equals(objectName.getKeyProperty("worker"))) {
                         writeProcessorState(writer, objectName, mBeanServer, mode);
                     }
                 }
@@ -506,19 +428,13 @@ public class StatusTransformer {
 
             writer.write("</connector>");
         } else if (mode == 2) {
-            indent(writer, 2).append('{').println();
+            writer.append('{').println();
 
-            indent(writer, 3);
-            String jsonName = JSONFilter.escape(name);
-            if (jsonName.length() > 4 && jsonName.startsWith("\\\"") && jsonName.endsWith("\\\"")) {
-                jsonName = jsonName.substring(2, jsonName.length() - 2);
-            }
-            appendJSonValue(writer, "name", jsonName).append(',').println();
-            indent(writer, 3).append('"').append("threadInfo").append('"').append(':').append('{');
-            appendJSonValue(writer, "maxThreads", mBeanServer.getAttribute(tpName, "maxThreads")).append(',');
-            appendJSonValue(writer, "currentThreadCount", mBeanServer.getAttribute(tpName, "currentThreadCount"))
-                    .append(',');
-            appendJSonValue(writer, "currentThreadsBusy", mBeanServer.getAttribute(tpName, "currentThreadsBusy"));
+            appendJSonValue(writer, "name", JSONFilter.escape(name)).append(',').println();
+            writer.append('"').append("threadInfo").append('"').append(':').append('{');
+            appendJSonValue(writer, "maxThreads", mBeanServer.getAttribute(tpName, "maxThreads").toString()).append(',');
+            appendJSonValue(writer, "currentThreadCount", mBeanServer.getAttribute(tpName, "currentThreadCount").toString()).append(',');
+            appendJSonValue(writer, "currentThreadsBusy", mBeanServer.getAttribute(tpName, "currentThreadsBusy").toString());
             writer.append('}');
 
             ObjectName grpName = null;
@@ -531,39 +447,22 @@ public class StatusTransformer {
 
             if (grpName != null) {
                 writer.append(',').println();
-                indent(writer, 3).append('"').append("requestInfo").append('"').append(':').append('{');
-                appendJSonValue(writer, "maxTime", mBeanServer.getAttribute(grpName, "maxTime")).append(',');
-                appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(grpName, "processingTime"))
-                        .append(',');
-                appendJSonValue(writer, "requestCount", mBeanServer.getAttribute(grpName, "requestCount")).append(',');
-                appendJSonValue(writer, "errorCount", mBeanServer.getAttribute(grpName, "errorCount")).append(',');
-                appendJSonValue(writer, "bytesReceived", mBeanServer.getAttribute(grpName, "bytesReceived"))
-                        .append(',');
-                appendJSonValue(writer, "bytesSent", mBeanServer.getAttribute(grpName, "bytesSent"));
+                writer.append('"').append("requestInfo").append('"').append(':').append('{');
+                appendJSonValue(writer, "maxTime", mBeanServer.getAttribute(grpName, "maxTime").toString()).append(',');
+                appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(grpName, "processingTime").toString()).append(',');
+                appendJSonValue(writer, "requestCount", mBeanServer.getAttribute(grpName, "requestCount").toString()).append(',');
+                appendJSonValue(writer, "errorCount", mBeanServer.getAttribute(grpName, "errorCount").toString()).append(',');
+                appendJSonValue(writer, "bytesReceived", mBeanServer.getAttribute(grpName, "bytesReceived").toString()).append(',');
+                appendJSonValue(writer, "bytesSent", mBeanServer.getAttribute(grpName, "bytesSent").toString());
                 writer.append('}').println();
                 // Note: No detailed per processor info
             }
 
-            indent(writer, 2).append('}');
+            writer.append('}');
         }
     }
 
 
-    /**
-     * Return the connector name without the port, for auto port connectors.
-     *
-     * @param name the connector name
-     *
-     * @return the name without the port for the auto connectors
-     */
-    protected static String getConnectorName(String name) {
-        if (name.indexOf("-auto-") > 0) {
-            return name.substring(0, name.lastIndexOf("-")) + "\"";
-        } else {
-            return name;
-        }
-    }
-
     /**
      * Write processor state.
      *
@@ -581,7 +480,7 @@ public class StatusTransformer {
         int stage = stageValue.intValue();
         boolean fullStatus = true;
         boolean showRequest = true;
-        String stageStr;
+        String stageStr = null;
 
         switch (stage) {
 
@@ -659,7 +558,7 @@ public class StatusTransformer {
                     writer.write(' ');
                     writer.write(Escape.htmlElementContent(mBeanServer.getAttribute(pName, "currentUri")));
                     String queryString = (String) mBeanServer.getAttribute(pName, "currentQueryString");
-                    if (queryString != null && !queryString.isEmpty()) {
+                    if (queryString != null && !queryString.equals("")) {
                         writer.write("?");
                         writer.print(Escape.htmlElementContent(queryString));
                     }
@@ -705,7 +604,7 @@ public class StatusTransformer {
                             Escape.htmlElementContent(mBeanServer.getAttribute(pName, "currentUri")) + "\"");
 
                     String queryString = (String) mBeanServer.getAttribute(pName, "currentQueryString");
-                    if (queryString != null && !queryString.isEmpty()) {
+                    if (queryString != null && !queryString.equals("")) {
                         writer.write(" currentQueryString=\"" + Escape.htmlElementContent(queryString) + "\"");
                     } else {
                         writer.write(" currentQueryString=\"&#63;\"");
@@ -793,7 +692,7 @@ public class StatusTransformer {
             // for now we don't write out the Detailed state in XML
         } else if (mode == 2) {
             writer.append(',').println();
-            indent(writer, 1).append('"').append("context").append('"').append(':').append('[').println();
+            writer.append('"').append("context").append('"').append(':').append('[');
             Iterator<ObjectName> iterator = hostsON.iterator();
             boolean first = true;
             while (iterator.hasNext()) {
@@ -805,8 +704,7 @@ public class StatusTransformer {
                 ObjectName contextON = iterator.next();
                 writeContext(writer, contextON, mBeanServer, mode);
             }
-            writer.println();
-            indent(writer, 1).append(']').println();
+            writer.append(']').println();
         }
 
     }
@@ -831,8 +729,8 @@ public class StatusTransformer {
             return;
         }
 
-        String hostName;
-        String contextName;
+        String hostName = null;
+        String contextName = null;
         if (name.startsWith("//")) {
             name = name.substring(2);
         }
@@ -893,13 +791,12 @@ public class StatusTransformer {
         } else if (mode == 1) {
             // for now we don't write out the context in XML
         } else if (mode == 2) {
-            indent(writer, 2).append('{').println();
-            appendJSonValue(indent(writer, 3), "name", JSONFilter.escape(JSONFilter.escape(name))).append(',');
+            writer.append('{');
+            appendJSonValue(writer, "name", JSONFilter.escape(JSONFilter.escape(name))).append(',');
             appendJSonValue(writer, "startTime",
-                    new Date(((Long) mBeanServer.getAttribute(objectName, "startTime")).longValue()).toString())
-                    .append(',');
-            appendJSonValue(writer, "startupTime", mBeanServer.getAttribute(objectName, "startupTime")).append(',');
-            appendJSonValue(writer, "tldScanTime", mBeanServer.getAttribute(objectName, "tldScanTime"));
+                    new Date(((Long) mBeanServer.getAttribute(objectName, "startTime")).longValue()).toString()).append(',');
+            appendJSonValue(writer, "startupTime", mBeanServer.getAttribute(objectName, "startupTime").toString()).append(',');
+            appendJSonValue(writer, "tldScanTime", mBeanServer.getAttribute(objectName, "tldScanTime").toString());
             if (managerON != null) {
                 writeManager(writer, managerON, mBeanServer, mode);
             }
@@ -907,7 +804,7 @@ public class StatusTransformer {
                 writeJspMonitor(writer, jspMonitorONs, mBeanServer, mode);
             }
             writer.append(',').println();
-            indent(writer, 3).append('"').append("wrapper").append('"').append(':').append('[').println();
+            writer.append('"').append("wrapper").append('"').append(':').append('[');
             String onStr = objectName.getDomain() + ":j2eeType=Servlet,WebModule=" + webModuleName + ",*";
             ObjectName servletObjectName = new ObjectName(onStr);
             Set<ObjectInstance> set = mBeanServer.queryMBeans(servletObjectName, null);
@@ -920,9 +817,8 @@ public class StatusTransformer {
                 }
                 writeWrapper(writer, oi.getObjectName(), mBeanServer, mode);
             }
-            writer.println();
-            indent(writer, 3).append(']').println();
-            indent(writer, 2).append('}');
+            writer.append(']').println();
+            writer.append('}');
         }
 
     }
@@ -963,21 +859,15 @@ public class StatusTransformer {
             // for now we don't write out the wrapper details
         } else if (mode == 2) {
             writer.append(',').println();
-            indent(writer, 3).append('"').append("manager").append('"').append(':').append('{');
-            appendJSonValue(writer, "activeSessions", mBeanServer.getAttribute(objectName, "activeSessions"))
-                    .append(',');
-            appendJSonValue(writer, "sessionCounter", mBeanServer.getAttribute(objectName, "sessionCounter"))
-                    .append(',');
-            appendJSonValue(writer, "maxActive", mBeanServer.getAttribute(objectName, "maxActive")).append(',');
-            appendJSonValue(writer, "rejectedSessions", mBeanServer.getAttribute(objectName, "rejectedSessions"))
-                    .append(',');
-            appendJSonValue(writer, "expiredSessions", mBeanServer.getAttribute(objectName, "expiredSessions"))
-                    .append(',');
-            appendJSonValue(writer, "sessionMaxAliveTime", mBeanServer.getAttribute(objectName, "sessionMaxAliveTime"))
-                    .append(',');
-            appendJSonValue(writer, "sessionAverageAliveTime",
-                    mBeanServer.getAttribute(objectName, "sessionAverageAliveTime")).append(',');
-            appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(objectName, "processingTime"));
+            writer.append('"').append("manager").append('"').append(':').append('{');
+            appendJSonValue(writer, "activeSessions", mBeanServer.getAttribute(objectName, "activeSessions").toString()).append(',');
+            appendJSonValue(writer, "sessionCounter", mBeanServer.getAttribute(objectName, "sessionCounter").toString()).append(',');
+            appendJSonValue(writer, "maxActive", mBeanServer.getAttribute(objectName, "maxActive").toString()).append(',');
+            appendJSonValue(writer, "rejectedSessions", mBeanServer.getAttribute(objectName, "rejectedSessions").toString()).append(',');
+            appendJSonValue(writer, "expiredSessions", mBeanServer.getAttribute(objectName, "expiredSessions").toString()).append(',');
+            appendJSonValue(writer, "sessionMaxAliveTime", mBeanServer.getAttribute(objectName, "sessionMaxAliveTime").toString()).append(',');
+            appendJSonValue(writer, "sessionAverageAliveTime", mBeanServer.getAttribute(objectName, "sessionAverageAliveTime").toString()).append(',');
+            appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(objectName, "processingTime").toString());
             writer.append('}');
         }
 
@@ -1017,9 +907,9 @@ public class StatusTransformer {
             // for now we don't write out anything
         } else if (mode == 2) {
             writer.append(',').println();
-            indent(writer, 3).append('"').append("jsp").append('"').append(':').append('{');
-            appendJSonValue(writer, "jspCount", Integer.valueOf(jspCount)).append(',');
-            appendJSonValue(writer, "jspReloadCount", Integer.valueOf(jspReloadCount));
+            writer.append('"').append("jsp").append('"').append(':').append('{');
+            appendJSonValue(writer, "jspCount", Integer.toString(jspCount)).append(',');
+            appendJSonValue(writer, "jspReloadCount", Integer.toString(jspReloadCount));
             writer.append('}');
         }
     }
@@ -1074,15 +964,14 @@ public class StatusTransformer {
         } else if (mode == 1) {
             // for now we don't write out the wrapper details
         } else if (mode == 2) {
-            indent(writer, 4).append('{');
+            writer.append('{');
             appendJSonValue(writer, "servletName", JSONFilter.escape(servletName)).append(',');
-            appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(objectName, "processingTime"))
-                    .append(',');
-            appendJSonValue(writer, "maxTime", mBeanServer.getAttribute(objectName, "maxTime")).append(',');
-            appendJSonValue(writer, "requestCount", mBeanServer.getAttribute(objectName, "requestCount")).append(',');
-            appendJSonValue(writer, "errorCount", mBeanServer.getAttribute(objectName, "errorCount")).append(',');
-            appendJSonValue(writer, "loadTime", mBeanServer.getAttribute(objectName, "loadTime")).append(',');
-            appendJSonValue(writer, "classLoadTime", mBeanServer.getAttribute(objectName, "classLoadTime"));
+            appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(objectName, "processingTime").toString()).append(',');
+            appendJSonValue(writer, "maxTime", mBeanServer.getAttribute(objectName, "maxTime").toString()).append(',');
+            appendJSonValue(writer, "requestCount", mBeanServer.getAttribute(objectName, "requestCount").toString()).append(',');
+            appendJSonValue(writer, "errorCount", mBeanServer.getAttribute(objectName, "errorCount").toString()).append(',');
+            appendJSonValue(writer, "loadTime", mBeanServer.getAttribute(objectName, "loadTime").toString()).append(',');
+            appendJSonValue(writer, "classLoadTime", mBeanServer.getAttribute(objectName, "classLoadTime").toString());
             writer.append('}');
         }
 
