@@ -27,6 +27,7 @@ import javax.management.ObjectName;
 import org.apache.catalina.Container;
 import org.apache.catalina.Context;
 import org.apache.catalina.Group;
+import org.apache.catalina.Loader;
 import org.apache.catalina.Role;
 import org.apache.catalina.Server;
 import org.apache.catalina.User;
@@ -56,7 +57,7 @@ public class MBeanUtils {
      * The set of exceptions to the normal rules used by <code>createManagedBean()</code>. The first element of each
      * pair is a class name, and the second element is the managed bean name.
      */
-    private static final String[][] exceptions = { { "org.apache.catalina.users.MemoryGroup", "Group" },
+    private static final String exceptions[][] = { { "org.apache.catalina.users.MemoryGroup", "Group" },
             { "org.apache.catalina.users.MemoryRole", "Role" }, { "org.apache.catalina.users.MemoryUser", "User" },
             { "org.apache.catalina.users.GenericGroup", "Group" }, { "org.apache.catalina.users.GenericRole", "Role" },
             { "org.apache.catalina.users.GenericUser", "User" } };
@@ -449,12 +450,37 @@ public class MBeanUtils {
      */
     static ObjectName createObjectName(String domain, Group group) throws MalformedObjectNameException {
 
-        return new ObjectName(domain + ":type=Group,groupname=" + ObjectName.quote(group.getGroupname()) +
-            ",database=" + group.getUserDatabase().getId());
+        ObjectName name = null;
+        name = new ObjectName(domain + ":type=Group,groupname=" + ObjectName.quote(group.getGroupname()) +
+                ",database=" + group.getUserDatabase().getId());
+        return name;
 
     }
 
 
+    /**
+     * Create an <code>ObjectName</code> for this <code>Loader</code> object.
+     *
+     * @param domain Domain in which this name is to be created
+     * @param loader The Loader to be named
+     *
+     * @return a new object name
+     *
+     * @exception MalformedObjectNameException if a name cannot be created
+     */
+    static ObjectName createObjectName(String domain, Loader loader) throws MalformedObjectNameException {
+
+        ObjectName name = null;
+        Context context = loader.getContext();
+
+        ContextName cn = new ContextName(context.getName(), false);
+        Container host = context.getParent();
+        name = new ObjectName(domain + ":type=Loader,host=" + host.getName() + ",context=" + cn.getDisplayName());
+
+        return name;
+    }
+
+
     /**
      * Create an <code>ObjectName</code> for this <code>Role</code> object.
      *
@@ -467,9 +493,9 @@ public class MBeanUtils {
      */
     static ObjectName createObjectName(String domain, Role role) throws MalformedObjectNameException {
 
-        return new ObjectName(domain + ":type=Role,rolename=" + ObjectName.quote(role.getRolename()) +
-            ",database=" + role.getUserDatabase().getId());
-
+        ObjectName name = new ObjectName(domain + ":type=Role,rolename=" + ObjectName.quote(role.getRolename()) +
+                ",database=" + role.getUserDatabase().getId());
+        return name;
     }
 
 
@@ -485,8 +511,9 @@ public class MBeanUtils {
      */
     static ObjectName createObjectName(String domain, User user) throws MalformedObjectNameException {
 
-        return new ObjectName(domain + ":type=User,username=" + ObjectName.quote(user.getUsername()) +
-            ",database=" + user.getUserDatabase().getId());
+        ObjectName name = new ObjectName(domain + ":type=User,username=" + ObjectName.quote(user.getUsername()) +
+                ",database=" + user.getUserDatabase().getId());
+        return name;
     }
 
 
@@ -502,7 +529,9 @@ public class MBeanUtils {
      */
     static ObjectName createObjectName(String domain, UserDatabase userDatabase) throws MalformedObjectNameException {
 
-        return new ObjectName(domain + ":type=UserDatabase,database=" + userDatabase.getId());
+        ObjectName name = null;
+        name = new ObjectName(domain + ":type=UserDatabase,database=" + userDatabase.getId());
+        return name;
 
     }
 
@@ -513,7 +542,7 @@ public class MBeanUtils {
      */
     public static synchronized Registry createRegistry() {
         if (registry == null) {
-            registry = Registry.getRegistry(null);
+            registry = Registry.getRegistry(null, null);
             ClassLoader cl = MBeanUtils.class.getClassLoader();
 
             registry.loadDescriptors("org.apache.catalina.mbeans", cl);
@@ -544,7 +573,7 @@ public class MBeanUtils {
      */
     public static synchronized MBeanServer createServer() {
         if (mserver == null) {
-            mserver = Registry.getRegistry(null).getMBeanServer();
+            mserver = Registry.getRegistry(null, null).getMBeanServer();
         }
         return mserver;
     }
@@ -720,8 +749,8 @@ public class MBeanUtils {
      */
     static void destroyMBeanUserDatabase(String userDatabase) throws Exception {
 
-        ObjectName query;
-        Set<ObjectName> results;
+        ObjectName query = null;
+        Set<ObjectName> results = null;
 
         // Groups
         query = new ObjectName("Users:type=Group,database=" + userDatabase + ",*");
