@@ -31,8 +31,7 @@ import org.apache.tomcat.util.res.StringManager;
  */
 public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
-    protected static final StringManager sm =
-            StringManager.getManager(DigestCredentialHandlerBase.class);
+    protected static final StringManager sm = StringManager.getManager(DigestCredentialHandlerBase.class);
 
     public static final int DEFAULT_SALT_LENGTH = 32;
 
@@ -44,8 +43,8 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * @return the number of iterations of the associated algorithm that will be
-     * used when creating a new stored credential for a given input credential.
+     * @return the number of iterations of the associated algorithm that will be used when creating a new stored
+     *             credential for a given input credential.
      */
     public int getIterations() {
         return iterations;
@@ -53,8 +52,9 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * Set the number of iterations of the associated algorithm that will be
-     * used when creating a new stored credential for a given input credential.
+     * Set the number of iterations of the associated algorithm that will be used when creating a new stored credential
+     * for a given input credential.
+     *
      * @param iterations the iterations count
      */
     public void setIterations(int iterations) {
@@ -63,8 +63,7 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * @return the salt length that will be used when creating a new stored
-     * credential for a given input credential.
+     * @return the salt length that will be used when creating a new stored credential for a given input credential.
      */
     public int getSaltLength() {
         return saltLength;
@@ -72,8 +71,8 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * Set the salt length that will be used when creating a new stored
-     * credential for a given input credential.
+     * Set the salt length that will be used when creating a new stored credential for a given input credential.
+     *
      * @param saltLength the salt length
      */
     public void setSaltLength(int saltLength) {
@@ -82,8 +81,9 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * When checking input credentials against stored credentials will a warning
-     * message be logged if invalid stored credentials are discovered?
+     * When checking input credentials against stored credentials will a warning message be logged if invalid stored
+     * credentials are discovered?
+     *
      * @return <code>true</code> if logging will occur
      */
     public boolean getLogInvalidStoredCredentials() {
@@ -92,11 +92,10 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * Set whether a warning message will be logged if invalid stored
-     * credentials are discovered while checking input credentials against
-     * stored credentials?
-     * @param logInvalidStoredCredentials <code>true</code> to log, the
-     *   default value is <code>false</code>
+     * Set whether a warning message will be logged if invalid stored credentials are discovered while checking input
+     * credentials against stored credentials?
+     *
+     * @param logInvalidStoredCredentials <code>true</code> to log, the default value is <code>false</code>
      */
     public void setLogInvalidStoredCredentials(boolean logInvalidStoredCredentials) {
         this.logInvalidStoredCredentials = logInvalidStoredCredentials;
@@ -138,8 +137,7 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
             // Output the simple/old format for backwards compatibility
             return serverCredential;
         } else {
-            StringBuilder result =
-                    new StringBuilder((saltLength << 1) + 10 + serverCredential.length() + 2);
+            StringBuilder result = new StringBuilder((saltLength << 1) + 10 + serverCredential.length() + 2);
             result.append(HexUtils.toHexString(salt));
             result.append('$');
             result.append(iterations);
@@ -152,16 +150,15 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * Checks whether the provided credential matches the stored credential when
-     * the stored credential is in the form salt$iteration-count$credential
+     * Checks whether the provided credential matches the stored credential when the stored credential is in the form
+     * salt$iteration-count$credential
      *
      * @param inputCredentials  The input credential
      * @param storedCredentials The stored credential
      *
      * @return <code>true</code> if they match, otherwise <code>false</code>
      */
-    protected boolean matchesSaltIterationsEncoded(String inputCredentials,
-            String storedCredentials) {
+    protected boolean matchesSaltIterationsEncoded(String inputCredentials, String storedCredentials) {
 
         if (storedCredentials == null) {
             // Stored credentials are invalid
@@ -180,7 +177,7 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
             return false;
         }
 
-        String hexSalt = storedCredentials.substring(0,  sep1);
+        String hexSalt = storedCredentials.substring(0, sep1);
 
         int iterations = Integer.parseInt(storedCredentials.substring(sep1 + 1, sep2));
 
@@ -193,8 +190,8 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
             return false;
         }
 
-        String inputHexEncoded = mutate(inputCredentials, salt, iterations,
-                HexUtils.fromHexString(storedHexEncoded).length * Byte.SIZE);
+        String inputHexEncoded =
+                mutate(inputCredentials, salt, iterations, HexUtils.fromHexString(storedHexEncoded).length * Byte.SIZE);
         if (inputHexEncoded == null) {
             // Failed to mutate user credentials. Automatic fail.
             // Root cause should be logged by mutate()
@@ -209,8 +206,7 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
         if (logInvalidStoredCredentials) {
             // Logging credentials could be a security concern but they are
             // invalid and that is probably a bigger problem
-            getLog().warn(sm.getString("credentialHandler.invalidStoredCredential",
-                    storedCredentials));
+            getLog().warn(sm.getString("credentialHandler.invalidStoredCredential", storedCredentials));
         }
     }
 
@@ -224,41 +220,33 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * Generates the equivalent stored credentials for the given input
-     * credentials, salt and iterations. If the algorithm requires a key length,
-     * the default will be used.
+     * Generates the equivalent stored credentials for the given input credentials, salt and iterations. If the
+     * algorithm requires a key length, the default will be used.
      *
-     * @param inputCredentials  User provided credentials
-     * @param salt              Salt, if any
-     * @param iterations        Number of iterations of the algorithm associated
-     *                          with this CredentialHandler applied to the
-     *                          inputCredentials to generate the equivalent
-     *                          stored credentials
+     * @param inputCredentials User provided credentials
+     * @param salt             Salt, if any
+     * @param iterations       Number of iterations of the algorithm associated with this CredentialHandler applied to
+     *                             the inputCredentials to generate the equivalent stored credentials
      *
-     * @return  The equivalent stored credentials for the given input
-     *          credentials or <code>null</code> if the generation fails
+     * @return The equivalent stored credentials for the given input credentials or <code>null</code> if the generation
+     *             fails
      */
     protected abstract String mutate(String inputCredentials, byte[] salt, int iterations);
 
 
     /**
-     * Generates the equivalent stored credentials for the given input
-     * credentials, salt, iterations and key length. The default implementation
-     * calls ignores the key length and calls
-     * {@link #mutate(String, byte[], int)}. Sub-classes that use the key length
-     * should override this method.
+     * Generates the equivalent stored credentials for the given input credentials, salt, iterations and key length. The
+     * default implementation calls ignores the key length and calls {@link #mutate(String, byte[], int)}. Sub-classes
+     * that use the key length should override this method.
      *
-     * @param inputCredentials  User provided credentials
-     * @param salt              Salt, if any
-     * @param iterations        Number of iterations of the algorithm associated
-     *                          with this CredentialHandler applied to the
-     *                          inputCredentials to generate the equivalent
-     *                          stored credentials
-     * @param keyLength         Length of the produced digest in bits for
-     *                          implementations where it's applicable
+     * @param inputCredentials User provided credentials
+     * @param salt             Salt, if any
+     * @param iterations       Number of iterations of the algorithm associated with this CredentialHandler applied to
+     *                             the inputCredentials to generate the equivalent stored credentials
+     * @param keyLength        Length of the produced digest in bits for implementations where it's applicable
      *
-     * @return  The equivalent stored credentials for the given input
-     *          credentials or <code>null</code> if the generation fails
+     * @return The equivalent stored credentials for the given input credentials or <code>null</code> if the generation
+     *             fails
      */
     protected String mutate(String inputCredentials, byte[] salt, int iterations, int keyLength) {
         return mutate(inputCredentials, salt, iterations);
@@ -266,25 +254,23 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
 
 
     /**
-     * Set the algorithm used to convert input credentials to stored
-     * credentials.
+     * Set the algorithm used to convert input credentials to stored credentials.
+     *
      * @param algorithm the algorithm
-     * @throws NoSuchAlgorithmException if the specified algorithm
-     *  is not supported
+     *
+     * @throws NoSuchAlgorithmException if the specified algorithm is not supported
      */
     public abstract void setAlgorithm(String algorithm) throws NoSuchAlgorithmException;
 
 
     /**
-     * @return the algorithm used to convert input credentials to stored
-     * credentials.
+     * @return the algorithm used to convert input credentials to stored credentials.
      */
     public abstract String getAlgorithm();
 
 
     /**
-     * @return the default number of iterations used by the
-     * {@link CredentialHandler}.
+     * @return the default number of iterations used by the {@link CredentialHandler}.
      */
     protected abstract int getDefaultIterations();
 
@@ -295,21 +281,18 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
     protected abstract Log getLog();
 
     /**
-     * Implements String equality which always compares all characters in the
-     * string, without stopping early if any characters do not match.
+     * Implements String equality which always compares all characters in the string, without stopping early if any
+     * characters do not match.
      * <p>
-     * <i>Note:</i>
-     * This implementation was adapted from {@link MessageDigest#isEqual}
-     * which we assume is as optimizer-defeating as possible.
+     * <i>Note:</i> This implementation was adapted from {@link MessageDigest#isEqual} which we assume is as
+     * optimizer-defeating as possible.
      *
-     * @param s1 The first string to compare.
-     * @param s2 The second string to compare.
-     * @param ignoreCase <code>true</code> if the strings should be compared
-     *        without regard to case. Note that "true" here is only guaranteed
-     *        to work with plain ASCII characters.
+     * @param s1         The first string to compare.
+     * @param s2         The second string to compare.
+     * @param ignoreCase <code>true</code> if the strings should be compared without regard to case. Note that "true"
+     *                       here is only guaranteed to work with plain ASCII characters.
      *
-     * @return <code>true</code> if the strings are equal to each other,
-     *         <code>false</code> otherwise.
+     * @return <code>true</code> if the strings are equal to each other, <code>false</code> otherwise.
      */
     public static boolean equals(final String s1, final String s2, final boolean ignoreCase) {
         if (s1 == s2) {
@@ -335,7 +318,7 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
             final int index2 = ((i - len2) >>> 31) * i;
             char c1 = s1.charAt(i);
             char c2 = s2.charAt(index2);
-            if(ignoreCase) {
+            if (ignoreCase) {
                 c1 = Character.toLowerCase(c1);
                 c2 = Character.toLowerCase(c2);
             }
@@ -345,22 +328,18 @@ public abstract class DigestCredentialHandlerBase implements CredentialHandler {
     }
 
     /**
-     * Implements byte-array equality which always compares all bytes in the
-     * array, without stopping early if any bytes do not match.
+     * Implements byte-array equality which always compares all bytes in the array, without stopping early if any bytes
+     * do not match.
      * <p>
-     * <i>Note:</i>
-     * Implementation note: this method delegates to {@link MessageDigest#isEqual}
-     * under the assumption that it provides a constant-time comparison of the
-     * bytes in the arrays. Java 7+ has such an implementation, but neither the
-     * Javadoc nor any specification requires it. Therefore, Tomcat should
-     * continue to use <i>this</i> method internally in case the JDK
-     * implementation changes so this method can be re-implemented properly.
+     * <i>Note:</i> Implementation note: this method delegates to {@link MessageDigest#isEqual} under the assumption
+     * that it provides a constant-time comparison of the bytes in the arrays. Java 7+ has such an implementation, but
+     * neither the Javadoc nor any specification requires it. Therefore, Tomcat should continue to use <i>this</i>
+     * method internally in case the JDK implementation changes so this method can be re-implemented properly.
      *
      * @param b1 The first array to compare.
      * @param b2 The second array to compare.
      *
-     * @return <code>true</code> if the arrays are equal to each other,
-     *         <code>false</code> otherwise.
+     * @return <code>true</code> if the arrays are equal to each other, <code>false</code> otherwise.
      */
     public static boolean equals(final byte[] b1, final byte[] b2) {
         return MessageDigest.isEqual(b1, b2);
