@@ -92,7 +92,7 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
     /**
      * The configuration information for this <code>LoginModule</code>.
      */
-    protected Map<String, ?> options = null;
+    protected Map<String,?> options = null;
 
 
     /**
@@ -110,7 +110,7 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
     /**
      * The state information that is shared with other configured <code>LoginModule</code> instances.
      */
-    protected Map<String, ?> sharedState = null;
+    protected Map<String,?> sharedState = null;
 
 
     /**
@@ -127,15 +127,7 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
         }
     }
 
-    /**
-     * Phase 2 of authenticating a <code>Subject</code> when Phase 1 fails. This method is called if the
-     * <code>LoginContext</code> failed somewhere in the overall authentication chain.
-     *
-     * @return <code>true</code> if this method succeeded, or <code>false</code> if this <code>LoginModule</code> should
-     *             be ignored
-     *
-     * @exception LoginException if the abort fails
-     */
+
     @Override
     public boolean abort() throws LoginException {
 
@@ -158,15 +150,6 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
     }
 
 
-    /**
-     * Phase 2 of authenticating a <code>Subject</code> when Phase 1 was successful. This method is called if the
-     * <code>LoginContext</code> succeeded in the overall authentication chain.
-     *
-     * @return <code>true</code> if the authentication succeeded, or <code>false</code> if this <code>LoginModule</code>
-     *             should be ignored
-     *
-     * @exception LoginException if the commit fails
-     */
     @Override
     public boolean commit() throws LoginException {
         if (log.isDebugEnabled()) {
@@ -197,17 +180,9 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
     }
 
 
-    /**
-     * Initialize this <code>LoginModule</code> with the specified configuration information.
-     *
-     * @param subject         The <code>Subject</code> to be authenticated
-     * @param callbackHandler A <code>CallbackHandler</code> for communicating with the end user as necessary
-     * @param sharedState     State information shared with other <code>LoginModule</code> instances
-     * @param options         Configuration information for this specific <code>LoginModule</code> instance
-     */
     @Override
-    public void initialize(Subject subject, CallbackHandler callbackHandler, Map<String, ?> sharedState,
-            Map<String, ?> options) {
+    public void initialize(Subject subject, CallbackHandler callbackHandler, Map<String,?> sharedState,
+            Map<String,?> options) {
         if (log.isDebugEnabled()) {
             log.debug("Init");
         }
@@ -238,7 +213,7 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
             credentialHandler = new MessageDigestCredentialHandler();
         }
 
-        for (Entry<String, ?> entry : options.entrySet()) {
+        for (Entry<String,?> entry : options.entrySet()) {
             if ("pathname".equals(entry.getKey())) {
                 continue;
             }
@@ -258,21 +233,13 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
     }
 
 
-    /**
-     * Phase 1 of authenticating a <code>Subject</code>.
-     *
-     * @return <code>true</code> if the authentication succeeded, or <code>false</code> if this <code>LoginModule</code>
-     *             should be ignored
-     *
-     * @exception LoginException if the authentication fails
-     */
     @Override
     public boolean login() throws LoginException {
         // Set up our CallbackHandler requests
         if (callbackHandler == null) {
             throw new LoginException(sm.getString("jaasMemoryLoginModule.noCallbackHandler"));
         }
-        Callback callbacks[] = new Callback[9];
+        Callback callbacks[] = new Callback[10];
         callbacks[0] = new NameCallback("Username: ");
         callbacks[1] = new PasswordCallback("Password: ", false);
         callbacks[2] = new TextInputCallback("nonce");
@@ -280,8 +247,9 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
         callbacks[4] = new TextInputCallback("cnonce");
         callbacks[5] = new TextInputCallback("qop");
         callbacks[6] = new TextInputCallback("realmName");
-        callbacks[7] = new TextInputCallback("md5a2");
-        callbacks[8] = new TextInputCallback("authMethod");
+        callbacks[7] = new TextInputCallback("digestA2");
+        callbacks[8] = new TextInputCallback("algorithm");
+        callbacks[9] = new TextInputCallback("authMethod");
 
         // Interact with the user to retrieve the username and password
         String username = null;
@@ -291,20 +259,23 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
         String cnonce = null;
         String qop = null;
         String realmName = null;
-        String md5a2 = null;
+        String digestA2 = null;
+        String algorithm = null;
         String authMethod = null;
 
         try {
             callbackHandler.handle(callbacks);
             username = ((NameCallback) callbacks[0]).getName();
-            password = new String(((PasswordCallback) callbacks[1]).getPassword());
+            char[] passwordArray = ((PasswordCallback) callbacks[1]).getPassword();
+            password = (passwordArray == null) ? null : new String(passwordArray);
             nonce = ((TextInputCallback) callbacks[2]).getText();
             nc = ((TextInputCallback) callbacks[3]).getText();
             cnonce = ((TextInputCallback) callbacks[4]).getText();
             qop = ((TextInputCallback) callbacks[5]).getText();
             realmName = ((TextInputCallback) callbacks[6]).getText();
-            md5a2 = ((TextInputCallback) callbacks[7]).getText();
-            authMethod = ((TextInputCallback) callbacks[8]).getText();
+            digestA2 = ((TextInputCallback) callbacks[7]).getText();
+            algorithm = ((TextInputCallback) callbacks[8]).getText();
+            authMethod = ((TextInputCallback) callbacks[9]).getText();
         } catch (IOException | UnsupportedCallbackException e) {
             throw new LoginException(sm.getString("jaasMemoryLoginModule.callbackHandlerError", e.toString()));
         }
@@ -314,7 +285,7 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
             // BASIC or FORM
             principal = super.authenticate(username, password);
         } else if (authMethod.equals(HttpServletRequest.DIGEST_AUTH)) {
-            principal = super.authenticate(username, password, nonce, nc, cnonce, qop, realmName, md5a2);
+            principal = super.authenticate(username, password, nonce, nc, cnonce, qop, realmName, digestA2, algorithm);
         } else if (authMethod.equals(HttpServletRequest.CLIENT_CERT_AUTH)) {
             principal = super.getPrincipal(username);
         } else {
@@ -334,13 +305,6 @@ public class JAASMemoryLoginModule extends MemoryRealm implements LoginModule {
     }
 
 
-    /**
-     * Log out this user.
-     *
-     * @return <code>true</code> in all cases because the <code>LoginModule</code> should not be ignored
-     *
-     * @exception LoginException if logging out failed
-     */
     @Override
     public boolean logout() throws LoginException {
         subject.getPrincipals().remove(principal);
