@@ -42,10 +42,8 @@ import org.apache.catalina.Session;
 import org.apache.juli.logging.Log;
 
 /**
- * Implementation of the {@link org.apache.catalina.Store Store}
- * interface that stores serialized session objects in a database.
- * Sessions that are saved are still subject to being expired
- * based on inactivity.
+ * Implementation of the {@link org.apache.catalina.Store Store} interface that stores serialized session objects in a
+ * database. Sessions that are saved are still subject to being expired based on inactivity.
  *
  * @author Bip Thelin
  */
@@ -157,9 +155,7 @@ public class DataSourceStore extends StoreBase {
     public void setSessionTable(String sessionTable) {
         String oldSessionTable = this.sessionTable;
         this.sessionTable = sessionTable;
-        support.firePropertyChange("sessionTable",
-                oldSessionTable,
-                this.sessionTable);
+        support.firePropertyChange("sessionTable", oldSessionTable, this.sessionTable);
     }
 
     /**
@@ -177,9 +173,7 @@ public class DataSourceStore extends StoreBase {
     public void setSessionAppCol(String sessionAppCol) {
         String oldSessionAppCol = this.sessionAppCol;
         this.sessionAppCol = sessionAppCol;
-        support.firePropertyChange("sessionAppCol",
-                oldSessionAppCol,
-                this.sessionAppCol);
+        support.firePropertyChange("sessionAppCol", oldSessionAppCol, this.sessionAppCol);
     }
 
     /**
@@ -197,9 +191,7 @@ public class DataSourceStore extends StoreBase {
     public void setSessionIdCol(String sessionIdCol) {
         String oldSessionIdCol = this.sessionIdCol;
         this.sessionIdCol = sessionIdCol;
-        support.firePropertyChange("sessionIdCol",
-                oldSessionIdCol,
-                this.sessionIdCol);
+        support.firePropertyChange("sessionIdCol", oldSessionIdCol, this.sessionIdCol);
     }
 
     /**
@@ -217,9 +209,7 @@ public class DataSourceStore extends StoreBase {
     public void setSessionDataCol(String sessionDataCol) {
         String oldSessionDataCol = this.sessionDataCol;
         this.sessionDataCol = sessionDataCol;
-        support.firePropertyChange("sessionDataCol",
-                oldSessionDataCol,
-                this.sessionDataCol);
+        support.firePropertyChange("sessionDataCol", oldSessionDataCol, this.sessionDataCol);
     }
 
     /**
@@ -237,9 +227,7 @@ public class DataSourceStore extends StoreBase {
     public void setSessionValidCol(String sessionValidCol) {
         String oldSessionValidCol = this.sessionValidCol;
         this.sessionValidCol = sessionValidCol;
-        support.firePropertyChange("sessionValidCol",
-                oldSessionValidCol,
-                this.sessionValidCol);
+        support.firePropertyChange("sessionValidCol", oldSessionValidCol, this.sessionValidCol);
     }
 
     /**
@@ -257,9 +245,7 @@ public class DataSourceStore extends StoreBase {
     public void setSessionMaxInactiveCol(String sessionMaxInactiveCol) {
         String oldSessionMaxInactiveCol = this.sessionMaxInactiveCol;
         this.sessionMaxInactiveCol = sessionMaxInactiveCol;
-        support.firePropertyChange("sessionMaxInactiveCol",
-                oldSessionMaxInactiveCol,
-                this.sessionMaxInactiveCol);
+        support.firePropertyChange("sessionMaxInactiveCol", oldSessionMaxInactiveCol, this.sessionMaxInactiveCol);
     }
 
     /**
@@ -277,9 +263,7 @@ public class DataSourceStore extends StoreBase {
     public void setSessionLastAccessedCol(String sessionLastAccessedCol) {
         String oldSessionLastAccessedCol = this.sessionLastAccessedCol;
         this.sessionLastAccessedCol = sessionLastAccessedCol;
-        support.firePropertyChange("sessionLastAccessedCol",
-                oldSessionLastAccessedCol,
-                this.sessionLastAccessedCol);
+        support.firePropertyChange("sessionLastAccessedCol", oldSessionLastAccessedCol, this.sessionLastAccessedCol);
     }
 
     /**
@@ -296,8 +280,7 @@ public class DataSourceStore extends StoreBase {
      */
     public void setDataSourceName(String dataSourceName) {
         if (dataSourceName == null || dataSourceName.trim().isEmpty()) {
-            manager.getContext().getLogger().warn(
-                    sm.getString(getStoreName() + ".missingDataSourceName"));
+            manager.getContext().getLogger().warn(sm.getString(getStoreName() + ".missingDataSourceName"));
             return;
         }
         this.dataSourceName = dataSourceName;
@@ -318,13 +301,12 @@ public class DataSourceStore extends StoreBase {
     }
 
     /**
-     * Set to {@code true} to cause the datasource to be looked up in the webapp
-     * JNDI Context.
+     * Set to {@code true} to cause the datasource to be looked up in the webapp JNDI Context.
      *
      * @param localDataSource the new flag value
      */
     public void setLocalDataSource(boolean localDataSource) {
-      this.localDataSource = localDataSource;
+        this.localDataSource = localDataSource;
     }
 
 
@@ -341,12 +323,11 @@ public class DataSourceStore extends StoreBase {
     }
 
     /**
-     * Return an array containing the session identifiers of all Sessions
-     * currently saved in this Store.  If there are no such Sessions, a
-     * zero-length array is returned.
+     * Return an array containing the session identifiers of all Sessions currently saved in this Store. If there are no
+     * such Sessions, a zero-length array is returned.
+     *
+     * @param expiredOnly flag, whether only keys of expired sessions should be returned
      *
-     * @param expiredOnly flag, whether only keys of expired sessions should
-     *        be returned
      * @return array containing the list of session IDs
      *
      * @exception IOException if an input/output error occurred
@@ -362,11 +343,10 @@ public class DataSourceStore extends StoreBase {
             }
             try {
 
-                String keysSql = "SELECT " + sessionIdCol + " FROM "
-                        + sessionTable + " WHERE " + sessionAppCol + " = ?";
+                String keysSql =
+                        "SELECT " + sessionIdCol + " FROM " + sessionTable + " WHERE " + sessionAppCol + " = ?";
                 if (expiredOnly) {
-                    keysSql += " AND (" + sessionLastAccessedCol + " + "
-                            + sessionMaxInactiveCol + " * 1000 < ?)";
+                    keysSql += " AND (" + sessionLastAccessedCol + " + " + sessionMaxInactiveCol + " * 1000 < ?)";
                 }
                 try (PreparedStatement preparedKeysSql = _conn.prepareStatement(keysSql)) {
                     preparedKeysSql.setString(1, getName());
@@ -398,8 +378,7 @@ public class DataSourceStore extends StoreBase {
     }
 
     /**
-     * Return an integer containing a count of all Sessions
-     * currently saved in this Store.  If there are no Sessions,
+     * Return an integer containing a count of all Sessions currently saved in this Store. If there are no Sessions,
      * <code>0</code> is returned.
      *
      * @return the count of all sessions currently saved in this Store
@@ -409,9 +388,7 @@ public class DataSourceStore extends StoreBase {
     @Override
     public int getSize() throws IOException {
         int size = 0;
-        String sizeSql = "SELECT COUNT(" + sessionIdCol
-                + ") FROM " + sessionTable + " WHERE "
-                + sessionAppCol + " = ?";
+        String sizeSql = "SELECT COUNT(" + sessionIdCol + ") FROM " + sessionTable + " WHERE " + sessionAppCol + " = ?";
 
         int numberOfTries = 2;
         while (numberOfTries > 0) {
@@ -421,7 +398,7 @@ public class DataSourceStore extends StoreBase {
                 return size;
             }
 
-            try (PreparedStatement preparedSizeSql = _conn.prepareStatement(sizeSql)){
+            try (PreparedStatement preparedSizeSql = _conn.prepareStatement(sizeSql)) {
                 preparedSizeSql.setString(1, getName());
                 try (ResultSet rst = preparedSizeSql.executeQuery()) {
                     if (rst.next()) {
@@ -441,13 +418,15 @@ public class DataSourceStore extends StoreBase {
     }
 
     /**
-     * Load the Session associated with the id <code>id</code>.
-     * If no such session is found <code>null</code> is returned.
+     * Load the Session associated with the id <code>id</code>. If no such session is found <code>null</code> is
+     * returned.
      *
      * @param id a value of type <code>String</code>
+     *
      * @return the stored <code>Session</code>
+     *
      * @exception ClassNotFoundException if an error occurs
-     * @exception IOException if an input/output error occurred
+     * @exception IOException            if an input/output error occurred
      */
     @Override
     public Session load(String id) throws ClassNotFoundException, IOException {
@@ -456,10 +435,8 @@ public class DataSourceStore extends StoreBase {
         Log contextLog = context.getLogger();
 
         int numberOfTries = 2;
-        String loadSql = "SELECT " + sessionIdCol + ", "
-                + sessionDataCol + " FROM " + sessionTable
-                + " WHERE " + sessionIdCol + " = ? AND "
-                + sessionAppCol + " = ?";
+        String loadSql = "SELECT " + sessionIdCol + ", " + sessionDataCol + " FROM " + sessionTable + " WHERE " +
+                sessionIdCol + " = ? AND " + sessionAppCol + " = ?";
         while (numberOfTries > 0) {
             Connection _conn = getConnection();
             if (_conn == null) {
@@ -468,16 +445,14 @@ public class DataSourceStore extends StoreBase {
 
             ClassLoader oldThreadContextCL = context.bind(Globals.IS_SECURITY_ENABLED, null);
 
-            try (PreparedStatement preparedLoadSql = _conn.prepareStatement(loadSql)){
+            try (PreparedStatement preparedLoadSql = _conn.prepareStatement(loadSql)) {
                 preparedLoadSql.setString(1, id);
                 preparedLoadSql.setString(2, getName());
                 try (ResultSet rst = preparedLoadSql.executeQuery()) {
                     if (rst.next()) {
-                        try (ObjectInputStream ois =
-                                getObjectInputStream(rst.getBinaryStream(2))) {
+                        try (ObjectInputStream ois = getObjectInputStream(rst.getBinaryStream(2))) {
                             if (contextLog.isDebugEnabled()) {
-                                contextLog.debug(sm.getString(
-                                        getStoreName() + ".loading", id, sessionTable));
+                                contextLog.debug(sm.getString(getStoreName() + ".loading", id, sessionTable));
                             }
 
                             _session = (StandardSession) manager.createEmptySession();
@@ -502,9 +477,8 @@ public class DataSourceStore extends StoreBase {
     }
 
     /**
-     * Remove the Session with the specified session identifier from
-     * this Store, if present.  If no such Session is present, this method
-     * takes no action.
+     * Remove the Session with the specified session identifier from this Store, if present. If no such Session is
+     * present, this method takes no action.
      *
      * @param id Session identifier of the Session to be removed
      *
@@ -539,18 +513,17 @@ public class DataSourceStore extends StoreBase {
     }
 
     /**
-     * Remove the Session with the specified session identifier from
-     * this Store, if present.  If no such Session is present, this method
-     * takes no action.
+     * Remove the Session with the specified session identifier from this Store, if present. If no such Session is
+     * present, this method takes no action.
      *
-     * @param id Session identifier of the Session to be removed
+     * @param id    Session identifier of the Session to be removed
      * @param _conn open connection to be used
+     *
      * @throws SQLException if an error occurs while talking to the database
      */
     private void remove(String id, Connection _conn) throws SQLException {
-        String removeSql = "DELETE FROM " + sessionTable
-                + " WHERE " + sessionIdCol + " = ?  AND "
-                + sessionAppCol + " = ?";
+        String removeSql =
+                "DELETE FROM " + sessionTable + " WHERE " + sessionIdCol + " = ?  AND " + sessionAppCol + " = ?";
         try (PreparedStatement preparedRemoveSql = _conn.prepareStatement(removeSql)) {
             preparedRemoveSql.setString(1, id);
             preparedRemoveSql.setString(2, getName());
@@ -565,8 +538,7 @@ public class DataSourceStore extends StoreBase {
      */
     @Override
     public void clear() throws IOException {
-        String clearSql = "DELETE FROM " + sessionTable
-                + " WHERE " + sessionAppCol + " = ?";
+        String clearSql = "DELETE FROM " + sessionTable + " WHERE " + sessionAppCol + " = ?";
 
         int numberOfTries = 2;
         while (numberOfTries > 0) {
@@ -575,7 +547,7 @@ public class DataSourceStore extends StoreBase {
                 return;
             }
 
-            try (PreparedStatement preparedClearSql = _conn.prepareStatement(clearSql)){
+            try (PreparedStatement preparedClearSql = _conn.prepareStatement(clearSql)) {
                 preparedClearSql.setString(1, getName());
                 preparedClearSql.execute();
                 // Break out after the finally block
@@ -593,17 +565,15 @@ public class DataSourceStore extends StoreBase {
      * Save a session to the Store.
      *
      * @param session the session to be stored
+     *
      * @exception IOException if an input/output error occurs
      */
     @Override
     public void save(Session session) throws IOException {
         ByteArrayOutputStream bos = null;
-        String saveSql = "INSERT INTO " + sessionTable + " ("
-                + sessionIdCol + ", " + sessionAppCol + ", "
-                + sessionDataCol + ", " + sessionValidCol
-                + ", " + sessionMaxInactiveCol + ", "
-                + sessionLastAccessedCol
-                + ") VALUES (?, ?, ?, ?, ?, ?)";
+        String saveSql = "INSERT INTO " + sessionTable + " (" + sessionIdCol + ", " + sessionAppCol + ", " +
+                sessionDataCol + ", " + sessionValidCol + ", " + sessionMaxInactiveCol + ", " + sessionLastAccessedCol +
+                ") VALUES (?, ?, ?, ?, ?, ?)";
 
         synchronized (session) {
             int numberOfTries = 2;
@@ -620,8 +590,7 @@ public class DataSourceStore extends StoreBase {
                     remove(session.getIdInternal(), _conn);
 
                     bos = new ByteArrayOutputStream();
-                    try (ObjectOutputStream oos =
-                            new ObjectOutputStream(new BufferedOutputStream(bos))) {
+                    try (ObjectOutputStream oos = new ObjectOutputStream(new BufferedOutputStream(bos))) {
                         ((StandardSession) session).writeObjectData(oos);
                     }
                     byte[] obs = bos.toByteArray();
@@ -651,8 +620,8 @@ public class DataSourceStore extends StoreBase {
         }
 
         if (manager.getContext().getLogger().isDebugEnabled()) {
-            manager.getContext().getLogger().debug(sm.getString(getStoreName() + ".saving",
-                    session.getIdInternal(), sessionTable));
+            manager.getContext().getLogger()
+                    .debug(sm.getString(getStoreName() + ".saving", session.getIdInternal(), sessionTable));
         }
     }
 
@@ -660,9 +629,8 @@ public class DataSourceStore extends StoreBase {
     // --------------------------------------------------------- Protected Methods
 
     /**
-     * Check the connection associated with this store, if it's
-     * <code>null</code> or closed try to reopen it.
-     * Returns <code>null</code> if the connection could not be established.
+     * Check the connection associated with this store, if it's <code>null</code> or closed try to reopen it. Returns
+     * <code>null</code> if the connection could not be established.
      *
      * @return <code>Connection</code> if the connection succeeded
      */
@@ -674,20 +642,20 @@ public class DataSourceStore extends StoreBase {
                 manager.getContext().getLogger().info(sm.getString(getStoreName() + ".checkConnectionDBClosed"));
                 conn = open();
                 if (conn == null || conn.isClosed()) {
-                    manager.getContext().getLogger().info(sm.getString(getStoreName() + ".checkConnectionDBReOpenFail"));
+                    manager.getContext().getLogger()
+                            .info(sm.getString(getStoreName() + ".checkConnectionDBReOpenFail"));
                 }
             }
         } catch (SQLException ex) {
-            manager.getContext().getLogger().error(sm.getString(getStoreName() + ".checkConnectionSQLException",
-                    ex.toString()));
+            manager.getContext().getLogger()
+                    .error(sm.getString(getStoreName() + ".checkConnectionSQLException", ex.toString()));
         }
 
         return conn;
     }
 
     /**
-     * Open (if necessary) and return a database connection for use by
-     * this Store.
+     * Open (if necessary) and return a database connection for use by this Store.
      *
      * @return database connection ready to use
      *
@@ -697,7 +665,7 @@ public class DataSourceStore extends StoreBase {
         if (dataSourceName != null && dataSource == null) {
             org.apache.catalina.Context context = getManager().getContext();
             ClassLoader oldThreadContextCL = null;
-            if (localDataSource) {
+            if (getLocalDataSource()) {
                 oldThreadContextCL = context.bind(Globals.IS_SECURITY_ENABLED, null);
             }
 
@@ -707,11 +675,9 @@ public class DataSourceStore extends StoreBase {
                 Context envCtx = (Context) initCtx.lookup("java:comp/env");
                 this.dataSource = (DataSource) envCtx.lookup(this.dataSourceName);
             } catch (NamingException e) {
-                context.getLogger().error(
-                        sm.getString(getStoreName() + ".wrongDataSource",
-                                this.dataSourceName), e);
+                context.getLogger().error(sm.getString(getStoreName() + ".wrongDataSource", this.dataSourceName), e);
             } finally {
-                if (localDataSource) {
+                if (getLocalDataSource()) {
                     context.unbind(Globals.IS_SECURITY_ENABLED, oldThreadContextCL);
                 }
             }
@@ -749,13 +715,13 @@ public class DataSourceStore extends StoreBase {
         try {
             dbConnection.close();
         } catch (SQLException e) {
-            manager.getContext().getLogger().error(sm.getString(getStoreName() + ".close", e.toString())); // Just log it here
+            manager.getContext().getLogger().error(sm.getString(getStoreName() + ".close", e.toString())); // Just log
+                                                                                                           // it here
         }
     }
 
     /**
-     * Release the connection, if it
-     * is associated with a connection pool.
+     * Release the connection, if it is associated with a connection pool.
      *
      * @param conn The connection to be released
      */
