@@ -26,21 +26,21 @@ import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.util.ArrayList;
 import java.util.List;
-import java.util.concurrent.locks.Lock;
 
-import javax.servlet.ServletContext;
+import jakarta.servlet.ServletContext;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.Globals;
 import org.apache.catalina.Session;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.tomcat.util.concurrent.KeyedReentrantReadWriteLock;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
  * Concrete implementation of the <b>Store</b> interface that utilizes a file per saved Session in a configured
  * directory. Sessions that are saved are still subject to being expired based on inactivity.
+ *
+ * @author Craig R. McClanahan
  */
 public final class FileStore extends StoreBase {
 
@@ -70,7 +70,6 @@ public final class FileStore extends StoreBase {
      */
     private File directoryFile = null;
 
-    private KeyedReentrantReadWriteLock sessionLocksById = new KeyedReentrantReadWriteLock();
 
     /**
      * Name to register for this Store, used for logging.
@@ -115,12 +114,20 @@ public final class FileStore extends StoreBase {
     }
 
 
+    /**
+     * Return the name for this Store, used for logging.
+     */
     @Override
     public String getStoreName() {
         return storeName;
     }
 
 
+    /**
+     * Return the number of Sessions present in this Store.
+     *
+     * @exception IOException if an input/output error occurs
+     */
     @Override
     public int getSize() throws IOException {
         // Acquire the list of files in our storage directory
@@ -128,7 +135,7 @@ public final class FileStore extends StoreBase {
         if (dir == null) {
             return 0;
         }
-        String[] files = dir.list();
+        String files[] = dir.list();
 
         // Figure out which files are sessions
         int keycount = 0;
@@ -145,6 +152,11 @@ public final class FileStore extends StoreBase {
 
     // --------------------------------------------------------- Public Methods
 
+    /**
+     * Remove all of the Sessions in this Store.
+     *
+     * @exception IOException if an input/output error occurs
+     */
     @Override
     public void clear() throws IOException {
         String[] keys = keys();
@@ -154,6 +166,12 @@ public final class FileStore extends StoreBase {
     }
 
 
+    /**
+     * Return an array containing the session identifiers of all Sessions currently saved in this Store. If there are no
+     * such Sessions, a zero-length array is returned.
+     *
+     * @exception IOException if an input/output error occurred
+     */
     @Override
     public String[] keys() throws IOException {
         // Acquire the list of files in our storage directory
@@ -161,7 +179,7 @@ public final class FileStore extends StoreBase {
         if (dir == null) {
             return new String[0];
         }
-        String[] files = dir.list();
+        String files[] = dir.list();
 
         // Bugzilla 32130
         if (files == null || files.length < 1) {
@@ -180,73 +198,83 @@ public final class FileStore extends StoreBase {
     }
 
 
+    /**
+     * Load and return the Session associated with the specified session identifier from this Store, without removing
+     * it. If there is no such stored Session, return <code>null</code>.
+     *
+     * @param id Session identifier of the session to load
+     *
+     * @exception ClassNotFoundException if a deserialization error occurs
+     * @exception IOException            if an input/output error occurs
+     */
     @Override
     public Session load(String id) throws ClassNotFoundException, IOException {
         // Open an input stream to the specified pathname, if any
         File file = file(id);
-        if (file == null) {
+        if (file == null || !file.exists()) {
             return null;
         }
 
         Context context = getManager().getContext();
         Log contextLog = context.getLogger();
 
-        if (contextLog.isTraceEnabled()) {
-            contextLog.trace(sm.getString(getStoreName() + ".loading", id, file.getAbsolutePath()));
+        if (contextLog.isDebugEnabled()) {
+            contextLog.debug(sm.getString(getStoreName() + ".loading", id, file.getAbsolutePath()));
         }
 
         ClassLoader oldThreadContextCL = context.bind(Globals.IS_SECURITY_ENABLED, null);
-        try {
-            Lock readLock = sessionLocksById.getLock(id).readLock();
-            readLock.lock();
-            try {
-                if (!file.exists()) {
-                    return null;
-                }
-                try (FileInputStream fis = new FileInputStream(file.getAbsolutePath());
-                        ObjectInputStream ois = getObjectInputStream(fis)) {
-                    StandardSession session = (StandardSession) manager.createEmptySession();
-                    session.readObjectData(ois);
-                    session.setManager(manager);
-                    return session;
-                } catch (FileNotFoundException e) {
-                    if (contextLog.isDebugEnabled()) {
-                        contextLog.debug(sm.getString("fileStore.noFile", id, file.getAbsolutePath()), e);
-                    }
-                    return null;
-                }
-            } finally {
-                readLock.unlock();
+
+        try (FileInputStream fis = new FileInputStream(file.getAbsolutePath());
+                ObjectInputStream ois = getObjectInputStream(fis)) {
+
+            StandardSession session = (StandardSession) manager.createEmptySession();
+            session.readObjectData(ois);
+            session.setManager(manager);
+            return session;
+        } catch (FileNotFoundException e) {
+            if (contextLog.isDebugEnabled()) {
+                contextLog.debug("No persisted data file found");
             }
+            return null;
         } finally {
             context.unbind(Globals.IS_SECURITY_ENABLED, oldThreadContextCL);
         }
     }
 
 
+    /**
+     * Remove the Session with the specified session identifier from this Store, if present. If no such Session is
+     * present, this method takes no action.
+     *
+     * @param id Session identifier of the Session to be removed
+     *
+     * @exception IOException if an input/output error occurs
+     */
     @Override
     public void remove(String id) throws IOException {
         File file = file(id);
         if (file == null) {
             return;
         }
-        if (manager.getContext().getLogger().isTraceEnabled()) {
+        if (manager.getContext().getLogger().isDebugEnabled()) {
             manager.getContext().getLogger()
-                    .trace(sm.getString(getStoreName() + ".removing", id, file.getAbsolutePath()));
+                    .debug(sm.getString(getStoreName() + ".removing", id, file.getAbsolutePath()));
         }
 
-        Lock writeLock = sessionLocksById.getLock(id).writeLock();
-        writeLock.lock();
-        try {
-            if (file.exists() && !file.delete()) {
-                throw new IOException(sm.getString("fileStore.deleteSessionFailed", file));
-            }
-        } finally {
-            writeLock.unlock();
+        if (file.exists() && !file.delete()) {
+            throw new IOException(sm.getString("fileStore.deleteSessionFailed", file));
         }
     }
 
 
+    /**
+     * Save the specified Session into this Store. Any previously saved information for the associated session
+     * identifier is replaced.
+     *
+     * @param session Session to be saved
+     *
+     * @exception IOException if an input/output error occurs
+     */
     @Override
     public void save(Session session) throws IOException {
         // Open an output stream to the specified pathname, if any
@@ -254,20 +282,14 @@ public final class FileStore extends StoreBase {
         if (file == null) {
             return;
         }
-        if (manager.getContext().getLogger().isTraceEnabled()) {
+        if (manager.getContext().getLogger().isDebugEnabled()) {
             manager.getContext().getLogger()
-                    .trace(sm.getString(getStoreName() + ".saving", session.getIdInternal(), file.getAbsolutePath()));
+                    .debug(sm.getString(getStoreName() + ".saving", session.getIdInternal(), file.getAbsolutePath()));
         }
 
-        Lock writeLock = sessionLocksById.getLock(session.getIdInternal()).writeLock();
-        writeLock.lock();
-        try {
-            try (FileOutputStream fos = new FileOutputStream(file.getAbsolutePath());
-                    ObjectOutputStream oos = new ObjectOutputStream(new BufferedOutputStream(fos))) {
-                ((StandardSession) session).writeObjectData(oos);
-            }
-        } finally {
-            writeLock.unlock();
+        try (FileOutputStream fos = new FileOutputStream(file.getAbsolutePath());
+                ObjectOutputStream oos = new ObjectOutputStream(new BufferedOutputStream(fos))) {
+            ((StandardSession) session).writeObjectData(oos);
         }
     }
 
@@ -278,12 +300,12 @@ public final class FileStore extends StoreBase {
      * Return a File object representing the pathname to our session persistence directory, if any. The directory will
      * be created if it does not already exist.
      */
-    private synchronized File directory() throws IOException {
-        // Synchronised to avoid concurrent attempts to create the directory.
+    private File directory() throws IOException {
         if (this.directory == null) {
             return null;
         }
         if (this.directoryFile != null) {
+            // NOTE: Race condition is harmless, so do not synchronize
             return this.directoryFile;
         }
         File file = new File(this.directory);
