@@ -42,6 +42,8 @@ import org.apache.juli.logging.LogFactory;
  * <p>
  * <b>IMPLEMENTATION NOTE</b>: Correct behavior of session storing and reloading depends upon external calls to the
  * {@link Lifecycle#start()} and {@link Lifecycle#stop()} methods of this class at the correct times.
+ *
+ * @author Craig R. McClanahan
  */
 public abstract class PersistentManagerBase extends ManagerBase implements StoreManager {
 
@@ -289,8 +291,8 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             if (super.findSession(id) != null) {
                 return true;
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("persistentManager.isLoadedError", id), ioe);
+        } catch (IOException e) {
+            log.error(sm.getString("persistentManager.isLoadedError", id), e);
         }
         return false;
     }
@@ -313,6 +315,9 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
     }
 
 
+    /**
+     * @return the Store object which manages persistent Session storage for this Manager.
+     */
     @Override
     public Store getStore() {
         return this.store;
@@ -375,8 +380,8 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             } else {
                 store.clear();
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("persistentManager.storeClearError"), ioe);
+        } catch (IOException e) {
+            log.error(sm.getString("persistentManager.storeClearError"), e);
         }
 
     }
@@ -391,10 +396,10 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
     public void processExpires() {
 
         long timeNow = System.currentTimeMillis();
-        Session[] sessions = findSessions();
+        Session sessions[] = findSessions();
         int expireHere = 0;
-        if (log.isTraceEnabled()) {
-            log.trace("Start expire sessions " + getName() + " at " + timeNow + " sessioncount " + sessions.length);
+        if (log.isDebugEnabled()) {
+            log.debug("Start expire sessions " + getName() + " at " + timeNow + " sessioncount " + sessions.length);
         }
         for (Session session : sessions) {
             if (!session.isValid()) {
@@ -408,8 +413,8 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
         }
 
         long timeEnd = System.currentTimeMillis();
-        if (log.isTraceEnabled()) {
-            log.trace("End expire sessions " + getName() + " processingTime " + (timeEnd - timeNow) +
+        if (log.isDebugEnabled()) {
+            log.debug("End expire sessions " + getName() + " processingTime " + (timeEnd - timeNow) +
                     " expired sessions: " + expireHere);
         }
         processingTime += (timeEnd - timeNow);
@@ -466,6 +471,12 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
         return session;
     }
 
+    /**
+     * Remove this Session from the active Sessions for this Manager, but not from the Store. (Used by the
+     * PersistentValve)
+     *
+     * @param session Session to be removed
+     */
     @Override
     public void removeSuper(Session session) {
         super.remove(session, false);
@@ -488,7 +499,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             return;
         }
 
-        String[] ids;
+        String[] ids = null;
         try {
             if (SecurityUtil.isPackageProtectionEnabled()) {
                 try {
@@ -500,8 +511,8 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             } else {
                 ids = store.keys();
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("persistentManager.storeLoadKeysError"), ioe);
+        } catch (IOException e) {
+            log.error(sm.getString("persistentManager.storeLoadKeysError"), e);
             return;
         }
 
@@ -517,8 +528,8 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
         for (String id : ids) {
             try {
                 swapIn(id);
-            } catch (IOException ioe) {
-                log.error(sm.getString("persistentManager.storeLoadError"), ioe);
+            } catch (IOException e) {
+                log.error(sm.getString("persistentManager.storeLoadError"), e);
             }
         }
 
@@ -557,8 +568,8 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             } else {
                 store.remove(id);
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("persistentManager.removeError"), ioe);
+        } catch (IOException e) {
+            log.error(sm.getString("persistentManager.removeError"), e);
         }
     }
 
@@ -576,7 +587,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             return;
         }
 
-        Session[] sessions = findSessions();
+        Session sessions[] = findSessions();
         int n = sessions.length;
         if (n == 0) {
             return;
@@ -589,7 +600,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
         for (Session session : sessions) {
             try {
                 swapOut(session);
-            } catch (IOException ignore) {
+            } catch (IOException e) {
                 // This is logged in writeSession()
             }
         }
@@ -605,7 +616,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             // Store session count
             result += getStore().getSize();
         } catch (IOException ioe) {
-            log.warn(sm.getString("persistentManager.storeSizeException"), ioe);
+            log.warn(sm.getString("persistentManager.storeSizeException"));
         }
         return result;
     }
@@ -618,8 +629,8 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
         try {
             // Store session ID list
             sessionIds.addAll(Arrays.asList(getStore().keys()));
-        } catch (IOException ioe) {
-            log.warn(sm.getString("persistentManager.storeKeysException"), ioe);
+        } catch (IOException e) {
+            log.warn(sm.getString("persistentManager.storeKeysException"));
         }
         return sessionIds;
     }
@@ -644,7 +655,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             return null;
         }
 
-        Object swapInLock;
+        Object swapInLock = null;
 
         /*
          * The purpose of this sync and these locks is to make sure that a session is only loaded once. It doesn't
@@ -656,7 +667,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             swapInLock = sessionSwapInLocks.computeIfAbsent(id, k -> new Object());
         }
 
-        Session session;
+        Session session = null;
 
         synchronized (swapInLock) {
             // First check to see if another thread has loaded the session into
@@ -697,8 +708,8 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
     }
 
     private void reactivateLoadedSession(String id, Session session) {
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("persistentManager.swapIn", id));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("persistentManager.swapIn", id));
         }
 
         session.setManager(this);
@@ -794,9 +805,9 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             } else {
                 store.save(session);
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("persistentManager.serializeError", session.getIdInternal()), ioe);
-            throw ioe;
+        } catch (IOException e) {
+            log.error(sm.getString("persistentManager.serializeError", session.getIdInternal(), e));
+            throw e;
         }
 
     }
@@ -810,12 +821,12 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
      *                                   used
      */
     @Override
-    protected void startInternal() throws LifecycleException {
+    protected synchronized void startInternal() throws LifecycleException {
 
         super.startInternal();
 
         if (store == null) {
-            log.error(sm.getString("persistentManager.noStore"));
+            log.error("No Store configured, persistence disabled");
         } else if (store instanceof Lifecycle) {
             ((Lifecycle) store).start();
         }
@@ -832,10 +843,10 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
      *                                   used
      */
     @Override
-    protected void stopInternal() throws LifecycleException {
+    protected synchronized void stopInternal() throws LifecycleException {
 
-        if (log.isTraceEnabled()) {
-            log.trace("Stopping");
+        if (log.isDebugEnabled()) {
+            log.debug("Stopping");
         }
 
         setState(LifecycleState.STOPPING);
@@ -844,7 +855,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             unload();
         } else {
             // Expire all active sessions
-            Session[] sessions = findSessions();
+            Session sessions[] = findSessions();
             for (Session value : sessions) {
                 StandardSession session = (StandardSession) value;
                 if (!session.isValid()) {
@@ -875,7 +886,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             return;
         }
 
-        Session[] sessions = findSessions();
+        Session sessions[] = findSessions();
 
         // Swap out all sessions idle longer than maxIdleSwap
         if (maxIdleSwap >= 0) {
@@ -891,13 +902,13 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
                             // Session is currently being accessed - skip it
                             continue;
                         }
-                        if (log.isTraceEnabled()) {
-                            log.trace(sm.getString("persistentManager.swapMaxIdle", session.getIdInternal(),
+                        if (log.isDebugEnabled()) {
+                            log.debug(sm.getString("persistentManager.swapMaxIdle", session.getIdInternal(),
                                     Integer.valueOf(timeIdle)));
                         }
                         try {
                             swapOut(session);
-                        } catch (IOException ignore) {
+                        } catch (IOException e) {
                             // This is logged in writeSession()
                         }
                     }
@@ -917,7 +928,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             return;
         }
 
-        Session[] sessions = findSessions();
+        Session sessions[] = findSessions();
 
         // FIXME: Smarter algorithm (LRU)
         int limit = (int) (getMaxActiveSessions() * 0.9);
@@ -941,13 +952,13 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
                         // Session is currently being accessed - skip it
                         continue;
                     }
-                    if (log.isTraceEnabled()) {
-                        log.trace(sm.getString("persistentManager.swapTooManyActive", session.getIdInternal(),
+                    if (log.isDebugEnabled()) {
+                        log.debug(sm.getString("persistentManager.swapTooManyActive", session.getIdInternal(),
                                 Integer.valueOf(timeIdle)));
                     }
                     try {
                         swapOut(session);
-                    } catch (IOException ignore) {
+                    } catch (IOException e) {
                         // This is logged in writeSession()
                     }
                     toswap--;
@@ -967,7 +978,7 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
             return;
         }
 
-        Session[] sessions = findSessions();
+        Session sessions[] = findSessions();
 
         // Back up all sessions idle longer than maxIdleBackup
         if (maxIdleBackup >= 0) {
@@ -985,14 +996,14 @@ public abstract class PersistentManagerBase extends ManagerBase implements Store
                     }
                     int timeIdle = (int) (session.getIdleTimeInternal() / 1000L);
                     if (timeIdle >= maxIdleBackup) {
-                        if (log.isTraceEnabled()) {
-                            log.trace(sm.getString("persistentManager.backupMaxIdle", session.getIdInternal(),
+                        if (log.isDebugEnabled()) {
+                            log.debug(sm.getString("persistentManager.backupMaxIdle", session.getIdInternal(),
                                     Integer.valueOf(timeIdle)));
                         }
 
                         try {
                             writeSession(session);
-                        } catch (IOException ignore) {
+                        } catch (IOException e) {
                             // This is logged in writeSession()
                         }
                         session.setNote(PERSISTED_LAST_ACCESSED_TIME, Long.valueOf(lastAccessedTime));
