@@ -31,7 +31,7 @@ import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.servlet.ServletContext;
+import jakarta.servlet.ServletContext;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.LifecycleException;
@@ -47,10 +47,12 @@ import org.apache.tomcat.util.ExceptionUtils;
 /**
  * Standard implementation of the <b>Manager</b> interface that provides simple session persistence across restarts of
  * this component (such as when the entire server is shut down and restarted, or when a particular web application is
- * reloaded).
+ * reloaded.
  * <p>
  * <b>IMPLEMENTATION NOTE</b>: Correct behavior of session storing and reloading depends upon external calls to the
  * <code>start()</code> and <code>stop()</code> methods of this class at the correct times.
+ *
+ * @author Craig R. McClanahan
  */
 public class StandardManager extends ManagerBase {
 
@@ -98,9 +100,9 @@ public class StandardManager extends ManagerBase {
      * Path name of the disk file in which active sessions are saved when we stop, and from which these sessions are
      * loaded when we start. A <code>null</code> value indicates that no persistence is desired. If this pathname is
      * relative, it will be resolved against the temporary working directory provided by our context, available via the
-     * <code>javax.servlet.context.tempdir</code> context attribute.
+     * <code>jakarta.servlet.context.tempdir</code> context attribute.
      */
-    protected String pathname = "SESSIONS.ser";
+    protected String pathname = null;
 
 
     // ------------------------------------------------------------- Properties
@@ -164,8 +166,8 @@ public class StandardManager extends ManagerBase {
      * @exception IOException            if an input/output error occurs
      */
     protected void doLoad() throws ClassNotFoundException, IOException {
-        if (log.isTraceEnabled()) {
-            log.trace("Start: Loading persisted sessions");
+        if (log.isDebugEnabled()) {
+            log.debug("Start: Loading persisted sessions");
         }
 
         // Initialize our internal data structures
@@ -176,12 +178,12 @@ public class StandardManager extends ManagerBase {
         if (file == null) {
             return;
         }
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("standardManager.loading", pathname));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("standardManager.loading", pathname));
         }
-        Loader loader;
+        Loader loader = null;
         ClassLoader classLoader = null;
-        Log logger;
+        Log logger = null;
         try (FileInputStream fis = new FileInputStream(file.getAbsolutePath());
                 BufferedInputStream bis = new BufferedInputStream(fis)) {
             Context c = getContext();
@@ -200,8 +202,8 @@ public class StandardManager extends ManagerBase {
                         getSessionAttributeValueClassNamePattern(), getWarnOnSessionAttributeFilterFailure())) {
                     Integer count = (Integer) ois.readObject();
                     int n = count.intValue();
-                    if (log.isTraceEnabled()) {
-                        log.trace("Loading " + n + " persisted sessions");
+                    if (log.isDebugEnabled()) {
+                        log.debug("Loading " + n + " persisted sessions");
                     }
                     for (int i = 0; i < n; i++) {
                         StandardSession session = getNewSession();
@@ -215,6 +217,7 @@ public class StandardManager extends ManagerBase {
                             session.setValid(true);
                             session.expire();
                         }
+                        sessionCounter++;
                     }
                 } finally {
                     // Delete the persistent storage file
@@ -227,13 +230,13 @@ public class StandardManager extends ManagerBase {
             }
         } catch (FileNotFoundException e) {
             if (log.isDebugEnabled()) {
-                log.debug(sm.getString("standardManager.noFile", file.getAbsolutePath()), e);
+                log.debug("No persisted data file found");
             }
             return;
         }
 
-        if (log.isTraceEnabled()) {
-            log.trace("Finish: Loading persisted sessions");
+        if (log.isDebugEnabled()) {
+            log.debug("Finish: Loading persisted sessions");
         }
     }
 
@@ -266,8 +269,8 @@ public class StandardManager extends ManagerBase {
      */
     protected void doUnload() throws IOException {
 
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("standardManager.unloading.debug"));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("standardManager.unloading.debug"));
         }
 
         if (sessions.isEmpty()) {
@@ -280,8 +283,8 @@ public class StandardManager extends ManagerBase {
         if (file == null) {
             return;
         }
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("standardManager.unloading", pathname));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("standardManager.unloading", pathname));
         }
 
         // Keep a note of sessions that are expired
@@ -292,8 +295,8 @@ public class StandardManager extends ManagerBase {
                 ObjectOutputStream oos = new ObjectOutputStream(bos)) {
 
             synchronized (sessions) {
-                if (log.isTraceEnabled()) {
-                    log.trace("Unloading " + sessions.size() + " sessions");
+                if (log.isDebugEnabled()) {
+                    log.debug("Unloading " + sessions.size() + " sessions");
                 }
                 // Write the number of active sessions, followed by the details
                 oos.writeObject(Integer.valueOf(sessions.size()));
@@ -308,7 +311,7 @@ public class StandardManager extends ManagerBase {
 
         // Expire all the sessions we just wrote
         if (log.isDebugEnabled()) {
-            log.debug(sm.getString("standardManager.expiringSessions", Integer.toString(list.size())));
+            log.debug("Expiring " + list.size() + " persisted sessions");
         }
         for (StandardSession session : list) {
             try {
@@ -320,8 +323,8 @@ public class StandardManager extends ManagerBase {
             }
         }
 
-        if (log.isTraceEnabled()) {
-            log.trace("Unloading complete");
+        if (log.isDebugEnabled()) {
+            log.debug("Unloading complete");
         }
     }
 
@@ -334,7 +337,7 @@ public class StandardManager extends ManagerBase {
      *                                   used
      */
     @Override
-    protected void startInternal() throws LifecycleException {
+    protected synchronized void startInternal() throws LifecycleException {
 
         super.startInternal();
 
@@ -358,10 +361,10 @@ public class StandardManager extends ManagerBase {
      *                                   used
      */
     @Override
-    protected void stopInternal() throws LifecycleException {
+    protected synchronized void stopInternal() throws LifecycleException {
 
-        if (log.isTraceEnabled()) {
-            log.trace("Stopping");
+        if (log.isDebugEnabled()) {
+            log.debug("Stopping");
         }
 
         setState(LifecycleState.STOPPING);
@@ -375,7 +378,7 @@ public class StandardManager extends ManagerBase {
         }
 
         // Expire all active sessions
-        Session[] sessions = findSessions();
+        Session sessions[] = findSessions();
         for (Session session : sessions) {
             try {
                 if (session.isValid()) {
@@ -403,7 +406,7 @@ public class StandardManager extends ManagerBase {
      * @return the file
      */
     protected File file() {
-        if (pathname == null || pathname.isEmpty()) {
+        if (pathname == null || pathname.length() == 0) {
             return null;
         }
         File file = new File(pathname);
