@@ -314,9 +314,6 @@ public class StandardSession implements HttpSession, Session, Serializable {
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setId(String id, boolean notify) {
 
@@ -342,7 +339,7 @@ public class StandardSession implements HttpSession, Session, Serializable {
     public void tellNew() {
 
         // Notify interested session event listeners
-        fireSessionEvent(Session.SESSION_CREATED_EVENT, null);
+        fireSessionEvent(SESSION_CREATED_EVENT, null);
 
         // Notify interested application event listeners
         Context context = manager.getContext();
@@ -780,7 +777,7 @@ public class StandardSession implements HttpSession, Session, Serializable {
 
             // Notify interested session event listeners
             if (notify) {
-                fireSessionEvent(Session.SESSION_DESTROYED_EVENT, null);
+                fireSessionEvent(SESSION_DESTROYED_EVENT, null);
             }
 
             // Call the logout method
@@ -819,7 +816,7 @@ public class StandardSession implements HttpSession, Session, Serializable {
     public void passivate() {
 
         // Notify interested session event listeners
-        fireSessionEvent(Session.SESSION_PASSIVATED_EVENT, null);
+        fireSessionEvent(SESSION_PASSIVATED_EVENT, null);
 
         // Notify ActivationListeners
         HttpSessionEvent event = null;
@@ -853,7 +850,7 @@ public class StandardSession implements HttpSession, Session, Serializable {
         }
 
         // Notify interested session event listeners
-        fireSessionEvent(Session.SESSION_ACTIVATED_EVENT, null);
+        fireSessionEvent(SESSION_ACTIVATED_EVENT, null);
 
         // Notify ActivationListeners
         HttpSessionEvent event = null;
@@ -1486,7 +1483,7 @@ public class StandardSession implements HttpSession, Session, Serializable {
         if (getPersistAuthentication()) {
             sessionAuthType = getAuthType();
             sessionPrincipal = getPrincipal();
-            if (!(sessionPrincipal instanceof Serializable)) {
+            if (sessionPrincipal != null && !(sessionPrincipal instanceof Serializable)) {
                 sessionPrincipal = null;
                 manager.getContext().getLogger().warn(sm.getString("standardSession.principalNotSerializable", id));
             }
