@@ -35,12 +35,12 @@ public class ExpressionParseTree {
     private static final StringManager sm = StringManager.getManager(ExpressionParseTree.class);
     /**
      * Contains the current set of completed nodes. This is a workspace for the
-     * parser.
+     * parser. Needs to be LinkedList since it can contain {@code null}s.
      */
     private final LinkedList<Node> nodeStack = new LinkedList<>();
     /**
      * Contains operator nodes that don't yet have values. This is a workspace
-     * for the parser.
+     * for the parser. Needs to be LinkedList since it can contain {@code null}s.
      */
     private final LinkedList<OppNode> oppStack = new LinkedList<>();
     /**
@@ -243,7 +243,7 @@ public class ExpressionParseTree {
         String resolved = null;
 
 
-        public StringNode(String value) {
+        StringNode(String value) {
             this.value = new StringBuilder(value);
         }
 
