@@ -14,7 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.catalina.ssi;
 
 import java.io.IOException;
@@ -22,14 +21,14 @@ import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.util.Locale;
 
-import javax.servlet.ServletOutputStream;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpServletResponseWrapper;
+import jakarta.servlet.ServletOutputStream;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpServletResponseWrapper;
 
 import org.apache.tomcat.util.http.FastHttpDateFormat;
 
 /**
- * A HttpServletResponseWrapper, used from
+ * An HttpServletResponseWrapper, used from
  * <code>SSIServletExternalResolver</code>
  *
  * @author Bip Thelin
@@ -81,7 +80,7 @@ public class ResponseIncludeWrapper extends HttpServletResponseWrapper {
 
 
     /**
-     * Return a printwriter, throws and exception if a OutputStream already
+     * Return a printwriter, throws and exception if an OutputStream already
      * been returned.
      *
      * @return a PrintWriter object
@@ -89,7 +88,7 @@ public class ResponseIncludeWrapper extends HttpServletResponseWrapper {
      *                if the outputstream already been called
      */
     @Override
-    public PrintWriter getWriter() throws java.io.IOException {
+    public PrintWriter getWriter() throws IOException {
         if (servletOutputStream == null) {
             if (printWriter == null) {
                 setCharacterEncoding(getCharacterEncoding());
@@ -104,15 +103,15 @@ public class ResponseIncludeWrapper extends HttpServletResponseWrapper {
 
 
     /**
-     * Return a OutputStream, throws and exception if a printwriter already
+     * Return an OutputStream, throws and exception if a printwriter already
      * been returned.
      *
-     * @return a OutputStream object
+     * @return an OutputStream object
      * @exception java.io.IOException
      *                if the printwriter already been called
      */
     @Override
-    public ServletOutputStream getOutputStream() throws java.io.IOException {
+    public ServletOutputStream getOutputStream() throws IOException {
         if (printWriter == null) {
             if (servletOutputStream == null) {
                 servletOutputStream = captureServletOutputStream;
