@@ -16,6 +16,7 @@
  */
 package org.apache.catalina.ssi;
 
+
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
@@ -23,9 +24,14 @@ import java.io.PrintWriter;
 
 import org.apache.catalina.util.IOTools;
 import org.apache.tomcat.util.res.StringManager;
-
 /**
- * Implements the Server-side #exec command.
+ * Implements the Server-side #exec command
+ *
+ * @author Bip Thelin
+ * @author Amy Roh
+ * @author Paul Speed
+ * @author Dan Sandberg
+ * @author David Becker
  */
 public class SSIExec implements SSICommand {
     private static final StringManager sm = StringManager.getManager(SSIExec.class);
@@ -33,17 +39,21 @@ public class SSIExec implements SSICommand {
     protected static final int BUFFER_SIZE = 1024;
 
 
+    /**
+     * @see SSICommand
+     */
     @Override
-    public long process(SSIMediator ssiMediator, String commandName, String[] paramNames, String[] paramValues,
-            PrintWriter writer) {
+    public long process(SSIMediator ssiMediator, String commandName,
+            String[] paramNames, String[] paramValues, PrintWriter writer) {
         long lastModified = 0;
         String configErrMsg = ssiMediator.getConfigErrMsg();
         String paramName = paramNames[0];
         String paramValue = paramValues[0];
         String substitutedValue = ssiMediator.substituteVariables(paramValue);
         if (paramName.equalsIgnoreCase("cgi")) {
-            lastModified = ssiInclude.process(ssiMediator, "include", new String[] { "virtual" },
-                    new String[] { substitutedValue }, writer);
+            lastModified = ssiInclude.process(ssiMediator, "include",
+                    new String[]{"virtual"}, new String[]{substitutedValue},
+                    writer);
         } else if (paramName.equalsIgnoreCase("cmd")) {
             boolean foundProgram = false;
             try {
@@ -52,8 +62,7 @@ public class SSIExec implements SSICommand {
                 foundProgram = true;
                 char[] buf = new char[BUFFER_SIZE];
                 try (BufferedReader stdOutReader = new BufferedReader(new InputStreamReader(proc.getInputStream()));
-                        BufferedReader stdErrReader =
-                                new BufferedReader(new InputStreamReader(proc.getErrorStream()))) {
+                        BufferedReader stdErrReader = new BufferedReader(new InputStreamReader(proc.getErrorStream()));) {
                     IOTools.flow(stdErrReader, writer, buf);
                     IOTools.flow(stdOutReader, writer, buf);
                 }
@@ -62,14 +71,14 @@ public class SSIExec implements SSICommand {
             } catch (InterruptedException e) {
                 ssiMediator.log(sm.getString("ssiExec.executeFailed", substitutedValue), e);
                 writer.write(configErrMsg);
-            } catch (IOException ioe) {
+            } catch (IOException e) {
                 if (!foundProgram) {
                     // Apache doesn't output an error message if it can't find
                     // a program
                 }
-                ssiMediator.log(sm.getString("ssiExec.executeFailed", substitutedValue), ioe);
+                ssiMediator.log(sm.getString("ssiExec.executeFailed", substitutedValue), e);
             }
         }
         return lastModified;
     }
-}
+}
\ No newline at end of file
