@@ -28,17 +28,18 @@ import java.io.Reader;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import javax.servlet.FilterChain;
-import javax.servlet.GenericFilter;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.GenericFilter;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 /**
- * Filter to process SSI requests within a webpage. Mapped to a content types from within web.xml.
+ * Filter to process SSI requests within a webpage. Mapped to a content types
+ * from within web.xml.
  *
+ * @author David Becker
  * @see org.apache.catalina.ssi.SSIServlet
  */
 public class SSIFilter extends GenericFilter {
@@ -52,7 +53,8 @@ public class SSIFilter extends GenericFilter {
     /** regex pattern to match when evaluating content types */
     protected Pattern contentTypeRegEx = null;
     /** default pattern for ssi filter content type matching */
-    protected final Pattern shtmlRegEx = Pattern.compile("text/x-server-parsed-html(;.*)?");
+    protected final Pattern shtmlRegEx =
+        Pattern.compile("text/x-server-parsed-html(;.*)?");
     /** Allow exec (normally blocked for security) */
     protected boolean allowExec = false;
 
@@ -78,16 +80,17 @@ public class SSIFilter extends GenericFilter {
         allowExec = Boolean.parseBoolean(getInitParameter("allowExec"));
 
         if (debug > 0) {
-            getServletContext().log("SSIFilter.init() SSI invoker started with 'debug'=" + debug);
+            getServletContext().log(
+                    "SSIFilter.init() SSI invoker started with 'debug'=" + debug);
         }
     }
 
     @Override
-    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
-            throws IOException, ServletException {
+    public void doFilter(ServletRequest request, ServletResponse response,
+            FilterChain chain) throws IOException, ServletException {
         // cast once
-        HttpServletRequest req = (HttpServletRequest) request;
-        HttpServletResponse res = (HttpServletResponse) response;
+        HttpServletRequest req = (HttpServletRequest)request;
+        HttpServletResponse res = (HttpServletResponse)response;
 
         // setup to capture output
         ByteArrayServletOutputStream basos = new ByteArrayServletOutputStream();
@@ -108,17 +111,22 @@ public class SSIFilter extends GenericFilter {
             String encoding = res.getCharacterEncoding();
 
             // set up SSI processing
-            SSIExternalResolver ssiExternalResolver = new SSIServletExternalResolver(getServletContext(), req, res,
-                    isVirtualWebappRelative, debug, encoding);
-            SSIProcessor ssiProcessor = new SSIProcessor(ssiExternalResolver, debug, allowExec);
+            SSIExternalResolver ssiExternalResolver =
+                new SSIServletExternalResolver(getServletContext(), req,
+                        res, isVirtualWebappRelative, debug, encoding);
+            SSIProcessor ssiProcessor = new SSIProcessor(ssiExternalResolver,
+                    debug, allowExec);
 
             // prepare readers/writers
-            Reader reader = new InputStreamReader(new ByteArrayInputStream(bytes), encoding);
+            Reader reader =
+                new InputStreamReader(new ByteArrayInputStream(bytes), encoding);
             ByteArrayOutputStream ssiout = new ByteArrayOutputStream();
-            PrintWriter writer = new PrintWriter(new OutputStreamWriter(ssiout, encoding));
+            PrintWriter writer =
+                new PrintWriter(new OutputStreamWriter(ssiout, encoding));
 
             // do SSI processing
-            long lastModified = ssiProcessor.process(reader, responseIncludeWrapper.getLastModified(), writer);
+            long lastModified = ssiProcessor.process(reader,
+                    responseIncludeWrapper.getLastModified(), writer);
 
             // set output bytes
             writer.flush();
@@ -126,14 +134,16 @@ public class SSIFilter extends GenericFilter {
 
             // override headers
             if (expires != null) {
-                res.setDateHeader("expires", (new java.util.Date()).getTime() + expires.longValue() * 1000);
+                res.setDateHeader("expires", (new java.util.Date()).getTime()
+                        + expires.longValue() * 1000);
             }
             if (lastModified > 0) {
                 res.setDateHeader("last-modified", lastModified);
             }
             res.setContentLength(bytes.length);
 
-            Matcher shtmlMatcher = shtmlRegEx.matcher(responseIncludeWrapper.getContentType());
+            Matcher shtmlMatcher =
+                shtmlRegEx.matcher(responseIncludeWrapper.getContentType());
             if (shtmlMatcher.matches()) {
                 // Convert SHTML mime type to ordinary HTML mime type but preserve
                 // encoding, if any.
