@@ -22,9 +22,13 @@ import java.io.PrintWriter;
 import java.text.DecimalFormat;
 
 import org.apache.tomcat.util.res.StringManager;
-
 /**
- * Implements the Server-side #fsize command.
+ * Implements the Server-side #fsize command
+ *
+ * @author Bip Thelin
+ * @author Paul Speed
+ * @author Dan Sandberg
+ * @author David Becker
  */
 public final class SSIFsize implements SSICommand {
     private static final StringManager sm = StringManager.getManager(SSIFsize.class);
@@ -32,28 +36,35 @@ public final class SSIFsize implements SSICommand {
     static final int ONE_MEBIBYTE = 1024 * 1024;
 
 
+    /**
+     * @see SSICommand
+     */
     @Override
-    public long process(SSIMediator ssiMediator, String commandName, String[] paramNames, String[] paramValues,
-            PrintWriter writer) {
+    public long process(SSIMediator ssiMediator, String commandName,
+            String[] paramNames, String[] paramValues, PrintWriter writer) {
         long lastModified = 0;
         String configErrMsg = ssiMediator.getConfigErrMsg();
         for (int i = 0; i < paramNames.length; i++) {
             String paramName = paramNames[i];
             String paramValue = paramValues[i];
-            String substitutedValue = ssiMediator.substituteVariables(paramValue);
+            String substitutedValue = ssiMediator
+                    .substituteVariables(paramValue);
             try {
-                if (paramName.equalsIgnoreCase("file") || paramName.equalsIgnoreCase("virtual")) {
+                if (paramName.equalsIgnoreCase("file")
+                        || paramName.equalsIgnoreCase("virtual")) {
                     boolean virtual = paramName.equalsIgnoreCase("virtual");
-                    lastModified = ssiMediator.getFileLastModified(substitutedValue, virtual);
-                    long size = ssiMediator.getFileSize(substitutedValue, virtual);
+                    lastModified = ssiMediator.getFileLastModified(
+                            substitutedValue, virtual);
+                    long size = ssiMediator.getFileSize(substitutedValue,
+                            virtual);
                     String configSizeFmt = ssiMediator.getConfigSizeFmt();
                     writer.write(formatSize(size, configSizeFmt));
                 } else {
                     ssiMediator.log(sm.getString("ssiCommand.invalidAttribute", paramName));
                     writer.write(configErrMsg);
                 }
-            } catch (IOException ioe) {
-                ssiMediator.log(sm.getString("ssiFsize.noSize", substitutedValue), ioe);
+            } catch (IOException e) {
+                ssiMediator.log(sm.getString("ssiFsize.noSize", substitutedValue), e);
                 writer.write(configErrMsg);
             }
         }
@@ -86,8 +97,8 @@ public final class SSIFsize implements SSICommand {
     // We try to mimic httpd here, as we do everywhere.
     // All the 'magic' numbers are from the util_script.c httpd source file.
     // Should use KiB and MiB in output but use k and M for consistency with httpd.
-    private String formatSize(long size, String format) {
-        String retString;
+    protected String formatSize(long size, String format) {
+        String retString = "";
         if (format.equalsIgnoreCase("bytes")) {
             DecimalFormat decimalFormat = new DecimalFormat("#,##0");
             retString = decimalFormat.format(size);
@@ -103,9 +114,10 @@ public final class SSIFsize implements SSICommand {
                 retString += "k";
             } else if (size < 99 * ONE_MEBIBYTE) {
                 DecimalFormat decimalFormat = new DecimalFormat("0.0M");
-                retString = decimalFormat.format(size / (double) ONE_MEBIBYTE);
+                retString = decimalFormat.format(size / (double)ONE_MEBIBYTE);
             } else {
-                retString = Long.toString((size + (529 * ONE_KIBIBYTE)) / ONE_MEBIBYTE);
+                retString = Long.toString((size + (529 * ONE_KIBIBYTE))
+                        / ONE_MEBIBYTE);
                 retString += "M";
             }
             retString = padLeft(retString, 5);
