@@ -27,14 +27,14 @@ import java.net.URL;
 import java.net.URLConnection;
 import java.util.Locale;
 
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 /**
- * Servlet to process SSI requests within a webpage. Mapped to a path from within web.xml.
+ * Servlet to process SSI requests within a webpage. Mapped to a path from
+ * within web.xml.
  *
  * @author Bip Thelin
  * @author Amy Roh
@@ -60,8 +60,13 @@ public class SSIServlet extends HttpServlet {
     protected boolean allowExec = false;
 
 
-    // ----------------- Public methods.
-
+    //----------------- Public methods.
+    /**
+     * Initialize this servlet.
+     *
+     * @exception ServletException
+     *                if an error occurs
+     */
     @Override
     public void init() throws ServletException {
 
@@ -69,7 +74,8 @@ public class SSIServlet extends HttpServlet {
             debug = Integer.parseInt(getServletConfig().getInitParameter("debug"));
         }
 
-        isVirtualWebappRelative = Boolean.parseBoolean(getServletConfig().getInitParameter("isVirtualWebappRelative"));
+        isVirtualWebappRelative =
+            Boolean.parseBoolean(getServletConfig().getInitParameter("isVirtualWebappRelative"));
 
         if (getServletConfig().getInitParameter("expires") != null) {
             expires = Long.valueOf(getServletConfig().getInitParameter("expires"));
@@ -83,7 +89,8 @@ public class SSIServlet extends HttpServlet {
             outputEncoding = getServletConfig().getInitParameter("outputEncoding");
         }
 
-        allowExec = Boolean.parseBoolean(getServletConfig().getInitParameter("allowExec"));
+        allowExec = Boolean.parseBoolean(
+                getServletConfig().getInitParameter("allowExec"));
 
         if (debug > 0) {
             log("SSIServlet.init() SSI invoker started with 'debug'=" + debug);
@@ -93,16 +100,20 @@ public class SSIServlet extends HttpServlet {
 
 
     /**
-     * Process and forward the GET request to our <code>requestHandler()</code>.
+     * Process and forward the GET request to our <code>requestHandler()</code>*
      *
-     * @param req a value of type 'HttpServletRequest'
-     * @param res a value of type 'HttpServletResponse'
-     *
-     * @exception IOException      if an error occurs
-     * @exception ServletException if an error occurs
+     * @param req
+     *            a value of type 'HttpServletRequest'
+     * @param res
+     *            a value of type 'HttpServletResponse'
+     * @exception IOException
+     *                if an error occurs
+     * @exception ServletException
+     *                if an error occurs
      */
     @Override
-    public void doGet(HttpServletRequest req, HttpServletResponse res) throws IOException, ServletException {
+    public void doGet(HttpServletRequest req, HttpServletResponse res)
+            throws IOException, ServletException {
         if (debug > 0) {
             log("SSIServlet.doGet()");
         }
@@ -111,16 +122,21 @@ public class SSIServlet extends HttpServlet {
 
 
     /**
-     * Process and forward the POST request to our <code>requestHandler()</code>.
+     * Process and forward the POST request to our
+     * <code>requestHandler()</code>.
      *
-     * @param req a value of type 'HttpServletRequest'
-     * @param res a value of type 'HttpServletResponse'
-     *
-     * @exception IOException      if an error occurs
-     * @exception ServletException if an error occurs
+     * @param req
+     *            a value of type 'HttpServletRequest'
+     * @param res
+     *            a value of type 'HttpServletResponse'
+     * @exception IOException
+     *                if an error occurs
+     * @exception ServletException
+     *                if an error occurs
      */
     @Override
-    public void doPost(HttpServletRequest req, HttpServletResponse res) throws IOException, ServletException {
+    public void doPost(HttpServletRequest req, HttpServletResponse res)
+            throws IOException, ServletException {
         if (debug > 0) {
             log("SSIServlet.doPost()");
         }
@@ -131,22 +147,25 @@ public class SSIServlet extends HttpServlet {
     /**
      * Process our request and locate right SSI command.
      *
-     * @param req a value of type 'HttpServletRequest'
-     * @param res a value of type 'HttpServletResponse'
-     *
+     * @param req
+     *            a value of type 'HttpServletRequest'
+     * @param res
+     *            a value of type 'HttpServletResponse'
      * @throws IOException an IO error occurred
      */
-    protected void requestHandler(HttpServletRequest req, HttpServletResponse res) throws IOException {
+    protected void requestHandler(HttpServletRequest req,
+            HttpServletResponse res) throws IOException {
         ServletContext servletContext = getServletContext();
         String path = SSIServletRequestUtil.getRelativePath(req);
         if (debug > 0) {
-            log("SSIServlet.requestHandler()\n" + "Serving " + (buffered ? "buffered " : "unbuffered ") + "resource '" +
-                    path + "'");
+            log("SSIServlet.requestHandler()\n" + "Serving "
+                    + (buffered?"buffered ":"unbuffered ") + "resource '"
+                    + path + "'");
         }
         // Exclude any resource in the /WEB-INF and /META-INF subdirectories
         // (the "toUpperCase()" avoids problems on Windows systems)
-        if (path == null || path.toUpperCase(Locale.ENGLISH).startsWith("/WEB-INF") ||
-                path.toUpperCase(Locale.ENGLISH).startsWith("/META-INF")) {
+        if (path == null || path.toUpperCase(Locale.ENGLISH).startsWith("/WEB-INF")
+                || path.toUpperCase(Locale.ENGLISH).startsWith("/META-INF")) {
             res.sendError(HttpServletResponse.SC_NOT_FOUND);
             return;
         }
@@ -161,17 +180,21 @@ public class SSIServlet extends HttpServlet {
         }
         res.setContentType(resourceMimeType + ";charset=" + outputEncoding);
         if (expires != null) {
-            res.setDateHeader("Expires", (new java.util.Date()).getTime() + expires.longValue() * 1000);
+            res.setDateHeader("Expires", (new java.util.Date()).getTime()
+                    + expires.longValue() * 1000);
         }
         processSSI(req, res, resource);
     }
 
 
-    protected void processSSI(HttpServletRequest req, HttpServletResponse res, URL resource) throws IOException {
-        SSIExternalResolver ssiExternalResolver = new SSIServletExternalResolver(getServletContext(), req, res,
-                isVirtualWebappRelative, debug, inputEncoding);
-        SSIProcessor ssiProcessor = new SSIProcessor(ssiExternalResolver, debug, allowExec);
-        PrintWriter printWriter;
+    protected void processSSI(HttpServletRequest req, HttpServletResponse res,
+            URL resource) throws IOException {
+        SSIExternalResolver ssiExternalResolver =
+            new SSIServletExternalResolver(getServletContext(), req, res,
+                    isVirtualWebappRelative, debug, inputEncoding);
+        SSIProcessor ssiProcessor = new SSIProcessor(ssiExternalResolver,
+                debug, allowExec);
+        PrintWriter printWriter = null;
         StringWriter stringWriter = null;
         if (buffered) {
             stringWriter = new StringWriter();
@@ -194,12 +217,14 @@ public class SSIServlet extends HttpServlet {
         }
 
         try (BufferedReader bufferedReader = new BufferedReader(isr)) {
-            long lastModified = ssiProcessor.process(bufferedReader, resourceInfo.getLastModified(), printWriter);
+            long lastModified = ssiProcessor.process(bufferedReader,
+                    resourceInfo.getLastModified(), printWriter);
             if (lastModified > 0) {
                 res.setDateHeader("last-modified", lastModified);
             }
-            if (stringWriter != null) {
+            if (buffered) {
                 printWriter.flush();
+                @SuppressWarnings("null")
                 String text = stringWriter.toString();
                 res.getWriter().write(text);
             }
