@@ -16,8 +16,8 @@
  */
 package org.apache.catalina.ssi;
 
-import javax.servlet.RequestDispatcher;
-import javax.servlet.http.HttpServletRequest;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.http.HttpServletRequest;
 
 import org.apache.tomcat.util.http.RequestUtil;
 
@@ -37,11 +37,14 @@ public class SSIServletRequestUtil {
                 RequestDispatcher.INCLUDE_REQUEST_URI) != null) {
             String result = (String)request.getAttribute(
                     RequestDispatcher.INCLUDE_PATH_INFO);
-            if (result == null)
+            if (result == null) {
                 result = (String)request.getAttribute(
                         RequestDispatcher.INCLUDE_SERVLET_PATH);
-            if ((result == null) || (result.equals(""))) result = "/";
-            return (result);
+            }
+            if ((result == null) || (result.equals(""))) {
+                result = "/";
+            }
+            return result;
         }
         // No, extract the desired path directly from the request
         String result = request.getPathInfo();
