@@ -28,8 +28,10 @@ import org.apache.juli.logging.LogFactory;
 import org.apache.naming.StringManager;
 
 /**
- * Concrete implementation of the <code>UserDatabase</code> interface that processes the <code>/etc/passwd</code> file
- * on a Unix system.
+ * Concrete implementation of the <code>UserDatabase</code> interface
+ * that processes the <code>/etc/passwd</code> file on a Unix system.
+ *
+ * @author Craig R. McClanahan
  */
 public final class PasswdUserDatabase implements UserDatabase {
 
@@ -43,7 +45,7 @@ public final class PasswdUserDatabase implements UserDatabase {
 
 
     /**
-     * The set of home directories for all defined users, keyed by username.
+     * The set of home directories for all defined users, keyed by user name.
      */
     private final Map<String,String> homes = new HashMap<>();
 
@@ -54,12 +56,20 @@ public final class PasswdUserDatabase implements UserDatabase {
     private UserConfig userConfig = null;
 
 
+    /**
+     * Return the UserConfig listener with which we are associated.
+     */
     @Override
     public UserConfig getUserConfig() {
         return userConfig;
     }
 
 
+    /**
+     * Set the UserConfig listener with which we are associated.
+     *
+     * @param userConfig The new UserConfig listener
+     */
     @Override
     public void setUserConfig(UserConfig userConfig) {
         this.userConfig = userConfig;
@@ -67,12 +77,20 @@ public final class PasswdUserDatabase implements UserDatabase {
     }
 
 
+    /**
+     * Return an absolute pathname to the home directory for the specified user.
+     *
+     * @param user User for which a home directory should be retrieved
+     */
     @Override
     public String getHome(String user) {
         return homes.get(user);
     }
 
 
+    /**
+     * Return an enumeration of the user names defined on this server.
+     */
     @Override
     public Enumeration<String> getUsers() {
         return Collections.enumeration(homes.keySet());
@@ -86,9 +104,9 @@ public final class PasswdUserDatabase implements UserDatabase {
         try (BufferedReader reader = new BufferedReader(new FileReader(PASSWORD_FILE))) {
             String line = reader.readLine();
             while (line != null) {
-                String[] tokens = line.split(":");
+                String tokens[] = line.split(":");
                 // Need non-zero 1st and 6th tokens
-                if (tokens.length > 5 && !tokens[0].isEmpty() && !tokens[5].isEmpty()) {
+                if (tokens.length > 5 && tokens[0].length() > 0 && tokens[5].length() > 0) {
                     // Add this user and corresponding directory
                     homes.put(tokens[0], tokens[5]);
                 }
