@@ -384,6 +384,9 @@ public class Tomcat {
                                       String servletClass) {
         // will do class for name and set init params
         Wrapper sw = ctx.createWrapper();
+        if (sw == null) {
+            return null;
+        }
         sw.setServletClass(servletClass);
         sw.setName(servletName);
         ctx.addChild(sw);
@@ -1305,7 +1308,7 @@ public class Tomcat {
             }
         }
         SecurityClassLoad.securityClassLoad(Thread.currentThread().getContextClassLoader());
-        org.apache.catalina.startup.Tomcat tomcat = new org.apache.catalina.startup.Tomcat();
+        Tomcat tomcat = new Tomcat();
         // Create a Catalina instance and let it parse the configuration files
         // It will also set a shutdown hook to stop the Server when needed
         // Use the default configuration source
