@@ -14,8 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
-
 package org.apache.catalina.startup;
 
 
@@ -37,7 +35,7 @@ public interface UserDatabase {
     /**
      * @return the UserConfig listener with which we are associated.
      */
-    public UserConfig getUserConfig();
+    UserConfig getUserConfig();
 
 
     /**
@@ -45,7 +43,7 @@ public interface UserDatabase {
      *
      * @param userConfig The new UserConfig listener
      */
-    public void setUserConfig(UserConfig userConfig);
+    void setUserConfig(UserConfig userConfig);
 
 
     // ------------------------------------------------------- Public Methods
@@ -56,13 +54,13 @@ public interface UserDatabase {
      *
      * @param user User for which a home directory should be retrieved
      */
-    public String getHome(String user);
+    String getHome(String user);
 
 
     /**
      * @return an enumeration of the usernames defined on this server.
      */
-    public Enumeration<String> getUsers();
+    Enumeration<String> getUsers();
 
 
 }
