@@ -1,4 +1,4 @@
-/*
+/**
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -36,23 +36,18 @@ import org.apache.tomcat.util.IntrospectionUtils;
 import org.apache.tomcat.util.net.SocketProperties;
 
 /**
- * Store the Connector attributes. Connector has really special design. A Connector is only a startup Wrapper for a
- * ProtocolHandler. This meant that ProtocolHandler get all there attributes from the Connector attribute map. Strange
- * is that some attributes change their name and the attribute sslProtocol need a special handling
+ * Store the Connector attributes. Connector has really special design. A
+ * Connector is only a startup Wrapper for a ProtocolHandler. This meant that
+ * ProtocolHandler get all there attributes from the Connector attribute map.
+ * Strange is that some attributes change their name.
  */
 public class ConnectorStoreAppender extends StoreAppender {
 
-    protected static final HashMap<String,String> replacements = new HashMap<>();
+    protected static final HashMap<String, String> replacements = new HashMap<>();
     protected static final Set<String> internalExecutorAttributes = new HashSet<>();
     static {
         replacements.put("timeout", "connectionUploadTimeout");
-        replacements.put("clientauth", "clientAuth");
-        replacements.put("keystore", "keystoreFile");
         replacements.put("randomfile", "randomFile");
-        replacements.put("keypass", "keystorePass");
-        replacements.put("keytype", "keystoreType");
-        replacements.put("protocol", "sslProtocol");
-        replacements.put("protocols", "sslProtocols");
 
         internalExecutorAttributes.add("maxThreads");
         internalExecutorAttributes.add("minSpareThreads");
@@ -60,7 +55,8 @@ public class ConnectorStoreAppender extends StoreAppender {
     }
 
     @Override
-    public void printAttributes(PrintWriter writer, int indent, boolean include, Object bean, StoreDescription desc)
+    public void printAttributes(PrintWriter writer, int indent,
+            boolean include, Object bean, StoreDescription desc)
             throws Exception {
 
         // Render a className attribute if requested
@@ -74,7 +70,7 @@ public class ConnectorStoreAppender extends StoreAppender {
         String protocol = connector.getProtocol();
         List<String> propertyKeys = getPropertyKeys(connector);
         // Create blank instance
-        Object bean2 = new Connector(protocol);// defaultInstance(bean);
+        Object bean2 = new Connector(protocol);//defaultInstance(bean);
         for (String key : propertyKeys) {
             Object value = IntrospectionUtils.getProperty(bean, key);
             if (desc.isTransientAttribute(key)) {
@@ -109,17 +105,17 @@ public class ConnectorStoreAppender extends StoreAppender {
      * Get all properties from Connector and current ProtocolHandler.
      *
      * @param bean The connector
-     *
      * @return List of Connector property names
-     *
      * @throws IntrospectionException Error introspecting connector
      */
-    protected List<String> getPropertyKeys(Connector bean) throws IntrospectionException {
+    protected List<String> getPropertyKeys(Connector bean)
+            throws IntrospectionException {
         List<String> propertyKeys = new ArrayList<>();
         // Acquire the list of properties for this bean
         ProtocolHandler protocolHandler = bean.getProtocolHandler();
         // Acquire the list of properties for this bean
-        PropertyDescriptor[] descriptors = Introspector.getBeanInfo(bean.getClass()).getPropertyDescriptors();
+        PropertyDescriptor descriptors[] = Introspector.getBeanInfo(
+                bean.getClass()).getPropertyDescriptors();
         if (descriptors == null) {
             descriptors = new PropertyDescriptor[0];
         }
@@ -127,17 +123,21 @@ public class ConnectorStoreAppender extends StoreAppender {
             if (descriptor instanceof IndexedPropertyDescriptor) {
                 continue; // Indexed properties are not persisted
             }
-            if (!isPersistable(descriptor.getPropertyType()) || (descriptor.getReadMethod() == null) ||
-                    (descriptor.getWriteMethod() == null)) {
+            if (!isPersistable(descriptor.getPropertyType())
+                    || (descriptor.getReadMethod() == null)
+                    || (descriptor.getWriteMethod() == null)) {
                 continue; // Must be a read-write primitive or String
             }
-            if ("protocol".equals(descriptor.getName()) || "protocolHandlerClassName".equals(descriptor.getName())) {
+            if ("protocol".equals(descriptor.getName())
+                    || "protocolHandlerClassName".equals(descriptor
+                            .getName())) {
                 continue;
             }
             propertyKeys.add(descriptor.getName());
         }
         // Add the properties of the protocol handler
-        descriptors = Introspector.getBeanInfo(protocolHandler.getClass()).getPropertyDescriptors();
+        descriptors = Introspector.getBeanInfo(
+                protocolHandler.getClass()).getPropertyDescriptors();
         if (descriptors == null) {
             descriptors = new PropertyDescriptor[0];
         }
@@ -145,8 +145,9 @@ public class ConnectorStoreAppender extends StoreAppender {
             if (descriptor instanceof IndexedPropertyDescriptor) {
                 continue; // Indexed properties are not persisted
             }
-            if (!isPersistable(descriptor.getPropertyType()) || (descriptor.getReadMethod() == null) ||
-                    (descriptor.getWriteMethod() == null)) {
+            if (!isPersistable(descriptor.getPropertyType())
+                    || (descriptor.getReadMethod() == null)
+                    || (descriptor.getWriteMethod() == null)) {
                 continue; // Must be a read-write primitive or String
             }
             String key = descriptor.getName();
@@ -163,7 +164,8 @@ public class ConnectorStoreAppender extends StoreAppender {
         }
         // Add the properties for the socket
         final String socketName = "socket.";
-        descriptors = Introspector.getBeanInfo(SocketProperties.class).getPropertyDescriptors();
+        descriptors = Introspector.getBeanInfo(
+                SocketProperties.class).getPropertyDescriptors();
         if (descriptors == null) {
             descriptors = new PropertyDescriptor[0];
         }
@@ -171,8 +173,9 @@ public class ConnectorStoreAppender extends StoreAppender {
             if (descriptor instanceof IndexedPropertyDescriptor) {
                 continue; // Indexed properties are not persisted
             }
-            if (!isPersistable(descriptor.getPropertyType()) || (descriptor.getReadMethod() == null) ||
-                    (descriptor.getWriteMethod() == null)) {
+            if (!isPersistable(descriptor.getPropertyType())
+                    || (descriptor.getReadMethod() == null)
+                    || (descriptor.getWriteMethod() == null)) {
                 continue; // Must be a read-write primitive or String
             }
             String key = descriptor.getName();
@@ -192,37 +195,59 @@ public class ConnectorStoreAppender extends StoreAppender {
      * Print Attributes for the connector
      *
      * @param aWriter Current writer
-     * @param indent  Indentation level
-     * @param bean    The connector bean
-     * @param aDesc   The connector description
-     *
+     * @param indent Indentation level
+     * @param bean The connector bean
+     * @param aDesc The connector description
      * @throws Exception Store error occurred
      */
-    protected void storeConnectorAttributes(PrintWriter aWriter, int indent, Object bean, StoreDescription aDesc)
-            throws Exception {
+    protected void storeConnectorAttributes(PrintWriter aWriter, int indent,
+            Object bean, StoreDescription aDesc) throws Exception {
         if (aDesc.isAttributes()) {
             printAttributes(aWriter, indent, false, bean, aDesc);
         }
     }
 
+    /**
+     * Print the open tag for connector attributes (override).
+     *
+     * @see org.apache.catalina.storeconfig.StoreAppender#printOpenTag(java.io.PrintWriter,
+     *      int, java.lang.Object,
+     *      org.apache.catalina.storeconfig.StoreDescription)
+     */
     @Override
-    public void printOpenTag(PrintWriter aWriter, int indent, Object bean, StoreDescription aDesc) throws Exception {
+    public void printOpenTag(PrintWriter aWriter, int indent, Object bean,
+            StoreDescription aDesc) throws Exception {
         aWriter.print("<");
         aWriter.print(aDesc.getTag());
         storeConnectorAttributes(aWriter, indent, bean, aDesc);
         aWriter.println(">");
     }
 
+    /**
+     * Print a tag for connector attributes (override).
+     *
+     * @see org.apache.catalina.storeconfig.StoreAppender#printTag(java.io.PrintWriter,
+     *      int, java.lang.Object,
+     *      org.apache.catalina.storeconfig.StoreDescription)
+     */
     @Override
-    public void printTag(PrintWriter aWriter, int indent, Object bean, StoreDescription aDesc) throws Exception {
+    public void printTag(PrintWriter aWriter, int indent, Object bean,
+            StoreDescription aDesc) throws Exception {
         aWriter.print("<");
         aWriter.print(aDesc.getTag());
         storeConnectorAttributes(aWriter, indent, bean, aDesc);
         aWriter.println("/>");
     }
 
+    /**
+     * Print a value but replace certain attribute names.
+     *
+     * @see org.apache.catalina.storeconfig.StoreAppender#printValue(java.io.PrintWriter,
+     *      int, String, Object)
+     */
     @Override
-    public void printValue(PrintWriter writer, int indent, String name, Object value) {
+    public void printValue(PrintWriter writer, int indent, String name,
+            Object value) {
         String repl = name;
         if (replacements.get(name) != null) {
             repl = replacements.get(name);
@@ -231,23 +256,22 @@ public class ConnectorStoreAppender extends StoreAppender {
     }
 
     /**
-     * Print Connector Values.
-     * <ul>
-     * <li>Special handling to default jkHome.</li>
-     * <li>Don't save catalina.base path at server.xml</li>
-     * <li>
-     * </ul>
+     * Print Connector Values. <ul><li> Special handling to default jkHome.
+     * </li><li> Don't save catalina.base path at server.xml</li><li></ul>
      *
-     * @see org.apache.catalina.storeconfig.StoreAppender#isPrintValue(Object, Object, String, StoreDescription)
+     * @see org.apache.catalina.storeconfig.StoreAppender#isPrintValue(Object,
+     *      Object, String, StoreDescription)
      */
     @Override
-    public boolean isPrintValue(Object bean, Object bean2, String attrName, StoreDescription desc) {
+    public boolean isPrintValue(Object bean, Object bean2, String attrName,
+            StoreDescription desc) {
         boolean isPrint = super.isPrintValue(bean, bean2, attrName, desc);
         if (isPrint) {
             if ("jkHome".equals(attrName)) {
                 Connector connector = (Connector) bean;
                 File catalinaBase = getCatalinaBase();
-                File jkHomeBase = getJkHomeBase((String) connector.getProperty("jkHome"), catalinaBase);
+                File jkHomeBase = getJkHomeBase((String) connector
+                        .getProperty("jkHome"), catalinaBase);
                 isPrint = !catalinaBase.equals(jkHomeBase);
 
             }
@@ -260,8 +284,7 @@ public class ConnectorStoreAppender extends StoreAppender {
         File file = new File(System.getProperty(Globals.CATALINA_BASE_PROP));
         try {
             file = file.getCanonicalFile();
-        } catch (IOException ioe) {
-            // Ignore
+        } catch (IOException e) {
         }
         return file;
     }
@@ -275,10 +298,10 @@ public class ConnectorStoreAppender extends StoreAppender {
         }
         try {
             jkHomeBase = file.getCanonicalFile();
-        } catch (IOException ioe) {
+        } catch (IOException e) {
             jkHomeBase = file;
         }
         return jkHomeBase;
     }
 
-}
+}
\ No newline at end of file
