@@ -60,26 +60,28 @@ import org.apache.juli.logging.LogFactory;
 
 /**
  * The default implementation of a Channel.<br>
- * The GroupChannel manages the replication channel. It coordinates message being sent and received with membership
- * announcements. The channel has a chain of interceptors that can modify the message or perform other logic.<br>
+ * The GroupChannel manages the replication channel. It coordinates
+ * message being sent and received with membership announcements.
+ * The channel has an chain of interceptors that can modify the message or perform other logic.<br>
  * It manages a complete group, both membership and replication.
  */
-public class GroupChannel extends ChannelInterceptorBase implements ManagedChannel, JmxChannel, GroupChannelMBean {
+public class GroupChannel extends ChannelInterceptorBase
+        implements ManagedChannel, JmxChannel, GroupChannelMBean {
 
     private static final Log log = LogFactory.getLog(GroupChannel.class);
     protected static final StringManager sm = StringManager.getManager(GroupChannel.class);
 
     /**
-     * Flag to determine if the channel manages its own heartbeat If set to true, the channel will start a local thread
-     * for the heart beat.
+     * Flag to determine if the channel manages its own heartbeat
+     * If set to true, the channel will start a local thread for the heart beat.
      */
     protected boolean heartbeat = true;
 
     /**
-     * If <code>heartbeat == true</code> then how often do we want this heartbeat to run. The default value is 5000
-     * milliseconds.
+     * If <code>heartbeat == true</code> then how often do we want this
+     * heartbeat to run. The default value is 5000 milliseconds.
      */
-    protected long heartbeatSleeptime = 5 * 1000;
+    protected long heartbeatSleeptime = 5*1000;
 
     /**
      * Internal heartbeat future
@@ -88,7 +90,7 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     protected ScheduledFuture<?> monitorFuture;
 
     /**
-     * The <code>ChannelCoordinator</code> coordinates the bottom layer components:<br>
+     * The  <code>ChannelCoordinator</code> coordinates the bottom layer components:<br>
      * - MembershipService<br>
      * - ChannelSender <br>
      * - ChannelReceiver<br>
@@ -96,8 +98,9 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     protected final ChannelCoordinator coordinator = new ChannelCoordinator();
 
     /**
-     * The first interceptor in the interceptor stack. The interceptors are chained in a linked list, so we only need a
-     * reference to the first one
+     * The first interceptor in the interceptor stack.
+     * The interceptors are chained in a linked list, so we only need a reference to the
+     * first one
      */
     protected ChannelInterceptor interceptors = null;
 
@@ -147,7 +150,8 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     private ObjectName oname = null;
 
     /**
-     * Creates a GroupChannel. This constructor will also add the first interceptor in the GroupChannel.<br>
+     * Creates a GroupChannel. This constructor will also
+     * add the first interceptor in the GroupChannel.<br>
      * The first interceptor is always the channel itself.
      */
     public GroupChannel() {
@@ -155,16 +159,28 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     }
 
 
+    /**
+     * Adds an interceptor to the stack for message processing<br>
+     * Interceptors are ordered in the way they are added.<br>
+     * <code>channel.addInterceptor(A);</code><br>
+     * <code>channel.addInterceptor(C);</code><br>
+     * <code>channel.addInterceptor(B);</code><br>
+     * Will result in an interceptor stack like this:<br>
+     * <code>A -&gt; C -&gt; B</code><br>
+     * The complete stack will look like this:<br>
+     * <code>Channel -&gt; A -&gt; C -&gt; B -&gt; ChannelCoordinator</code><br>
+     * @param interceptor ChannelInterceptorBase
+     */
     @Override
     public void addInterceptor(ChannelInterceptor interceptor) {
-        if (interceptors == null) {
+        if ( interceptors == null ) {
             interceptors = interceptor;
             interceptors.setNext(coordinator);
             interceptors.setPrevious(null);
             coordinator.setPrevious(interceptors);
         } else {
             ChannelInterceptor last = interceptors;
-            while (last.getNext() != coordinator) {
+            while ( last.getNext() != coordinator ) {
                 last = last.getNext();
             }
             last.setNext(interceptor);
@@ -176,36 +192,61 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
 
     /**
      * Sends a heartbeat through the interceptor stack.<br>
-     * Invoke this method from the application on a periodic basis if you have turned off internal heartbeats
-     * <code>channel.setHeartbeat(false)</code>
+     * Invoke this method from the application on a periodic basis if
+     * you have turned off internal heartbeats <code>channel.setHeartbeat(false)</code>
      */
     @Override
     public void heartbeat() {
         super.heartbeat();
 
         for (MembershipListener listener : membershipListeners) {
-            if (listener instanceof Heartbeat) {
-                ((Heartbeat) listener).heartbeat();
+            if ( listener instanceof Heartbeat ) {
+                ((Heartbeat)listener).heartbeat();
             }
         }
 
         for (ChannelListener listener : channelListeners) {
-            if (listener instanceof Heartbeat) {
-                ((Heartbeat) listener).heartbeat();
+            if ( listener instanceof Heartbeat ) {
+                ((Heartbeat)listener).heartbeat();
             }
         }
     }
 
 
+    /**
+     * Send a message to the destinations specified
+     * @param destination Member[] - destination.length &gt; 0
+     * @param msg Serializable - the message to send
+     * @param options sender options, options can trigger guarantee levels and different
+     *                interceptors to react to the message see class documentation for the
+     *                <code>Channel</code> object.<br>
+     * @return UniqueId - the unique Id that was assigned to this message
+     * @throws ChannelException - if an error occurs processing the message
+     * @see org.apache.catalina.tribes.Channel
+     */
     @Override
-    public UniqueId send(Member[] destination, Serializable msg, int options) throws ChannelException {
-        return send(destination, msg, options, null);
+    public UniqueId send(Member[] destination, Serializable msg, int options)
+            throws ChannelException {
+        return send(destination,msg,options,null);
     }
 
+    /**
+     * @param destination Member[] - destination.length &gt; 0
+     * @param msg Serializable - the message to send
+     * @param options sender options, options can trigger guarantee levels and different
+     *                interceptors to react to the message see class documentation for the
+     *                <code>Channel</code> object.<br>
+     * @param handler - callback object for error handling and completion notification,
+     *                  used when a message is sent asynchronously using the
+     *                  <code>Channel.SEND_OPTIONS_ASYNCHRONOUS</code> flag enabled.
+     * @return UniqueId - the unique Id that was assigned to this message
+     * @throws ChannelException - if an error occurs processing the message
+     * @see org.apache.catalina.tribes.Channel
+     */
     @Override
     public UniqueId send(Member[] destination, Serializable msg, int options, ErrorHandler handler)
             throws ChannelException {
-        if (msg == null) {
+        if ( msg == null ) {
             throw new ChannelException(sm.getString("groupChannel.nullMessage"));
         }
         XByteBuffer buffer = null;
@@ -213,39 +254,41 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
             if (destination == null || destination.length == 0) {
                 throw new ChannelException(sm.getString("groupChannel.noDestination"));
             }
-            ChannelData data = new ChannelData(true);// generates a unique Id
+            ChannelData data = new ChannelData(true);//generates a unique Id
             data.setAddress(getLocalMember(false));
             data.setTimestamp(System.currentTimeMillis());
-            byte[] b;
-            if (msg instanceof ByteMessage) {
-                b = ((ByteMessage) msg).getMessage();
+            byte[] b = null;
+            if ( msg instanceof ByteMessage ){
+                b = ((ByteMessage)msg).getMessage();
                 options = options | SEND_OPTIONS_BYTE_MESSAGE;
             } else {
                 b = XByteBuffer.serialize(msg);
                 options = options & (~SEND_OPTIONS_BYTE_MESSAGE);
             }
             data.setOptions(options);
-            // XByteBuffer buffer = new XByteBuffer(b.length+128,false);
-            buffer = BufferPool.getBufferPool().getBuffer(b.length + 128, false);
-            buffer.append(b, 0, b.length);
+            //XByteBuffer buffer = new XByteBuffer(b.length+128,false);
+            buffer = BufferPool.getBufferPool().getBuffer(b.length+128, false);
+            buffer.append(b,0,b.length);
             data.setMessage(buffer);
             InterceptorPayload payload = null;
-            if (handler != null) {
+            if ( handler != null ) {
                 payload = new InterceptorPayload();
                 payload.setErrorHandler(handler);
             }
             getFirstInterceptor().sendMessage(destination, data, payload);
-            if (Logs.MESSAGES.isTraceEnabled()) {
-                Logs.MESSAGES.trace("GroupChannel - Sent msg:" + new UniqueId(data.getUniqueId()) + " at " +
-                        new java.sql.Timestamp(System.currentTimeMillis()) + " to " + Arrays.toNameString(destination));
-                Logs.MESSAGES.trace("GroupChannel - Send Message:" + new UniqueId(data.getUniqueId()) + " is " + msg);
+            if ( Logs.MESSAGES.isTraceEnabled() ) {
+                Logs.MESSAGES.trace("GroupChannel - Sent msg:" + new UniqueId(data.getUniqueId()) +
+                        " at " + new java.sql.Timestamp(System.currentTimeMillis()) + " to " +
+                        Arrays.toNameString(destination));
+                Logs.MESSAGES.trace("GroupChannel - Send Message:" +
+                        new UniqueId(data.getUniqueId()) + " is " + msg);
             }
 
             return new UniqueId(data.getUniqueId());
         } catch (RuntimeException | IOException e) {
             throw new ChannelException(e);
         } finally {
-            if (buffer != null) {
+            if ( buffer != null ) {
                 BufferPool.getBufferPool().returnBuffer(buffer);
             }
         }
@@ -254,39 +297,44 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
 
     /**
      * Callback from the interceptor stack. <br>
-     * When a message is received from a remote node, this method will be invoked by the previous interceptor.<br>
-     * This method can also be used to send a message to other components within the same application, but it's an
-     * extreme case, and you're probably better off doing that logic between the applications itself.
-     *
+     * When a message is received from a remote node, this method will be
+     * invoked by the previous interceptor.<br>
+     * This method can also be used to send a message to other components
+     * within the same application, but its an extreme case, and you're probably
+     * better off doing that logic between the applications itself.
      * @param msg ChannelMessage
      */
     @Override
     public void messageReceived(ChannelMessage msg) {
-        if (msg == null) {
+        if ( msg == null ) {
             return;
         }
         try {
-            if (Logs.MESSAGES.isTraceEnabled()) {
-                Logs.MESSAGES.trace("GroupChannel - Received msg:" + new UniqueId(msg.getUniqueId()) + " at " +
-                        new java.sql.Timestamp(System.currentTimeMillis()) + " from " + msg.getAddress().getName());
+            if ( Logs.MESSAGES.isTraceEnabled() ) {
+                Logs.MESSAGES.trace("GroupChannel - Received msg:" +
+                        new UniqueId(msg.getUniqueId()) + " at " +
+                        new java.sql.Timestamp(System.currentTimeMillis()) + " from " +
+                        msg.getAddress().getName());
             }
 
-            Serializable fwd;
-            if ((msg.getOptions() & SEND_OPTIONS_BYTE_MESSAGE) == SEND_OPTIONS_BYTE_MESSAGE) {
+            Serializable fwd = null;
+            if ( (msg.getOptions() & SEND_OPTIONS_BYTE_MESSAGE) == SEND_OPTIONS_BYTE_MESSAGE ) {
                 fwd = new ByteMessage(msg.getMessage().getBytes());
             } else {
                 try {
-                    fwd = XByteBuffer.deserialize(msg.getMessage().getBytesDirect(), 0, msg.getMessage().getLength());
-                } catch (Exception sx) {
-                    log.error(sm.getString("groupChannel.unable.deserialize", msg), sx);
+                    fwd = XByteBuffer.deserialize(msg.getMessage().getBytesDirect(), 0,
+                            msg.getMessage().getLength());
+                }catch (Exception sx) {
+                    log.error(sm.getString("groupChannel.unable.deserialize", msg),sx);
                     return;
                 }
             }
-            if (Logs.MESSAGES.isTraceEnabled()) {
-                Logs.MESSAGES.trace("GroupChannel - Receive Message:" + new UniqueId(msg.getUniqueId()) + " is " + fwd);
+            if ( Logs.MESSAGES.isTraceEnabled() ) {
+                Logs.MESSAGES.trace("GroupChannel - Receive Message:" +
+                        new UniqueId(msg.getUniqueId()) + " is " + fwd);
             }
 
-            // get the actual member with the correct alive time
+            //get the actual member with the correct alive time
             Member source = msg.getAddress();
             boolean rx = false;
             boolean delivered = false;
@@ -294,62 +342,61 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
                 if (channelListener != null && channelListener.accept(fwd, source)) {
                     channelListener.messageReceived(fwd, source);
                     delivered = true;
-                    // if the message was accepted by an RPC channel, that channel
-                    // is responsible for returning the reply, otherwise we send an absence reply
+                    //if the message was accepted by an RPC channel, that channel
+                    //is responsible for returning the reply, otherwise we send an absence reply
                     if (channelListener instanceof RpcChannel) {
                         rx = true;
                     }
                 }
-            } // for
+            }//for
             if ((!rx) && (fwd instanceof RpcMessage)) {
-                // if we have a message that requires a response,
-                // but none was given, send back an immediate one
-                sendNoRpcChannelReply((RpcMessage) fwd, source);
+                //if we have a message that requires a response,
+                //but none was given, send back an immediate one
+                sendNoRpcChannelReply((RpcMessage)fwd,source);
             }
-            if (Logs.MESSAGES.isTraceEnabled()) {
-                Logs.MESSAGES.trace("GroupChannel delivered[" + delivered + "] id:" + new UniqueId(msg.getUniqueId()));
+            if ( Logs.MESSAGES.isTraceEnabled() ) {
+                Logs.MESSAGES.trace("GroupChannel delivered[" + delivered + "] id:" +
+                        new UniqueId(msg.getUniqueId()));
             }
 
-        } catch (Exception x) {
-            // this could be the channel listener throwing an exception, we should log it
-            // as a warning.
-            if (log.isWarnEnabled()) {
-                log.warn(sm.getString("groupChannel.receiving.error"), x);
+        } catch ( Exception x ) {
+            //this could be the channel listener throwing an exception, we should log it
+            //as a warning.
+            if ( log.isWarnEnabled() ) {
+                log.warn(sm.getString("groupChannel.receiving.error"),x);
             }
-            throw new RemoteProcessException(sm.getString("groupChannel.receiving.error"), x);
+            throw new RemoteProcessException(sm.getString("groupChannel.receiving.error"),x);
         }
     }
 
     /**
      * Sends a <code>NoRpcChannelReply</code> message to a member<br>
-     * This method gets invoked by the channel if an RPC message comes in and no channel listener accepts the message.
-     * This avoids timeout
-     *
-     * @param msg         RpcMessage
+     * This method gets invoked by the channel if an RPC message comes in
+     * and no channel listener accepts the message. This avoids timeout
+     * @param msg RpcMessage
      * @param destination Member - the destination for the reply
      */
     protected void sendNoRpcChannelReply(RpcMessage msg, Member destination) {
         try {
-            // avoid circular loop
-            if (msg instanceof RpcMessage.NoRpcChannelReply) {
+            //avoid circular loop
+            if ( msg instanceof RpcMessage.NoRpcChannelReply) {
                 return;
             }
             RpcMessage.NoRpcChannelReply reply = new RpcMessage.NoRpcChannelReply(msg.rpcId, msg.uuid);
-            send(new Member[] { destination }, reply, SEND_OPTIONS_ASYNCHRONOUS);
-        } catch (Exception x) {
-            log.error(sm.getString("groupChannel.sendFail.noRpcChannelReply"), x);
+            send(new Member[]{destination}, reply, SEND_OPTIONS_ASYNCHRONOUS);
+        } catch ( Exception x ) {
+            log.error(sm.getString("groupChannel.sendFail.noRpcChannelReply"),x);
         }
     }
 
     /**
-     * memberAdded gets invoked by the interceptor below the channel and the channel will broadcast it to the membership
-     * listeners
-     *
+     * memberAdded gets invoked by the interceptor below the channel
+     * and the channel will broadcast it to the membership listeners
      * @param member Member - the new member
      */
     @Override
     public void memberAdded(Member member) {
-        // notify upwards
+        //notify upwards
         for (MembershipListener membershipListener : membershipListeners) {
             if (membershipListener != null) {
                 membershipListener.memberAdded(member);
@@ -358,14 +405,13 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     }
 
     /**
-     * memberDisappeared gets invoked by the interceptor below the channel and the channel will broadcast it to the
-     * membership listeners
-     *
+     * memberDisappeared gets invoked by the interceptor below the channel
+     * and the channel will broadcast it to the membership listeners
      * @param member Member - the member that left or crashed
      */
     @Override
     public void memberDisappeared(Member member) {
-        // notify upwards
+        //notify upwards
         for (MembershipListener membershipListener : membershipListeners) {
             if (membershipListener != null) {
                 membershipListener.memberDisappeared(member);
@@ -374,12 +420,13 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     }
 
     /**
-     * Sets up the default implementation interceptor stack if no interceptors have been added
-     *
+     * Sets up the default implementation interceptor stack
+     * if no interceptors have been added
      * @throws ChannelException Cluster error
      */
     protected synchronized void setupDefaultStack() throws ChannelException {
-        if (getFirstInterceptor() != null && ((getFirstInterceptor().getNext() instanceof ChannelCoordinator))) {
+        if (getFirstInterceptor() != null &&
+                ((getFirstInterceptor().getNext() instanceof ChannelCoordinator))) {
             addInterceptor(new MessageDispatchInterceptor());
         }
         Iterator<ChannelInterceptor> interceptors = getInterceptors();
@@ -391,21 +438,20 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     }
 
     /**
-     * Validates the option flags that each interceptor is using and reports an error if two interceptor share the same
-     * flag.
-     *
+     * Validates the option flags that each interceptor is using and reports
+     * an error if two interceptor share the same flag.
      * @throws ChannelException Error with option flag
      */
     protected void checkOptionFlags() throws ChannelException {
         StringBuilder conflicts = new StringBuilder();
         ChannelInterceptor first = interceptors;
-        while (first != null) {
+        while ( first != null ) {
             int flag = first.getOptionFlag();
-            if (flag != 0) {
+            if ( flag != 0 ) {
                 ChannelInterceptor next = first.getNext();
-                while (next != null) {
+                while ( next != null ) {
                     int nflag = next.getOptionFlag();
-                    if (nflag != 0 && (((flag & nflag) == flag) || ((flag & nflag) == nflag))) {
+                    if (nflag!=0 && (((flag & nflag) == flag ) || ((flag & nflag) == nflag)) ) {
                         conflicts.append('[');
                         conflicts.append(first.getClass().getName());
                         conflicts.append(':');
@@ -415,20 +461,27 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
                         conflicts.append(':');
                         conflicts.append(nflag);
                         conflicts.append("] ");
-                    } // end if
+                    }//end if
                     next = next.getNext();
-                } // while
-            } // end if
+                }//while
+            }//end if
             first = first.getNext();
-        } // while
-        if (conflicts.length() > 0) {
-            throw new ChannelException(sm.getString("groupChannel.optionFlag.conflict", conflicts.toString()));
+        }//while
+        if ( conflicts.length() > 0 ) {
+            throw new ChannelException(sm.getString("groupChannel.optionFlag.conflict",
+                    conflicts.toString()));
         }
 
     }
 
     protected boolean ownExecutor = false;
 
+    /**
+     * Starts the channel.
+     * @param svc int - what service to start
+     * @throws ChannelException Start error
+     * @see org.apache.catalina.tribes.Channel#start(int)
+     */
     @Override
     public synchronized void start(int svc) throws ChannelException {
         setupDefaultStack();
@@ -450,7 +503,7 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     }
 
     protected void startHeartbeat() {
-        if (heartbeat && (heartbeatFuture == null || heartbeatFuture.isDone())) {
+        if (heartbeat && (heartbeatFuture == null || (heartbeatFuture != null && heartbeatFuture.isDone()))) {
             if (heartbeatFuture != null && heartbeatFuture.isDone()) {
                 // There was an error executing the scheduled task, get it and log it
                 try {
@@ -459,11 +512,17 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
                     log.error(sm.getString("groupChannel.unable.sendHeartbeat"), e);
                 }
             }
-            heartbeatFuture = utilityExecutor.scheduleWithFixedDelay(new HeartbeatRunnable(), heartbeatSleeptime,
-                    heartbeatSleeptime, TimeUnit.MILLISECONDS);
+            heartbeatFuture = utilityExecutor.scheduleWithFixedDelay(new HeartbeatRunnable(),
+                    heartbeatSleeptime, heartbeatSleeptime, TimeUnit.MILLISECONDS);
         }
     }
 
+    /**
+     * Stops the channel.
+     * @param svc int
+     * @throws ChannelException Stop error
+     * @see org.apache.catalina.tribes.Channel#stop(int)
+     */
     @Override
     public synchronized void stop(int svc) throws ChannelException {
         if (monitorFuture != null) {
@@ -488,7 +547,6 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
 
     /**
      * Returns the first interceptor of the stack. Useful for traversal.
-     *
      * @return ChannelInterceptor
      */
     public ChannelInterceptor getFirstInterceptor() {
@@ -509,73 +567,122 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
         this.utilityExecutor = utilityExecutor;
     }
 
+    /**
+     * Returns the channel receiver component
+     * @return ChannelReceiver
+     */
     @Override
     public ChannelReceiver getChannelReceiver() {
         return coordinator.getClusterReceiver();
     }
 
+    /**
+     * Returns the channel sender component
+     * @return ChannelSender
+     */
     @Override
     public ChannelSender getChannelSender() {
         return coordinator.getClusterSender();
     }
 
+    /**
+     * Returns the membership service component
+     * @return MembershipService
+     */
     @Override
     public MembershipService getMembershipService() {
         return coordinator.getMembershipService();
     }
 
+    /**
+     * Sets the channel receiver component
+     * @param clusterReceiver ChannelReceiver
+     */
     @Override
     public void setChannelReceiver(ChannelReceiver clusterReceiver) {
         coordinator.setClusterReceiver(clusterReceiver);
     }
 
+    /**
+     * Sets the channel sender component
+     * @param clusterSender ChannelSender
+     */
     @Override
     public void setChannelSender(ChannelSender clusterSender) {
         coordinator.setClusterSender(clusterSender);
     }
 
+    /**
+     * Sets the membership component
+     * @param membershipService MembershipService
+     */
     @Override
     public void setMembershipService(MembershipService membershipService) {
         coordinator.setMembershipService(membershipService);
     }
 
+    /**
+     * Adds a membership listener to the channel.<br>
+     * Membership listeners are uniquely identified using the equals(Object) method
+     * @param membershipListener MembershipListener
+     */
     @Override
     public void addMembershipListener(MembershipListener membershipListener) {
-        if (!this.membershipListeners.contains(membershipListener)) {
+        if (!this.membershipListeners.contains(membershipListener) ) {
             this.membershipListeners.add(membershipListener);
         }
     }
 
+    /**
+     * Removes a membership listener from the channel.<br>
+     * Membership listeners are uniquely identified using the equals(Object) method
+     * @param membershipListener MembershipListener
+     */
+
     @Override
     public void removeMembershipListener(MembershipListener membershipListener) {
         membershipListeners.remove(membershipListener);
     }
 
+    /**
+     * Adds a channel listener to the channel.<br>
+     * Channel listeners are uniquely identified using the equals(Object) method
+     * @param channelListener ChannelListener
+     */
     @Override
     public void addChannelListener(ChannelListener channelListener) {
-        if (!this.channelListeners.contains(channelListener)) {
+        if (!this.channelListeners.contains(channelListener) ) {
             this.channelListeners.add(channelListener);
         } else {
-            throw new IllegalArgumentException(sm.getString("groupChannel.listener.alreadyExist", channelListener,
-                    channelListener.getClass().getName()));
+            throw new IllegalArgumentException(sm.getString("groupChannel.listener.alreadyExist",
+                    channelListener,channelListener.getClass().getName()));
         }
     }
 
+    /**
+     * Removes a channel listener from the channel.<br>
+     * Channel listeners are uniquely identified using the equals(Object) method
+     * @param channelListener ChannelListener
+     */
     @Override
     public void removeChannelListener(ChannelListener channelListener) {
         channelListeners.remove(channelListener);
     }
 
+    /**
+     * Returns an iterator of all the interceptors in this stack
+     * @return Iterator
+     */
     @Override
     public Iterator<ChannelInterceptor> getInterceptors() {
-        return new InterceptorIterator(this.getNext(), this.coordinator);
+        return new InterceptorIterator(this.getNext(),this.coordinator);
     }
 
     /**
      * Enables/disables the option check<br>
-     * Setting this to true, will make the GroupChannel perform a conflict check on the interceptors. If two
-     * interceptors are using the same option flag and throw an error upon start.
-     *
+     * Setting this to true, will make the GroupChannel perform a conflict check
+     * on the interceptors. If two interceptors are using the same option flag
+     * and throw an error upon start.
      * @param optionCheck boolean
      */
     public void setOptionCheck(boolean optionCheck) {
@@ -585,7 +692,6 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     /**
      * Configure local heartbeat sleep time<br>
      * Only used when <code>getHeartbeat()==true</code>
-     *
      * @param heartbeatSleeptime long - time in milliseconds to sleep between heartbeats
      */
     public void setHeartbeatSleeptime(long heartbeatSleeptime) {
@@ -593,9 +699,9 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     }
 
     /**
-     * Enables or disables local heartbeat. if <code>setHeartbeat(true)</code> is invoked then the channel will start an
-     * internal thread to invoke <code>Channel.heartbeat()</code> every <code>getHeartbeatSleeptime</code> milliseconds
-     *
+     * Enables or disables local heartbeat.
+     * if <code>setHeartbeat(true)</code> is invoked then the channel will start an internal
+     * thread to invoke <code>Channel.heartbeat()</code> every <code>getHeartbeatSleeptime</code> milliseconds
      * @param heartbeat boolean
      */
     @Override
@@ -603,19 +709,28 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
         this.heartbeat = heartbeat;
     }
 
+    /**
+     * @see #setOptionCheck(boolean)
+     * @return boolean
+     */
     @Override
     public boolean getOptionCheck() {
         return optionCheck;
     }
 
+    /**
+     * @see #setHeartbeat(boolean)
+     * @return boolean
+     */
     @Override
     public boolean getHeartbeat() {
         return heartbeat;
     }
 
     /**
-     * @return the sleep time in milliseconds that the internal heartbeat will sleep in between invocations of
-     *             <code>Channel.heartbeat()</code>
+     * Returns the sleep time in milliseconds that the internal heartbeat will
+     * sleep in between invocations of <code>Channel.heartbeat()</code>
+     * @return long
      */
     @Override
     public long getHeartbeatSleeptime() {
@@ -663,7 +778,8 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     }
 
     @Override
-    public ObjectName preRegister(MBeanServer server, ObjectName name) throws Exception {
+    public ObjectName preRegister(MBeanServer server, ObjectName name)
+            throws Exception {
         // NOOP
         return null;
     }
@@ -689,7 +805,6 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
     public static class InterceptorIterator implements Iterator<ChannelInterceptor> {
         private final ChannelInterceptor end;
         private ChannelInterceptor start;
-
         public InterceptorIterator(ChannelInterceptor start, ChannelInterceptor end) {
             this.end = end;
             this.start = start;
@@ -697,13 +812,13 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
 
         @Override
         public boolean hasNext() {
-            return start != null && start != end;
+            return start!=null && start != end;
         }
 
         @Override
         public ChannelInterceptor next() {
             ChannelInterceptor result = null;
-            if (hasNext()) {
+            if ( hasNext() ) {
                 result = start;
                 start = start.getNext();
             }
@@ -712,17 +827,15 @@ public class GroupChannel extends ChannelInterceptorBase implements ManagedChann
 
         @Override
         public void remove() {
-            // empty operation
+            //empty operation
         }
     }
 
     /**
-     * <p>
-     * Title: Internal heartbeat runnable
-     * </p>
-     * <p>
-     * Description: if <code>Channel.getHeartbeat()==true</code> then a thread of this class is created
-     * </p>
+     * <p>Title: Internal heartbeat runnable</p>
+     *
+     * <p>Description: if <code>Channel.getHeartbeat()==true</code> then a thread of this class
+     * is created</p>
      */
     public class HeartbeatRunnable implements Runnable {
         @Override
