@@ -42,23 +42,19 @@ import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 
 /**
- * <p>Title: A perfect failure detector </p>
- *
- * <p>Description: The TcpFailureDetector is a useful interceptor
- * that adds reliability to the membership layer.</p>
+ * The TcpFailureDetector is a useful interceptor that adds reliability to the
+ * membership layer.
  * <p>
  * If the network is busy, or the system is busy so that the membership receiver thread
  * is not getting enough time to update its table, members can be &quot;timed out&quot;
  * This failure detector will intercept the memberDisappeared message(unless its a true shutdown message)
  * and connect to the member using TCP.
- * </p>
  * <p>
- * The TcpFailureDetector works in two ways. <br>
- * 1. It intercepts memberDisappeared events
- * 2. It catches send errors
- * </p>
- *
- * @version 1.0
+ * The TcpFailureDetector works in two ways:
+ * <ol>
+ * <li>It intercepts memberDisappeared events</li>
+ * <li>It catches send errors</li>
+ * </ol>
  */
 public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFailureDetectorMBean {
 
@@ -113,15 +109,20 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
                         (!Arrays.equals(TCP_FAIL_DETECT,msg.getMessage().getBytes()) ) );
         }//end if
 
-        //ignore the message, it doesnt have the flag set
-        if ( process ) super.messageReceived(msg);
-        else if ( log.isDebugEnabled() ) log.debug("Received a failure detector packet:"+msg);
+        //ignore the message, it doesn't have the flag set
+        if ( process ) {
+            super.messageReceived(msg);
+        } else if ( log.isDebugEnabled() ) {
+            log.debug("Received a failure detector packet:"+msg);
+        }
     }//messageReceived
 
 
     @Override
     public void memberAdded(Member member) {
-        if ( membership == null ) setupMembership();
+        if ( membership == null ) {
+            setupMembership();
+        }
         boolean notify = false;
         synchronized (membership) {
             if (removeSuspects.containsKey(member)) {
@@ -141,16 +142,22 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
                 }
             }
         }
-        if ( notify ) super.memberAdded(member);
+        if ( notify ) {
+            super.memberAdded(member);
+        }
     }
 
     @Override
     public void memberDisappeared(Member member) {
-        if ( membership == null ) setupMembership();
+        if ( membership == null ) {
+            setupMembership();
+        }
         boolean shutdown = Arrays.equals(member.getCommand(),Member.SHUTDOWN_PAYLOAD);
         if (shutdown) {
             synchronized (membership) {
-                if (!membership.contains(member)) return;
+                if (!membership.contains(member)) {
+                    return;
+                }
                 membership.removeMember(member);
                 removeSuspects.remove(member);
                 if (member instanceof StaticMember) {
@@ -160,12 +167,14 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
             super.memberDisappeared(member);
         } else {
             boolean notify = false;
-            if(log.isInfoEnabled())
+            if(log.isInfoEnabled()) {
                 log.info(sm.getString("tcpFailureDetector.memberDisappeared.verify", member));
+            }
             synchronized (membership) {
                 if (!membership.contains(member)) {
-                    if(log.isInfoEnabled())
+                    if(log.isInfoEnabled()) {
                         log.info(sm.getString("tcpFailureDetector.already.disappeared", member));
+                    }
                     return;
                 }
                 //check to see if the member really is gone
@@ -183,31 +192,39 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
                 }
             }
             if ( notify ) {
-                if(log.isInfoEnabled())
+                if(log.isInfoEnabled()) {
                     log.info(sm.getString("tcpFailureDetector.member.disappeared", member));
+                }
                 super.memberDisappeared(member);
             } else {
-                if(log.isInfoEnabled())
+                if(log.isInfoEnabled()) {
                     log.info(sm.getString("tcpFailureDetector.still.alive", member));
+                }
             }
         }
     }
 
     @Override
     public boolean hasMembers() {
-        if ( membership == null ) setupMembership();
+        if ( membership == null ) {
+            setupMembership();
+        }
         return membership.hasMembers();
     }
 
     @Override
     public Member[] getMembers() {
-        if ( membership == null ) setupMembership();
+        if ( membership == null ) {
+            setupMembership();
+        }
         return membership.getMembers();
     }
 
     @Override
     public Member getMember(Member mbr) {
-        if ( membership == null ) setupMembership();
+        if ( membership == null ) {
+            setupMembership();
+        }
         return membership.getMember(mbr);
     }
 
@@ -225,10 +242,15 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
     @Override
     public void checkMembers(boolean checkAll) {
         try {
-            if (membership == null) setupMembership();
+            if (membership == null) {
+                setupMembership();
+            }
             synchronized (membership) {
-                if (!checkAll) performBasicCheck();
-                else performForcedCheck();
+                if (!checkAll) {
+                    performBasicCheck();
+                } else {
+                    performForcedCheck();
+                }
             }
         } catch (Exception x) {
             log.warn(sm.getString("tcpFailureDetector.heartbeat.failed"),x);
@@ -240,7 +262,9 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
         Member[] members = super.getMembers();
         for (int i = 0; members != null && i < members.length; i++) {
             if (memberAlive(members[i])) {
-                if (membership.memberAlive(members[i])) super.memberAdded(members[i]);
+                if (membership.memberAlive(members[i])) {
+                    super.memberAdded(members[i]);
+                }
                 addSuspects.remove(members[i]);
             } else {
                 if (membership.getMember(members[i])!=null) {
@@ -265,7 +289,7 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
                 continue;
             }
             if (membership.memberAlive(members[i])) {
-                //we don't have this one in our membership, check to see if he/she is alive
+                //we don't have this one in our membership, check to see if the member is alive
                 if (memberAlive(members[i])) {
                     log.warn(sm.getString("tcpFailureDetector.performBasicCheck.memberAdded", members[i]));
                     super.memberAdded(members[i]);
@@ -286,8 +310,9 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
                 }
                 super.memberDisappeared(m);
                 removeSuspects.remove(m);
-                if (log.isInfoEnabled())
+                if (log.isInfoEnabled()) {
                     log.info(sm.getString("tcpFailureDetector.suspectMember.dead", m));
+                }
             } else {
                 if (removeSuspectsTimeout > 0) {
                     long timeNow = System.currentTimeMillis();
@@ -307,8 +332,9 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
                 membership.memberAlive(m);
                 super.memberAdded(m);
                 addSuspects.remove(m);
-                if (log.isInfoEnabled())
+                if (log.isInfoEnabled()) {
                     log.info(sm.getString("tcpFailureDetector.suspectMember.alive", m));
+                }
             } //end if
         }
     }
@@ -329,7 +355,9 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
                                          long readTimeout, long conTimeout,
                                          int optionFlag) {
         //could be a shutdown notification
-        if ( Arrays.equals(mbr.getCommand(),Member.SHUTDOWN_PAYLOAD) ) return false;
+        if ( Arrays.equals(mbr.getCommand(),Member.SHUTDOWN_PAYLOAD) ) {
+            return false;
+        }
 
         try (Socket socket = new Socket()) {
             InetAddress ia = InetAddress.getByAddress(mbr.getHost());
@@ -342,8 +370,11 @@ public class TcpFailureDetector extends ChannelInterceptorBase implements TcpFai
                 data.setMessage(new XByteBuffer(msgData,false));
                 data.setTimestamp(System.currentTimeMillis());
                 int options = optionFlag | Channel.SEND_OPTIONS_BYTE_MESSAGE;
-                if ( readTest ) options = (options | Channel.SEND_OPTIONS_USE_ACK);
-                else options = (options & (~Channel.SEND_OPTIONS_USE_ACK));
+                if ( readTest ) {
+                    options = (options | Channel.SEND_OPTIONS_USE_ACK);
+                } else {
+                    options = (options & (~Channel.SEND_OPTIONS_USE_ACK));
+                }
                 data.setOptions(options);
                 byte[] message = XByteBuffer.createDataPackage(data);
                 socket.getOutputStream().write(message);
