@@ -38,11 +38,13 @@ import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 
 /**
- * A <b>membership</b> implementation using simple multicast. This is the representation of a multicast membership
- * service. This class is responsible for maintaining a list of active cluster nodes in the cluster. If a node fails to
- * send out a heartbeat, the node will be dismissed.
+ * A <b>membership</b> implementation using simple multicast.
+ * This is the representation of a multicast membership service.
+ * This class is responsible for maintaining a list of active cluster nodes in the cluster.
+ * If a node fails to send out a heartbeat, the node will be dismissed.
  */
-public class McastService extends MembershipServiceBase implements MessageListener, McastServiceMBean {
+public class McastService
+        extends MembershipServiceBase implements MessageListener, McastServiceMBean {
 
     private static final Log log = LogFactory.getLog(McastService.class);
 
@@ -63,7 +65,7 @@ public class McastService extends MembershipServiceBase implements MessageListen
     /**
      * The local member
      */
-    protected MemberImpl localMember;
+    protected MemberImpl localMember ;
     private int mcastSoTimeout;
     private int mcastTTL;
 
@@ -80,33 +82,31 @@ public class McastService extends MembershipServiceBase implements MessageListen
      * Create a membership service.
      */
     public McastService() {
-        // default values
+        //default values
         setDefaults(this.properties);
     }
 
     /**
      * Sets the properties for the membership service.
-     *
-     * @param properties <br>
-     *                       All are required<br>
-     *                       1. mcastPort - the port to listen to<BR>
-     *                       2. mcastAddress - the mcast group address<BR>
-     *                       4. bindAddress - the bind address if any - only one that can be null<BR>
-     *                       5. memberDropTime - the time a member is gone before it is considered gone.<BR>
-     *                       6. mcastFrequency - the frequency of sending messages<BR>
-     *                       7. tcpListenPort - the port this member listens to<BR>
-     *                       8. tcpListenHost - the bind address of this member<BR>
-     *
+     * @param properties
+     * <br>All are required<br>
+     * 1. mcastPort - the port to listen to<BR>
+     * 2. mcastAddress - the mcast group address<BR>
+     * 4. bindAddress - the bind address if any - only one that can be null<BR>
+     * 5. memberDropTime - the time a member is gone before it is considered gone.<BR>
+     * 6. mcastFrequency - the frequency of sending messages<BR>
+     * 7. tcpListenPort - the port this member listens to<BR>
+     * 8. tcpListenHost - the bind address of this member<BR>
      * @exception java.lang.IllegalArgumentException if a property is missing.
      */
     @Override
     public void setProperties(Properties properties) {
-        hasProperty(properties, "mcastPort");
-        hasProperty(properties, "mcastAddress");
-        hasProperty(properties, "memberDropTime");
-        hasProperty(properties, "mcastFrequency");
-        hasProperty(properties, "tcpListenPort");
-        hasProperty(properties, "tcpListenHost");
+        hasProperty(properties,"mcastPort");
+        hasProperty(properties,"mcastAddress");
+        hasProperty(properties,"memberDropTime");
+        hasProperty(properties,"mcastFrequency");
+        hasProperty(properties,"tcpListenPort");
+        hasProperty(properties,"tcpListenHost");
         setDefaults(properties);
         this.properties = properties;
     }
@@ -116,23 +116,23 @@ public class McastService extends MembershipServiceBase implements MessageListen
      */
     @Override
     public String getLocalMemberName() {
-        return localMember.toString();
+        return localMember.toString() ;
     }
 
     @Override
     public Member getLocalMember(boolean alive) {
-        if (alive && localMember != null && impl != null) {
-            localMember.setMemberAliveTime(System.currentTimeMillis() - impl.getServiceStartTime());
+        if ( alive && localMember != null && impl != null) {
+            localMember.setMemberAliveTime(System.currentTimeMillis()-impl.getServiceStartTime());
         }
         return localMember;
     }
 
     @Override
     public void setLocalMemberProperties(String listenHost, int listenPort, int securePort, int udpPort) {
-        properties.setProperty("tcpListenHost", listenHost);
-        properties.setProperty("tcpListenPort", String.valueOf(listenPort));
-        properties.setProperty("udpListenPort", String.valueOf(udpPort));
-        properties.setProperty("tcpSecurePort", String.valueOf(securePort));
+        properties.setProperty("tcpListenHost",listenHost);
+        properties.setProperty("tcpListenPort",String.valueOf(listenPort));
+        properties.setProperty("udpListenPort",String.valueOf(udpPort));
+        properties.setProperty("tcpSecurePort",String.valueOf(securePort));
         try {
             if (localMember != null) {
                 localMember.setHostname(listenHost);
@@ -147,7 +147,7 @@ public class McastService extends MembershipServiceBase implements MessageListen
             localMember.setSecurePort(securePort);
             localMember.setUdpPort(udpPort);
             localMember.getData(true, true);
-        } catch (IOException x) {
+        }catch ( IOException x ) {
             throw new IllegalArgumentException(x);
         }
     }
@@ -183,9 +183,9 @@ public class McastService extends MembershipServiceBase implements MessageListen
     }
 
     @Override
-    public int getRecoveryCounter() {
+    public int getRecoveryCounter(){
         String p = properties.getProperty("recoveryCounter");
-        if (p != null) {
+        if(p != null){
             return Integer.parseInt(p);
         }
         return -1;
@@ -198,7 +198,7 @@ public class McastService extends MembershipServiceBase implements MessageListen
     @Override
     public boolean getRecoveryEnabled() {
         String p = properties.getProperty("recoveryEnabled");
-        if (p != null) {
+        if(p != null){
             return Boolean.parseBoolean(p);
         }
         return false;
@@ -209,22 +209,22 @@ public class McastService extends MembershipServiceBase implements MessageListen
     }
 
     @Override
-    public long getRecoverySleepTime() {
+    public long getRecoverySleepTime(){
         String p = properties.getProperty("recoverySleepTime");
-        if (p != null) {
+        if(p != null){
             return Long.parseLong(p);
         }
         return -1;
     }
 
     public void setLocalLoopbackDisabled(boolean localLoopbackDisabled) {
-        properties.setProperty("localLoopbackDisabled", String.valueOf(localLoopbackDisabled));
+        properties.setProperty("localLoopbackDisabled",String.valueOf(localLoopbackDisabled));
     }
 
     @Override
     public boolean getLocalLoopbackDisabled() {
         String p = properties.getProperty("localLoopbackDisabled");
-        if (p != null) {
+        if(p != null){
             return Boolean.parseBoolean(p);
         }
         return false;
@@ -249,7 +249,6 @@ public class McastService extends MembershipServiceBase implements MessageListen
     public void setMcastDropTime(long time) {
         setDropTime(time);
     }
-
     public void setDropTime(long time) {
         properties.setProperty("memberDropTime", String.valueOf(time));
     }
@@ -262,29 +261,28 @@ public class McastService extends MembershipServiceBase implements MessageListen
 
     /**
      * Check if a required property is available.
-     *
      * @param properties The set of properties
-     * @param name       The property to check for
+     * @param name The property to check for
      */
-    protected void hasProperty(Properties properties, String name) {
-        if (properties.getProperty(name) == null) {
+    protected void hasProperty(Properties properties, String name){
+        if ( properties.getProperty(name)==null) {
             throw new IllegalArgumentException(sm.getString("mcastService.missing.property", name));
         }
     }
 
     @Override
     public void start(int level) throws Exception {
-        hasProperty(properties, "mcastPort");
-        hasProperty(properties, "mcastAddress");
-        hasProperty(properties, "memberDropTime");
-        hasProperty(properties, "mcastFrequency");
-        hasProperty(properties, "tcpListenPort");
-        hasProperty(properties, "tcpListenHost");
-        hasProperty(properties, "tcpSecurePort");
-        hasProperty(properties, "udpListenPort");
+        hasProperty(properties,"mcastPort");
+        hasProperty(properties,"mcastAddress");
+        hasProperty(properties,"memberDropTime");
+        hasProperty(properties,"mcastFrequency");
+        hasProperty(properties,"tcpListenPort");
+        hasProperty(properties,"tcpListenHost");
+        hasProperty(properties,"tcpSecurePort");
+        hasProperty(properties,"udpListenPort");
 
 
-        if (impl != null) {
+        if ( impl != null ) {
             impl.start(level);
             return;
         }
@@ -293,7 +291,7 @@ public class McastService extends MembershipServiceBase implements MessageListen
         int securePort = Integer.parseInt(getProperties().getProperty("tcpSecurePort"));
         int udpPort = Integer.parseInt(getProperties().getProperty("udpListenPort"));
 
-        if (localMember == null) {
+        if ( localMember == null ) {
             localMember = new MemberImpl(host, port, 100);
             localMember.setUniqueId(UUIDGenerator.randomUUID(true));
             localMember.setLocal(true);
@@ -304,39 +302,46 @@ public class McastService extends MembershipServiceBase implements MessageListen
         }
         localMember.setSecurePort(securePort);
         localMember.setUdpPort(udpPort);
-        if (this.payload != null) {
+        if ( this.payload != null ) {
             localMember.setPayload(payload);
         }
-        if (this.domain != null) {
+        if ( this.domain != null ) {
             localMember.setDomain(domain);
         }
         localMember.setServiceStartTime(System.currentTimeMillis());
         java.net.InetAddress bind = null;
-        if (properties.getProperty("mcastBindAddress") != null) {
+        if ( properties.getProperty("mcastBindAddress")!= null ) {
             bind = java.net.InetAddress.getByName(properties.getProperty("mcastBindAddress"));
         }
         int ttl = -1;
         int soTimeout = -1;
-        if (properties.getProperty("mcastTTL") != null) {
+        if ( properties.getProperty("mcastTTL") != null ) {
             try {
                 ttl = Integer.parseInt(properties.getProperty("mcastTTL"));
-            } catch (Exception x) {
-                log.error(sm.getString("McastService.parseTTL", properties.getProperty("mcastTTL")), x);
+            } catch ( Exception x ) {
+                log.error(sm.getString("McastService.parseTTL",
+                        properties.getProperty("mcastTTL")), x);
             }
         }
-        if (properties.getProperty("mcastSoTimeout") != null) {
+        if ( properties.getProperty("mcastSoTimeout") != null ) {
             try {
                 soTimeout = Integer.parseInt(properties.getProperty("mcastSoTimeout"));
-            } catch (Exception x) {
-                log.error(sm.getString("McastService.parseSoTimeout", properties.getProperty("mcastSoTimeout")), x);
+            } catch ( Exception x ) {
+                log.error(sm.getString("McastService.parseSoTimeout",
+                        properties.getProperty("mcastSoTimeout")), x);
             }
         }
 
-        impl = new McastServiceImpl(localMember, Long.parseLong(properties.getProperty("mcastFrequency")),
-                Long.parseLong(properties.getProperty("memberDropTime")),
-                Integer.parseInt(properties.getProperty("mcastPort")), bind,
-                java.net.InetAddress.getByName(properties.getProperty("mcastAddress")), ttl, soTimeout, this, this,
-                Boolean.parseBoolean(properties.getProperty("localLoopbackDisabled")));
+        impl = new McastServiceImpl(localMember,Long.parseLong(properties.getProperty("mcastFrequency")),
+                                    Long.parseLong(properties.getProperty("memberDropTime")),
+                                    Integer.parseInt(properties.getProperty("mcastPort")),
+                                    bind,
+                                    java.net.InetAddress.getByName(properties.getProperty("mcastAddress")),
+                                    ttl,
+                                    soTimeout,
+                                    this,
+                                    this,
+                                    Boolean.parseBoolean(properties.getProperty("localLoopbackDisabled")));
         impl.setMembershipService(this);
         String value = properties.getProperty("recoveryEnabled");
         boolean recEnabled = Boolean.parseBoolean(value);
@@ -362,8 +367,8 @@ public class McastService extends MembershipServiceBase implements MessageListen
      */
     @Override
     public void stop(int svc) {
-        try {
-            if (impl != null && impl.stop(svc)) {
+        try  {
+            if ( impl != null && impl.stop(svc) ) {
                 if (oname != null) {
                     JmxRegistry.getRegistry(channel).unregisterJmx(oname);
                     oname = null;
@@ -372,8 +377,9 @@ public class McastService extends MembershipServiceBase implements MessageListen
                 impl = null;
                 channel = null;
             }
-        } catch (Exception x) {
-            log.error(sm.getString("McastService.stopFail", Integer.valueOf(svc)), x);
+        } catch ( Exception x)  {
+            log.error(sm.getString(
+                    "McastService.stopFail", Integer.valueOf(svc)), x);
         }
     }
 
@@ -387,7 +393,7 @@ public class McastService extends MembershipServiceBase implements MessageListen
 
     @Override
     public void messageReceived(ChannelMessage msg) {
-        if (msglistener != null && msglistener.accept(msg)) {
+        if (msglistener!=null && msglistener.accept(msg)) {
             msglistener.messageReceived(msg);
         }
     }
@@ -396,19 +402,19 @@ public class McastService extends MembershipServiceBase implements MessageListen
     public boolean accept(ChannelMessage msg) {
         return true;
     }
-
     @Override
     public void broadcast(ChannelMessage message) throws ChannelException {
-        if (impl == null || (impl.startLevel & Channel.MBR_TX_SEQ) != Channel.MBR_TX_SEQ) {
+        if (impl==null || (impl.startLevel & Channel.MBR_TX_SEQ)!=Channel.MBR_TX_SEQ ) {
             throw new ChannelException(sm.getString("mcastService.noStart"));
         }
 
-        byte[] data = XByteBuffer.createDataPackage((ChannelData) message);
-        if (data.length > McastServiceImpl.MAX_PACKET_SIZE) {
-            throw new ChannelException(sm.getString("mcastService.exceed.maxPacketSize", Integer.toString(data.length),
+        byte[] data = XByteBuffer.createDataPackage((ChannelData)message);
+        if (data.length>McastServiceImpl.MAX_PACKET_SIZE) {
+            throw new ChannelException(sm.getString("mcastService.exceed.maxPacketSize",
+                    Integer.toString(data.length) ,
                     Integer.toString(McastServiceImpl.MAX_PACKET_SIZE)));
         }
-        DatagramPacket packet = new DatagramPacket(data, 0, data.length);
+        DatagramPacket packet = new DatagramPacket(data,0,data.length);
         try {
             impl.send(false, packet);
         } catch (Exception x) {
@@ -448,13 +454,13 @@ public class McastService extends MembershipServiceBase implements MessageListen
     @Override
     public void setPayload(byte[] payload) {
         this.payload = payload;
-        if (localMember != null) {
+        if ( localMember != null ) {
             localMember.setPayload(payload);
             try {
                 if (impl != null) {
                     impl.send(false);
                 }
-            } catch (Exception x) {
+            }catch ( Exception x ) {
                 log.error(sm.getString("McastService.payload"), x);
             }
         }
@@ -463,23 +469,23 @@ public class McastService extends MembershipServiceBase implements MessageListen
     @Override
     public void setDomain(byte[] domain) {
         this.domain = domain;
-        if (localMember != null) {
+        if ( localMember != null ) {
             localMember.setDomain(domain);
             try {
                 if (impl != null) {
                     impl.send(false);
                 }
-            } catch (Exception x) {
+            }catch ( Exception x ) {
                 log.error(sm.getString("McastService.domain"), x);
             }
         }
     }
 
     public void setDomain(String domain) {
-        if (domain == null) {
+        if ( domain == null ) {
             return;
         }
-        if (domain.startsWith("{")) {
+        if ( domain.startsWith("{") ) {
             setDomain(Arrays.fromString(domain));
         } else {
             setDomain(Arrays.convert(domain));
@@ -494,16 +500,16 @@ public class McastService extends MembershipServiceBase implements MessageListen
     protected void setDefaults(Properties properties) {
         // default values
         if (properties.getProperty("mcastPort") == null) {
-            properties.setProperty("mcastPort", "45564");
+            properties.setProperty("mcastPort","45564");
         }
         if (properties.getProperty("mcastAddress") == null) {
-            properties.setProperty("mcastAddress", "228.0.0.4");
+            properties.setProperty("mcastAddress","228.0.0.4");
         }
         if (properties.getProperty("memberDropTime") == null) {
-            properties.setProperty("memberDropTime", "3000");
+            properties.setProperty("memberDropTime","3000");
         }
         if (properties.getProperty("mcastFrequency") == null) {
-            properties.setProperty("mcastFrequency", "500");
+            properties.setProperty("mcastFrequency","500");
         }
         if (properties.getProperty("recoveryCounter") == null) {
             properties.setProperty("recoveryCounter", "10");
@@ -521,26 +527,24 @@ public class McastService extends MembershipServiceBase implements MessageListen
 
     /**
      * Simple test program
-     *
      * @param args Command-line arguments
-     *
      * @throws Exception If an error occurs
      */
     public static void main(String args[]) throws Exception {
         McastService service = new McastService();
         Properties p = new Properties();
-        p.setProperty("mcastPort", "5555");
-        p.setProperty("mcastAddress", "224.10.10.10");
-        p.setProperty("mcastClusterDomain", "catalina");
-        p.setProperty("bindAddress", "localhost");
-        p.setProperty("memberDropTime", "3000");
-        p.setProperty("mcastFrequency", "500");
-        p.setProperty("tcpListenPort", "4000");
-        p.setProperty("tcpListenHost", "127.0.0.1");
-        p.setProperty("tcpSecurePort", "4100");
-        p.setProperty("udpListenPort", "4200");
+        p.setProperty("mcastPort","5555");
+        p.setProperty("mcastAddress","224.10.10.10");
+        p.setProperty("mcastClusterDomain","catalina");
+        p.setProperty("bindAddress","localhost");
+        p.setProperty("memberDropTime","3000");
+        p.setProperty("mcastFrequency","500");
+        p.setProperty("tcpListenPort","4000");
+        p.setProperty("tcpListenHost","127.0.0.1");
+        p.setProperty("tcpSecurePort","4100");
+        p.setProperty("udpListenPort","4200");
         service.setProperties(p);
         service.start();
-        Thread.sleep(60 * 1000 * 60);
+        Thread.sleep(60*1000*60);
     }
 }
