@@ -593,7 +593,11 @@ public class McastServiceImpl extends MembershipProviderBase {
                         log.debug("Error receiving mcast package"+(doRunReceiver?". Sleeping 500ms":"."),x);
                     }
                     if (doRunReceiver) {
-                        try { Thread.sleep(500); } catch ( Exception ignore ){}
+                        try {
+                            sleep(500);
+                        } catch (Exception ignore){
+                            // Ignore
+                        }
                         if ( (++errorCounter)>=recoveryCounter ) {
                             errorCounter=0;
                             RecoveryThread.recover(McastServiceImpl.this);
@@ -633,7 +637,11 @@ public class McastServiceImpl extends MembershipProviderBase {
                         RecoveryThread.recover(McastServiceImpl.this);
                     }
                 }
-                try { Thread.sleep(time); } catch ( Exception ignore ) {}
+                try {
+                    sleep(time);
+                } catch (Exception ignore) {
+                    // Ignore
+                }
             }
         }
     }//class SenderThread
@@ -709,7 +717,7 @@ public class McastServiceImpl extends MembershipProviderBase {
                                         Integer.toString(++attempt),
                                         Long.toString(parent.recoverySleepTime)));
                             }
-                            Thread.sleep(parent.recoverySleepTime);
+                            sleep(parent.recoverySleepTime);
                         }
                     }catch (InterruptedException ignore) {
                     }
