@@ -394,18 +394,20 @@ public class MemberImpl implements Member, java.io.Externalizable {
         System.arraycopy(data, pos, payload, 0, payload.length);
         pos += payload.length;
 
-        member.setHost(addr);
-        member.setPort(XByteBuffer.toInt(portd, 0));
-        member.setSecurePort(XByteBuffer.toInt(sportd, 0));
-        member.setUdpPort(XByteBuffer.toInt(uportd, 0));
-        member.setMemberAliveTime(XByteBuffer.toLong(alived, 0));
-        member.setUniqueId(uniqueId);
-        member.payload = payload;
-        member.domain = domain;
-        member.command = command;
+        synchronized (member) {
+            member.setHost(addr);
+            member.setPort(XByteBuffer.toInt(portd, 0));
+            member.setSecurePort(XByteBuffer.toInt(sportd, 0));
+            member.setUdpPort(XByteBuffer.toInt(uportd, 0));
+            member.setMemberAliveTime(XByteBuffer.toLong(alived, 0));
+            member.setUniqueId(uniqueId);
+            member.payload = payload;
+            member.domain = domain;
+            member.command = command;
 
-        member.dataPkg = new byte[length];
-        System.arraycopy(data, offset, member.dataPkg, 0, length);
+            member.dataPkg = new byte[length];
+            System.arraycopy(data, offset, member.dataPkg, 0, length);
+        }
 
         return member;
     }
@@ -605,10 +607,7 @@ public class MemberImpl implements Member, java.io.Externalizable {
     @Override
     public synchronized void setPayload(byte[] payload) {
         // longs to avoid any possibility of overflow
-        long oldPayloadLength = 0;
-        if (this.payload != null) {
-            oldPayloadLength = this.payload.length;
-        }
+        long oldPayloadLength = this.payload.length;
         long newPayloadLength = 0;
         if (payload != null) {
             newPayloadLength = payload.length;
