@@ -40,8 +40,7 @@ import org.apache.catalina.tribes.util.StringManager;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 
-public class StaticMembershipProvider extends MembershipProviderBase
-        implements RpcCallback, ChannelListener, Heartbeat {
+public class StaticMembershipProvider extends MembershipProviderBase implements RpcCallback, ChannelListener, Heartbeat {
 
     protected static final StringManager sm = StringManager.getManager(StaticMembershipProvider.class);
     private static final Log log = LogFactory.getLog(StaticMembershipProvider.class);
@@ -83,20 +82,20 @@ public class StaticMembershipProvider extends MembershipProviderBase
 
     @Override
     public void start(int level) throws Exception {
-        if (Channel.MBR_RX_SEQ == (level & Channel.MBR_RX_SEQ)) {
-            // no-op
+        if (Channel.MBR_RX_SEQ==(level & Channel.MBR_RX_SEQ)) {
+            //no-op
         }
-        if (Channel.MBR_TX_SEQ == (level & Channel.MBR_TX_SEQ)) {
-            // no-op
+        if (Channel.MBR_TX_SEQ==(level & Channel.MBR_TX_SEQ)) {
+            //no-op
         }
         startLevel = (startLevel | level);
         if (startLevel == (Channel.MBR_RX_SEQ | Channel.MBR_TX_SEQ)) {
             startMembership(getAliveMembers(staticMembers.toArray(new Member[0])));
             running = true;
-            if (thread == null && useThread) {
+            if ( thread == null && useThread) {
                 thread = new PingThread();
                 thread.setDaemon(true);
-                thread.setName("StaticMembership.PingThread[" + this.channel.getName() + "]");
+                thread.setName("StaticMembership.PingThread[" + this.channel.getName() +"]");
                 thread.start();
             }
         }
@@ -104,14 +103,14 @@ public class StaticMembershipProvider extends MembershipProviderBase
 
     @Override
     public boolean stop(int level) throws Exception {
-        if (Channel.MBR_RX_SEQ == (level & Channel.MBR_RX_SEQ)) {
+        if (Channel.MBR_RX_SEQ==(level & Channel.MBR_RX_SEQ)) {
             // no-op
         }
-        if (Channel.MBR_TX_SEQ == (level & Channel.MBR_TX_SEQ)) {
+        if (Channel.MBR_TX_SEQ==(level & Channel.MBR_TX_SEQ)) {
             // no-op
         }
         startLevel = (startLevel & (~level));
-        if (startLevel == 0) {
+        if ( startLevel == 0 ) {
             running = false;
             if (thread != null) {
                 thread.interrupt();
@@ -158,7 +157,7 @@ public class StaticMembershipProvider extends MembershipProviderBase
 
     protected void memberAdded(Member member) {
         Member mbr = setupMember(member);
-        if (membership.memberAlive(mbr)) {
+        if(membership.memberAlive(mbr)) {
             Runnable r = () -> {
                 Thread currentThread = Thread.currentThread();
                 String name = currentThread.getName();
@@ -196,7 +195,7 @@ public class StaticMembershipProvider extends MembershipProviderBase
     }
 
     protected void stopMembership(Member[] members) {
-        if (members.length == 0) {
+        if (members.length == 0 ) {
             return;
         }
         Member localmember = service.getLocalMember(false);
@@ -248,7 +247,8 @@ public class StaticMembershipProvider extends MembershipProviderBase
         } else {
             // other messages are ignored.
             if (log.isInfoEnabled()) {
-                log.info(sm.getString("staticMembershipProvider.replyRequest.ignored", memMsg.getTypeDesc()));
+                log.info(sm.getString("staticMembershipProvider.replyRequest.ignored",
+                        memMsg.getTypeDesc()));
             }
             return null;
         }
@@ -267,7 +267,8 @@ public class StaticMembershipProvider extends MembershipProviderBase
         } else {
             // other messages are ignored.
             if (log.isInfoEnabled()) {
-                log.info(sm.getString("staticMembershipProvider.leftOver.ignored", memMsg.getTypeDesc()));
+                log.info(sm.getString("staticMembershipProvider.leftOver.ignored",
+                        memMsg.getTypeDesc()));
             }
         }
     }
@@ -288,8 +289,7 @@ public class StaticMembershipProvider extends MembershipProviderBase
         Member[] members = getAliveMembers(staticMembers.toArray(new Member[0]));
         if (members.length > 0) {
             try {
-                MemberMessage msg =
-                        new MemberMessage(membershipId, MemberMessage.MSG_PING, service.getLocalMember(true));
+                MemberMessage msg = new MemberMessage(membershipId, MemberMessage.MSG_PING, service.getLocalMember(true));
                 Response[] resp = rpcChannel.send(members, msg, RpcChannel.ALL_REPLY, sendOptions, rpcTimeout);
                 for (Response response : resp) {
                     messageReceived(response.getMessage(), response.getSource());
@@ -387,14 +387,14 @@ public class StaticMembershipProvider extends MembershipProviderBase
 
         protected String getTypeDesc() {
             switch (msgtype) {
-                case MSG_START:
-                    return "MSG_START";
-                case MSG_STOP:
-                    return "MSG_STOP";
-                case MSG_PING:
-                    return "MSG_PING";
-                default:
-                    return "UNKNOWN";
+            case MSG_START:
+                return "MSG_START";
+            case MSG_STOP:
+                return "MSG_STOP";
+            case MSG_PING:
+                return "MSG_PING";
+            default:
+                return "UNKNOWN";
             }
         }
     }
@@ -406,9 +406,9 @@ public class StaticMembershipProvider extends MembershipProviderBase
                 try {
                     sleep(pingInterval);
                     ping();
-                } catch (InterruptedException ix) {
-                } catch (Exception x) {
-                    log.warn(sm.getString("staticMembershipProvider.pingThread.failed"), x);
+                }catch (InterruptedException ix) {
+                }catch (Exception x) {
+                    log.warn(sm.getString("staticMembershipProvider.pingThread.failed"),x);
                 }
             }
         }
