@@ -54,7 +54,7 @@ public abstract class AbstractStreamProvider implements StreamProvider {
                 public void checkServerTrusted(X509Certificate[] chain, String authType) throws CertificateException {}
                 @Override
                 public X509Certificate[] getAcceptedIssuers() {
-                    return null;
+                    return new X509Certificate[0];
                 }
             }
         };
@@ -81,7 +81,7 @@ public abstract class AbstractStreamProvider implements StreamProvider {
         URLConnection connection;
         try {
             connection = new URI(url).toURL().openConnection();
-        } catch (URISyntaxException e) {
+        } catch (URISyntaxException | IllegalArgumentException e) {
             // Not ideal but consistent with API
             throw new IOException(e);
         }
@@ -145,7 +145,7 @@ public abstract class AbstractStreamProvider implements StreamProvider {
             }
         } else {
             log.warn(sm.getString("abstractStream.CACertUndefined"));
-            return InsecureStreamProvider.INSECURE_TRUST_MANAGERS;
+            return INSECURE_TRUST_MANAGERS;
         }
     }
 }
