@@ -14,7 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.catalina.tribes.membership.cloud;
 
 import java.io.IOException;
@@ -76,8 +75,9 @@ public abstract class CloudMembershipProvider extends MembershipProviderBase imp
         String val = null;
         for (String key : keys) {
             val = AccessController.doPrivileged((PrivilegedAction<String>) () -> System.getenv(key));
-            if (val != null)
+            if (val != null) {
                 break;
+            }
         }
         return val;
     }
@@ -156,17 +156,18 @@ public abstract class CloudMembershipProvider extends MembershipProviderBase imp
             log.debug(message);
         }
         Runnable r = () -> {
-            String name = Thread.currentThread().getName();
+            Thread currentThread = Thread.currentThread();
+            String name = currentThread.getName();
             try {
                 String threadName = add ? "CloudMembership-memberAdded" : "CloudMembership-memberDisappeared";
-                Thread.currentThread().setName(threadName);
+                currentThread.setName(threadName);
                 if (add) {
                     membershipListener.memberAdded(member);
                 } else {
                     membershipListener.memberDisappeared(member);
                 }
             } finally {
-                Thread.currentThread().setName(name);
+                currentThread.setName(name);
             }
         };
         executor.execute(r);
