@@ -30,16 +30,17 @@ import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 
 /**
- * A {@link org.apache.catalina.tribes.MembershipService} that uses Kubernetes API(default) or DNS to retrieve the
- * members of a cluster.<br>
+ * A {@link org.apache.catalina.tribes.MembershipService} that uses Kubernetes API(default) or DNS to retrieve
+ * the members of a cluster.<br>
  * <p>
- * The default implementation of the MembershipProvider component is the {@link KubernetesMembershipProvider}. The
- * MembershipProvider can be configured by the <code>membershipProviderClassName</code> property. Possible shortcuts are
- * {@code kubernetes} and {@code dns}. For dns look at the {@link DNSMembershipProvider}.
+ * The default implementation of the MembershipProvider component is the {@link KubernetesMembershipProvider}.
+ * The MembershipProvider can be configured by the <code>membershipProviderClassName</code> property.
+ * Possible shortcuts are {@code kubernetes} and {@code dns}. For dns look at the {@link DNSMembershipProvider}.
  * </p>
  * <p>
  * <strong>Configuration example</strong>
  * </p>
+ *
  * {@code server.xml }
  *
  * <pre>
@@ -60,9 +61,11 @@ import org.apache.juli.logging.LogFactory;
  *         ...
  *  }
  *  </pre>
+ *
  */
 
-public class CloudMembershipService extends MembershipServiceBase implements CloudMembershipServiceMBean {
+public class CloudMembershipService extends MembershipServiceBase
+        implements CloudMembershipServiceMBean {
 
     private static final Log log = LogFactory.getLog(CloudMembershipService.class);
     protected static final StringManager sm = StringManager.getManager(CloudMembershipService.class);
@@ -70,10 +73,8 @@ public class CloudMembershipService extends MembershipServiceBase implements Clo
     public static final String MEMBERSHIP_PROVIDER_CLASS_NAME = "membershipProviderClassName";
     private static final String KUBE = "kubernetes";
     private static final String DNS = "dns";
-    private static final String KUBE_PROVIDER_CLASS =
-            "org.apache.catalina.tribes.membership.cloud.KubernetesMembershipProvider";
-    private static final String DNS_PROVIDER_CLASS =
-            "org.apache.catalina.tribes.membership.cloud.DNSMembershipProvider";
+    private static final String KUBE_PROVIDER_CLASS = "org.apache.catalina.tribes.membership.cloud.KubernetesMembershipProvider";
+    private static final String DNS_PROVIDER_CLASS = "org.apache.catalina.tribes.membership.cloud.DNSMembershipProvider";
     protected static final byte[] INITIAL_ID = new byte[16];
 
     private MembershipProvider membershipProvider;
@@ -86,9 +87,7 @@ public class CloudMembershipService extends MembershipServiceBase implements Clo
 
     /**
      * Return a property.
-     *
      * @param name the property name
-     *
      * @return the property value
      */
     public Object getProperty(String name) {
@@ -97,10 +96,8 @@ public class CloudMembershipService extends MembershipServiceBase implements Clo
 
     /**
      * Set a property.
-     *
-     * @param name  the property name
+     * @param name the property name
      * @param value the property value
-     *
      * @return <code>true</code> if the property was successfully set
      */
     public boolean setProperty(String name, String value) {
@@ -109,7 +106,6 @@ public class CloudMembershipService extends MembershipServiceBase implements Clo
 
     /**
      * Return the membership provider class.
-     *
      * @return the classname
      */
     public String getMembershipProviderClassName() {
@@ -118,7 +114,6 @@ public class CloudMembershipService extends MembershipServiceBase implements Clo
 
     /**
      * Set the membership provider class.
-     *
      * @param membershipProviderClassName the class name
      */
     public void setMembershipProviderClassName(String membershipProviderClassName) {
@@ -144,10 +139,11 @@ public class CloudMembershipService extends MembershipServiceBase implements Clo
             } else if (DNS.equals(provider)) {
                 provider = DNS_PROVIDER_CLASS;
             }
-            if (log.isTraceEnabled()) {
-                log.trace("Using membershipProvider: " + provider);
+            if (log.isDebugEnabled()) {
+                log.debug("Using membershipProvider: " + provider);
             }
-            membershipProvider = (MembershipProvider) Class.forName(provider).getConstructor().newInstance();
+            membershipProvider =
+                    (MembershipProvider) Class.forName(provider).getConstructor().newInstance();
             membershipProvider.setMembershipListener(this);
             membershipProvider.setMembershipService(this);
             membershipProvider.init(properties);
@@ -186,9 +182,9 @@ public class CloudMembershipService extends MembershipServiceBase implements Clo
 
     @Override
     public void setLocalMemberProperties(String listenHost, int listenPort, int securePort, int udpPort) {
-        if (log.isTraceEnabled()) {
-            log.trace(String.format("setLocalMemberProperties(%s, %d, %d, %d)", listenHost, Integer.valueOf(listenPort),
-                    Integer.valueOf(securePort), Integer.valueOf(udpPort)));
+        if (log.isDebugEnabled()) {
+            log.debug(String.format("setLocalMemberProperties(%s, %d, %d, %d)", listenHost,
+                    Integer.valueOf(listenPort), Integer.valueOf(securePort), Integer.valueOf(udpPort)));
         }
         properties.setProperty("tcpListenHost", listenHost);
         properties.setProperty("tcpListenPort", String.valueOf(listenPort));
