@@ -52,7 +52,7 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
 
     private volatile boolean running = false;
 
-    private final AtomicReference<Selector> selector = new AtomicReference<>();
+    private AtomicReference<Selector> selector = new AtomicReference<>();
     private ServerSocketChannel serverChannel = null;
     private DatagramChannel datagramChannel = null;
 
@@ -67,17 +67,24 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
         super.stop();
     }
 
+    /**
+     * Start cluster receiver.
+     *
+     * @throws IOException If the receiver fails to start
+     *
+     * @see org.apache.catalina.tribes.ChannelReceiver#start()
+     */
     @Override
     public void start() throws IOException {
         super.start();
         try {
-            setPool(new RxTaskPool(getMaxThreads(), getMinThreads(), this));
-        } catch (Exception e) {
-            log.fatal(sm.getString("nioReceiver.threadpool.fail"), e);
-            if (e instanceof IOException) {
-                throw (IOException) e;
+            setPool(new RxTaskPool(getMaxThreads(),getMinThreads(),this));
+        } catch (Exception x) {
+            log.fatal(sm.getString("nioReceiver.threadpool.fail"), x);
+            if ( x instanceof IOException ) {
+                throw (IOException)x;
             } else {
-                throw new IOException(e.getMessage());
+                throw new IOException(x.getMessage());
             }
         }
         try {
@@ -90,19 +97,19 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
             Thread t = new Thread(this, "NioReceiver" + channelName);
             t.setDaemon(true);
             t.start();
-        } catch (Exception e) {
-            log.fatal(sm.getString("nioReceiver.start.fail"), e);
-            if (e instanceof IOException) {
-                throw (IOException) e;
+        } catch (Exception x) {
+            log.fatal(sm.getString("nioReceiver.start.fail"), x);
+            if ( x instanceof IOException ) {
+                throw (IOException)x;
             } else {
-                throw new IOException(e.getMessage());
+                throw new IOException(x.getMessage());
             }
         }
     }
 
     @Override
     public AbstractRxTask createRxTask() {
-        NioReplicationTask thread = new NioReplicationTask(this, this);
+        NioReplicationTask thread = new NioReplicationTask(this,this);
         thread.setUseBufferPool(this.getUseBufferPool());
         thread.setRxBufSize(getRxBufSize());
         thread.setOptions(getWorkerThreadOptions());
@@ -110,6 +117,7 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
     }
 
 
+
     protected void bind() throws IOException {
         // allocate an unbound server socket channel
         serverChannel = ServerSocketChannel.open();
@@ -118,19 +126,19 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
         // create a new Selector for use below
         this.selector.set(Selector.open());
         // set the port the server channel will listen to
-        // serverSocket.bind(new InetSocketAddress(getBind(), getTcpListenPort()));
-        bind(serverSocket, getPort(), getAutoBind());
+        //serverSocket.bind(new InetSocketAddress(getBind(), getTcpListenPort()));
+        bind(serverSocket,getPort(),getAutoBind());
         // set non-blocking mode for the listening socket
         serverChannel.configureBlocking(false);
         // register the ServerSocketChannel with the Selector
         serverChannel.register(this.selector.get(), SelectionKey.OP_ACCEPT);
 
-        // set up the datagram channel
-        if (this.getUdpPort() > 0) {
+        //set up the datagram channel
+        if (this.getUdpPort()>0) {
             datagramChannel = DatagramChannel.open();
             configureDatagraChannel();
-            // bind to the address to avoid security checks
-            bindUdp(datagramChannel.socket(), getUdpPort(), getAutoBind());
+            //bind to the address to avoid security checks
+            bindUdp(datagramChannel.socket(),getUdpPort(),getAutoBind());
         }
     }
 
@@ -160,98 +168,87 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
         if (events.isEmpty()) {
             return;
         }
-        Runnable r;
-        while ((r = events.pollFirst()) != null) {
+        Runnable r = null;
+        while ((r = events.pollFirst()) != null ) {
             try {
                 if (log.isTraceEnabled()) {
                     log.trace("Processing event in selector:" + r);
                 }
                 r.run();
-            } catch (Exception e) {
-                log.error(sm.getString("nioReceiver.eventsError"), e);
+            } catch (Exception x) {
+                log.error(sm.getString("nioReceiver.eventsError"), x);
             }
         }
     }
 
     public static void cancelledKey(SelectionKey key) {
-        ObjectReader reader = (ObjectReader) key.attachment();
-        if (reader != null) {
+        ObjectReader reader = (ObjectReader)key.attachment();
+        if ( reader != null ) {
             reader.setCancelled(true);
             reader.finish();
         }
         key.cancel();
         key.attach(null);
         if (key.channel() instanceof SocketChannel) {
-            try {
-                ((SocketChannel) key.channel()).socket().close();
-            } catch (IOException ioe) {
-                if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("nioReceiver.closeError"), ioe);
-                }
-            }
+            try { ((SocketChannel)key.channel()).socket().close(); } catch (IOException e) { if (log.isDebugEnabled()) {
+                log.debug("", e);
+            } }
         }
         if (key.channel() instanceof DatagramChannel) {
-            try {
-                ((DatagramChannel) key.channel()).socket().close();
-            } catch (Exception e) {
-                if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("nioReceiver.closeError"), e);
-                }
-            }
-        }
-        try {
-            key.channel().close();
-        } catch (IOException ioe) {
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("nioReceiver.closeError"), ioe);
-            }
+            try { ((DatagramChannel)key.channel()).socket().close(); } catch (Exception e) { if (log.isDebugEnabled()) {
+                log.debug("", e);
+            } }
         }
+        try { key.channel().close(); } catch (IOException e) { if (log.isDebugEnabled()) {
+            log.debug("", e);
+        } }
 
     }
-
     protected long lastCheck = System.currentTimeMillis();
-
     protected void socketTimeouts() {
         long now = System.currentTimeMillis();
-        if ((now - lastCheck) < getSelectorTimeout()) {
+        if ( (now-lastCheck) < getSelectorTimeout() ) {
             return;
         }
-        // timeout
+        //timeout
         Selector tmpsel = this.selector.get();
-        Set<SelectionKey> keys = (isListening() && tmpsel != null) ? tmpsel.keys() : null;
-        if (keys == null) {
+        Set<SelectionKey> keys =  (isListening()&&tmpsel!=null)?tmpsel.keys():null;
+        if ( keys == null ) {
             return;
         }
         for (SelectionKey key : keys) {
             try {
-                // if (key.interestOps() == SelectionKey.OP_READ) {
-                // //only timeout sockets that we are waiting for a read from
-                // ObjectReader ka = (ObjectReader) key.attachment();
-                // long delta = now - ka.getLastAccess();
-                // if (delta > (long) getTimeout()) {
-                // cancelledKey(key);
-                // }
-                // }
-                // else
-                if (key.interestOps() == 0) {
-                    // check for keys that didn't make it in.
+//                if (key.interestOps() == SelectionKey.OP_READ) {
+//                    //only timeout sockets that we are waiting for a read from
+//                    ObjectReader ka = (ObjectReader) key.attachment();
+//                    long delta = now - ka.getLastAccess();
+//                    if (delta > (long) getTimeout()) {
+//                        cancelledKey(key);
+//                    }
+//                }
+//                else
+                if ( key.interestOps() == 0 ) {
+                    //check for keys that didn't make it in.
                     ObjectReader ka = (ObjectReader) key.attachment();
-                    if (ka != null) {
+                    if ( ka != null ) {
                         long delta = now - ka.getLastAccess();
                         if (delta > getTimeout() && (!ka.isAccessed())) {
                             if (log.isWarnEnabled()) {
-                                log.warn(sm.getString("nioReceiver.threadsExhausted", Integer.valueOf(getTimeout()),
-                                        Boolean.valueOf(ka.isCancelled()), key,
+                                log.warn(sm.getString(
+                                        "nioReceiver.threadsExhausted",
+                                        Integer.valueOf(getTimeout()),
+                                        Boolean.valueOf(ka.isCancelled()),
+                                        key,
                                         new java.sql.Timestamp(ka.getLastAccess())));
                             }
                             ka.setLastAccess(now);
-                            // key.interestOps(SelectionKey.OP_READ);
-                        } // end if
+                            //key.interestOps(SelectionKey.OP_READ);
+                        }//end if
                     } else {
                         cancelledKey(key);
-                    } // end if
-                } // end if
-            } catch (CancelledKeyException ckx) {
+                    }//end if
+                }//end if
+            }catch ( CancelledKeyException ckx ) {
                 cancelledKey(key);
             }
         }
@@ -260,8 +257,8 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
 
 
     /**
-     * Get data from channel and store in byte array send it to cluster
-     *
+     * Get data from channel and store in byte array
+     * send it to cluster
      * @throws IOException IO error
      */
     protected void listen() throws Exception {
@@ -275,9 +272,9 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
         // Avoid NPEs if selector is set to null on stop.
         Selector selector = this.selector.get();
 
-        if (selector != null && datagramChannel != null) {
-            ObjectReader oreader = new ObjectReader(MAX_UDP_SIZE); // max size for a datagram packet
-            registerChannel(selector, datagramChannel, SelectionKey.OP_READ, oreader);
+        if (selector!=null && datagramChannel!=null) {
+            ObjectReader oreader = new ObjectReader(MAX_UDP_SIZE); //max size for a datagram packet
+            registerChannel(selector,datagramChannel,SelectionKey.OP_READ,oreader);
         }
 
         while (doListen() && selector != null) {
@@ -288,22 +285,22 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
                 socketTimeouts();
                 int n = selector.select(getSelectorTimeout());
                 if (n == 0) {
-                    // there is a good chance that we got here
-                    // because the TcpReplicationThread called
-                    // selector wakeup().
-                    // if that happens, we must ensure that that
-                    // thread has enough time to call interestOps
-                    // synchronized (interestOpsMutex) {
-                    // if we got the lock, means there are no
-                    // keys trying to register for the
-                    // interestOps method
-                    // }
+                    //there is a good chance that we got here
+                    //because the TcpReplicationThread called
+                    //selector wakeup().
+                    //if that happens, we must ensure that that
+                    //thread has enough time to call interestOps
+//                    synchronized (interestOpsMutex) {
+                        //if we got the lock, means there are no
+                        //keys trying to register for the
+                        //interestOps method
+//                    }
                     continue; // nothing to do
                 }
                 // get an iterator over the set of selected keys
                 Iterator<SelectionKey> it = selector.selectedKeys().iterator();
                 // look at each key in the selected set
-                while (it.hasNext()) {
+                while (it!=null && it.hasNext()) {
                     SelectionKey key = it.next();
                     // Is a new connection coming in?
                     if (key.isAcceptable()) {
@@ -315,10 +312,13 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
                         channel.socket().setKeepAlive(getSoKeepAlive());
                         channel.socket().setOOBInline(getOoBInline());
                         channel.socket().setReuseAddress(getSoReuseAddress());
-                        channel.socket().setSoLinger(getSoLingerOn(), getSoLingerTime());
+                        channel.socket().setSoLinger(getSoLingerOn(),getSoLingerTime());
                         channel.socket().setSoTimeout(getTimeout());
                         Object attach = new ObjectReader(channel);
-                        registerChannel(selector, channel, SelectionKey.OP_READ, attach);
+                        registerChannel(selector,
+                                        channel,
+                                        SelectionKey.OP_READ,
+                                        attach);
                     }
                     // is there data to read on this channel?
                     if (key.isReadable()) {
@@ -341,20 +341,21 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
 
         }
         serverChannel.close();
-        if (datagramChannel != null) {
+        if (datagramChannel!=null) {
             try {
                 datagramChannel.close();
-            } catch (Exception e) {
+            }catch (Exception iox) {
                 if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("nioReceiver.closeError"), e);
+                    log.debug("Unable to close datagram channel.",iox);
                 }
             }
-            datagramChannel = null;
+            datagramChannel=null;
         }
         closeSelector();
     }
 
 
+
     /**
      * Close Selector.
      *
@@ -371,14 +372,14 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
                 int count = 0;
                 while (running && count < 50) {
                     Thread.sleep(100);
-                    count++;
+                    count ++;
                 }
                 if (running) {
                     log.warn(sm.getString("nioReceiver.stop.threadRunning"));
                 }
                 closeSelector();
-            } catch (Exception e) {
-                log.error(sm.getString("nioReceiver.stop.fail"), e);
+            } catch (Exception x) {
+                log.error(sm.getString("nioReceiver.stop.fail"), x);
             } finally {
                 this.selector.set(null);
             }
@@ -397,16 +398,16 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
                 key.attach(null);
                 key.cancel();
             }
-        } catch (IOException ioe) {
+        } catch (IOException ignore){
             if (log.isWarnEnabled()) {
-                log.warn(sm.getString("nioReceiver.cleanup.fail"), ioe);
+                log.warn(sm.getString("nioReceiver.cleanup.fail"), ignore);
             }
-        } catch (ClosedSelectorException ignore) {
+        } catch (ClosedSelectorException ignore){
             // Ignore
         }
         try {
             selector.selectNow();
-        } catch (Throwable t) {
+        } catch (Throwable t){
             ExceptionUtils.handleThrowable(t);
             // Ignore everything else
         }
@@ -416,18 +417,20 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
     // ----------------------------------------------------------
 
     /**
-     * Register the given channel with the given selector for the given operations of interest
-     *
+     * Register the given channel with the given selector for
+     * the given operations of interest
      * @param selector The selector to use
-     * @param channel  The channel
-     * @param ops      The operations to register
-     * @param attach   Attachment object
-     *
+     * @param channel The channel
+     * @param ops The operations to register
+     * @param attach Attachment object
      * @throws Exception IO error with channel
      */
-    protected void registerChannel(Selector selector, SelectableChannel channel, int ops, Object attach)
-            throws Exception {
-        if (channel == null) {
+    protected void registerChannel(Selector selector,
+                                   SelectableChannel channel,
+                                   int ops,
+                                   Object attach) throws Exception {
+        if (channel == null)
+         {
             return; // could happen
         }
         // set the new channel non-blocking
@@ -444,8 +447,8 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
         running = true;
         try {
             listen();
-        } catch (Exception e) {
-            log.error(sm.getString("nioReceiver.run.fail"), e);
+        } catch (Exception x) {
+            log.error(sm.getString("nioReceiver.run.fail"), x);
         } finally {
             running = false;
         }
@@ -455,11 +458,11 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
 
     /**
      * Sample data handler method for a channel with data ready to read.
-     *
-     * @param key A SelectionKey object associated with a channel determined by the selector to be ready for reading. If
-     *                the channel returns an EOF condition, it is closed here, which automatically invalidates the
-     *                associated key. The selector will then de-register the channel on the next select call.
-     *
+     * @param key A SelectionKey object associated with a channel
+     *  determined by the selector to be ready for reading.  If the
+     *  channel returns an EOF condition, it is closed here, which
+     *  automatically invalidates the associated key.  The selector
+     *  will then de-register the channel on the next select call.
      * @throws Exception IO error with channel
      */
     protected void readDataFromSocket(SelectionKey key) throws Exception {
@@ -470,11 +473,11 @@ public class NioReceiver extends ReceiverBase implements Runnable, NioReceiverMB
             // thread becomes available, the thread pool itself has a waiting mechanism
             // so we will not wait here.
             if (log.isDebugEnabled()) {
-                log.debug(sm.getString("nioReceiver.noThread"));
+                log.debug("No TcpReplicationThread available");
             }
         } else {
             // invoking this wakes up the worker thread then returns
-            // add task to thread pool
+            //add task to thread pool
             task.serviceChannel(key);
             getExecutor().execute(task);
         }
