@@ -27,43 +27,60 @@ import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.modeler.Registry;
 import org.apache.tomcat.util.res.StringManager;
 
-public abstract class LifecycleMBeanBase extends LifecycleBase implements JmxEnabled {
+public abstract class LifecycleMBeanBase extends LifecycleBase
+        implements JmxEnabled {
 
     private static final Log log = LogFactory.getLog(LifecycleMBeanBase.class);
 
-    private static final StringManager sm = StringManager.getManager("org.apache.catalina.util");
+    private static final StringManager sm =
+        StringManager.getManager("org.apache.catalina.util");
 
 
     /* Cache components of the MBean registration. */
     private String domain = null;
     private ObjectName oname = null;
-    @Deprecated
-    protected MBeanServer mserver = null;
 
+    /**
+     * Sub-classes wishing to perform additional initialization should override
+     * this method, ensuring that super.initInternal() is the first call in the
+     * overriding method.
+     */
     @Override
     protected void initInternal() throws LifecycleException {
         // If oname is not null then registration has already happened via
         // preRegister().
         if (oname == null) {
-            mserver = Registry.getRegistry(null, null).getMBeanServer();
-
             oname = register(this, getObjectNameKeyProperties());
         }
     }
 
 
+    /**
+     * Sub-classes wishing to perform additional clean-up should override this
+     * method, ensuring that super.destroyInternal() is the last call in the
+     * overriding method.
+     */
     @Override
     protected void destroyInternal() throws LifecycleException {
         unregister(oname);
     }
 
 
+    /**
+     * Specify the domain under which this component should be registered. Used
+     * with components that cannot (easily) navigate the component hierarchy to
+     * determine the correct domain to use.
+     */
     @Override
     public final void setDomain(String domain) {
         this.domain = domain;
     }
 
 
+    /**
+     * Obtain the domain under which this component will be / has been
+     * registered.
+     */
     @Override
     public final String getDomain() {
         if (domain == null) {
@@ -79,13 +96,17 @@ public abstract class LifecycleMBeanBase extends LifecycleBase implements JmxEna
 
 
     /**
-     * Method implemented by subclasses to identify the domain in which MBeans should be registered.
+     * Method implemented by sub-classes to identify the domain in which MBeans
+     * should be registered.
      *
-     * @return The name of the domain to use to register MBeans.
+     * @return  The name of the domain to use to register MBeans.
      */
     protected abstract String getDomainInternal();
 
 
+    /**
+     * Obtain the name under which this component has been registered with JMX.
+     */
     @Override
     public final ObjectName getObjectName() {
         return oname;
@@ -93,26 +114,31 @@ public abstract class LifecycleMBeanBase extends LifecycleBase implements JmxEna
 
 
     /**
-     * Allow subclasses to specify the key properties component of the {@link ObjectName} that will be used to register
-     * this component.
+     * Allow sub-classes to specify the key properties component of the
+     * {@link ObjectName} that will be used to register this component.
      *
-     * @return The string representation of the key properties component of the desired {@link ObjectName}
+     * @return  The string representation of the key properties component of the
+     *          desired {@link ObjectName}
      */
     protected abstract String getObjectNameKeyProperties();
 
 
     /**
-     * Utility method to enable subclasses to easily register additional components that don't implement
-     * {@link JmxEnabled} with an MBean server. <br>
-     * Note: This method should only be used once {@link #initInternal()} has been called and before
-     * {@link #destroyInternal()} has been called.
+     * Utility method to enable sub-classes to easily register additional
+     * components that don't implement {@link JmxEnabled} with an MBean server.
+     * <br>
+     * Note: This method should only be used once {@link #initInternal()} has
+     * been called and before {@link #destroyInternal()} has been called.
      *
-     * @param obj                     The object the register
-     * @param objectNameKeyProperties The key properties component of the object name to use to register the object
+     * @param obj                       The object the register
+     * @param objectNameKeyProperties   The key properties component of the
+     *                                  object name to use to register the
+     *                                  object
      *
-     * @return The name used to register the object
+     * @return  The name used to register the object
      */
-    protected final ObjectName register(Object obj, String objectNameKeyProperties) {
+    protected final ObjectName register(Object obj,
+            String objectNameKeyProperties) {
 
         // Construct an object name with the right domain
         StringBuilder name = new StringBuilder(getDomain());
@@ -123,7 +149,7 @@ public abstract class LifecycleMBeanBase extends LifecycleBase implements JmxEna
 
         try {
             on = new ObjectName(name.toString());
-            Registry.getRegistry(null).registerComponent(obj, on, null);
+            Registry.getRegistry(null, null).registerComponent(obj, on, null);
         } catch (Exception e) {
             log.warn(sm.getString("lifecycleMBeanBase.registerFail", obj, name), e);
         }
@@ -133,30 +159,36 @@ public abstract class LifecycleMBeanBase extends LifecycleBase implements JmxEna
 
 
     /**
-     * Utility method to enable subclasses to easily unregister additional components that don't implement
-     * {@link JmxEnabled} with an MBean server. <br>
-     * Note: This method should only be used once {@link #initInternal()} has been called and before
-     * {@link #destroyInternal()} has been called.
+     * Utility method to enable sub-classes to easily unregister additional
+     * components that don't implement {@link JmxEnabled} with an MBean server.
+     * <br>
+     * Note: This method should only be used once {@link #initInternal()} has
+     * been called and before {@link #destroyInternal()} has been called.
      *
-     * @param objectNameKeyProperties The key properties component of the object name to use to unregister the object
+     * @param objectNameKeyProperties   The key properties component of the
+     *                                  object name to use to unregister the
+     *                                  object
      */
     protected final void unregister(String objectNameKeyProperties) {
         // Construct an object name with the right domain
-        String name = getDomain() + ':' + objectNameKeyProperties;
-        Registry.getRegistry(null).unregisterComponent(name);
+        StringBuilder name = new StringBuilder(getDomain());
+        name.append(':');
+        name.append(objectNameKeyProperties);
+        Registry.getRegistry(null, null).unregisterComponent(name.toString());
     }
 
 
     /**
-     * Utility method to enable subclasses to easily unregister additional components that don't implement
-     * {@link JmxEnabled} with an MBean server. <br>
-     * Note: This method should only be used once {@link #initInternal()} has been called and before
-     * {@link #destroyInternal()} has been called.
+     * Utility method to enable sub-classes to easily unregister additional
+     * components that don't implement {@link JmxEnabled} with an MBean server.
+     * <br>
+     * Note: This method should only be used once {@link #initInternal()} has
+     * been called and before {@link #destroyInternal()} has been called.
      *
-     * @param on The name of the component to unregister
+     * @param on    The name of the component to unregister
      */
     protected final void unregister(ObjectName on) {
-        Registry.getRegistry(null).unregisterComponent(on);
+        Registry.getRegistry(null, null).unregisterComponent(on);
     }
 
 
@@ -187,10 +219,14 @@ public abstract class LifecycleMBeanBase extends LifecycleBase implements JmxEna
     }
 
 
+    /**
+     * Allows the object to be registered with an alternative
+     * {@link MBeanServer} and/or {@link ObjectName}.
+     */
     @Override
-    public final ObjectName preRegister(MBeanServer server, ObjectName name) throws Exception {
+    public final ObjectName preRegister(MBeanServer server, ObjectName name)
+            throws Exception {
 
-        this.mserver = server;
         this.oname = name;
         this.domain = name.getDomain().intern();
 
