@@ -345,7 +345,7 @@ public class AccessLogValve extends AbstractAccessLogValve {
      * @param encoding The name of the character set.
      */
     public void setEncoding(String encoding) {
-        if (encoding != null && !encoding.isEmpty()) {
+        if (encoding != null && encoding.length() > 0) {
             this.encoding = encoding;
         } else {
             this.encoding = null;
@@ -355,7 +355,8 @@ public class AccessLogValve extends AbstractAccessLogValve {
     // --------------------------------------------------------- Public Methods
 
     /**
-     * Provides support for access log rotation.
+     * Execute a periodic task, such as reloading, etc. This method will be invoked inside the classloading context of
+     * this container. Unexpected throwables will be caught and logged.
      */
     @Override
     public synchronized void backgroundProcess() {
@@ -377,14 +378,14 @@ public class AccessLogValve extends AbstractAccessLogValve {
                     for (String oldAccessLog : oldAccessLogs) {
                         boolean match = false;
 
-                        if (prefix != null && !prefix.isEmpty()) {
+                        if (prefix != null && prefix.length() > 0) {
                             if (!oldAccessLog.startsWith(prefix)) {
                                 continue;
                             }
                             match = true;
                         }
 
-                        if (suffix != null && !suffix.isEmpty()) {
+                        if (suffix != null && suffix.length() > 0) {
                             if (!oldAccessLog.endsWith(suffix)) {
                                 continue;
                             }
@@ -558,6 +559,11 @@ public class AccessLogValve extends AbstractAccessLogValve {
     }
 
 
+    /**
+     * Log the specified message to the log file, switching files if the date has changed since the previous log call.
+     *
+     * @param message Message to be logged
+     */
     @Override
     public void log(CharArrayWriter message) {
 
@@ -644,7 +650,7 @@ public class AccessLogValve extends AbstractAccessLogValve {
      *                                   used
      */
     @Override
-    protected void startInternal() throws LifecycleException {
+    protected synchronized void startInternal() throws LifecycleException {
 
         // Initialize the Date formatters
         String format = getFileDateFormat();
@@ -668,7 +674,7 @@ public class AccessLogValve extends AbstractAccessLogValve {
      *                                   used
      */
     @Override
-    protected void stopInternal() throws LifecycleException {
+    protected synchronized void stopInternal() throws LifecycleException {
 
         super.stopInternal();
         close(false);
