@@ -23,10 +23,10 @@ import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.regex.Pattern;
 
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpSession;
-import javax.servlet.http.HttpSessionBindingEvent;
-import javax.servlet.http.HttpSessionBindingListener;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpSession;
+import jakarta.servlet.http.HttpSessionBindingEvent;
+import jakarta.servlet.http.HttpSessionBindingListener;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.Host;
@@ -45,7 +45,8 @@ public class CrawlerSessionManagerValve extends ValveBase {
 
     private static final Log log = LogFactory.getLog(CrawlerSessionManagerValve.class);
 
-    private final Map<String,String> clientIdSessionId = new ConcurrentHashMap<>();
+    private final Map<String, String> clientIdSessionId = new ConcurrentHashMap<>();
+    private final Map<String, String> sessionIdClientId = new ConcurrentHashMap<>();
 
     private String crawlerUserAgents = ".*[bB]ot.*|.*Yahoo! Slurp.*|.*Feedfetcher-Google.*";
     private Pattern uaPattern = null;
@@ -76,7 +77,7 @@ public class CrawlerSessionManagerValve extends ValveBase {
      */
     public void setCrawlerUserAgents(String crawlerUserAgents) {
         this.crawlerUserAgents = crawlerUserAgents;
-        if (crawlerUserAgents == null || crawlerUserAgents.isEmpty()) {
+        if (crawlerUserAgents == null || crawlerUserAgents.length() == 0) {
             uaPattern = null;
         } else {
             uaPattern = Pattern.compile(crawlerUserAgents);
@@ -101,7 +102,7 @@ public class CrawlerSessionManagerValve extends ValveBase {
      */
     public void setCrawlerIps(String crawlerIps) {
         this.crawlerIps = crawlerIps;
-        if (crawlerIps == null || crawlerIps.isEmpty()) {
+        if (crawlerIps == null || crawlerIps.length() == 0) {
             ipPattern = null;
         } else {
             ipPattern = Pattern.compile(crawlerIps);
@@ -138,7 +139,7 @@ public class CrawlerSessionManagerValve extends ValveBase {
     }
 
 
-    public Map<String,String> getClientIpSessionId() {
+    public Map<String, String> getClientIpSessionId() {
         return clientIdSessionId;
     }
 
@@ -174,20 +175,13 @@ public class CrawlerSessionManagerValve extends ValveBase {
     @Override
     public void invoke(Request request, Response response) throws IOException, ServletException {
 
-        Host host = request.getHost();
-        if (host == null) {
-            // Request will have no session
-            getNext().invoke(request, response);
-            return;
-        }
-
         boolean isBot = false;
         String sessionId = null;
         String clientIp = request.getRemoteAddr();
-        String clientIdentifier = getClientIdentifier(host, request.getContext(), clientIp);
+        String clientIdentifier = getClientIdentifier(request.getHost(), request.getContext(), clientIp);
 
-        if (log.isTraceEnabled()) {
-            log.trace(request.hashCode() + ": ClientIdentifier=" + clientIdentifier + ", RequestedSessionId=" +
+        if (log.isDebugEnabled()) {
+            log.debug(request.hashCode() + ": ClientIdentifier=" + clientIdentifier + ", RequestedSessionId=" +
                     request.getRequestedSessionId());
         }
 
@@ -204,15 +198,15 @@ public class CrawlerSessionManagerValve extends ValveBase {
             // If more than one UA header - assume not a bot
             if (uaHeader != null && !uaHeaders.hasMoreElements()) {
 
-                if (log.isTraceEnabled()) {
-                    log.trace(request.hashCode() + ": UserAgent=" + uaHeader);
+                if (log.isDebugEnabled()) {
+                    log.debug(request.hashCode() + ": UserAgent=" + uaHeader);
                 }
 
                 if (uaPattern.matcher(uaHeader).matches()) {
                     isBot = true;
 
-                    if (log.isTraceEnabled()) {
-                        log.trace(request.hashCode() + ": Bot found. UserAgent=" + uaHeader);
+                    if (log.isDebugEnabled()) {
+                        log.debug(request.hashCode() + ": Bot found. UserAgent=" + uaHeader);
                     }
                 }
             }
@@ -220,8 +214,8 @@ public class CrawlerSessionManagerValve extends ValveBase {
             if (ipPattern != null && ipPattern.matcher(clientIp).matches()) {
                 isBot = true;
 
-                if (log.isTraceEnabled()) {
-                    log.trace(request.hashCode() + ": Bot found. IP=" + clientIp);
+                if (log.isDebugEnabled()) {
+                    log.debug(request.hashCode() + ": Bot found. IP=" + clientIp);
                 }
             }
 
@@ -230,8 +224,8 @@ public class CrawlerSessionManagerValve extends ValveBase {
                 sessionId = clientIdSessionId.get(clientIdentifier);
                 if (sessionId != null) {
                     request.setRequestedSessionId(sessionId);
-                    if (log.isTraceEnabled()) {
-                        log.trace(request.hashCode() + ": SessionID=" + sessionId);
+                    if (log.isDebugEnabled()) {
+                        log.debug(request.hashCode() + ": SessionID=" + sessionId);
                     }
                 }
             }
@@ -245,18 +239,19 @@ public class CrawlerSessionManagerValve extends ValveBase {
                 HttpSession s = request.getSession(false);
                 if (s != null) {
                     clientIdSessionId.put(clientIdentifier, s.getId());
+                    sessionIdClientId.put(s.getId(), clientIdentifier);
                     // #valueUnbound() will be called on session expiration
                     s.setAttribute(this.getClass().getName(),
                             new CrawlerHttpSessionBindingListener(clientIdSessionId, clientIdentifier));
                     s.setMaxInactiveInterval(sessionInactiveInterval);
 
-                    if (log.isTraceEnabled()) {
-                        log.trace(request.hashCode() + ": New bot session. SessionID=" + s.getId());
+                    if (log.isDebugEnabled()) {
+                        log.debug(request.hashCode() + ": New bot session. SessionID=" + s.getId());
                     }
                 }
             } else {
-                if (log.isTraceEnabled()) {
-                    log.trace(request.hashCode() + ": Bot session accessed. SessionID=" + sessionId);
+                if (log.isDebugEnabled()) {
+                    log.debug(request.hashCode() + ": Bot session accessed. SessionID=" + sessionId);
                 }
             }
         }
@@ -277,10 +272,10 @@ public class CrawlerSessionManagerValve extends ValveBase {
     private static class CrawlerHttpSessionBindingListener implements HttpSessionBindingListener, Serializable {
         private static final long serialVersionUID = 1L;
 
-        private final transient Map<String,String> clientIdSessionId;
+        private final transient Map<String, String> clientIdSessionId;
         private final transient String clientIdentifier;
 
-        private CrawlerHttpSessionBindingListener(Map<String,String> clientIdSessionId, String clientIdentifier) {
+        private CrawlerHttpSessionBindingListener(Map<String, String> clientIdSessionId, String clientIdentifier) {
             this.clientIdSessionId = clientIdSessionId;
             this.clientIdentifier = clientIdentifier;
         }
