@@ -25,9 +25,9 @@ import java.io.Writer;
 import java.util.Scanner;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import javax.servlet.RequestDispatcher;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.catalina.connector.Request;
 import org.apache.catalina.connector.Response;
@@ -94,7 +94,7 @@ public class ErrorReportValve extends ValveBase {
 
         if (response.isCommitted()) {
             if (response.setErrorReported()) {
-                // Error wasn't previously reported, but we can't write an error
+                // Error wasn't previously reported but we can't write an error
                 // page because the response has already been committed.
 
                 // See if IO is allowed
@@ -217,7 +217,7 @@ public class ErrorReportValve extends ValveBase {
         if (message == null) {
             if (throwable != null) {
                 String exceptionMessage = throwable.getMessage();
-                if (exceptionMessage != null && !exceptionMessage.isEmpty()) {
+                if (exceptionMessage != null && exceptionMessage.length() > 0) {
                     try (Scanner scanner = new Scanner(exceptionMessage)) {
                         message = Escape.htmlElementContent(scanner.nextLine());
                     }
@@ -329,7 +329,7 @@ public class ErrorReportValve extends ValveBase {
             } catch (Throwable t) {
                 ExceptionUtils.handleThrowable(t);
                 if (container.getLogger().isDebugEnabled()) {
-                    container.getLogger().debug(sm.getString("errorReportValve.contentTypeFail"), t);
+                    container.getLogger().debug("Failure to set the content-type of response", t);
                 }
             }
             Writer writer = response.getReporter();
@@ -347,7 +347,7 @@ public class ErrorReportValve extends ValveBase {
 
 
     /**
-     * Print out a partial servlet stack trace (truncating at the last occurrence of javax.servlet.).
+     * Print out a partial servlet stack trace (truncating at the last occurrence of jakarta.servlet.).
      *
      * @param t The stack trace to process
      *
@@ -389,8 +389,7 @@ public class ErrorReportValve extends ValveBase {
         response.setContentType("text/html");
         response.setCharacterEncoding("UTF-8");
 
-        try (OutputStream os = response.getOutputStream();
-             InputStream is = new FileInputStream(file)) {
+        try (OutputStream os = response.getOutputStream(); InputStream is = new FileInputStream(file);) {
             IOTools.flow(is, os);
         } catch (IOException e) {
             getContainer().getLogger().warn(sm.getString("errorReportValve.errorPageIOException", location), e);
