@@ -25,7 +25,7 @@ import java.sql.SQLException;
 import java.sql.Timestamp;
 import java.util.Properties;
 
-import javax.servlet.ServletException;
+import jakarta.servlet.ServletException;
 
 import org.apache.catalina.AccessLog;
 import org.apache.catalina.LifecycleException;
@@ -68,11 +68,11 @@ import org.apache.tomcat.util.ExceptionUtils;
  * remoteHost CHAR(15) NOT NULL,
  * userName CHAR(15),
  * timestamp TIMESTAMP NOT NULL,
+ * virtualHost VARCHAR(64) NOT NULL,
+ * method VARCHAR(8) NOT NULL,
  * query VARCHAR(255) NOT NULL,
  * status SMALLINT UNSIGNED NOT NULL,
  * bytes INT UNSIGNED NOT NULL,
- * virtualHost VARCHAR(64) NOT NULL,
- * method VARCHAR(8) NOT NULL,
  * referer VARCHAR(128),
  * userAgent VARCHAR(128),
  * PRIMARY KEY (id),
@@ -95,15 +95,15 @@ import org.apache.tomcat.util.ExceptionUtils;
  * If the request method is "common", only these fields are used:
  * <code>remoteHost, user, timeStamp, query, status, bytes</code>
  * </p>
+ * <p>
+ * <i>TO DO: provide option for excluding logging of certain MIME types.</i>
+ * </p>
  *
  * @author Andre de Jesus
  * @author Peter Rossbach
- *
- * @deprecated Non scalable design, and not documented. Will be removed in Tomcat 12.
  */
-@Deprecated
-public class JDBCAccessLogValve extends ValveBase implements AccessLog {
 
+public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
 
     // ----------------------------------------------------------- Constructors
 
@@ -159,47 +159,47 @@ public class JDBCAccessLogValve extends ValveBase implements AccessLog {
      *
      * @since 6.0.15
      */
-    protected boolean useLongContentLength = false;
+    boolean useLongContentLength = false;
 
     /**
      * The connection username to use when trying to connect to the database.
      */
-    protected String connectionName = null;
+    String connectionName = null;
 
 
     /**
      * The connection URL to use when trying to connect to the database.
      */
-    protected String connectionPassword = null;
+    String connectionPassword = null;
 
     /**
      * Instance of the JDBC Driver class we use as a connection factory.
      */
-    protected Driver driver = null;
+    Driver driver = null;
 
 
-    protected String driverName;
-    protected String connectionURL;
-    protected String tableName;
-    protected String remoteHostField;
-    protected String userField;
-    protected String timestampField;
-    protected String virtualHostField;
-    protected String methodField;
-    protected String queryField;
-    protected String statusField;
-    protected String bytesField;
-    protected String refererField;
-    protected String userAgentField;
-    protected String pattern;
-    protected boolean resolveHosts;
+    private String driverName;
+    private String connectionURL;
+    private String tableName;
+    private String remoteHostField;
+    private String userField;
+    private String timestampField;
+    private String virtualHostField;
+    private String methodField;
+    private String queryField;
+    private String statusField;
+    private String bytesField;
+    private String refererField;
+    private String userAgentField;
+    private String pattern;
+    private boolean resolveHosts;
 
 
-    protected Connection conn;
-    protected PreparedStatement ps;
+    private Connection conn;
+    private PreparedStatement ps;
 
 
-    protected long currentTimeMillis;
+    private long currentTimeMillis;
 
     /**
      * Should this valve set request attributes for IP address, hostname, protocol and port used for the request.
@@ -207,7 +207,7 @@ public class JDBCAccessLogValve extends ValveBase implements AccessLog {
      *
      * @see #setRequestAttributesEnabled(boolean)
      */
-    protected boolean requestAttributesEnabled = true;
+    boolean requestAttributesEnabled = true;
 
 
     // ------------------------------------------------------------- Properties
@@ -427,6 +427,15 @@ public class JDBCAccessLogValve extends ValveBase implements AccessLog {
     // --------------------------------------------------------- Public Methods
 
 
+    /**
+     * This method is invoked by Tomcat on each query.
+     *
+     * @param request  The Request object.
+     * @param response The Response object.
+     *
+     * @exception IOException      Should not be thrown.
+     * @exception ServletException Database SQLException is wrapped in a ServletException.
+     */
     @Override
     public void invoke(Request request, Response response) throws IOException, ServletException {
         getNext().invoke(request, response);
@@ -561,7 +570,6 @@ public class JDBCAccessLogValve extends ValveBase implements AccessLog {
         }
         conn = driver.connect(connectionURL, props);
         conn.setAutoCommit(true);
-        prepare();
         String logPattern = pattern;
         if (logPattern.equals("common")) {
             ps = conn.prepareStatement(
@@ -575,16 +583,6 @@ public class JDBCAccessLogValve extends ValveBase implements AccessLog {
         }
     }
 
-
-    /**
-     * Prepare tables for processing. Used by subclasses for testing.
-     *
-     * @throws SQLException if an exception occurs
-     */
-    protected void prepare() throws SQLException {
-    }
-
-
     /**
      * Close the specified database connection.
      */
@@ -624,7 +622,7 @@ public class JDBCAccessLogValve extends ValveBase implements AccessLog {
      *                                   used
      */
     @Override
-    protected void startInternal() throws LifecycleException {
+    protected synchronized void startInternal() throws LifecycleException {
         try {
             open();
         } catch (SQLException e) {
@@ -642,7 +640,7 @@ public class JDBCAccessLogValve extends ValveBase implements AccessLog {
      *                                   used
      */
     @Override
-    protected void stopInternal() throws LifecycleException {
+    protected synchronized void stopInternal() throws LifecycleException {
         super.stopInternal();
         close();
     }
