@@ -18,10 +18,10 @@ package org.apache.catalina.valves;
 
 import java.io.IOException;
 
-import javax.servlet.ServletException;
-import javax.servlet.SessionCookieConfig;
-import javax.servlet.http.Cookie;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.SessionCookieConfig;
+import jakarta.servlet.http.Cookie;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.catalina.connector.Request;
 import org.apache.catalina.connector.Response;
@@ -157,7 +157,7 @@ public class LoadBalancerDrainingValve extends ValveBase {
                 !request.isRequestedSessionIdValid()) {
 
             if (containerLog.isDebugEnabled()) {
-                containerLog.debug(sm.getString("loadBalancerDrainingValve.draining"));
+                containerLog.debug("Load-balancer is in DISABLED state; draining this node");
             }
 
             boolean ignoreRebalance = false;
@@ -187,7 +187,8 @@ public class LoadBalancerDrainingValve extends ValveBase {
 
             if (ignoreRebalance) {
                 if (containerLog.isDebugEnabled()) {
-                    containerLog.debug(sm.getString("loadBalancerDrainingValve.skip", _ignoreCookieName));
+                    containerLog.debug("Client is presenting a valid " + _ignoreCookieName +
+                            " cookie, re-balancing is being skipped");
                 }
 
                 getNext().invoke(request, response);
@@ -202,8 +203,8 @@ public class LoadBalancerDrainingValve extends ValveBase {
                 sessionCookie.setMaxAge(0); // Delete
                 sessionCookie.setValue(""); // Purge the cookie's value
                 // Replicate logic used to set secure attribute for session cookies
-                SessionCookieConfig sessionCookieConfig =
-                        request.getContext().getServletContext().getSessionCookieConfig();
+                SessionCookieConfig sessionCookieConfig = request.getContext().getServletContext()
+                        .getSessionCookieConfig();
                 sessionCookie.setSecure(request.isSecure() || sessionCookieConfig.isSecure());
                 response.addCookie(sessionCookie);
             }
