@@ -20,8 +20,8 @@ package org.apache.catalina.valves;
 import java.io.IOException;
 import java.util.regex.Pattern;
 
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.LifecycleException;
@@ -41,7 +41,7 @@ import org.apache.juli.logging.Log;
  * <li>The subclass extracts the request property to be filtered, and calls the common <code>process()</code> method.
  * <li>If there is a deny expression configured, the property will be compared to the expression. If a match is found,
  * this request will be rejected with a "Forbidden" HTTP response.</li>
- * <li>If there is an allow expression configured, the property will be compared to each such expression. If a match is
+ * <li>If there is a allow expression configured, the property will be compared to each such expression. If a match is
  * found, this request will be allowed to pass through to the next Valve in the current pipeline.</li>
  * <li>If a deny expression was specified but no allow expression, allow this request to pass through (because none of
  * the deny expressions matched it).
@@ -111,8 +111,9 @@ public abstract class RequestFilterValve extends ValveBase {
     protected int denyStatus = HttpServletResponse.SC_FORBIDDEN;
 
     /**
+     * <p>
      * If <code>invalidAuthenticationWhenDeny</code> is true and the context has <code>preemptiveAuthentication</code>
-     * set, set an invalid authorization header to trigger basic auth instead of denying the request.
+     * set, set an invalid authorization header to trigger basic auth instead of denying the request..
      */
     private boolean invalidAuthenticationWhenDeny = false;
 
@@ -148,7 +149,7 @@ public abstract class RequestFilterValve extends ValveBase {
      * @param allow The new allow expression
      */
     public void setAllow(String allow) {
-        if (allow == null || allow.isEmpty()) {
+        if (allow == null || allow.length() == 0) {
             this.allow = null;
             allowValue = null;
             allowValid = true;
@@ -182,7 +183,7 @@ public abstract class RequestFilterValve extends ValveBase {
      * @param deny The new deny expression
      */
     public void setDeny(String deny) {
-        if (deny == null || deny.isEmpty()) {
+        if (deny == null || deny.length() == 0) {
             this.deny = null;
             denyValue = null;
             denyValid = true;
@@ -330,7 +331,7 @@ public abstract class RequestFilterValve extends ValveBase {
 
 
     @Override
-    protected void startInternal() throws LifecycleException {
+    protected synchronized void startInternal() throws LifecycleException {
         if (!allowValid || !denyValid) {
             throw new LifecycleException(sm.getString("requestFilterValve.configInvalid"));
         }
@@ -419,7 +420,11 @@ public abstract class RequestFilterValve extends ValveBase {
         }
 
         // Allow if denies specified but not allows
-        // Otherwise deny this request
-        return deny != null && allow == null;
+        if (deny != null && allow == null) {
+            return true;
+        }
+
+        // Deny this request
+        return false;
     }
 }
