@@ -31,6 +31,8 @@ import org.apache.tomcat.util.res.StringManager;
  * Convenience base class for implementations of the <b>Valve</b> interface. A subclass <strong>MUST</strong> implement
  * an <code>invoke()</code> method to provide the required functionality, and <strong>MAY</strong> implement the
  * <code>Lifecycle</code> interface to provide configuration management and lifecycle support.
+ *
+ * @author Craig R. McClanahan
  */
 public abstract class ValveBase extends LifecycleMBeanBase implements Contained, Valve {
 
@@ -140,7 +142,7 @@ public abstract class ValveBase extends LifecycleMBeanBase implements Contained,
      *                                   used
      */
     @Override
-    protected void startInternal() throws LifecycleException {
+    protected synchronized void startInternal() throws LifecycleException {
         setState(LifecycleState.STARTING);
     }
 
@@ -153,7 +155,7 @@ public abstract class ValveBase extends LifecycleMBeanBase implements Contained,
      *                                   used
      */
     @Override
-    protected void stopInternal() throws LifecycleException {
+    protected synchronized void stopInternal() throws LifecycleException {
         setState(LifecycleState.STOPPING);
     }
 
