@@ -37,7 +37,7 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
     private URL baseUrl;
     private String baseUrlString;
     private JarFile archive = null;
-    protected Map<String,JarEntry> archiveEntries = null;
+    protected Map<String, JarEntry> archiveEntries = null;
     protected final Object archiveLock = new Object();
     private long archiveUseCount = 0;
     private JarContents jarContents;
@@ -69,18 +69,15 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
 
         ArrayList<String> result = new ArrayList<>();
         if (path.startsWith(webAppMount)) {
-            String pathInJar =
-                    getInternalPath() + path.substring(webAppMount.length());
+            String pathInJar = getInternalPath() + path.substring(webAppMount.length());
             // Always strip off the leading '/' to get the JAR path
             if (pathInJar.length() > 0 && pathInJar.charAt(0) == '/') {
                 pathInJar = pathInJar.substring(1);
             }
             for (String name : getArchiveEntries(false).keySet()) {
-                if (name.length() > pathInJar.length() &&
-                        name.startsWith(pathInJar)) {
+                if (name.length() > pathInJar.length() && name.startsWith(pathInJar)) {
                     if (name.charAt(name.length() - 1) == '/') {
-                        name = name.substring(
-                                pathInJar.length(), name.length() - 1);
+                        name = name.substring(pathInJar.length(), name.length() - 1);
                     } else {
                         name = name.substring(pathInJar.length());
                     }
@@ -102,10 +99,9 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
             if (webAppMount.startsWith(path)) {
                 int i = webAppMount.indexOf('/', path.length());
                 if (i == -1) {
-                    return new String[] {webAppMount.substring(path.length())};
+                    return new String[] { webAppMount.substring(path.length()) };
                 } else {
-                    return new String[] {
-                            webAppMount.substring(path.length(), i)};
+                    return new String[] { webAppMount.substring(path.length(), i) };
                 }
             }
         }
@@ -119,8 +115,7 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
 
         ResourceSet<String> result = new ResourceSet<>();
         if (path.startsWith(webAppMount)) {
-            String pathInJar =
-                    getInternalPath() + path.substring(webAppMount.length());
+            String pathInJar = getInternalPath() + path.substring(webAppMount.length());
             // Always strip off the leading '/' to get the JAR path and make
             // sure it ends in '/'
             if (pathInJar.length() > 0) {
@@ -160,25 +155,21 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
 
 
     /**
-     * Obtain the map of entries in the archive. May return null in which case
-     * {@link #getArchiveEntry(String)} should be used.
+     * Obtain the map of entries in the archive. May return null in which case {@link #getArchiveEntry(String)} should
+     * be used.
      *
-     * @param single Is this request being make to support a single lookup? If
-     *               false, a map will always be returned. If true,
-     *               implementations may use this as a hint in determining the
-     *               optimum way to respond.
+     * @param single Is this request being make to support a single lookup? If false, a map will always be returned. If
+     *                   true, implementations may use this as a hint in determining the optimum way to respond.
      *
-     * @return The archives entries mapped to their names or null if
-     *         {@link #getArchiveEntry(String)} should be used.
+     * @return The archives entries mapped to their names or null if {@link #getArchiveEntry(String)} should be used.
      */
-    protected abstract Map<String,JarEntry> getArchiveEntries(boolean single);
+    protected abstract Map<String, JarEntry> getArchiveEntries(boolean single);
 
 
     /**
-     * Obtain a single entry from the archive. For performance reasons,
-     * {@link #getArchiveEntries(boolean)} should always be called first and the
-     * archive entry looked up in the map if one is returned. Only if that call
-     * returns null should this method be used.
+     * Obtain a single entry from the archive. For performance reasons, {@link #getArchiveEntries(boolean)} should
+     * always be called first and the archive entry looked up in the map if one is returned. Only if that call returns
+     * null should this method be used.
      *
      * @param pathInArchive The path in the archive of the entry required
      *
@@ -198,8 +189,7 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
         checkPath(path);
 
         if (is == null) {
-            throw new NullPointerException(
-                    sm.getString("dirResourceSet.writeNpe"));
+            throw new NullPointerException(sm.getString("dirResourceSet.writeNpe"));
         }
 
         return false;
@@ -212,8 +202,8 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
         WebResourceRoot root = getRoot();
 
         /*
-         * If jarContents reports that this resource definitely does not contain
-         * the path, we can end this method and move on to the next jar.
+         * If jarContents reports that this resource definitely does not contain the path, we can end this method and
+         * move on to the next jar.
          */
         if (jarContents != null && !jarContents.mightContainResource(path, webAppMount)) {
             return new EmptyResource(root, path);
@@ -224,22 +214,18 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
          *
          * The path parameter passed into this method always starts with '/'.
          *
-         * The path parameter passed into this method may or may not end with a
-         * '/'. JarFile.getEntry() will return a matching directory entry
-         * whether or not the name ends in a '/'. However, if the entry is
-         * requested without the '/' subsequent calls to JarEntry.isDirectory()
-         * will return false.
+         * The path parameter passed into this method may or may not end with a '/'. JarFile.getEntry() will return a
+         * matching directory entry whether or not the name ends in a '/'. However, if the entry is requested without
+         * the '/' subsequent calls to JarEntry.isDirectory() will return false.
          *
-         * Paths in JARs never start with '/'. Leading '/' need to be removed
-         * before any JarFile.getEntry() call.
+         * Paths in JARs never start with '/'. Leading '/' need to be removed before any JarFile.getEntry() call.
          */
 
         // If the JAR has been mounted below the web application root, return
         // an empty resource for requests outside of the mount point.
 
         if (path.startsWith(webAppMount)) {
-            String pathInJar = getInternalPath() + path.substring(
-                    webAppMount.length());
+            String pathInJar = getInternalPath() + path.substring(webAppMount.length());
             // Always strip off the leading '/' to get the JAR path
             if (pathInJar.length() > 0 && pathInJar.charAt(0) == '/') {
                 pathInJar = pathInJar.substring(1);
@@ -250,15 +236,14 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
                 if (!path.endsWith("/")) {
                     path = path + "/";
                 }
-                return new JarResourceRoot(root, new File(getBase()),
-                        baseUrlString, path);
+                return new JarResourceRoot(root, new File(getBase()), baseUrlString, path);
             } else {
                 JarEntry jarEntry = null;
                 if (isMultiRelease()) {
                     // Calls JarFile.getJarEntry() which is multi-release aware
                     jarEntry = getArchiveEntry(pathInJar);
                 } else {
-                    Map<String,JarEntry> jarEntries = getArchiveEntries(true);
+                    Map<String, JarEntry> jarEntries = getArchiveEntries(true);
                     if (!(pathInJar.charAt(pathInJar.length() - 1) == '/')) {
                         if (jarEntries == null) {
                             jarEntry = getArchiveEntry(pathInJar + '/');
@@ -290,8 +275,7 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
 
     protected abstract boolean isMultiRelease();
 
-    protected abstract WebResource createArchiveResource(JarEntry jarEntry,
-            String webAppPath, Manifest manifest);
+    protected abstract WebResource createArchiveResource(JarEntry jarEntry, String webAppPath, Manifest manifest);
 
     @Override
     public final boolean isReadOnly() {
@@ -305,8 +289,7 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
             return;
         }
 
-        throw new IllegalArgumentException(
-                sm.getString("abstractArchiveResourceSet.setReadOnlyFalse"));
+        throw new IllegalArgumentException(sm.getString("abstractArchiveResourceSet.setReadOnlyFalse"));
     }
 
     @SuppressWarnings("deprecation")
