@@ -22,6 +22,7 @@ import java.util.TreeSet;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.atomic.AtomicLong;
+import java.util.concurrent.atomic.LongAdder;
 
 import org.apache.catalina.WebResource;
 import org.apache.catalina.WebResourceRoot.CacheStrategy;
@@ -45,14 +46,13 @@ public class Cache {
 
     private long ttl = 5000;
     private long maxSize = 10 * 1024 * 1024;
-    private int objectMaxSize = (int) maxSize/OBJECT_MAX_SIZE_FACTOR;
+    private int objectMaxSize = (int) maxSize / OBJECT_MAX_SIZE_FACTOR;
     private CacheStrategy cacheStrategy;
 
-    private AtomicLong lookupCount = new AtomicLong(0);
-    private AtomicLong hitCount = new AtomicLong(0);
+    private LongAdder lookupCount = new LongAdder();
+    private LongAdder hitCount = new LongAdder();
 
-    private final ConcurrentMap<String,CachedResource> resourceCache =
-            new ConcurrentHashMap<>();
+    private final ConcurrentMap<String, CachedResource> resourceCache = new ConcurrentHashMap<>();
 
     public Cache(StandardRoot root) {
         this.root = root;
@@ -71,7 +71,7 @@ public class Cache {
             }
         }
 
-        lookupCount.incrementAndGet();
+        lookupCount.increment();
 
         CachedResource cacheEntry = resourceCache.get(path);
 
@@ -83,8 +83,8 @@ public class Cache {
         if (cacheEntry == null) {
             // Local copy to ensure consistency
             int objectMaxSizeBytes = getObjectMaxSizeBytes();
-            CachedResource newCacheEntry = new CachedResource(this, root, path, getTtl(),
-                    objectMaxSizeBytes, useClassLoaderResources);
+            CachedResource newCacheEntry = new CachedResource(this, root, path, getTtl(), objectMaxSizeBytes,
+                    useClassLoaderResources);
 
             // Concurrent callers will end up with the same CachedResource
             // instance
@@ -127,26 +127,26 @@ public class Cache {
                     // that isn't added to the cache.
                     // There are assumptions here. They are:
                     // - refactoring the Cache to use a combined key of
-                    //   path+useClassLoaderResources adds unnecessary
-                    //   complexity
+                    // path+useClassLoaderResources adds unnecessary
+                    // complexity
                     // - the race condition is rare (over the lifetime of an
-                    //   application)
+                    // application)
                     // - it would be rare for an application to need to cache a
-                    //   resource for both values of useClassLoaderResources
+                    // resource for both values of useClassLoaderResources
                     cacheEntry = newCacheEntry;
                 }
                 // Make sure it is validated
                 cacheEntry.validateResource(useClassLoaderResources);
             }
         } else {
-            hitCount.incrementAndGet();
+            hitCount.increment();
         }
 
         return cacheEntry;
     }
 
     protected WebResource[] getResources(String path, boolean useClassLoaderResources) {
-        lookupCount.incrementAndGet();
+        lookupCount.increment();
 
         // Don't call noCache(path) since the class loader only caches
         // individual resources. Therefore, always cache collections here
@@ -161,8 +161,8 @@ public class Cache {
         if (cacheEntry == null) {
             // Local copy to ensure consistency
             int objectMaxSizeBytes = getObjectMaxSizeBytes();
-            CachedResource newCacheEntry = new CachedResource(this, root, path, getTtl(),
-                    objectMaxSizeBytes, useClassLoaderResources);
+            CachedResource newCacheEntry = new CachedResource(this, root, path, getTtl(), objectMaxSizeBytes,
+                    useClassLoaderResources);
 
             // Concurrent callers will end up with the same CachedResource
             // instance
@@ -197,7 +197,7 @@ public class Cache {
                 cacheEntry.validateResources(useClassLoaderResources);
             }
         } else {
-            hitCount.incrementAndGet();
+            hitCount.increment();
         }
 
         return cacheEntry.getWebResources();
@@ -207,30 +207,25 @@ public class Cache {
         // Create an ordered set of all cached resources with the least recently
         // used first. This is a background process so we can afford to take the
         // time to order the elements first
-        TreeSet<CachedResource> orderedResources =
-                new TreeSet<>(new EvictionOrder());
+        TreeSet<CachedResource> orderedResources = new TreeSet<>(
+                Comparator.comparingLong(CachedResource::getNextCheck));
         orderedResources.addAll(resourceCache.values());
 
         Iterator<CachedResource> iter = orderedResources.iterator();
 
-        long targetSize =
-                maxSize * (100 - TARGET_FREE_PERCENT_BACKGROUND) / 100;
+        long targetSize = maxSize * (100 - TARGET_FREE_PERCENT_BACKGROUND) / 100;
         long newSize = evict(targetSize, iter);
 
         if (newSize > targetSize) {
-            log.info(sm.getString("cache.backgroundEvictFail",
-                    Long.valueOf(TARGET_FREE_PERCENT_BACKGROUND),
-                    root.getContext().getName(),
-                    Long.valueOf(newSize / 1024)));
+            log.info(sm.getString("cache.backgroundEvictFail", Long.valueOf(TARGET_FREE_PERCENT_BACKGROUND),
+                    root.getContext().getName(), Long.valueOf(newSize / 1024)));
         }
     }
 
     private boolean noCache(String path) {
         // Don't cache classes. The class loader handles this.
         // Don't cache JARs. The ResourceSet handles this.
-        if ((path.endsWith(".class") &&
-                (path.startsWith("/WEB-INF/classes/") || path.startsWith("/WEB-INF/lib/")))
-                ||
+        if ((path.endsWith(".class") && (path.startsWith("/WEB-INF/classes/") || path.startsWith("/WEB-INF/lib/"))) ||
                 (path.startsWith("/WEB-INF/lib/") && path.endsWith(".jar"))) {
             return true;
         }
@@ -297,11 +292,11 @@ public class Cache {
     }
 
     public long getLookupCount() {
-        return lookupCount.get();
+        return lookupCount.sum();
     }
 
     public long getHitCount() {
-        return hitCount.get();
+        return hitCount.sum();
     }
 
     public void setObjectMaxSize(int objectMaxSize) {
@@ -328,8 +323,8 @@ public class Cache {
             return;
         }
         if (objectMaxSize > limit) {
-            log.warn(sm.getString("cache.objectMaxSizeTooBig",
-                    Integer.valueOf(objectMaxSize / 1024), Integer.valueOf((int)limit / 1024)));
+            log.warn(sm.getString("cache.objectMaxSizeTooBig", Integer.valueOf(objectMaxSize / 1024),
+                    Integer.valueOf((int) limit / 1024)));
             objectMaxSize = (int) limit;
         }
     }
@@ -342,23 +337,4 @@ public class Cache {
     public long getSize() {
         return size.get() / 1024;
     }
-
-    private static class EvictionOrder implements Comparator<CachedResource> {
-
-        @Override
-        public int compare(CachedResource cr1, CachedResource cr2) {
-            long nc1 = cr1.getNextCheck();
-            long nc2 = cr2.getNextCheck();
-
-            // Oldest resource should be first (so iterator goes from oldest to
-            // youngest.
-            if (nc1 == nc2) {
-                return 0;
-            } else if (nc1 > nc2) {
-                return -1;
-            } else {
-                return 1;
-            }
-        }
-    }
 }
