@@ -17,20 +17,18 @@
 package org.apache.catalina.webresources;
 
 import java.util.BitSet;
-import java.util.Collection;
 import java.util.Enumeration;
 import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 
-import org.apache.tomcat.util.compat.JreCompat;
-
 /**
  * This class represents the contents of a jar by determining whether a given resource <b>might</b> be in the cache,
  * based on a bloom filter. This is not a general-purpose bloom filter because it contains logic to strip out characters
  * from the beginning of the key. The hash methods are simple but good enough for this purpose.
  */
 public final class JarContents {
-
+    private final BitSet bits1;
+    private final BitSet bits2;
     /**
      * Constant used by a typical hashing method.
      */
@@ -46,10 +44,6 @@ public final class JarContents {
      */
     private static final int TABLE_SIZE = 2048;
 
-    private final BitSet bits1 = new BitSet(TABLE_SIZE);
-    private final BitSet bits2 = new BitSet(TABLE_SIZE);
-
-
     /**
      * Parses the passed-in jar and populates the bit array.
      *
@@ -57,66 +51,38 @@ public final class JarContents {
      */
     public JarContents(JarFile jar) {
         Enumeration<JarEntry> entries = jar.entries();
+        bits1 = new BitSet(TABLE_SIZE);
+        bits2 = new BitSet(TABLE_SIZE);
+
         while (entries.hasMoreElements()) {
             JarEntry entry = entries.nextElement();
-            processEntry(entry);
-        }
-    }
+            String name = entry.getName();
+            int startPos = 0;
 
-
-    /**
-     * Populates the bit array from the provided set of JAR entries.
-     *
-     * @param entries The set of entries for the JAR file being processed
-     */
-    public JarContents(Collection<JarEntry> entries) {
-        for (JarEntry entry : entries) {
-            processEntry(entry);
-        }
-    }
-
-
-    private void processEntry(JarEntry entry) {
-        String name = entry.getName();
-        int startPos = 0;
-
-        // If the path starts with a slash, that's not useful information.
-        // Skipping it increases the significance of our key by
-        // removing an insignificant character.
-        boolean precedingSlash = name.charAt(0) == '/';
-        if (precedingSlash) {
-            startPos = 1;
-        }
-
-        // Versioned entries should be added to the table according to their real name
-        if (name.startsWith("META-INF/versions/", startPos)) {
-            int i = name.indexOf('/', 18 + startPos);
-            if (i > 0) {
-                int version = Integer.parseInt(name.substring(18 + startPos, i));
-                if (version <= JreCompat.getInstance().jarFileRuntimeMajorVersion()) {
-                    startPos = i + 1;
-                }
+            // If the path starts with a slash, that's not useful information.
+            // Skipping it increases the significance of our key by
+            // removing an insignificant character.
+            boolean precedingSlash = name.charAt(0) == '/';
+            if (precedingSlash) {
+                startPos = 1;
             }
-            if (startPos == name.length()) {
-                return;
-            }
-        }
 
-        // Find the correct table slot
-        int pathHash1 = hashcode(name, startPos, HASH_PRIME_1);
-        int pathHash2 = hashcode(name, startPos, HASH_PRIME_2);
-
-        bits1.set(pathHash1 % TABLE_SIZE);
-        bits2.set(pathHash2 % TABLE_SIZE);
-
-        // While directory entry names always end in "/", application code
-        // may look them up without the trailing "/". Add this second form.
-        if (entry.isDirectory()) {
-            pathHash1 = hashcode(name, startPos, name.length() - 1, HASH_PRIME_1);
-            pathHash2 = hashcode(name, startPos, name.length() - 1, HASH_PRIME_2);
+            // Find the correct table slot
+            int pathHash1 = hashcode(name, startPos, HASH_PRIME_1);
+            int pathHash2 = hashcode(name, startPos, HASH_PRIME_2);
 
             bits1.set(pathHash1 % TABLE_SIZE);
             bits2.set(pathHash2 % TABLE_SIZE);
+
+            // While directory entry names always end in "/", application code
+            // may look them up without the trailing "/". Add this second form.
+            if (entry.isDirectory()) {
+                pathHash1 = hashcode(name, startPos, name.length() - 1, HASH_PRIME_1);
+                pathHash2 = hashcode(name, startPos, name.length() - 1, HASH_PRIME_2);
+
+                bits1.set(pathHash1 % TABLE_SIZE);
+                bits2.set(pathHash2 % TABLE_SIZE);
+            }
         }
     }
 
@@ -150,7 +116,7 @@ public final class JarContents {
      * Method that identifies whether a given path <b>MIGHT</b> be in this jar. Uses the Bloom filter mechanism.
      *
      * @param path       Requested path. Sometimes starts with "/WEB-INF/classes".
-     * @param webappRoot The value of the webapp location, which can be stripped from the path. Typically it is
+     * @param webappRoot The value of the webapp location, which can be stripped from the path. Typically is
      *                       "/WEB-INF/classes".
      *
      * @return Whether the prefix of the path is known to be in this jar.
@@ -171,4 +137,4 @@ public final class JarContents {
                 bits2.get(hashcode(path, startPos, HASH_PRIME_2) % TABLE_SIZE));
     }
 
-}
+}
\ No newline at end of file
