@@ -33,7 +33,7 @@ import org.apache.tomcat.util.net.SocketWrapperBase;
  */
 public abstract class AbstractProcessorLight implements Processor {
 
-    private final Set<DispatchType> dispatches = new CopyOnWriteArraySet<>();
+    private Set<DispatchType> dispatches = new CopyOnWriteArraySet<>();
 
 
     @Override
@@ -44,8 +44,8 @@ public abstract class AbstractProcessorLight implements Processor {
         do {
             if (dispatches != null) {
                 DispatchType nextDispatch = dispatches.next();
-                if (getLog().isTraceEnabled()) {
-                    getLog().trace("Processing dispatch type: [" + nextDispatch + "]");
+                if (getLog().isDebugEnabled()) {
+                    getLog().debug("Processing dispatch type: [" + nextDispatch + "]");
                 }
                 state = dispatch(nextDispatch.getSocketStatus());
                 if (!dispatches.hasNext()) {
@@ -69,20 +69,15 @@ public abstract class AbstractProcessorLight implements Processor {
                 state = SocketState.CLOSED;
             }
 
-            if (getLog().isTraceEnabled()) {
-                getLog().trace(
+            if (getLog().isDebugEnabled()) {
+                getLog().debug(
                         "Socket: [" + socketWrapper + "], Status in: [" + status + "], State out: [" + state + "]");
             }
 
-            /*
-             * If state is already CLOSED don't call asyncPostProcess() as that will likely change the state to some
-             * other value causing processing to continue when it should cease. The AsyncStateMachine will be recycled
-             * as part of the Processor clean-up on CLOSED so it doesn't matter what state it is left in at this point.
-             */
-            if (isAsync() && state != SocketState.CLOSED) {
+            if (isAsync()) {
                 state = asyncPostProcess();
-                if (getLog().isTraceEnabled()) {
-                    getLog().trace(
+                if (getLog().isDebugEnabled()) {
+                    getLog().debug(
                             "Socket: [" + socketWrapper + "], State after async post processing: [" + state + "]");
                 }
             }
@@ -173,7 +168,7 @@ public abstract class AbstractProcessorLight implements Processor {
     protected abstract SocketState service(SocketWrapperBase<?> socketWrapper) throws IOException;
 
     /**
-     * Process an in-progress request that is no longer in standard HTTP mode. Uses currently include Servlet 3.0 Async
+     * Process an in-progress request that is not longer in standard HTTP mode. Uses currently include Servlet 3.0 Async
      * and HTTP upgrade connections. Further uses may be added in the future. These will typically start as HTTP
      * requests.
      *
@@ -185,15 +180,7 @@ public abstract class AbstractProcessorLight implements Processor {
      */
     protected abstract SocketState dispatch(SocketEvent status) throws IOException;
 
-    /**
-     * Calls the post process of the async state machine.
-     *
-     * @return The state the caller should put the socket in when this method returns
-     */
     protected abstract SocketState asyncPostProcess();
 
-    /**
-     * @return the logger associated with this processor type
-     */
     protected abstract Log getLog();
 }
