@@ -20,7 +20,6 @@ import java.io.IOException;
 import java.net.InetAddress;
 import java.net.SocketException;
 import java.nio.ByteBuffer;
-import java.util.HashSet;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ExecutionException;
@@ -37,8 +36,9 @@ import javax.management.MBeanRegistrationException;
 import javax.management.MBeanServer;
 import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
-import javax.servlet.http.HttpUpgradeHandler;
-import javax.servlet.http.WebConnection;
+
+import jakarta.servlet.http.HttpUpgradeHandler;
+import jakarta.servlet.http.WebConnection;
 
 import org.apache.coyote.http11.upgrade.InternalHttpUpgradeHandler;
 import org.apache.juli.logging.Log;
@@ -77,7 +77,7 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
      * Endpoint that provides low-level network I/O - must be matched to the ProtocolHandler implementation
      * (ProtocolHandler using NIO, requires NIO Endpoint etc.).
      */
-    private final AbstractEndpoint<S,?> endpoint;
+    private final AbstractEndpoint<S, ?> endpoint;
 
 
     private Handler<S> handler;
@@ -91,7 +91,7 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
     private ScheduledFuture<?> timeoutFuture = null;
     private ScheduledFuture<?> monitorFuture;
 
-    public AbstractProtocol(AbstractEndpoint<S,?> endpoint) {
+    public AbstractProtocol(AbstractEndpoint<S, ?> endpoint) {
         this.endpoint = endpoint;
         ConnectionHandler<S> cHandler = new ConnectionHandler<>(this);
         getEndpoint().setHandler(cHandler);
@@ -179,9 +179,8 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
     /**
      * When client certificate information is presented in a form other than instances of
      * {@link java.security.cert.X509Certificate} it needs to be converted before it can be used and this property
-     * controls which JSSE provider is used to perform the conversion. For example it is used with the AJP connectors,
-     * the HTTP APR connector and with the {@link org.apache.catalina.valves.SSLValve}. If not specified, the default
-     * provider will be used.
+     * controls which JSSE provider is used to perform the conversion. For example it is used with the AJP connectors
+     * and with the {@link org.apache.catalina.valves.SSLValve}. If not specified, the default provider will be used.
      *
      * @return The name of the JSSE provider to use
      */
@@ -205,12 +204,6 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
     }
 
 
-    @Override
-    public boolean isAprRequired() {
-        return false;
-    }
-
-
     @Override
     public boolean isSendfileSupported() {
         return endpoint.getUseSendfile();
@@ -282,14 +275,6 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
     }
 
 
-    public int getMaxQueueSize() {
-        return endpoint.getMaxQueueSize();
-    }
-
-    public void setMaxQueueSize(int maxQueueSize) {
-        endpoint.setMaxQueueSize(maxQueueSize);
-    }
-
     public int getAcceptCount() {
         return endpoint.getAcceptCount();
     }
@@ -383,29 +368,6 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
         return endpoint.getConnectionCount();
     }
 
-    /**
-     * NO-OP.
-     *
-     * @param threadCount Unused
-     *
-     * @deprecated Will be removed in Tomcat 10.
-     */
-    @Deprecated
-    public void setAcceptorThreadCount(int threadCount) {
-    }
-
-    /**
-     * Always returns 1.
-     *
-     * @return Always 1.
-     *
-     * @deprecated Will be removed in Tomcat 10.
-     */
-    @Deprecated
-    public int getAcceptorThreadCount() {
-        return 1;
-    }
-
     public void setAcceptorThreadPriority(int threadPriority) {
         endpoint.setAcceptorThreadPriority(threadPriority);
     }
@@ -466,19 +428,18 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
 
 
     public void addWaitingProcessor(Processor processor) {
-        if (getLog().isTraceEnabled()) {
-            getLog().trace(sm.getString("abstractProtocol.waitingProcessor.add", processor));
+        if (getLog().isDebugEnabled()) {
+            getLog().debug(sm.getString("abstractProtocol.waitingProcessor.add", processor));
         }
         waitingProcessors.add(processor);
     }
 
 
     public void removeWaitingProcessor(Processor processor) {
-        boolean result = waitingProcessors.remove(processor);
-        if (getLog().isTraceEnabled()) {
-            getLog().trace(sm.getString(
-                    "abstractProtocol.waitingProcessor.remove", processor, Boolean.valueOf(result)));
+        if (getLog().isDebugEnabled()) {
+            getLog().debug(sm.getString("abstractProtocol.waitingProcessor.remove", processor));
         }
+        waitingProcessors.remove(processor);
     }
 
 
@@ -492,12 +453,12 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
 
     // ----------------------------------------------- Accessors for sub-classes
 
-    protected AbstractEndpoint<S,?> getEndpoint() {
+    protected AbstractEndpoint<S, ?> getEndpoint() {
         return endpoint;
     }
 
 
-    public Handler<S> getHandler() {
+    protected Handler<S> getHandler() {
         return handler;
     }
 
@@ -838,11 +799,10 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
         }
 
 
-        @SuppressWarnings("deprecation")
         @Override
         public SocketState process(SocketWrapperBase<S> wrapper, SocketEvent status) {
-            if (getLog().isTraceEnabled()) {
-                getLog().trace(sm.getString("abstractConnectionHandler.process", wrapper.getSocket(), status));
+            if (getLog().isDebugEnabled()) {
+                getLog().debug(sm.getString("abstractConnectionHandler.process", wrapper.getSocket(), status));
             }
             if (wrapper == null) {
                 // Nothing to do. Socket has been closed.
@@ -856,8 +816,8 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
             // held by this variable will be associated with the SocketWrapper before this
             // method returns.
             Processor processor = (Processor) wrapper.takeCurrentProcessor();
-            if (getLog().isTraceEnabled()) {
-                getLog().trace(sm.getString("abstractConnectionHandler.connectionsGet", processor, socket));
+            if (getLog().isDebugEnabled()) {
+                getLog().debug(sm.getString("abstractConnectionHandler.connectionsGet", processor, socket));
             }
 
             // Timeouts are calculated on a dedicated thread and then
@@ -888,8 +848,8 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
                         UpgradeProtocol upgradeProtocol = getProtocol().getNegotiatedProtocol(negotiatedProtocol);
                         if (upgradeProtocol != null) {
                             processor = upgradeProtocol.getProcessor(wrapper, getProtocol().getAdapter());
-                            if (getLog().isTraceEnabled()) {
-                                getLog().trace(sm.getString("abstractConnectionHandler.processorCreate", processor));
+                            if (getLog().isDebugEnabled()) {
+                                getLog().debug(sm.getString("abstractConnectionHandler.processorCreate", processor));
                             }
                         } else if (negotiatedProtocol.equals("http/1.1")) {
                             // Explicitly negotiated the default protocol.
@@ -917,20 +877,19 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
                 }
                 if (processor == null) {
                     processor = recycledProcessors.pop();
-                    if (getLog().isTraceEnabled()) {
-                        getLog().trace(sm.getString("abstractConnectionHandler.processorPop", processor));
+                    if (getLog().isDebugEnabled()) {
+                        getLog().debug(sm.getString("abstractConnectionHandler.processorPop", processor));
                     }
                 }
                 if (processor == null) {
                     processor = getProtocol().createProcessor();
                     register(processor);
-                    if (getLog().isTraceEnabled()) {
-                        getLog().trace(sm.getString("abstractConnectionHandler.processorCreate", processor));
+                    if (getLog().isDebugEnabled()) {
+                        getLog().debug(sm.getString("abstractConnectionHandler.processorCreate", processor));
                     }
                 }
 
-                // Can switch to non-deprecated version in Tomcat 10.1.x
-                processor.setSslSupport(wrapper.getSslSupport(getProtocol().getClientCertProvider()));
+                processor.setSslSupport(wrapper.getSslSupport());
 
                 SocketState state = SocketState.CLOSED;
                 do {
@@ -965,8 +924,8 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
                             release(processor);
                             // Create the upgrade processor
                             processor = getProtocol().createUpgradeProcessor(wrapper, upgradeToken);
-                            if (getLog().isTraceEnabled()) {
-                                getLog().trace(
+                            if (getLog().isDebugEnabled()) {
+                                getLog().debug(
                                         sm.getString("abstractConnectionHandler.upgradeCreate", processor, wrapper));
                             }
                             // Initialise the upgrade handler (which may trigger
@@ -1115,20 +1074,6 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
         }
 
 
-        @Override
-        public Set<S> getOpenSockets() {
-            Set<SocketWrapperBase<S>> set = proto.getEndpoint().getConnections();
-            Set<S> result = new HashSet<>();
-            for (SocketWrapperBase<S> socketWrapper : set) {
-                S socket = socketWrapper.getSocket();
-                if (socket != null) {
-                    result.add(socket);
-                }
-            }
-            return result;
-        }
-
-
         /**
          * Expected to be used by the handler once the processor is no longer required. Care must be taken to ensure
          * that this method is only called once per processor, after the request processing has completed.
@@ -1154,14 +1099,17 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
                     // recycledProcessors since that pool is only for AJP or
                     // HTTP processors
                     recycledProcessors.push(processor);
-                    if (getLog().isTraceEnabled()) {
-                        getLog().trace("Pushed Processor [" + processor + "]");
+                    if (getLog().isDebugEnabled()) {
+                        getLog().debug("Pushed Processor [" + processor + "]");
                     }
                 }
             }
         }
 
 
+        /**
+         * Expected to be used by the Endpoint to release resources on socket close, errors etc.
+         */
         @Override
         public void release(SocketWrapperBase<S> socketWrapper) {
             Processor processor = (Processor) socketWrapper.takeCurrentProcessor();
@@ -1179,8 +1127,8 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
                         ObjectName rpName = new ObjectName(
                                 getProtocol().getDomain() + ":type=RequestProcessor,worker=" + getProtocol().getName() +
                                         ",name=" + getProtocol().getProtocolName() + "Request" + count);
-                        if (getLog().isTraceEnabled()) {
-                            getLog().trace("Register [" + processor + "] as [" + rpName + "]");
+                        if (getLog().isDebugEnabled()) {
+                            getLog().debug("Register [" + processor + "] as [" + rpName + "]");
                         }
                         Registry.getRegistry(null, null).registerComponent(rp, rpName, null);
                         rp.setRpName(rpName);
@@ -1203,8 +1151,8 @@ public abstract class AbstractProtocol<S> implements ProtocolHandler, MBeanRegis
                         RequestInfo rp = r.getRequestProcessor();
                         rp.setGlobalProcessor(null);
                         ObjectName rpName = rp.getRpName();
-                        if (getLog().isTraceEnabled()) {
-                            getLog().trace("Unregister [" + rpName + "]");
+                        if (getLog().isDebugEnabled()) {
+                            getLog().debug("Unregister [" + rpName + "]");
                         }
                         Registry.getRegistry(null, null).unregisterComponent(rpName);
                         rp.setRpName(null);
