@@ -311,7 +311,10 @@ public final class Response {
      * Set the error flag.
      *
      * @return <code>false</code> if the error flag was already set
+     *
+     * @deprecated This method will be changed to return void in Tomcat 11 onwards
      */
+    @Deprecated
     public boolean setError() {
         return errorState.compareAndSet(0, 1);
     }
@@ -630,7 +633,7 @@ public final class Response {
         commitTimeNanos = -1;
         errorException = null;
         errorState.set(0);
-        headers.clear();
+        headers.recycle();
         trailerFieldsSupplier = null;
         // Servlet 3.1 non-blocking write listener
         listener = null;
