@@ -29,10 +29,9 @@ import org.apache.tomcat.util.net.SocketWrapperBase;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * The is the base implementation for the AJP protocol handlers. Implementations
- * typically extend this base class rather than implement {@link
- * org.apache.coyote.ProtocolHandler}. All of the implementations that ship with
- * Tomcat are implemented this way.
+ * The is the base implementation for the AJP protocol handlers. Implementations typically extend this base class rather
+ * than implement {@link org.apache.coyote.ProtocolHandler}. All of the implementations that ship with Tomcat are
+ * implemented this way.
  *
  * @param <S> The type of socket used by the implementation
  */
@@ -44,7 +43,7 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
     protected static final StringManager sm = StringManager.getManager(AbstractAjpProtocol.class);
 
 
-    public AbstractAjpProtocol(AbstractEndpoint<S,?> endpoint) {
+    public AbstractAjpProtocol(AbstractEndpoint<S, ?> endpoint) {
         super(endpoint);
         setConnectionTimeout(Constants.DEFAULT_CONNECTION_TIMEOUT);
         // AJP does not use Send File
@@ -61,20 +60,16 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
 
 
     /**
-     * {@inheritDoc}
-     *
-     * Overridden to make getter accessible to other classes in this package.
+     * {@inheritDoc} Overridden to make getter accessible to other classes in this package.
      */
     @Override
-    protected AbstractEndpoint<S,?> getEndpoint() {
+    protected AbstractEndpoint<S, ?> getEndpoint() {
         return super.getEndpoint();
     }
 
 
     /**
-     * {@inheritDoc}
-     *
-     * AJP does not support protocol negotiation so this always returns null.
+     * {@inheritDoc} AJP does not support protocol negotiation so this always returns null.
      */
     @Override
     protected UpgradeProtocol getNegotiatedProtocol(String name) {
@@ -83,9 +78,7 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
 
 
     /**
-     * {@inheritDoc}
-     *
-     * AJP does not support protocol upgrade so this always returns null.
+     * {@inheritDoc} AJP does not support protocol upgrade so this always returns null.
      */
     @Override
     protected UpgradeProtocol getUpgradeProtocol(String name) {
@@ -96,17 +89,18 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
     // ------------------------------------------ managed in the ProtocolHandler
 
     private boolean ajpFlush = true;
-    public boolean getAjpFlush() { return ajpFlush; }
+
+    public boolean getAjpFlush() {
+        return ajpFlush;
+    }
+
     /**
-     * Configure whether to aend an AJP flush packet when flushing. A flush
-     * packet is a zero byte AJP13 SEND_BODY_CHUNK packet. mod_jk and
-     * mod_proxy_ajp interpret this as a request to flush data to the client.
-     * AJP always does flush at the and of the response, so if it is not
-     * important, that the packets get streamed up to the client, do not use
-     * extra flush packets. For compatibility and to stay on the safe side,
-     * flush packets are enabled by default.
+     * Configure whether to aend an AJP flush packet when flushing. A flush packet is a zero byte AJP13 SEND_BODY_CHUNK
+     * packet. mod_jk and mod_proxy_ajp interpret this as a request to flush data to the client. AJP always does flush
+     * at the and of the response, so if it is not important, that the packets get streamed up to the client, do not use
+     * extra flush packets. For compatibility and to stay on the safe side, flush packets are enabled by default.
      *
-     * @param ajpFlush  The new flush setting
+     * @param ajpFlush The new flush setting
      */
     public void setAjpFlush(boolean ajpFlush) {
         this.ajpFlush = ajpFlush;
@@ -114,34 +108,39 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
 
 
     private boolean tomcatAuthentication = true;
+
     /**
-     * Should authentication be done in the native web server layer,
-     * or in the Servlet container ?
+     * Should authentication be done in the native web server layer, or in the Servlet container ?
      *
-     * @return {@code true} if authentication should be performed by Tomcat,
-     *         otherwise {@code false}
+     * @return {@code true} if authentication should be performed by Tomcat, otherwise {@code false}
      */
-    public boolean getTomcatAuthentication() { return tomcatAuthentication; }
+    public boolean getTomcatAuthentication() {
+        return tomcatAuthentication;
+    }
+
     public void setTomcatAuthentication(boolean tomcatAuthentication) {
         this.tomcatAuthentication = tomcatAuthentication;
     }
 
 
     private boolean tomcatAuthorization = false;
+
     /**
-     * Should authentication be done in the native web server layer and
-     * authorization in the Servlet container?
+     * Should authentication be done in the native web server layer and authorization in the Servlet container?
      *
-     * @return {@code true} if authorization should be performed by Tomcat,
-     *         otherwise {@code false}
+     * @return {@code true} if authorization should be performed by Tomcat, otherwise {@code false}
      */
-    public boolean getTomcatAuthorization() { return tomcatAuthorization; }
+    public boolean getTomcatAuthorization() {
+        return tomcatAuthorization;
+    }
+
     public void setTomcatAuthorization(boolean tomcatAuthorization) {
         this.tomcatAuthorization = tomcatAuthorization;
     }
 
 
     private String secret = null;
+
     /**
      * Set the secret that must be included with every request.
      *
@@ -150,26 +149,27 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
     public void setSecret(String secret) {
         this.secret = secret;
     }
+
     protected String getSecret() {
         return secret;
     }
+
     /**
      * Set the required secret that must be included with every request.
      *
      * @param requiredSecret The required secret
      *
-     * @deprecated Replaced by {@link #setSecret(String)}.
-     *             Will be removed in Tomcat 11 onwards
+     * @deprecated Replaced by {@link #setSecret(String)}. Will be removed in Tomcat 11 onwards
      */
     @Deprecated
     public void setRequiredSecret(String requiredSecret) {
         setSecret(requiredSecret);
     }
+
     /**
      * @return The current secret
      *
-     * @deprecated Replaced by {@link #getSecret()}.
-     *             Will be removed in Tomcat 11 onwards
+     * @deprecated Replaced by {@link #getSecret()}. Will be removed in Tomcat 11 onwards
      */
     @Deprecated
     protected String getRequiredSecret() {
@@ -178,21 +178,26 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
 
 
     private boolean secretRequired = true;
+
     public void setSecretRequired(boolean secretRequired) {
         this.secretRequired = secretRequired;
     }
+
     public boolean getSecretRequired() {
         return secretRequired;
     }
 
 
     private Pattern allowedRequestAttributesPattern;
+
     public void setAllowedRequestAttributesPattern(String allowedRequestAttributesPattern) {
         this.allowedRequestAttributesPattern = Pattern.compile(allowedRequestAttributesPattern);
     }
+
     public String getAllowedRequestAttributesPattern() {
         return allowedRequestAttributesPattern.pattern();
     }
+
     protected Pattern getAllowedRequestAttributesPatternInternal() {
         return allowedRequestAttributesPattern;
     }
@@ -202,13 +207,13 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
      * AJP packet size.
      */
     private int packetSize = Constants.MAX_PACKET_SIZE;
-    public int getPacketSize() { return packetSize; }
+
+    public int getPacketSize() {
+        return packetSize;
+    }
+
     public void setPacketSize(int packetSize) {
-        if(packetSize < Constants.MAX_PACKET_SIZE) {
-            this.packetSize = Constants.MAX_PACKET_SIZE;
-        } else {
-            this.packetSize = packetSize;
-        }
+        this.packetSize = Math.max(packetSize, Constants.MAX_PACKET_SIZE);
     }
 
 
@@ -226,6 +231,12 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
     }
 
 
+    @Override
+    public void addSslHostConfig(SSLHostConfig sslHostConfig, boolean replace) {
+        getLog().warn(sm.getString("ajpprotocol.noSSL", sslHostConfig.getHostName()));
+    }
+
+
     @Override
     public SSLHostConfig[] findSslHostConfigs() {
         return new SSLHostConfig[0];
@@ -252,8 +263,7 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
 
 
     @Override
-    protected Processor createUpgradeProcessor(SocketWrapperBase<?> socket,
-            UpgradeToken upgradeToken) {
+    protected Processor createUpgradeProcessor(SocketWrapperBase<?> socket, UpgradeToken upgradeToken) {
         throw new IllegalStateException(sm.getString("ajpprotocol.noUpgradeHandler",
                 upgradeToken.getHttpUpgradeHandler().getClass().getName()));
     }
