@@ -26,11 +26,9 @@ import org.apache.tomcat.util.buf.MessageBytes;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * A single packet for communication between the web server and the
- * container.  Designed to be reused many times with no creation of
- * garbage.  Understands the format of data types for these packets.
- * Can be used (somewhat confusingly) for both incoming and outgoing
- * packets.
+ * A single packet for communication between the web server and the container. Designed to be reused many times with no
+ * creation of garbage. Understands the format of data types for these packets. Can be used (somewhat confusingly) for
+ * both incoming and outgoing packets.
  *
  * @author Henri Gomez
  * @author Dan Milstein
@@ -73,10 +71,9 @@ public class AjpMessage {
 
 
     /**
-     * This actually means different things depending on whether the
-     * packet is read or write.  For read, it's the length of the
-     * payload (excluding the header).  For write, it's the length of
-     * the packet as a whole (counting the header).  Oh, well.
+     * This actually means different things depending on whether the packet is read or write. For read, it's the length
+     * of the payload (excluding the header). For write, it's the length of the packet as a whole (counting the header).
+     * Oh, well.
      */
     protected int len;
 
@@ -85,9 +82,8 @@ public class AjpMessage {
 
 
     /**
-     * Prepare this packet for accumulating a message from the container to
-     * the web server.  Set the write position to just after the header
-     * (but leave the length unwritten, because it is as yet unknown).
+     * Prepare this packet for accumulating a message from the container to the web server. Set the write position to
+     * just after the header (but leave the length unwritten, because it is as yet unknown).
      */
     public void reset() {
         len = 4;
@@ -96,9 +92,8 @@ public class AjpMessage {
 
 
     /**
-     * For a packet to be sent to the web server, finish the process of
-     * accumulating data and write the length of the data payload into
-     * the header.
+     * For a packet to be sent to the web server, finish the process of accumulating data and write the length of the
+     * data payload into the header.
      */
     public void end() {
         len = pos;
@@ -106,7 +101,7 @@ public class AjpMessage {
 
         buf[0] = (byte) 0x41;
         buf[1] = (byte) 0x42;
-        buf[2] = (byte) ((dLen>>>8) & 0xFF);
+        buf[2] = (byte) ((dLen >>> 8) & 0xFF);
         buf[3] = (byte) (dLen & 0xFF);
     }
 
@@ -124,9 +119,8 @@ public class AjpMessage {
     /**
      * Return the current message length.
      *
-     * @return For read, it's the length of the payload (excluding the header).
-     * For write, it's the length of the packet as a whole (counting the
-     * header).
+     * @return For read, it's the length of the payload (excluding the header). For write, it's the length of the packet
+     *             as a whole (counting the header).
      */
     public int getLen() {
         return len;
@@ -155,15 +149,13 @@ public class AjpMessage {
 
 
     /**
-     * Write a MessageBytes out at the current write position. A null
-     * MessageBytes is encoded as a string with length 0.
+     * Write a MessageBytes out at the current write position. A null MessageBytes is encoded as a string with length 0.
      *
      * @param mb The data to write
      */
     public void appendBytes(MessageBytes mb) {
         if (mb == null) {
-            log.error(sm.getString("ajpmessage.null"),
-                    new NullPointerException());
+            log.error(sm.getString("ajpmessage.null"), new NullPointerException());
             appendInt(0);
             appendByte(0);
             return;
@@ -181,8 +173,7 @@ public class AjpMessage {
                 // filtered (apart from TAB which is 9). 127 is a control (DEL).
                 // The values 128 to 255 are all OK. Converting those to signed
                 // gives -128 to -1.
-                if ((buffer[i] > -1 && buffer[i] <= 31 && buffer[i] != 9) ||
-                        buffer[i] == 127) {
+                if ((buffer[i] > -1 && buffer[i] <= 31 && buffer[i] != 9) || buffer[i] == 127) {
                     buffer[i] = ' ';
                 }
             }
@@ -192,15 +183,13 @@ public class AjpMessage {
 
 
     /**
-     * Write a ByteChunk out at the current write position. A null ByteChunk is
-     * encoded as a string with length 0.
+     * Write a ByteChunk out at the current write position. A null ByteChunk is encoded as a string with length 0.
      *
      * @param bc The data to write
      */
     public void appendByteChunk(ByteChunk bc) {
         if (bc == null) {
-            log.error(sm.getString("ajpmessage.null"),
-                    new NullPointerException());
+            log.error(sm.getString("ajpmessage.null"), new NullPointerException());
             appendInt(0);
             appendByte(0);
             return;
@@ -210,14 +199,12 @@ public class AjpMessage {
 
 
     /**
-     * Copy a chunk of bytes into the packet, starting at the current
-     * write position.  The chunk of bytes is encoded with the length
-     * in two bytes first, then the data itself, and finally a
-     * terminating \0 (which is <B>not</B> included in the encoded
-     * length).
+     * Copy a chunk of bytes into the packet, starting at the current write position. The chunk of bytes is encoded with
+     * the length in two bytes first, then the data itself, and finally a terminating \0 (which is <B>not</B> included
+     * in the encoded length).
      *
-     * @param b The array from which to copy bytes.
-     * @param off The offset into the array at which to start copying
+     * @param b        The array from which to copy bytes.
+     * @param off      The offset into the array at which to start copying
      * @param numBytes The number of bytes to copy.
      */
     public void appendBytes(byte[] b, int off, int numBytes) {
@@ -232,11 +219,9 @@ public class AjpMessage {
 
 
     /**
-     * Copy a chunk of bytes into the packet, starting at the current
-     * write position.  The chunk of bytes is encoded with the length
-     * in two bytes first, then the data itself, and finally a
-     * terminating \0 (which is <B>not</B> included in the encoded
-     * length).
+     * Copy a chunk of bytes into the packet, starting at the current write position. The chunk of bytes is encoded with
+     * the length in two bytes first, then the data itself, and finally a terminating \0 (which is <B>not</B> included
+     * in the encoded length).
      *
      * @param b The ByteBuffer from which to copy bytes.
      */
@@ -266,10 +251,8 @@ public class AjpMessage {
 
 
     /**
-     * Read an integer from packet, and advance the read position past
-     * it.  Integers are encoded as two unsigned bytes with the
-     * high-order byte first, and, as far as I can tell, in
-     * little-endian order within each byte.
+     * Read an integer from packet, and advance the read position past it. Integers are encoded as two unsigned bytes
+     * with the high-order byte first, and, as far as I can tell, in little-endian order within each byte.
      *
      * @return The integer value read from the message
      */
@@ -277,15 +260,15 @@ public class AjpMessage {
         int b1 = buf[pos++] & 0xFF;
         int b2 = buf[pos++] & 0xFF;
         validatePos(pos);
-        return (b1<<8) + b2;
+        return (b1 << 8) + b2;
     }
 
 
     public int peekInt() {
         validatePos(pos + 2);
         int b1 = buf[pos] & 0xFF;
-        int b2 = buf[pos+1] & 0xFF;
-        return (b1<<8) + b2;
+        int b2 = buf[pos + 1] & 0xFF;
+        return (b1 << 8) + b2;
     }
 
 
@@ -306,7 +289,7 @@ public class AjpMessage {
 
     private void doGetBytes(MessageBytes mb, boolean terminated) {
         int length = getInt();
-        if ((length == 0xFFFF) || (length == -1)) {
+        if (length == 0xFFFF || length == -1) {
             mb.recycle();
             return;
         }
@@ -325,10 +308,8 @@ public class AjpMessage {
 
 
     /**
-     * Read a 32 bits integer from packet, and advance the read position past
-     * it.  Integers are encoded as four unsigned bytes with the
-     * high-order byte first, and, as far as I can tell, in
-     * little-endian order within each byte.
+     * Read a 32 bits integer from packet, and advance the read position past it. Integers are encoded as four unsigned
+     * bytes with the high-order byte first, and, as far as I can tell, in little-endian order within each byte.
      *
      * @return The long value read from the message
      */
@@ -338,10 +319,10 @@ public class AjpMessage {
         b1 |= (buf[pos++] & 0xFF);
         b1 <<= 8;
         b1 |= (buf[pos++] & 0xFF);
-        b1 <<=8;
+        b1 <<= 8;
         b1 |= (buf[pos++] & 0xFF);
         validatePos(pos);
-        return  b1;
+        return b1;
     }
 
 
@@ -350,15 +331,14 @@ public class AjpMessage {
         int mark = getInt();
         len = getInt();
         // Verify message signature
-        if ((toContainer && mark != 0x1234) ||
-                (!toContainer && mark != 0x4142)) {
+        if ((toContainer && mark != 0x1234) || (!toContainer && mark != 0x4142)) {
             log.error(sm.getString("ajpmessage.invalid", "" + mark));
             if (log.isDebugEnabled()) {
                 dump("In");
             }
             return -1;
         }
-        if (log.isDebugEnabled())  {
+        if (log.isDebugEnabled()) {
             log.debug("Received " + len + " " + buf[0]);
         }
         return len;
@@ -367,11 +347,11 @@ public class AjpMessage {
 
     private void dump(String prefix) {
         if (log.isDebugEnabled()) {
-            log.debug(prefix + ": " + HexUtils.toHexString(buf) + " " + pos +"/" + (len + 4));
+            log.debug(prefix + ": " + HexUtils.toHexString(buf) + " " + pos + "/" + (len + 4));
         }
         int max = pos;
         if (len + 4 > pos) {
-            max = len+4;
+            max = len + 4;
         }
         if (max > 1000) {
             max = 1000;
@@ -387,8 +367,7 @@ public class AjpMessage {
     private void validatePos(int posToTest) {
         if (posToTest > len + 4) {
             // Trying to read data beyond the end of the AJP message
-            throw new ArrayIndexOutOfBoundsException(sm.getString(
-                    "ajpMessage.invalidPos", Integer.valueOf(posToTest)));
+            throw new ArrayIndexOutOfBoundsException(sm.getString("ajpMessage.invalidPos", Integer.valueOf(posToTest)));
         }
     }
     // ------------------------------------------------------ Protected Methods
@@ -396,7 +375,7 @@ public class AjpMessage {
 
     protected static String hexLine(byte buf[], int start, int len) {
         StringBuilder sb = new StringBuilder();
-        for (int i = start; i < start + 16 ; i++) {
+        for (int i = start; i < start + 16; i++) {
             if (i < len + 4) {
                 sb.append(hex(buf[i])).append(' ');
             } else {
