@@ -207,7 +207,11 @@ public class Http11OutputBuffer implements HttpOutputBuffer {
 
     // ----------------------------------------------- HttpOutputBuffer Methods
 
-
+    /**
+     * Flush the response.
+     *
+     * @throws IOException an underlying I/O error occurred
+     */
     @Override
     public void flush() throws IOException {
         if (lastActiveFilter == -1) {
@@ -300,10 +304,7 @@ public class Http11OutputBuffer implements HttpOutputBuffer {
      */
     protected void commit() throws IOException {
         response.setCommitted(true);
-        writeHeaders();
-    }
 
-    protected void writeHeaders() throws IOException {
         if (headerBuffer.position() > 0) {
             // Sending the response header buffer
             headerBuffer.flip();
@@ -323,26 +324,14 @@ public class Http11OutputBuffer implements HttpOutputBuffer {
 
     /**
      * Send the response status line.
-     *
-     * @deprecated Unused. Will be removed in Tomcat 11. Use {@link #sendStatus(int)}.
      */
-    @Deprecated
     public void sendStatus() {
-        sendStatus(response.getStatus());
-    }
-
-
-    /**
-     * Send the response status line.
-     *
-     * @param status The HTTP status code to include in the status line
-     */
-    public void sendStatus(int status) {
         // Write protocol name
         write(Constants.HTTP_11_BYTES);
         headerBuffer.put(Constants.SP);
 
         // Write status code
+        int status = response.getStatus();
         switch (status) {
             case 200:
                 write(Constants._200_BYTES);
@@ -403,7 +392,7 @@ public class Http11OutputBuffer implements HttpOutputBuffer {
             // values will be OK. Strings using other encodings may be
             // corrupted.
             byte[] buffer = bc.getBuffer();
-            for (int i = bc.getStart(); i < bc.getLength(); i++) {
+            for (int i = bc.getOffset(); i < bc.getLength(); i++) {
                 // byte values are signed i.e. -128 to 127
                 // The values are used unsigned. 0 to 31 are CTLs so they are
                 // filtered (apart from TAB which is 9). 127 is a control (DEL).
@@ -539,6 +528,9 @@ public class Http11OutputBuffer implements HttpOutputBuffer {
      */
     protected class SocketOutputBuffer implements HttpOutputBuffer {
 
+        /**
+         * Write chunk.
+         */
         @Override
         public int doWrite(ByteBuffer chunk) throws IOException {
             try {
