@@ -26,7 +26,6 @@ import org.apache.coyote.http11.HttpOutputBuffer;
 import org.apache.coyote.http11.OutputFilter;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.tomcat.util.res.StringManager;
 
 /**
  * Gzip output filter.
@@ -36,7 +35,6 @@ import org.apache.tomcat.util.res.StringManager;
 public class GzipOutputFilter implements OutputFilter {
 
     protected static final Log log = LogFactory.getLog(GzipOutputFilter.class);
-    private static final StringManager sm = StringManager.getManager(GzipOutputFilter.class);
 
 
     // ----------------------------------------------------- Instance Variables
@@ -88,19 +86,19 @@ public class GzipOutputFilter implements OutputFilter {
     // --------------------------------------------------- OutputFilter Methods
 
     /**
-     * {@inheritDoc} Added to allow flushing to happen for the gzip'ed outputstream.
+     * Added to allow flushing to happen for the gzip'ed outputstream
      */
     @Override
     public void flush() throws IOException {
         if (compressionStream != null) {
             try {
-                if (log.isTraceEnabled()) {
-                    log.trace("Flushing the compression stream!");
+                if (log.isDebugEnabled()) {
+                    log.debug("Flushing the compression stream!");
                 }
                 compressionStream.flush();
             } catch (IOException e) {
                 if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("gzipOutputFilter.flushFail"), e);
+                    log.debug("Ignored exception while flushing gzip filter", e);
                 }
             }
         }
@@ -131,6 +129,9 @@ public class GzipOutputFilter implements OutputFilter {
     }
 
 
+    /**
+     * Make the filter ready to process the next request.
+     */
     @Override
     public void recycle() {
         // Set compression stream to null
@@ -141,29 +142,26 @@ public class GzipOutputFilter implements OutputFilter {
     // ------------------------------------------- FakeOutputStream Inner Class
 
 
-    protected class FakeOutputStream extends OutputStream {
+    protected class FakeOutputStream
+        extends OutputStream {
         protected final ByteBuffer outputChunk = ByteBuffer.allocate(1);
-
         @Override
-        public void write(int b) throws IOException {
+        public void write(int b)
+            throws IOException {
             // Shouldn't get used for good performance, but is needed for
             // compatibility with Sun JDK 1.4.0
             outputChunk.put(0, (byte) (b & 0xff));
             buffer.doWrite(outputChunk);
         }
-
         @Override
-        public void write(byte[] b, int off, int len) throws IOException {
+        public void write(byte[] b, int off, int len)
+            throws IOException {
             buffer.doWrite(ByteBuffer.wrap(b, off, len));
         }
-
         @Override
-        public void flush() throws IOException {
-            /* NOOP */}
-
+        public void flush() throws IOException {/*NOOP*/}
         @Override
-        public void close() throws IOException {
-            /* NOOP */}
+        public void close() throws IOException {/*NOOP*/}
     }
 
 
