@@ -25,7 +25,8 @@ import org.apache.tomcat.util.buf.ByteChunk;
 import org.apache.tomcat.util.net.ApplicationBufferHandler;
 
 /**
- * Input filter responsible for replaying the request body when restoring the saved request after FORM authentication.
+ * Input filter responsible for replaying the request body when restoring the
+ * saved request after FORM authentication.
  */
 public class SavedRequestInputFilter implements InputFilter {
 
@@ -45,7 +46,7 @@ public class SavedRequestInputFilter implements InputFilter {
 
     @Override
     public int doRead(ApplicationBufferHandler handler) throws IOException {
-        if (input.getStart() >= input.getEnd()) {
+        if(input.getOffset()>= input.getEnd()) {
             return -1;
         }
 
@@ -57,20 +58,23 @@ public class SavedRequestInputFilter implements InputFilter {
     }
 
     /**
-     * {@inheritDoc} Set the content length on the request.
+     * Set the content length on the request.
      */
     @Override
     public void setRequest(org.apache.coyote.Request request) {
         request.setContentLength(input.getLength());
     }
 
+    /**
+     * Make the filter ready to process the next request.
+     */
     @Override
     public void recycle() {
         input = null;
     }
 
     /**
-     * @return null
+     * Return the name of the associated encoding; here, the value is null.
      */
     @Override
     public ByteChunk getEncodingName() {
@@ -79,14 +83,15 @@ public class SavedRequestInputFilter implements InputFilter {
 
     /**
      * Set the next buffer in the filter pipeline (has no effect).
-     *
-     * @param buffer ignored
      */
     @Override
     public void setBuffer(InputBuffer buffer) {
         // NOOP since this filter will be providing the request body
     }
 
+    /**
+     * Amount of bytes still available in a buffer.
+     */
     @Override
     public int available() {
         return input.getLength();
@@ -94,8 +99,6 @@ public class SavedRequestInputFilter implements InputFilter {
 
     /**
      * End the current request (has no effect).
-     *
-     * @return 0
      */
     @Override
     public long end() throws IOException {
@@ -104,6 +107,6 @@ public class SavedRequestInputFilter implements InputFilter {
 
     @Override
     public boolean isFinished() {
-        return input.getStart() >= input.getEnd();
+        return input.getOffset() >= input.getEnd();
     }
 }
