@@ -16,7 +16,7 @@
  */
 package org.apache.coyote.http11.upgrade;
 
-import javax.servlet.http.HttpUpgradeHandler;
+import jakarta.servlet.http.HttpUpgradeHandler;
 
 import org.apache.tomcat.util.net.AbstractEndpoint.Handler.SocketState;
 import org.apache.tomcat.util.net.SSLSupport;
@@ -25,56 +25,25 @@ import org.apache.tomcat.util.net.SocketWrapperBase;
 
 
 /**
- * This Tomcat specific interface is implemented by handlers that require direct access to Tomcat's I/O layer rather
- * than going through the Servlet API.
+ * This Tomcat specific interface is implemented by handlers that require direct
+ * access to Tomcat's I/O layer rather than going through the Servlet API.
  */
 public interface InternalHttpUpgradeHandler extends HttpUpgradeHandler {
 
-    /**
-     * Process the specified event.
-     *
-     * @param status the event
-     *
-     * @return the status following the event
-     */
     SocketState upgradeDispatch(SocketEvent status);
 
-    /**
-     * Check for a possible timeout.
-     *
-     * @param now the time to use for the timeout check
-     */
     void timeoutAsync(long now);
 
-    /**
-     * Associate with the specified socket.
-     *
-     * @param wrapper the socket
-     */
     void setSocketWrapper(SocketWrapperBase<?> wrapper);
 
-    /**
-     * Associate with the specified SSL support.
-     *
-     * @param sslSupport the SSL support
-     */
     void setSslSupport(SSLSupport sslSupport);
 
-    /**
-     * Pause processing for the connection.
-     */
     void pause();
 
-    /**
-     * @return {@code true} if able to process asynchronous IO, default is {@code false}
-     */
     default boolean hasAsyncIO() {
         return false;
     }
 
-    /**
-     * @return the associated upgrade information used to collect statistics for the connection
-     */
     default UpgradeInfo getUpgradeInfo() {
         return null;
     }
