@@ -16,16 +16,17 @@
  */
 package org.apache.coyote.http2;
 
-import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.locks.Condition;
+import java.util.concurrent.locks.Lock;
+import java.util.concurrent.locks.ReentrantLock;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Base class for all streams including the connection (referred to as Stream 0)
- * and is used primarily when managing prioritization.
+ * Base class for all streams including the connection (referred to as Stream 0) and is used primarily when managing
+ * prioritization.
  */
 abstract class AbstractStream {
 
@@ -35,9 +36,9 @@ abstract class AbstractStream {
     private final Integer identifier;
     private final String idAsString;
 
-    private volatile AbstractStream parentStream = null;
-    private final Set<AbstractNonZeroStream> childStreams = ConcurrentHashMap.newKeySet();
     private long windowSize = ConnectionSettingsBase.DEFAULT_INITIAL_WINDOW_SIZE;
+    protected final Lock windowAllocationLock = new ReentrantLock();
+    protected final Condition windowAllocationAvailable = windowAllocationLock.newCondition();
 
     private volatile int connectionAllocationRequested = 0;
     private volatile int connectionAllocationMade = 0;
@@ -64,94 +65,74 @@ abstract class AbstractStream {
     }
 
 
-    final void detachFromParent() {
-        if (parentStream != null) {
-            parentStream.getChildStreams().remove(this);
-            parentStream = null;
+    final void setWindowSize(long windowSize) {
+        windowAllocationLock.lock();
+        try {
+            this.windowSize = windowSize;
+        } finally {
+            windowAllocationLock.unlock();
         }
     }
 
 
-    final void addChild(AbstractNonZeroStream child) {
-        child.setParentStream(this);
-        childStreams.add(child);
-    }
-
-
-    final boolean isDescendant(AbstractStream stream) {
-        // Is the passed in Stream a descendant of this Stream?
-        // Start at the passed in Stream and work up
-        AbstractStream parent = stream.getParentStream();
-        while (parent != null && parent != this) {
-            parent = parent.getParentStream();
+    final long getWindowSize() {
+        windowAllocationLock.lock();
+        try {
+            return windowSize;
+        } finally {
+            windowAllocationLock.unlock();
         }
-        return parent != null;
-    }
-
-
-    final AbstractStream getParentStream() {
-        return parentStream;
-    }
-
-
-    final void setParentStream(AbstractStream parentStream) {
-        this.parentStream = parentStream;
-    }
-
-
-    final Set<AbstractNonZeroStream> getChildStreams() {
-        return childStreams;
-    }
-
-
-    final synchronized void setWindowSize(long windowSize) {
-        this.windowSize = windowSize;
-    }
-
-
-    final synchronized long getWindowSize() {
-        return windowSize;
     }
 
 
     /**
      * Increment window size.
+     *
      * @param increment The amount by which the window size should be increased
-     * @throws Http2Exception If the window size is now higher than
-     *  the maximum allowed
+     *
+     * @throws Http2Exception If the window size is now higher than the maximum allowed
      */
-    synchronized void incrementWindowSize(int increment) throws Http2Exception {
-        // No need for overflow protection here.
-        // Increment can't be more than Integer.MAX_VALUE and once windowSize
-        // goes beyond 2^31-1 an error is triggered.
-        windowSize += increment;
+    void incrementWindowSize(int increment) throws Http2Exception {
+        windowAllocationLock.lock();
+        try {
+            // No need for overflow protection here.
+            // Increment can't be more than Integer.MAX_VALUE and once windowSize
+            // goes beyond 2^31-1 an error is triggered.
+            windowSize += increment;
 
-        if (log.isDebugEnabled()) {
-            log.debug(sm.getString("abstractStream.windowSizeInc", getConnectionId(),
-                    getIdAsString(), Integer.toString(increment), Long.toString(windowSize)));
-        }
-
-        if (windowSize > ConnectionSettingsBase.MAX_WINDOW_SIZE) {
-            String msg = sm.getString("abstractStream.windowSizeTooBig", getConnectionId(), identifier,
-                    Integer.toString(increment), Long.toString(windowSize));
-            if (identifier.intValue() == 0) {
-                throw new ConnectionException(msg, Http2Error.FLOW_CONTROL_ERROR);
-            } else {
-                throw new StreamException(
-                        msg, Http2Error.FLOW_CONTROL_ERROR, identifier.intValue());
+            if (log.isDebugEnabled()) {
+                log.debug(sm.getString("abstractStream.windowSizeInc", getConnectionId(), getIdAsString(),
+                        Integer.toString(increment), Long.toString(windowSize)));
             }
+
+            if (windowSize > ConnectionSettingsBase.MAX_WINDOW_SIZE) {
+                String msg = sm.getString("abstractStream.windowSizeTooBig", getConnectionId(), identifier,
+                        Integer.toString(increment), Long.toString(windowSize));
+                if (identifier.intValue() == 0) {
+                    throw new ConnectionException(msg, Http2Error.FLOW_CONTROL_ERROR);
+                } else {
+                    throw new StreamException(msg, Http2Error.FLOW_CONTROL_ERROR, identifier.intValue());
+                }
+            }
+        } finally {
+            windowAllocationLock.unlock();
         }
     }
 
 
-    final synchronized void decrementWindowSize(int decrement) {
-        // No need for overflow protection here. Decrement can never be larger
-        // the Integer.MAX_VALUE and once windowSize goes negative no further
-        // decrements are permitted
-        windowSize -= decrement;
-        if (log.isDebugEnabled()) {
-            log.debug(sm.getString("abstractStream.windowSizeDec", getConnectionId(),
-                    getIdAsString(), Integer.toString(decrement), Long.toString(windowSize)));
+    final void decrementWindowSize(int decrement) {
+        windowAllocationLock.lock();
+        try {
+            // No need for overflow protection here. Decrement can never be larger
+            // the Integer.MAX_VALUE and once windowSize goes negative no further
+            // decrements are permitted
+            windowSize -= decrement;
+            if (log.isDebugEnabled()) {
+                log.debug(sm.getString("abstractStream.windowSizeDec", getConnectionId(), getIdAsString(),
+                        Integer.toString(decrement), Long.toString(windowSize)));
+            }
+        } finally {
+            windowAllocationLock.unlock();
         }
     }
 
@@ -181,6 +162,4 @@ abstract class AbstractStream {
 
 
     abstract String getConnectionId();
-
-    abstract int getWeight();
 }
