@@ -43,9 +43,8 @@ public class HpackDecoder {
     private Hpack.HeaderField[] headerTable;
 
     /**
-     * The current HEAD position of the header table. We use a ring buffer type
-     * construct as it would be silly to actually shuffle the items around in the
-     * array.
+     * The current HEAD position of the header table. We use a ring buffer type construct as it would be silly to
+     * actually shuffle the items around in the array.
      */
     private int firstSlotPosition = 0;
 
@@ -86,9 +85,8 @@ public class HpackDecoder {
     }
 
     /**
-     * Decodes the provided frame data. If this method leaves data in the buffer
-     * then this buffer should be compacted so this data is preserved, unless
-     * there is no more data in which case this should be considered a protocol error.
+     * Decodes the provided frame data. If this method leaves data in the buffer then this buffer should be compacted so
+     * this data is preserved, unless there is no more data in which case this should be considered a protocol error.
      *
      * @param buffer The buffer
      *
@@ -99,19 +97,18 @@ public class HpackDecoder {
             int originalPos = buffer.position();
             byte b = buffer.get();
             if ((b & 0b10000000) != 0) {
-                //if the first bit is set it is an indexed header field
-                buffer.position(buffer.position() - 1); //unget the byte
-                int index = Hpack.decodeInteger(buffer, 7); //prefix is 7
+                // if the first bit is set it is an indexed header field
+                buffer.position(buffer.position() - 1); // unget the byte
+                int index = Hpack.decodeInteger(buffer, 7); // prefix is 7
                 if (index == -1) {
                     buffer.position(originalPos);
                     return;
-                } else if(index == 0) {
-                    throw new HpackException(
-                            sm.getString("hpackdecoder.zeroNotValidHeaderTableIndex"));
+                } else if (index == 0) {
+                    throw new HpackException(sm.getString("hpackdecoder.zeroNotValidHeaderTableIndex"));
                 }
                 handleIndex(index);
             } else if ((b & 0b01000000) != 0) {
-                //Literal Header Field with Incremental Indexing
+                // Literal Header Field with Incremental Indexing
                 String headerName = readHeaderName(buffer, 6);
                 if (headerName == null) {
                     buffer.position(originalPos);
@@ -125,7 +122,7 @@ public class HpackDecoder {
                 emitHeader(headerName, headerValue);
                 addEntryToHeaderTable(new Hpack.HeaderField(headerName, headerValue));
             } else if ((b & 0b11110000) == 0) {
-                //Literal Header Field without Indexing
+                // Literal Header Field without Indexing
                 String headerName = readHeaderName(buffer, 4);
                 if (headerName == null) {
                     buffer.position(originalPos);
@@ -138,7 +135,7 @@ public class HpackDecoder {
                 }
                 emitHeader(headerName, headerValue);
             } else if ((b & 0b11110000) == 0b00010000) {
-                //Literal Header Field never indexed
+                // Literal Header Field never indexed
                 String headerName = readHeaderName(buffer, 4);
                 if (headerName == null) {
                     buffer.position(originalPos);
@@ -151,7 +148,7 @@ public class HpackDecoder {
                 }
                 emitHeader(headerName, headerValue);
             } else if ((b & 0b11100000) == 0b00100000) {
-                //context update max table size change
+                // context update max table size change
                 if (!handleMaxMemorySizeChange(buffer, originalPos)) {
                     return;
                 }
@@ -165,15 +162,15 @@ public class HpackDecoder {
         if (headerCount != 0) {
             throw new HpackException(sm.getString("hpackdecoder.tableSizeUpdateNotAtStart"));
         }
-        buffer.position(buffer.position() - 1); //unget the byte
+        buffer.position(buffer.position() - 1); // unget the byte
         int size = Hpack.decodeInteger(buffer, 5);
         if (size == -1) {
             buffer.position(originalPos);
             return false;
         }
         if (size > maxMemorySizeHard) {
-            throw new HpackException(sm.getString("hpackdecoder.maxMemorySizeExceeded",
-                    Integer.valueOf(size), Integer.valueOf(maxMemorySizeHard)));
+            throw new HpackException(sm.getString("hpackdecoder.maxMemorySizeExceeded", Integer.valueOf(size),
+                    Integer.valueOf(maxMemorySizeHard)));
         }
         maxMemorySizeSoft = size;
         if (currentMemorySize > maxMemorySizeSoft) {
@@ -198,7 +195,7 @@ public class HpackDecoder {
     }
 
     private String readHeaderName(ByteBuffer buffer, int prefixLength) throws HpackException {
-        buffer.position(buffer.position() - 1); //unget the byte
+        buffer.position(buffer.position() - 1); // unget the byte
         int index = Hpack.decodeInteger(buffer, prefixLength);
         if (index == -1) {
             return null;
@@ -242,9 +239,8 @@ public class HpackDecoder {
         } else {
             // index is 1 based
             if (index > Hpack.STATIC_TABLE_LENGTH + filledTableSlots) {
-                throw new HpackException(sm.getString("hpackdecoder.headerTableIndexInvalid",
-                        Integer.valueOf(index), Integer.valueOf(Hpack.STATIC_TABLE_LENGTH),
-                        Integer.valueOf(filledTableSlots)));
+                throw new HpackException(sm.getString("hpackdecoder.headerTableIndexInvalid", Integer.valueOf(index),
+                        Integer.valueOf(Hpack.STATIC_TABLE_LENGTH), Integer.valueOf(filledTableSlots)));
             }
             int adjustedIndex = getRealIndex(index - Hpack.STATIC_TABLE_LENGTH);
             Hpack.HeaderField res = headerTable[adjustedIndex];
@@ -259,6 +255,7 @@ public class HpackDecoder {
      * Handle an indexed header representation
      *
      * @param index The index
+     *
      * @throws HpackException If an error occurs processing the given index
      */
     private void handleIndex(int index) throws HpackException {
@@ -275,29 +272,29 @@ public class HpackDecoder {
     }
 
     /**
-     * because we use a ring buffer type construct, and don't actually shuffle
-     * items in the array, we need to figure out the real index to use.
+     * because we use a ring buffer type construct, and don't actually shuffle items in the array, we need to figure out
+     * the real index to use.
      * <p/>
      * package private for unit tests
      *
      * @param index The index from the hpack
+     *
      * @return the real index into the array
      */
     int getRealIndex(int index) throws HpackException {
-        //the index is one based, but our table is zero based, hence -1
-        //also because of our ring buffer setup the indexes are reversed
-        //index = 1 is at position firstSlotPosition + filledSlots
+        // the index is one based, but our table is zero based, hence -1
+        // also because of our ring buffer setup the indexes are reversed
+        // index = 1 is at position firstSlotPosition + filledSlots
         int realIndex = (firstSlotPosition + (filledTableSlots - index)) % headerTable.length;
         if (realIndex < 0) {
-            throw new HpackException(sm.getString("hpackdecoder.headerTableIndexInvalid",
-                    Integer.valueOf(index), Integer.valueOf(Hpack.STATIC_TABLE_LENGTH),
-                    Integer.valueOf(filledTableSlots)));
+            throw new HpackException(sm.getString("hpackdecoder.headerTableIndexInvalid", Integer.valueOf(index),
+                    Integer.valueOf(Hpack.STATIC_TABLE_LENGTH), Integer.valueOf(filledTableSlots)));
         }
         return realIndex;
     }
 
     private void addStaticTableEntry(int index) throws HpackException {
-        //adds an entry from the static table.
+        // adds an entry from the static table.
         if (log.isDebugEnabled()) {
             log.debug(sm.getString("hpackdecoder.useStatic", Integer.valueOf(index)));
         }
@@ -310,7 +307,7 @@ public class HpackDecoder {
             if (log.isDebugEnabled()) {
                 log.debug(sm.getString("hpackdecoder.clearDynamic"));
             }
-            //it is to big to fit, so we just completely clear the table.
+            // it is to big to fit, so we just completely clear the table.
             while (filledTableSlots > 0) {
                 headerTable[firstSlotPosition] = null;
                 firstSlotPosition++;
@@ -347,9 +344,9 @@ public class HpackDecoder {
     }
 
     private void resizeIfRequired() {
-        if(filledTableSlots == headerTable.length) {
-            Hpack.HeaderField[] newArray = new Hpack.HeaderField[headerTable.length + 10]; //we only grow slowly
-            for(int i = 0; i < headerTable.length; ++i) {
+        if (filledTableSlots == headerTable.length) {
+            Hpack.HeaderField[] newArray = new Hpack.HeaderField[headerTable.length + 10]; // we only grow slowly
+            for (int i = 0; i < headerTable.length; ++i) {
                 newArray[i] = headerTable[(firstSlotPosition + i) % headerTable.length];
             }
             firstSlotPosition = 0;
@@ -367,29 +364,26 @@ public class HpackDecoder {
          *
          * @param name  Header name
          * @param value Header value
-         * @throws HpackException If a header is received that is not compliant
-         *                        with the HTTP/2 specification
+         *
+         * @throws HpackException If a header is received that is not compliant with the HTTP/2 specification
          */
         void emitHeader(String name, String value) throws HpackException;
 
         /**
-         * Inform the recipient of the headers that a stream error needs to be
-         * triggered using the given message when {@link #validateHeaders()} is
-         * called. This is used when the Parser becomes aware of an error that
-         * is not visible to the recipient.
+         * Inform the recipient of the headers that a stream error needs to be triggered using the given message when
+         * {@link #validateHeaders()} is called. This is used when the Parser becomes aware of an error that is not
+         * visible to the recipient.
          *
          * @param streamException The exception to use when resetting the stream
          */
         void setHeaderException(StreamException streamException);
 
         /**
-         * Are the headers pass to the recipient so far valid? The decoder needs
-         * to process all the headers to maintain state even if there is a
-         * problem. In addition, it is easy for the the intended recipient to
-         * track if the complete set of headers is valid since to do that state
-         * needs to be maintained between the parsing of the initial headers and
-         * the parsing of any trailer headers. The recipient is the best place
-         * to maintain that state.
+         * Are the headers pass to the recipient so far valid? The decoder needs to process all the headers to maintain
+         * state even if there is a problem. In addition, it is easy for the the intended recipient to track if the
+         * complete set of headers is valid since to do that state needs to be maintained between the parsing of the
+         * initial headers and the parsing of any trailer headers. The recipient is the best place to maintain that
+         * state.
          *
          * @throws StreamException If the headers received to date are not valid
          */
@@ -427,11 +421,11 @@ public class HpackDecoder {
             // Only count the cookie header once since HTTP/2 splits it into
             // multiple headers to aid compression
             if (!countedCookie) {
-                headerCount ++;
+                headerCount++;
                 countedCookie = true;
             }
         } else {
-            headerCount ++;
+            headerCount++;
         }
         // Overhead will vary. The main concern is that lots of small headers
         // trigger the limiting mechanism correctly. Therefore, use an overhead
@@ -472,7 +466,7 @@ public class HpackDecoder {
     }
 
 
-    //package private fields for unit tests
+    // package private fields for unit tests
 
     int getFirstSlotPosition() {
         return firstSlotPosition;
