@@ -14,24 +14,29 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.el;
 
 import java.io.Externalizable;
 import java.io.IOException;
 import java.io.ObjectInput;
 import java.io.ObjectOutput;
+import java.lang.annotation.Annotation;
 
-import javax.el.ELContext;
-import javax.el.ELException;
-import javax.el.MethodExpression;
-import javax.el.MethodInfo;
+import jakarta.el.ELContext;
+import jakarta.el.ELException;
+import jakarta.el.MethodExpression;
+import jakarta.el.MethodInfo;
+import jakarta.el.MethodReference;
 
+import org.apache.el.util.MessageFactory;
 import org.apache.el.util.ReflectionUtil;
 
 
 public class MethodExpressionLiteral extends MethodExpression implements Externalizable {
 
+    private static final Annotation[] EMPTY_ANNOTATION_ARRAY = new Annotation[0];
+    private static final Object[] EMPTY_OBJECT_ARRAY = new Object[0];
+
     private Class<?> expectedType;
 
     private String expr;
@@ -52,12 +57,16 @@ public class MethodExpressionLiteral extends MethodExpression implements Externa
     @Override
     public MethodInfo getMethodInfo(ELContext context) throws ELException {
         context.notifyBeforeEvaluation(getExpressionString());
-        MethodInfo result =
-                new MethodInfo(this.expr, this.expectedType, this.paramTypes);
+        MethodInfo result = getMethodInfoInternal();
         context.notifyAfterEvaluation(getExpressionString());
         return result;
     }
 
+
+    private MethodInfo getMethodInfoInternal() throws ELException {
+        return new MethodInfo(this.expr, this.expectedType, this.paramTypes);
+    }
+
     @Override
     public Object invoke(ELContext context, Object[] params) throws ELException {
         context.notifyBeforeEvaluation(getExpressionString());
@@ -71,6 +80,19 @@ public class MethodExpressionLiteral extends MethodExpression implements Externa
         return result;
     }
 
+
+    @Override
+    public MethodReference getMethodReference(ELContext context) {
+        if (context == null) {
+            throw new NullPointerException(MessageFactory.get("error.context.null"));
+        }
+        context.notifyBeforeEvaluation(getExpressionString());
+        MethodReference result =
+                new MethodReference(null, getMethodInfoInternal(), EMPTY_ANNOTATION_ARRAY, EMPTY_OBJECT_ARRAY);
+        context.notifyAfterEvaluation(getExpressionString());
+        return result;
+    }
+
     @Override
     public String getExpressionString() {
         return this.expr;
