@@ -16,7 +16,7 @@
  */
 package org.apache.el.parser;
 
-import javax.el.ELException;
+import jakarta.el.ELException;
 
 import org.apache.el.lang.EvaluationContext;
 
@@ -29,9 +29,9 @@ public abstract class ArithmeticNode extends SimpleNode {
         super(i);
     }
 
-
     @Override
-    public Class<?> getType(EvaluationContext ctx) throws ELException {
+    public Class<?> getType(EvaluationContext ctx)
+            throws ELException {
         return Number.class;
     }
 }
