@@ -14,7 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.jasper.compiler;
 
 import java.io.ByteArrayOutputStream;
@@ -224,8 +223,9 @@ public class SmapUtil {
             copy(4 + 2 + 2); // magic min/maj version
             int constantPoolCountPos = genPos;
             int constantPoolCount = readU2();
-            if (log.isDebugEnabled())
+            if (log.isDebugEnabled()) {
                 log.debug("constant pool count: " + constantPoolCount);
+            }
             writeU2(constantPoolCount);
 
             // copy old constant pool return index of SDE symbol, if found
@@ -239,32 +239,37 @@ public class SmapUtil {
                 ++constantPoolCount;
                 randomAccessWriteU2(constantPoolCountPos, constantPoolCount);
 
-                if (log.isDebugEnabled())
+                if (log.isDebugEnabled()) {
                     log.debug("SourceDebugExtension not found, installed at: " + sdeIndex);
+                }
             } else {
-                if (log.isDebugEnabled())
+                if (log.isDebugEnabled()) {
                     log.debug("SourceDebugExtension found at: " + sdeIndex);
+                }
             }
             copy(2 + 2 + 2); // access, this, super
             int interfaceCount = readU2();
             writeU2(interfaceCount);
-            if (log.isDebugEnabled())
+            if (log.isDebugEnabled()) {
                 log.debug("interfaceCount: " + interfaceCount);
+            }
             copy(interfaceCount * 2);
             copyMembers(); // fields
             copyMembers(); // methods
             int attrCountPos = genPos;
             int attrCount = readU2();
             writeU2(attrCount);
-            if (log.isDebugEnabled())
+            if (log.isDebugEnabled()) {
                 log.debug("class attrCount: " + attrCount);
+            }
             // copy the class attributes, return true if SDE attr found (not copied)
             if (!copyAttrs(attrCount)) {
                 // we will be adding SDE and it isn't already counted
                 ++attrCount;
                 randomAccessWriteU2(attrCountPos, attrCount);
-                if (log.isDebugEnabled())
+                if (log.isDebugEnabled()) {
                     log.debug("class attrCount incremented");
+                }
             }
             writeAttrForSDE(sdeIndex);
         }
@@ -272,14 +277,16 @@ public class SmapUtil {
         void copyMembers() {
             int count = readU2();
             writeU2(count);
-            if (log.isDebugEnabled())
+            if (log.isDebugEnabled()) {
                 log.debug("members count: " + count);
+            }
             for (int i = 0; i < count; ++i) {
                 copy(6); // access, name, descriptor
                 int attrCount = readU2();
                 writeU2(attrCount);
-                if (log.isDebugEnabled())
+                if (log.isDebugEnabled()) {
                     log.debug("member attr count: " + attrCount);
+                }
                 copyAttrs(attrCount);
             }
         }
@@ -291,15 +298,17 @@ public class SmapUtil {
                 // don't write old SDE
                 if (nameIndex == sdeIndex) {
                     sdeFound = true;
-                    if (log.isDebugEnabled())
+                    if (log.isDebugEnabled()) {
                         log.debug("SDE attr found");
+                    }
                 } else {
                     writeU2(nameIndex); // name
                     int len = readU4();
                     writeU4(len);
                     copy(len);
-                    if (log.isDebugEnabled())
+                    if (log.isDebugEnabled()) {
                         log.debug("attr len: " + len);
+                    }
                 }
             }
             return sdeFound;
@@ -379,13 +388,15 @@ public class SmapUtil {
                     case 7 :  // Class
                     case 8 :  // String
                     case 16 : // MethodType
-                        if (log.isDebugEnabled())
+                        if (log.isDebugEnabled()) {
                             log.debug(i + " copying 2 bytes");
+                        }
                         copy(2);
                         break;
                     case 15 : // MethodHandle
-                        if (log.isDebugEnabled())
+                        if (log.isDebugEnabled()) {
                             log.debug(i + " copying 3 bytes");
+                        }
                         copy(3);
                         break;
                     case 9 :  // Field
@@ -395,14 +406,16 @@ public class SmapUtil {
                     case 4 :  // Float
                     case 12 : // NameAndType
                     case 18 : // InvokeDynamic
-                        if (log.isDebugEnabled())
+                        if (log.isDebugEnabled()) {
                             log.debug(i + " copying 4 bytes");
+                        }
                         copy(4);
                         break;
                     case 5 : // Long
                     case 6 : // Double
-                        if (log.isDebugEnabled())
+                        if (log.isDebugEnabled()) {
                             log.debug(i + " copying 8 bytes");
+                        }
                         copy(8);
                         i++;
                         break;
@@ -411,8 +424,9 @@ public class SmapUtil {
                         writeU2(len);
                         byte[] utf8 = readBytes(len);
                         String str = new String(utf8, "UTF-8");
-                        if (log.isDebugEnabled())
+                        if (log.isDebugEnabled()) {
                             log.debug(i + " read class attr -- '" + str + "'");
+                        }
                         if (str.equals(nameSDE)) {
                             sdeIndex = i;
                         }
@@ -762,12 +776,12 @@ public class SmapUtil {
 
         InputStream is = null;
         try {
-            is = cl.getResourceAsStream(className.replaceAll("\\.","/") + ".smap");
+            is = cl.getResourceAsStream(className.replace(".","/") + ".smap");
             if (is != null) {
                 encoding = SMAP_ENCODING;
                 found = true;
             } else {
-                is = cl.getResourceAsStream(className.replaceAll("\\.","/") + ".class");
+                is = cl.getResourceAsStream(className.replace(".","/") + ".class");
                 // Alternative approach would be to read the class file as per the
                 // JLS. That would require duplicating a lot of BCEL functionality.
                 int b = is.read();
