@@ -18,12 +18,12 @@ package org.apache.jasper.runtime;
 
 import java.io.IOException;
 
-import javax.servlet.ServletConfig;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.jsp.HttpJspPage;
+import jakarta.servlet.ServletConfig;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.jsp.HttpJspPage;
 
 import org.apache.jasper.Constants;
 import org.apache.jasper.compiler.Localizer;
@@ -60,6 +60,9 @@ public abstract class HttpJspBase extends HttpServlet implements HttpJspPage {
         _jspDestroy();
     }
 
+    /**
+     * Entry point into service.
+     */
     @Override
     public final void service(HttpServletRequest request, HttpServletResponse response)
         throws ServletException, IOException
