@@ -24,26 +24,27 @@ import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.Set;
 
-import javax.el.ELContext;
-import javax.el.ELException;
-import javax.el.ExpressionFactory;
-import javax.el.ImportHandler;
-import javax.el.ValueExpression;
-import javax.servlet.RequestDispatcher;
-import javax.servlet.Servlet;
-import javax.servlet.ServletConfig;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpSession;
-import javax.servlet.jsp.JspException;
-import javax.servlet.jsp.JspFactory;
-import javax.servlet.jsp.JspWriter;
-import javax.servlet.jsp.PageContext;
-import javax.servlet.jsp.tagext.BodyContent;
+import jakarta.el.ELContext;
+import jakarta.el.ELException;
+import jakarta.el.ExpressionFactory;
+import jakarta.el.ImportHandler;
+import jakarta.el.ValueExpression;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.Servlet;
+import jakarta.servlet.ServletConfig;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpSession;
+import jakarta.servlet.jsp.JspException;
+import jakarta.servlet.jsp.JspFactory;
+import jakarta.servlet.jsp.JspWriter;
+import jakarta.servlet.jsp.PageContext;
+import jakarta.servlet.jsp.el.NotFoundELResolver;
+import jakarta.servlet.jsp.tagext.BodyContent;
 
 import org.apache.jasper.Constants;
 import org.apache.jasper.compiler.Localizer;
@@ -51,7 +52,8 @@ import org.apache.jasper.el.ELContextImpl;
 import org.apache.jasper.runtime.JspContextWrapper.ELContextWrapper;
 
 /**
- * Implementation of the PageContext class from the JSP spec. Also doubles as a VariableResolver for the EL.
+ * Implementation of the PageContext class from the JSP spec. Also doubles as a
+ * VariableResolver for the EL.
  *
  * @author Anil K. Vijendran
  * @author Larry Cable
@@ -65,8 +67,6 @@ public class PageContextImpl extends PageContext {
 
     private static final JspFactory jspf = JspFactory.getDefaultFactory();
 
-    private static final BodyContentImpl[] EMPTY_BODY_CONTENT_IMPL_ARRAY = new BodyContentImpl[0];
-
     private BodyContentImpl[] outs;
 
     private int depth;
@@ -82,8 +82,12 @@ public class PageContextImpl extends PageContext {
 
     private String errorPageURL;
 
+    private boolean limitBodyContentBuffer;
+
+    private int bodyContentTagBufferSize = Constants.DEFAULT_TAG_BUFFER_SIZE;
+
     // page-scope attributes
-    private final transient HashMap<String,Object> attributes;
+    private final transient HashMap<String, Object> attributes;
 
     // per-request state
     private transient ServletRequest request;
@@ -100,15 +104,20 @@ public class PageContextImpl extends PageContext {
 
     private transient JspWriterImpl baseOut;
 
+    /*
+     * Constructor.
+     */
     PageContextImpl() {
-        this.outs = EMPTY_BODY_CONTENT_IMPL_ARRAY;
+        this.outs = new BodyContentImpl[0];
         this.attributes = new HashMap<>(16);
         this.depth = -1;
     }
 
     @Override
-    public void initialize(Servlet servlet, ServletRequest request, ServletResponse response, String errorPageURL,
-            boolean needsSession, int bufferSize, boolean autoFlush) throws IOException {
+    public void initialize(Servlet servlet, ServletRequest request,
+            ServletResponse response, String errorPageURL,
+            boolean needsSession, int bufferSize, boolean autoFlush)
+            throws IOException {
 
         // initialize state
         this.servlet = servlet;
@@ -118,6 +127,12 @@ public class PageContextImpl extends PageContext {
         this.request = request;
         this.response = response;
 
+        limitBodyContentBuffer = Boolean.parseBoolean(config.getInitParameter("limitBodyContentBuffer"));
+        String bodyContentTagBufferSize = config.getInitParameter("bodyContentTagBufferSize");
+        if (bodyContentTagBufferSize != null) {
+            this.bodyContentTagBufferSize = Integer.parseInt(bodyContentTagBufferSize);
+        }
+
         // initialize application context
         this.applicationContext = JspApplicationContextImpl.getInstance(context);
 
@@ -162,7 +177,8 @@ public class PageContextImpl extends PageContext {
         try {
             ((JspWriterImpl) out).flushBuffer();
         } catch (IOException ex) {
-            throw new IllegalStateException(Localizer.getMessage("jsp.error.flush"), ex);
+            IllegalStateException ise = new IllegalStateException(Localizer.getMessage("jsp.error.flush"), ex);
+            throw ise;
         } finally {
             servlet = null;
             config = null;
@@ -176,7 +192,7 @@ public class PageContextImpl extends PageContext {
             baseOut.recycle();
             session = null;
             attributes.clear();
-            for (BodyContentImpl body : outs) {
+            for (BodyContentImpl body: outs) {
                 body.recycle();
             }
         }
@@ -195,23 +211,23 @@ public class PageContextImpl extends PageContext {
         }
 
         switch (scope) {
-            case PAGE_SCOPE:
-                return attributes.get(name);
+        case PAGE_SCOPE:
+            return attributes.get(name);
 
-            case REQUEST_SCOPE:
-                return request.getAttribute(name);
+        case REQUEST_SCOPE:
+            return request.getAttribute(name);
 
-            case SESSION_SCOPE:
-                if (session == null) {
-                    throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
-                }
-                return session.getAttribute(name);
+        case SESSION_SCOPE:
+            if (session == null) {
+                throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
+            }
+            return session.getAttribute(name);
 
-            case APPLICATION_SCOPE:
-                return context.getAttribute(name);
+        case APPLICATION_SCOPE:
+            return context.getAttribute(name);
 
-            default:
-                throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
+        default:
+            throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
         }
     }
 
@@ -231,27 +247,28 @@ public class PageContextImpl extends PageContext {
             removeAttribute(name, scope);
         } else {
             switch (scope) {
-                case PAGE_SCOPE:
-                    attributes.put(name, o);
-                    break;
+            case PAGE_SCOPE:
+                attributes.put(name, o);
+                break;
 
-                case REQUEST_SCOPE:
-                    request.setAttribute(name, o);
-                    break;
+            case REQUEST_SCOPE:
+                request.setAttribute(name, o);
+                break;
 
-                case SESSION_SCOPE:
-                    if (session == null) {
-                        throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
-                    }
-                    session.setAttribute(name, o);
-                    break;
+            case SESSION_SCOPE:
+                if (session == null) {
+                    throw new IllegalStateException(Localizer
+                            .getMessage("jsp.error.page.noSession"));
+                }
+                session.setAttribute(name, o);
+                break;
 
-                case APPLICATION_SCOPE:
-                    context.setAttribute(name, o);
-                    break;
+            case APPLICATION_SCOPE:
+                context.setAttribute(name, o);
+                break;
 
-                default:
-                    throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
+            default:
+                throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
             }
         }
     }
@@ -264,27 +281,27 @@ public class PageContextImpl extends PageContext {
         }
 
         switch (scope) {
-            case PAGE_SCOPE:
-                attributes.remove(name);
-                break;
+        case PAGE_SCOPE:
+            attributes.remove(name);
+            break;
 
-            case REQUEST_SCOPE:
-                request.removeAttribute(name);
-                break;
+        case REQUEST_SCOPE:
+            request.removeAttribute(name);
+            break;
 
-            case SESSION_SCOPE:
-                if (session == null) {
-                    throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
-                }
-                session.removeAttribute(name);
-                break;
+        case SESSION_SCOPE:
+            if (session == null) {
+                throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
+            }
+            session.removeAttribute(name);
+            break;
 
-            case APPLICATION_SCOPE:
-                context.removeAttribute(name);
-                break;
+        case APPLICATION_SCOPE:
+            context.removeAttribute(name);
+            break;
 
-            default:
-                throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
+        default:
+            throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
         }
     }
 
@@ -308,7 +325,7 @@ public class PageContextImpl extends PageContext {
                 if (session.getAttribute(name) != null) {
                     return SESSION_SCOPE;
                 }
-            } catch (IllegalStateException ise) {
+            } catch(IllegalStateException ise) {
                 // Session has been invalidated.
                 // Ignore and fall through to application scope.
             }
@@ -340,7 +357,7 @@ public class PageContextImpl extends PageContext {
         if (session != null) {
             try {
                 o = session.getAttribute(name);
-            } catch (IllegalStateException ise) {
+            } catch(IllegalStateException ise) {
                 // Session has been invalidated.
                 // Ignore and fall through to application scope.
             }
@@ -355,23 +372,23 @@ public class PageContextImpl extends PageContext {
     @Override
     public Enumeration<String> getAttributeNamesInScope(final int scope) {
         switch (scope) {
-            case PAGE_SCOPE:
-                return Collections.enumeration(attributes.keySet());
+        case PAGE_SCOPE:
+            return Collections.enumeration(attributes.keySet());
 
-            case REQUEST_SCOPE:
-                return request.getAttributeNames();
+        case REQUEST_SCOPE:
+            return request.getAttributeNames();
 
-            case SESSION_SCOPE:
-                if (session == null) {
-                    throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
-                }
-                return session.getAttributeNames();
+        case SESSION_SCOPE:
+            if (session == null) {
+                throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
+            }
+            return session.getAttributeNames();
 
-            case APPLICATION_SCOPE:
-                return context.getAttributeNames();
+        case APPLICATION_SCOPE:
+            return context.getAttributeNames();
 
-            default:
-                throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
+        default:
+            throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
         }
     }
 
@@ -384,10 +401,10 @@ public class PageContextImpl extends PageContext {
 
         removeAttribute(name, PAGE_SCOPE);
         removeAttribute(name, REQUEST_SCOPE);
-        if (session != null) {
+        if( session != null ) {
             try {
                 removeAttribute(name, SESSION_SCOPE);
-            } catch (IllegalStateException ise) {
+            } catch(IllegalStateException ise) {
                 // Session has been invalidated.
                 // Ignore and fall throw to application scope.
             }
@@ -428,7 +445,8 @@ public class PageContextImpl extends PageContext {
     /**
      * Returns the exception associated with this page context, if any.
      * <p>
-     * Added wrapping for Throwables to avoid ClassCastException: see Bugzilla 31171 for details.
+     * Added wrapping for Throwables to avoid ClassCastException: see Bugzilla
+     * 31171 for details.
      *
      * @return The Exception associated with this page context, if any.
      */
@@ -453,7 +471,8 @@ public class PageContextImpl extends PageContext {
         String path = relativeUrlPath;
 
         if (!path.startsWith("/")) {
-            String uri = (String) request.getAttribute(RequestDispatcher.INCLUDE_SERVLET_PATH);
+            String uri = (String) request.getAttribute(
+                    RequestDispatcher.INCLUDE_SERVLET_PATH);
             if (uri == null) {
                 uri = ((HttpServletRequest) request).getServletPath();
             }
@@ -465,19 +484,23 @@ public class PageContextImpl extends PageContext {
     }
 
     @Override
-    public void include(String relativeUrlPath) throws ServletException, IOException {
-        JspRuntimeLibrary.include(request, response, relativeUrlPath, out, true);
+    public void include(String relativeUrlPath) throws ServletException,
+            IOException {
+        JspRuntimeLibrary
+                .include(request, response, relativeUrlPath, out, true);
     }
 
     @Override
-    public void include(final String relativeUrlPath, final boolean flush) throws ServletException, IOException {
+    public void include(final String relativeUrlPath, final boolean flush)
+            throws ServletException, IOException {
         JspRuntimeLibrary.include(request, response, relativeUrlPath, out, flush);
     }
 
     @Override
     @Deprecated
-    public javax.servlet.jsp.el.VariableResolver getVariableResolver() {
-        return new org.apache.jasper.el.VariableResolverImpl(this.getELContext());
+    public jakarta.servlet.jsp.el.VariableResolver getVariableResolver() {
+        return new org.apache.jasper.el.VariableResolverImpl(
+                this.getELContext());
     }
 
     @Override
@@ -487,7 +510,8 @@ public class PageContextImpl extends PageContext {
             out.clear();
             baseOut.clear();
         } catch (IOException ex) {
-            throw new IllegalStateException(Localizer.getMessage("jsp.error.attempt_to_clear_flushed_buffer"), ex);
+            throw new IllegalStateException(Localizer.getMessage(
+                    "jsp.error.attempt_to_clear_flushed_buffer"), ex);
         }
 
         // Make sure that the response object is not the wrapper for include
@@ -520,7 +544,7 @@ public class PageContextImpl extends PageContext {
         depth++;
         if (depth >= outs.length) {
             BodyContentImpl[] newOuts = Arrays.copyOf(outs, depth + 1);
-            newOuts[depth] = new BodyContentImpl(out);
+            newOuts[depth] = new BodyContentImpl(out, limitBodyContentBuffer, bodyContentTagBufferSize);
             outs = newOuts;
         }
 
@@ -551,17 +575,20 @@ public class PageContextImpl extends PageContext {
     }
 
     /**
-     * Provides programmatic access to the ExpressionEvaluator. The JSP Container must return a valid instance of an
-     * ExpressionEvaluator that can parse EL expressions.
+     * Provides programmatic access to the ExpressionEvaluator. The JSP
+     * Container must return a valid instance of an ExpressionEvaluator that can
+     * parse EL expressions.
      */
     @Override
     @Deprecated
-    public javax.servlet.jsp.el.ExpressionEvaluator getExpressionEvaluator() {
-        return new org.apache.jasper.el.ExpressionEvaluatorImpl(this.applicationContext.getExpressionFactory());
+    public jakarta.servlet.jsp.el.ExpressionEvaluator getExpressionEvaluator() {
+        return new org.apache.jasper.el.ExpressionEvaluatorImpl(
+                this.applicationContext.getExpressionFactory());
     }
 
     @Override
-    public void handlePageException(Exception ex) throws IOException, ServletException {
+    public void handlePageException(Exception ex) throws IOException,
+            ServletException {
         // Should never be called since handleException() called with a
         // Throwable in the generated servlet.
         handlePageException((Throwable) ex);
@@ -574,13 +601,16 @@ public class PageContextImpl extends PageContext {
             throw new NullPointerException(Localizer.getMessage("jsp.error.page.nullThrowable"));
         }
 
-        if (errorPageURL != null && !errorPageURL.isEmpty()) {
+        if (errorPageURL != null && !errorPageURL.equals("")) {
 
             /*
-             * Set request attributes. Do not set the javax.servlet.error.exception attribute here (instead, set in the
-             * generated servlet code for the error page) in order to prevent the ErrorReportValve, which is invoked as
-             * part of forwarding the request to the error page, from throwing it if the response has not been committed
-             * (the response will have been committed if the error page is a JSP page).
+             * Set request attributes. Do not set the
+             * jakarta.servlet.error.exception attribute here (instead, set in the
+             * generated servlet code for the error page) in order to prevent
+             * the ErrorReportValve, which is invoked as part of forwarding the
+             * request to the error page, from throwing it if the response has
+             * not been committed (the response will have been committed if the
+             * error page is a JSP page).
              */
             request.setAttribute(EXCEPTION, t);
             request.setAttribute(RequestDispatcher.ERROR_STATUS_CODE,
@@ -618,39 +648,47 @@ public class PageContextImpl extends PageContext {
             if (t instanceof ServletException) {
                 throw (ServletException) t;
             }
-            Throwable rootCause = null;
-            if (t instanceof JspException || t instanceof ELException ||
-                    t instanceof javax.servlet.jsp.el.ELException) {
-                rootCause = t.getCause();
-            }
-            if (rootCause != null) {
-                throw new ServletException(t.getClass().getName() + ": " + t.getMessage(), rootCause);
-            }
-            // ELException is a runtime exception
             if (t instanceof RuntimeException) {
                 throw (RuntimeException) t;
             }
+
+            Throwable rootCause = null;
+            if (t instanceof JspException || t instanceof ELException ||
+                    t instanceof jakarta.servlet.jsp.el.ELException) {
+                rootCause = t.getCause();
+            }
+
+            if (rootCause != null) {
+                throw new ServletException(
+                        t.getClass().getName() + ": " + t.getMessage(), rootCause);
+            }
+
             throw new ServletException(t);
         }
     }
 
     /**
-     * Proprietary method to evaluate EL expressions. XXX - This method should go away once the EL interpreter moves out
-     * of JSTL and into its own project. For now, this is necessary because the standard machinery is too slow.
-     *
-     * @param expression   The expression to be evaluated
-     * @param expectedType The expected resulting type
-     * @param pageContext  The page context
-     * @param functionMap  Maps prefix and name to Method
+     * Proprietary method to evaluate EL expressions. XXX - This method should
+     * go away once the EL interpreter moves out of JSTL and into its own
+     * project. For now, this is necessary because the standard machinery is too
+     * slow.
      *
+     * @param expression
+     *            The expression to be evaluated
+     * @param expectedType
+     *            The expected resulting type
+     * @param pageContext
+     *            The page context
+     * @param functionMap
+     *            Maps prefix and name to Method
      * @return The result of the evaluation
-     *
      * @throws ELException If an error occurs during the evaluation
      */
-    public static Object proprietaryEvaluate(final String expression, final Class<?> expectedType,
-            final PageContext pageContext, final ProtectedFunctionMapper functionMap) throws ELException {
-        final ExpressionFactory exprFactory =
-                jspf.getJspApplicationContext(pageContext.getServletContext()).getExpressionFactory();
+    public static Object proprietaryEvaluate(final String expression,
+            final Class<?> expectedType, final PageContext pageContext,
+            final ProtectedFunctionMapper functionMap)
+            throws ELException {
+        final ExpressionFactory exprFactory = jspf.getJspApplicationContext(pageContext.getServletContext()).getExpressionFactory();
         ELContext ctx = pageContext.getELContext();
         ELContextImpl ctxImpl;
         if (ctx instanceof ELContextWrapper) {
@@ -691,6 +729,11 @@ public class PageContextImpl extends PageContext {
                     }
                 }
             }
+            if (servlet instanceof JspSourceDirectives) {
+                if (((JspSourceDirectives) servlet).getErrorOnELNotFound()) {
+                    elContext.putContext(NotFoundELResolver.class, Boolean.TRUE);
+                }
+            }
         }
         return this.elContext;
     }
