@@ -36,20 +36,19 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.Vector;
 import java.util.concurrent.ConcurrentHashMap;
 
-import javax.servlet.Filter;
-import javax.servlet.FilterRegistration;
-import javax.servlet.FilterRegistration.Dynamic;
-import javax.servlet.RequestDispatcher;
-import javax.servlet.Servlet;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRegistration;
-import javax.servlet.SessionCookieConfig;
-import javax.servlet.SessionTrackingMode;
-import javax.servlet.descriptor.JspConfigDescriptor;
+import jakarta.servlet.Filter;
+import jakarta.servlet.FilterRegistration;
+import jakarta.servlet.FilterRegistration.Dynamic;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.Servlet;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRegistration;
+import jakarta.servlet.SessionCookieConfig;
+import jakarta.servlet.SessionTrackingMode;
+import jakarta.servlet.descriptor.JspConfigDescriptor;
 
 import org.apache.jasper.Constants;
 import org.apache.jasper.JasperException;
@@ -66,8 +65,12 @@ import org.apache.tomcat.util.scan.StandardJarScanner;
 
 
 /**
- * Simple <code>ServletContext</code> implementation without HTTP-specific methods.
+ * Simple <code>ServletContext</code> implementation without
+ * HTTP-specific methods.
+ *
+ * @author Peter Rossbach (pr@webapp.de)
  */
+
 public class JspCServletContext implements ServletContext {
 
 
@@ -101,13 +104,13 @@ public class JspCServletContext implements ServletContext {
     /**
      * Merged web.xml for the application.
      */
-    private final WebXml webXml;
+    private WebXml webXml;
 
 
     private List<URL> resourceJARs;
 
 
-    private final JspConfigDescriptor jspConfigDescriptor;
+    private JspConfigDescriptor jspConfigDescriptor;
 
 
     /**
@@ -121,19 +124,21 @@ public class JspCServletContext implements ServletContext {
     /**
      * Create a new instance of this ServletContext implementation.
      *
-     * @param aLogWriter       PrintWriter which is used for <code>log()</code> calls
+     * @param aLogWriter PrintWriter which is used for <code>log()</code> calls
      * @param aResourceBaseURL Resource base URL
-     * @param classLoader      Class loader for this {@link ServletContext}
-     * @param validate         Should a validating parser be used to parse web.xml?
-     * @param blockExternal    Should external entities be blocked when parsing web.xml?
-     *
+     * @param classLoader   Class loader for this {@link ServletContext}
+     * @param validate      Should a validating parser be used to parse web.xml?
+     * @param blockExternal Should external entities be blocked when parsing
+     *                      web.xml?
      * @throws JasperException An error occurred building the merged web.xml
      */
-    public JspCServletContext(PrintWriter aLogWriter, URL aResourceBaseURL, ClassLoader classLoader, boolean validate,
-            boolean blockExternal) throws JasperException {
+    public JspCServletContext(PrintWriter aLogWriter, URL aResourceBaseURL,
+            ClassLoader classLoader, boolean validate, boolean blockExternal)
+            throws JasperException {
 
         myAttributes = new HashMap<>();
-        myParameters.put(Constants.XML_BLOCK_EXTERNAL_INIT_PARAM, String.valueOf(blockExternal));
+        myParameters.put(Constants.XML_BLOCK_EXTERNAL_INIT_PARAM,
+                String.valueOf(blockExternal));
         myLogWriter = aLogWriter;
         myResourceBaseURL = aResourceBaseURL;
         this.loader = classLoader;
@@ -141,19 +146,21 @@ public class JspCServletContext implements ServletContext {
         jspConfigDescriptor = webXml.getJspConfigDescriptor();
     }
 
-    private WebXml buildMergedWebXml(boolean validate, boolean blockExternal) throws JasperException {
+    private WebXml buildMergedWebXml(boolean validate, boolean blockExternal)
+            throws JasperException {
         WebXml webXml = new WebXml();
         WebXmlParser webXmlParser = new WebXmlParser(validate, validate, blockExternal);
         // Use this class's classloader as Ant will have set the TCCL to its own
         webXmlParser.setClassLoader(getClass().getClassLoader());
 
         try {
-            URL url = getResource(org.apache.tomcat.util.descriptor.web.Constants.WEB_XML_LOCATION);
+            URL url = getResource(
+                    org.apache.tomcat.util.descriptor.web.Constants.WEB_XML_LOCATION);
             if (!webXmlParser.parseWebXml(url, webXml, false)) {
                 throw new JasperException(Localizer.getMessage("jspc.error.invalidWebXml"));
             }
-        } catch (IOException ioe) {
-            throw new JasperException(ioe);
+        } catch (IOException e) {
+            throw new JasperException(e);
         }
 
         // if the application is metadata-complete then we can skip fragment processing
@@ -168,7 +175,7 @@ public class JspCServletContext implements ServletContext {
             return webXml;
         }
 
-        Map<String,WebXml> fragments = scanForFragments(webXmlParser);
+        Map<String, WebXml> fragments = scanForFragments(webXmlParser);
         Set<WebXml> orderedFragments = WebXml.orderWebFragments(webXml, fragments, this);
 
         // Find resource JARs
@@ -185,7 +192,11 @@ public class JspCServletContext implements ServletContext {
         List<URL> resourceJars = new ArrayList<>();
         // Build list of potential resource JARs. Use same ordering as ContextConfig
         Set<WebXml> resourceFragments = new LinkedHashSet<>(orderedFragments);
-        resourceFragments.addAll(fragments);
+        for (WebXml fragment : fragments) {
+            if (!resourceFragments.contains(fragment)) {
+                resourceFragments.add(fragment);
+            }
+        }
 
         for (WebXml resourceFragment : resourceFragments) {
             try (Jar jar = JarFactory.newInstance(resourceFragment.getURL())) {
@@ -202,14 +213,15 @@ public class JspCServletContext implements ServletContext {
     }
 
 
-    private Map<String,WebXml> scanForFragments(WebXmlParser webXmlParser) throws JasperException {
+    private Map<String, WebXml> scanForFragments(WebXmlParser webXmlParser) throws JasperException {
         StandardJarScanner scanner = new StandardJarScanner();
         // TODO - enabling this means initializing the classloader first in JspC
         scanner.setScanClassPath(false);
         // TODO - configure filter rules from Ant rather then system properties
         scanner.setJarScanFilter(new StandardJarScanFilter());
 
-        FragmentJarScannerCallback callback = new FragmentJarScannerCallback(webXmlParser, false, true);
+        FragmentJarScannerCallback callback =
+                new FragmentJarScannerCallback(webXmlParser, false, true);
         scanner.scan(JarScanType.PLUGGABILITY, this, callback);
         if (!callback.isOk()) {
             throw new JasperException(Localizer.getMessage("jspc.error.invalidFragment"));
@@ -220,66 +232,113 @@ public class JspCServletContext implements ServletContext {
 
     // --------------------------------------------------------- Public Methods
 
+    /**
+     * Return the specified context attribute, if any.
+     *
+     * @param name Name of the requested attribute
+     */
     @Override
     public Object getAttribute(String name) {
         return myAttributes.get(name);
     }
 
 
+    /**
+     * Return an enumeration of context attribute names.
+     */
     @Override
     public Enumeration<String> getAttributeNames() {
         return Collections.enumeration(myAttributes.keySet());
     }
 
 
+    /**
+     * Return the servlet context for the specified path.
+     *
+     * @param uripath Server-relative path starting with '/'
+     */
     @Override
     public ServletContext getContext(String uripath) {
         return null;
     }
 
 
+    /**
+     * Return the context path.
+     */
     @Override
     public String getContextPath() {
         return null;
     }
 
 
+    /**
+     * Return the specified context initialization parameter.
+     *
+     * @param name Name of the requested parameter
+     */
     @Override
     public String getInitParameter(String name) {
         return myParameters.get(name);
     }
 
 
+    /**
+     * Return an enumeration of the names of context initialization
+     * parameters.
+     */
     @Override
     public Enumeration<String> getInitParameterNames() {
         return Collections.enumeration(myParameters.keySet());
     }
 
 
+    /**
+     * Return the Servlet API major version number.
+     */
     @Override
     public int getMajorVersion() {
         return 4;
     }
 
 
+    /**
+     * Return the MIME type for the specified filename.
+     *
+     * @param file Filename whose MIME type is requested
+     */
     @Override
     public String getMimeType(String file) {
         return null;
     }
 
 
+    /**
+     * Return the Servlet API minor version number.
+     */
     @Override
     public int getMinorVersion() {
         return 0;
     }
 
 
+    /**
+     * Return a request dispatcher for the specified servlet name.
+     *
+     * @param name Name of the requested servlet
+     */
     @Override
     public RequestDispatcher getNamedDispatcher(String name) {
         return null;
     }
 
 
+    /**
+     * Return the real path for the specified context-relative
+     * virtual path.
+     *
+     * @param path The context-relative virtual path to resolve
+     */
     @Override
     public String getRealPath(String path) {
         if (!myResourceBaseURL.getProtocol().equals("file")) {
@@ -289,11 +348,7 @@ public class JspCServletContext implements ServletContext {
             return null;
         }
         try {
-            URL url = getResource(path);
-            if (url == null) {
-                return null;
-            }
-            File f = new File(url.toURI());
+            File f = new File(getResource(path).toURI());
             return f.getAbsolutePath();
         } catch (Throwable t) {
             ExceptionUtils.handleThrowable(t);
@@ -302,12 +357,26 @@ public class JspCServletContext implements ServletContext {
     }
 
 
+    /**
+     * Return a request dispatcher for the specified context-relative path.
+     *
+     * @param path Context-relative path for which to acquire a dispatcher
+     */
     @Override
     public RequestDispatcher getRequestDispatcher(String path) {
         return null;
     }
 
 
+    /**
+     * Return a URL object of a resource that is mapped to the
+     * specified context-relative path.
+     *
+     * @param path Context-relative path of the desired resource
+     *
+     * @exception MalformedURLException if the resource path is
+     *  not properly formed
+     */
     @Override
     public URL getResource(String path) throws MalformedURLException {
 
@@ -318,7 +387,7 @@ public class JspCServletContext implements ServletContext {
         // Strip leading '/'
         path = path.substring(1);
 
-        URL url;
+        URL url = null;
         try {
             URI uri = new URI(myResourceBaseURL.toExternalForm() + path);
             url = uri.toURL();
@@ -347,14 +416,16 @@ public class JspCServletContext implements ServletContext {
     }
 
 
+    /**
+     * Return an InputStream allowing access to the resource at the
+     * specified context-relative path.
+     *
+     * @param path Context-relative path of the desired resource
+     */
     @Override
     public InputStream getResourceAsStream(String path) {
         try {
-            URL url = getResource(path);
-            if (url == null) {
-                return null;
-            }
-            return url.openStream();
+            return getResource(path).openStream();
         } catch (Throwable t) {
             ExceptionUtils.handleThrowable(t);
             return null;
@@ -362,6 +433,12 @@ public class JspCServletContext implements ServletContext {
     }
 
 
+    /**
+     * Return the set of resource paths for the "directory" at the
+     * specified context path.
+     *
+     * @param path Context-relative base path
+     */
     @Override
     public Set<String> getResourcePaths(String path) {
 
@@ -373,7 +450,7 @@ public class JspCServletContext implements ServletContext {
         if (basePath != null) {
             File theBaseDir = new File(basePath);
             if (theBaseDir.isDirectory()) {
-                String[] theFiles = theBaseDir.list();
+                String theFiles[] = theBaseDir.list();
                 if (theFiles != null) {
                     for (String theFile : theFiles) {
                         File testFile = new File(basePath + File.separator + theFile);
@@ -394,9 +471,11 @@ public class JspCServletContext implements ServletContext {
             for (URL jarUrl : resourceJARs) {
                 try (Jar jar = JarFactory.newInstance(jarUrl)) {
                     jar.nextEntry();
-                    for (String entryName = jar.getEntryName(); entryName != null; jar.nextEntry(), entryName =
-                            jar.getEntryName()) {
-                        if (entryName.startsWith(jarPath) && entryName.length() > jarPath.length()) {
+                    for (String entryName = jar.getEntryName();
+                            entryName != null;
+                            jar.nextEntry(), entryName = jar.getEntryName()) {
+                        if (entryName.startsWith(jarPath) &&
+                                entryName.length() > jarPath.length()) {
                             // Let the Set implementation handle duplicates
                             int sep = entryName.indexOf('/', jarPath.length());
                             if (sep < 0) {
@@ -408,8 +487,8 @@ public class JspCServletContext implements ServletContext {
                             }
                         }
                     }
-                } catch (IOException ioe) {
-                    log(ioe.getMessage(), ioe);
+                } catch (IOException e) {
+                    log(e.getMessage(), e);
                 }
             }
         }
@@ -418,59 +497,41 @@ public class JspCServletContext implements ServletContext {
     }
 
 
+    /**
+     * Return descriptive information about this server.
+     */
     @Override
     public String getServerInfo() {
-        return "JspC/ApacheTomcat9";
+        return "JspC/ApacheTomcat10";
     }
 
 
     /**
-     * Return a null reference for the specified servlet name.
-     *
-     * @param name Name of the requested servlet
-     *
-     * @deprecated This method has been deprecated with no replacement
+     * Return the name of this servlet context.
      */
-    @Override
-    @Deprecated
-    public Servlet getServlet(String name) throws ServletException {
-        return null;
-    }
-
-
     @Override
     public String getServletContextName() {
         return getServerInfo();
     }
 
 
-    @Override
-    @Deprecated
-    public Enumeration<String> getServletNames() {
-        return new Vector<String>().elements();
-    }
-
-
-    @Override
-    @Deprecated
-    public Enumeration<Servlet> getServlets() {
-        return new Vector<Servlet>().elements();
-    }
-
-
+    /**
+     * Log the specified message.
+     *
+     * @param message The message to be logged
+     */
     @Override
     public void log(String message) {
         myLogWriter.println(message);
     }
 
 
-    @Override
-    @Deprecated
-    public void log(Exception exception, String message) {
-        log(message, exception);
-    }
-
-
+    /**
+     * Log the specified message and exception.
+     *
+     * @param message The message to be logged
+     * @param exception The exception to be logged
+     */
     @Override
     public void log(String message, Throwable exception) {
         myLogWriter.println(message);
@@ -478,12 +539,23 @@ public class JspCServletContext implements ServletContext {
     }
 
 
+    /**
+     * Remove the specified context attribute.
+     *
+     * @param name Name of the attribute to remove
+     */
     @Override
     public void removeAttribute(String name) {
         myAttributes.remove(name);
     }
 
 
+    /**
+     * Set or replace the specified context attribute.
+     *
+     * @param name Name of the context attribute to set
+     * @param value Corresponding attribute value
+     */
     @Override
     public void setAttribute(String name, Object value) {
         myAttributes.put(name, value);
@@ -491,13 +563,15 @@ public class JspCServletContext implements ServletContext {
 
 
     @Override
-    public FilterRegistration.Dynamic addFilter(String filterName, String className) {
+    public FilterRegistration.Dynamic addFilter(String filterName,
+            String className) {
         return null;
     }
 
 
     @Override
-    public ServletRegistration.Dynamic addServlet(String servletName, String className) {
+    public ServletRegistration.Dynamic addServlet(String servletName,
+            String className) {
         return null;
     }
 
@@ -521,7 +595,8 @@ public class JspCServletContext implements ServletContext {
 
 
     @Override
-    public void setSessionTrackingModes(Set<SessionTrackingMode> sessionTrackingModes) {
+    public void setSessionTrackingModes(
+            Set<SessionTrackingMode> sessionTrackingModes) {
         // Do nothing
     }
 
@@ -533,19 +608,22 @@ public class JspCServletContext implements ServletContext {
 
 
     @Override
-    public Dynamic addFilter(String filterName, Class<? extends Filter> filterClass) {
+    public Dynamic addFilter(String filterName,
+            Class<? extends Filter> filterClass) {
         return null;
     }
 
 
     @Override
-    public ServletRegistration.Dynamic addServlet(String servletName, Servlet servlet) {
+    public ServletRegistration.Dynamic addServlet(String servletName,
+            Servlet servlet) {
         return null;
     }
 
 
     @Override
-    public ServletRegistration.Dynamic addServlet(String servletName, Class<? extends Servlet> servletClass) {
+    public ServletRegistration.Dynamic addServlet(String servletName,
+            Class<? extends Servlet> servletClass) {
         return null;
     }
 
@@ -557,13 +635,15 @@ public class JspCServletContext implements ServletContext {
 
 
     @Override
-    public <T extends Filter> T createFilter(Class<T> c) throws ServletException {
+    public <T extends Filter> T createFilter(Class<T> c)
+            throws ServletException {
         return null;
     }
 
 
     @Override
-    public <T extends Servlet> T createServlet(Class<T> c) throws ServletException {
+    public <T extends Servlet> T createServlet(Class<T> c)
+            throws ServletException {
         return null;
     }
 
@@ -605,7 +685,8 @@ public class JspCServletContext implements ServletContext {
 
 
     @Override
-    public <T extends EventListener> T createListener(Class<T> c) throws ServletException {
+    public <T extends EventListener> T createListener(Class<T> c)
+            throws ServletException {
         return null;
     }
 
@@ -635,7 +716,7 @@ public class JspCServletContext implements ServletContext {
 
 
     @Override
-    public Map<String,? extends FilterRegistration> getFilterRegistrations() {
+    public Map<String, ? extends FilterRegistration> getFilterRegistrations() {
         return null;
     }
 
@@ -647,7 +728,7 @@ public class JspCServletContext implements ServletContext {
 
 
     @Override
-    public Map<String,? extends ServletRegistration> getServletRegistrations() {
+    public Map<String, ? extends ServletRegistration> getServletRegistrations() {
         return null;
     }
 
