@@ -24,13 +24,13 @@ import java.security.AccessController;
 import java.security.PrivilegedActionException;
 import java.security.PrivilegedExceptionAction;
 
-import javax.servlet.RequestDispatcher;
-import javax.servlet.ServletConfig;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.ServletConfig;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.jasper.Constants;
 import org.apache.jasper.EmbeddedServletOptions;
@@ -45,9 +45,20 @@ import org.apache.tomcat.PeriodicEventListener;
 import org.apache.tomcat.util.security.Escape;
 
 /**
- * The Jasper JSP engine. The servlet container is responsible for providing a URLClassLoader for the web application
- * context Jasper is being used in. Jasper will try to get the Tomcat ServletContext attribute for its ServletContext
- * class loader, if that fails, it uses the parent class loader. In either case, it must be a URLClassLoader.
+ * The JSP engine (a.k.a Jasper).
+ *
+ * The servlet container is responsible for providing a
+ * URLClassLoader for the web application context Jasper
+ * is being used in. Jasper will try get the Tomcat
+ * ServletContext attribute for its ServletContext class
+ * loader, if that fails, it uses the parent class loader.
+ * In either case, it must be a URLClassLoader.
+ *
+ * @author Anil K. Vijendran
+ * @author Harish Prabandham
+ * @author Remy Maucherat
+ * @author Kin-man Chung
+ * @author Glenn Nielsen
  */
 public class JspServlet extends HttpServlet implements PeriodicEventListener {
 
@@ -65,6 +76,9 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
     private String jspFile;
 
 
+    /*
+     * Initializes this JspServlet.
+     */
     @Override
     public void init(ServletConfig config) throws ServletException {
 
@@ -76,7 +90,8 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
         // Check for a custom Options implementation
         String engineOptionsName = config.getInitParameter("engineOptionsClass");
         if (Constants.IS_SECURITY_ENABLED && engineOptionsName != null) {
-            log.info(Localizer.getMessage("jsp.info.ignoreSetting", "engineOptionsClass", engineOptionsName));
+            log.info(Localizer.getMessage(
+                    "jsp.info.ignoreSetting", "engineOptionsClass", engineOptionsName));
             engineOptionsName = null;
         }
         if (engineOptionsName != null) {
@@ -88,11 +103,11 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
                 Constructor<?> ctor = engineOptionsClass.getConstructor(ctorSig);
                 Object[] args = { config, context };
                 options = (Options) ctor.newInstance(args);
-            } catch (Throwable t) {
-                Throwable throwable = ExceptionUtils.unwrapInvocationTargetException(t);
-                ExceptionUtils.handleThrowable(throwable);
+            } catch (Throwable e) {
+                e = ExceptionUtils.unwrapInvocationTargetException(e);
+                ExceptionUtils.handleThrowable(e);
                 // Need to localize this.
-                log.warn(Localizer.getMessage("jsp.warning.engineOptionsClass", engineOptionsName), throwable);
+                log.warn(Localizer.getMessage("jsp.warning.engineOptionsClass", engineOptionsName), e);
                 // Use the default Options implementation
                 options = new EmbeddedServletOptions(config, context);
             }
@@ -111,39 +126,42 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
                 throw new ServletException(Localizer.getMessage("jsp.error.no.jsp", jspFile), e);
             }
             try {
-                if (SecurityUtil.isPackageProtectionEnabled()) {
-                    AccessController.doPrivileged((PrivilegedExceptionAction<Object>) () -> {
-                        serviceJspFile(null, null, jspFile, true);
-                        return null;
-                    });
+                if (SecurityUtil.isPackageProtectionEnabled()){
+                   AccessController.doPrivileged((PrivilegedExceptionAction<Object>) () -> {
+                       serviceJspFile(null, null, jspFile, true);
+                       return null;
+                   });
                 } else {
                     serviceJspFile(null, null, jspFile, true);
                 }
-            } catch (IOException ioe) {
-                throw new ServletException(Localizer.getMessage("jsp.error.precompilation", jspFile), ioe);
+            } catch (IOException e) {
+                throw new ServletException(Localizer.getMessage("jsp.error.precompilation", jspFile), e);
             } catch (PrivilegedActionException e) {
                 Throwable t = e.getCause();
                 if (t instanceof ServletException) {
-                    throw (ServletException) t;
+                    throw (ServletException)t;
                 }
                 throw new ServletException(Localizer.getMessage("jsp.error.precompilation", jspFile), e);
             }
         }
 
         if (log.isDebugEnabled()) {
-            log.debug(Localizer.getMessage("jsp.message.scratch.dir.is", options.getScratchDir().toString()));
+            log.debug(Localizer.getMessage("jsp.message.scratch.dir.is",
+                    options.getScratchDir().toString()));
             log.debug(Localizer.getMessage("jsp.message.dont.modify.servlets"));
         }
     }
 
 
     /**
-     * Returns the number of JSPs for which JspServletWrappers exist, i.e., the number of JSPs that have been loaded
-     * into the webapp with which this JspServlet is associated.
-     * <p>
-     * This info may be used for monitoring purposes.
+     * Returns the number of JSPs for which JspServletWrappers exist, i.e.,
+     * the number of JSPs that have been loaded into the webapp with which
+     * this JspServlet is associated.
      *
-     * @return The number of JSPs that have been loaded into the webapp with which this JspServlet is associated
+     * <p>This info may be used for monitoring purposes.
+     *
+     * @return The number of JSPs that have been loaded into the webapp with
+     * which this JspServlet is associated
      */
     public int getJspCount() {
         return this.rctxt.getJspCount();
@@ -162,10 +180,11 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
 
     /**
      * Gets the number of JSPs that have been reloaded.
-     * <p>
-     * This info may be used for monitoring purposes.
      *
-     * @return The number of JSPs (in the webapp with which this JspServlet is associated) that have been reloaded
+     * <p>This info may be used for monitoring purposes.
+     *
+     * @return The number of JSPs (in the webapp with which this JspServlet is
+     * associated) that have been reloaded
      */
     public int getJspReloadCount() {
         return this.rctxt.getJspReloadCount();
@@ -174,11 +193,11 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
 
     /**
      * Gets the number of JSPs that are in the JSP limiter queue
-     * <p>
-     * This info may be used for monitoring purposes.
      *
-     * @return The number of JSPs (in the webapp with which this JspServlet is associated) that are in the JSP limiter
-     *             queue
+     * <p>This info may be used for monitoring purposes.
+     *
+     * @return The number of JSPs (in the webapp with which this JspServlet is
+     * associated) that are in the JSP limiter queue
      */
     public int getJspQueueLength() {
         return this.rctxt.getJspQueueLength();
@@ -187,10 +206,11 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
 
     /**
      * Gets the number of JSPs that have been unloaded.
-     * <p>
-     * This info may be used for monitoring purposes.
      *
-     * @return The number of JSPs (in the webapp with which this JspServlet is associated) that have been unloaded
+     * <p>This info may be used for monitoring purposes.
+     *
+     * @return The number of JSPs (in the webapp with which this JspServlet is
+     * associated) that have been unloaded
      */
     public int getJspUnloadCount() {
         return this.rctxt.getJspUnloadCount();
@@ -198,37 +218,39 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
 
 
     /**
-     * <p>
-     * Look for a <em>precompilation request</em> as described in Section 8.4.2 of the JSP 1.2 Specification.
-     * <strong>WARNING</strong> - we cannot use <code>request.getParameter()</code> for this, because that will trigger
-     * parsing all of the request parameters, and not give a servlet the opportunity to call
-     * <code>request.setCharacterEncoding()</code> first.
-     * </p>
+     * <p>Look for a <em>precompilation request</em> as described in
+     * Section 8.4.2 of the JSP 1.2 Specification.  <strong>WARNING</strong> -
+     * we cannot use <code>request.getParameter()</code> for this, because
+     * that will trigger parsing all of the request parameters, and not give
+     * a servlet the opportunity to call
+     * <code>request.setCharacterEncoding()</code> first.</p>
      *
      * @param request The servlet request we are processing
      *
-     * @exception ServletException if an invalid parameter value for the <code>jsp_precompile</code> parameter name is
-     *                                 specified
+     * @exception ServletException if an invalid parameter value for the
+     *  <code>jsp_precompile</code> parameter name is specified
      */
     boolean preCompile(HttpServletRequest request) throws ServletException {
 
+        String precompileParameter = rctxt.getOptions().getJspPrecompilationQueryParameter();
         String queryString = request.getQueryString();
         if (queryString == null) {
             return false;
         }
-        int start = queryString.indexOf(Constants.PRECOMPILE);
+        int start = queryString.indexOf(precompileParameter);
         if (start < 0) {
             return false;
         }
-        queryString = queryString.substring(start + Constants.PRECOMPILE.length());
+        queryString =
+            queryString.substring(start + precompileParameter.length());
         if (queryString.length() == 0) {
-            return true; // ?jsp_precompile
+            return true;             // ?jsp_precompile
         }
         if (queryString.startsWith("&")) {
-            return true; // ?jsp_precompile&foo=bar...
+            return true;             // ?jsp_precompile&foo=bar...
         }
         if (!queryString.startsWith("=")) {
-            return false; // part of some other name or value
+            return false;            // part of some other name or value
         }
         int limit = queryString.length();
         int ampersand = queryString.indexOf('&');
@@ -237,45 +259,51 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
         }
         String value = queryString.substring(1, limit);
         if (value.equals("true")) {
-            return true; // ?jsp_precompile=true
+            return true;             // ?jsp_precompile=true
         } else if (value.equals("false")) {
             // Spec says if jsp_precompile=false, the request should not
             // be delivered to the JSP page; the easiest way to implement
             // this is to set the flag to true, and precompile the page anyway.
             // This still conforms to the spec, since it says the
             // precompilation request can be ignored.
-            return true; // ?jsp_precompile=false
+            return true;             // ?jsp_precompile=false
         } else {
-            throw new ServletException(
-                    Localizer.getMessage("jsp.error.precompilation.parameter", Constants.PRECOMPILE, value));
+            throw new ServletException(Localizer.getMessage("jsp.error.precompilation.parameter",
+                    precompileParameter, value));
         }
 
     }
 
 
     @Override
-    public void service(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
+    public void service (HttpServletRequest request, HttpServletResponse response)
+            throws ServletException, IOException {
 
         // jspFile may be configured as an init-param for this servlet instance
         String jspUri = jspFile;
 
         if (jspUri == null) {
             /*
-             * Check to see if the requested JSP has been the target of a RequestDispatcher.include()
+             * Check to see if the requested JSP has been the target of a
+             * RequestDispatcher.include()
              */
-            jspUri = (String) request.getAttribute(RequestDispatcher.INCLUDE_SERVLET_PATH);
+            jspUri = (String) request.getAttribute(
+                    RequestDispatcher.INCLUDE_SERVLET_PATH);
             if (jspUri != null) {
                 /*
-                 * Requested JSP has been target of RequestDispatcher.include(). Its path is assembled from the relevant
-                 * javax.servlet.include.* request attributes
+                 * Requested JSP has been target of
+                 * RequestDispatcher.include(). Its path is assembled from the
+                 * relevant jakarta.servlet.include.* request attributes
                  */
-                String pathInfo = (String) request.getAttribute(RequestDispatcher.INCLUDE_PATH_INFO);
+                String pathInfo = (String) request.getAttribute(
+                        RequestDispatcher.INCLUDE_PATH_INFO);
                 if (pathInfo != null) {
                     jspUri += pathInfo;
                 }
             } else {
                 /*
-                 * Requested JSP has not been the target of a RequestDispatcher.include(). Reconstruct its path from the
+                 * Requested JSP has not been the target of a
+                 * RequestDispatcher.include(). Reconstruct its path from the
                  * request's getServletPath() and getPathInfo()
                  */
                 jspUri = request.getServletPath();
@@ -286,13 +314,13 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
             }
         }
 
-        if (log.isTraceEnabled()) {
-            log.trace("JspEngine --> " + jspUri);
-            log.trace("\t     ServletPath: " + request.getServletPath());
-            log.trace("\t        PathInfo: " + request.getPathInfo());
-            log.trace("\t        RealPath: " + context.getRealPath(jspUri));
-            log.trace("\t      RequestURI: " + request.getRequestURI());
-            log.trace("\t     QueryString: " + request.getQueryString());
+        if (log.isDebugEnabled()) {
+            log.debug("JspEngine --> " + jspUri);
+            log.debug("\t     ServletPath: " + request.getServletPath());
+            log.debug("\t        PathInfo: " + request.getPathInfo());
+            log.debug("\t        RealPath: " + context.getRealPath(jspUri));
+            log.debug("\t      RequestURI: " + request.getRequestURI());
+            log.debug("\t     QueryString: " + request.getQueryString());
         }
 
         try {
@@ -300,17 +328,17 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
             serviceJspFile(request, response, jspUri, precompile);
         } catch (RuntimeException | IOException | ServletException e) {
             throw e;
-        } catch (Throwable t) {
-            ExceptionUtils.handleThrowable(t);
-            throw new ServletException(t);
+        } catch (Throwable e) {
+            ExceptionUtils.handleThrowable(e);
+            throw new ServletException(e);
         }
 
     }
 
     @Override
     public void destroy() {
-        if (log.isTraceEnabled()) {
-            log.trace("JspServlet.destroy()");
+        if (log.isDebugEnabled()) {
+            log.debug("JspServlet.destroy()");
         }
 
         rctxt.destroy();
@@ -325,12 +353,14 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
 
     // -------------------------------------------------------- Private Methods
 
-    private void serviceJspFile(HttpServletRequest request, HttpServletResponse response, String jspUri,
-            boolean precompile) throws ServletException, IOException {
+    private void serviceJspFile(HttpServletRequest request,
+                                HttpServletResponse response, String jspUri,
+                                boolean precompile)
+        throws ServletException, IOException {
 
         JspServletWrapper wrapper = rctxt.getWrapper(jspUri);
         if (wrapper == null) {
-            synchronized (this) {
+            synchronized(this) {
                 wrapper = rctxt.getWrapper(jspUri);
                 if (wrapper == null) {
                     // Check if the requested JSP page exists, to avoid
@@ -339,8 +369,9 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
                         handleMissingResource(request, response, jspUri);
                         return;
                     }
-                    wrapper = new JspServletWrapper(config, options, jspUri, rctxt);
-                    rctxt.addWrapper(jspUri, wrapper);
+                    wrapper = new JspServletWrapper(config, options, jspUri,
+                                                    rctxt);
+                    rctxt.addWrapper(jspUri,wrapper);
                 }
             }
         }
@@ -354,12 +385,14 @@ public class JspServlet extends HttpServlet implements PeriodicEventListener {
     }
 
 
-    private void handleMissingResource(HttpServletRequest request, HttpServletResponse response, String jspUri)
+    private void handleMissingResource(HttpServletRequest request,
+            HttpServletResponse response, String jspUri)
             throws ServletException, IOException {
 
-        String includeRequestUri = (String) request.getAttribute(RequestDispatcher.INCLUDE_REQUEST_URI);
+        String includeRequestUri =
+            (String)request.getAttribute(RequestDispatcher.INCLUDE_REQUEST_URI);
 
-        String msg = Localizer.getMessage("jsp.error.file.not.found", jspUri);
+        String msg = Localizer.getMessage("jsp.error.file.not.found",jspUri);
         if (includeRequestUri != null) {
             // This file was included. Throw an exception as
             // a response.sendError() will be ignored
