@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      https://www.apache.org/licenses/LICENSE-2.0
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -24,6 +24,7 @@ import java.sql.SQLException;
 import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.LinkedHashMap;
@@ -49,12 +50,12 @@ import org.apache.tomcat.dbcp.pool2.impl.BaseObjectPoolConfig;
 import org.apache.tomcat.dbcp.pool2.impl.GenericObjectPoolConfig;
 
 /**
- * JNDI object factory that creates an instance of {@link BasicDataSource} that has been configured based on the
- * {@link RefAddr} values of the specified {@code Reference}, which must match the names and data types of the
- * {@link BasicDataSource} bean properties with the following exceptions:
+ * JNDI object factory that creates an instance of {@code BasicDataSource} that has been configured based on the
+ * {@code RefAddr} values of the specified {@code Reference}, which must match the names and data types of the
+ * {@code BasicDataSource} bean properties with the following exceptions:
  * <ul>
  * <li>{@code connectionInitSqls} must be passed to this factory as a single String using semicolon to delimit the
- * statements whereas {@link BasicDataSource} requires a collection of Strings.</li>
+ * statements whereas {@code BasicDataSource} requires a collection of Strings.</li>
  * </ul>
  *
  * @since 2.0
@@ -120,17 +121,6 @@ public class BasicDataSourceFactory implements ObjectFactory {
      */
     private static final String PROP_DISCONNECTION_SQL_CODES = "disconnectionSqlCodes";
 
-    /**
-     * Property key for specifying the SQL State codes that should be ignored during disconnection checks.
-     * <p>
-     * The value for this property must be a comma-separated string of SQL State codes, where each code represents
-     * a state that will be excluded from being treated as a fatal disconnection. The expected format is a series
-     * of SQL State codes separated by commas, with no spaces between them (e.g., "08003,08004").
-     * </p>
-     * @since 2.13.0
-     */
-    private static final String PROP_DISCONNECTION_IGNORE_SQL_CODES = "disconnectionIgnoreSqlCodes";
-
     /*
      * Block with obsolete properties from DBCP 1.x. Warn users that these are ignored and they should use the 2.x
      * properties.
@@ -160,8 +150,8 @@ public class BasicDataSourceFactory implements ObjectFactory {
             PROP_CLEAR_STATEMENT_POOL_ON_RETURN,
             PROP_MAX_OPEN_PREPARED_STATEMENTS, PROP_CONNECTION_PROPERTIES, PROP_MAX_CONN_LIFETIME_MILLIS,
             PROP_LOG_EXPIRED_CONNECTIONS, PROP_ROLLBACK_ON_RETURN, PROP_ENABLE_AUTO_COMMIT_ON_RETURN,
-            PROP_DEFAULT_QUERY_TIMEOUT, PROP_FAST_FAIL_VALIDATION, PROP_DISCONNECTION_SQL_CODES, PROP_DISCONNECTION_IGNORE_SQL_CODES,
-            PROP_JMX_NAME, PROP_REGISTER_CONNECTION_MBEAN, PROP_CONNECTION_FACTORY_CLASS_NAME);
+            PROP_DEFAULT_QUERY_TIMEOUT, PROP_FAST_FAIL_VALIDATION, PROP_DISCONNECTION_SQL_CODES, PROP_JMX_NAME,
+            PROP_REGISTER_CONNECTION_MBEAN, PROP_CONNECTION_FACTORY_CLASS_NAME);
 
     /**
      * Obsolete properties from DBCP 1.x. with warning strings suggesting new properties. LinkedHashMap will guarantee
@@ -174,11 +164,11 @@ public class BasicDataSourceFactory implements ObjectFactory {
                 "Property " + NUPROP_MAX_ACTIVE + " is not used in DBCP2, use " + PROP_MAX_TOTAL + " instead. "
                         + PROP_MAX_TOTAL + " default value is " + GenericObjectPoolConfig.DEFAULT_MAX_TOTAL + ".");
         NUPROP_WARNTEXT.put(NUPROP_REMOVE_ABANDONED,
-                "Property " + NUPROP_REMOVE_ABANDONED + " is not used in DBCP2, use one or both of "
+                "Property " + NUPROP_REMOVE_ABANDONED + " is not used in DBCP2," + " use one or both of "
                         + PROP_REMOVE_ABANDONED_ON_BORROW + " or " + PROP_REMOVE_ABANDONED_ON_MAINTENANCE + " instead. "
                         + "Both have default value set to false.");
         NUPROP_WARNTEXT.put(NUPROP_MAXWAIT,
-                "Property " + NUPROP_MAXWAIT + " is not used in DBCP2 , use " + PROP_MAX_WAIT_MILLIS + " instead. "
+                "Property " + NUPROP_MAXWAIT + " is not used in DBCP2" + " , use " + PROP_MAX_WAIT_MILLIS + " instead. "
                         + PROP_MAX_WAIT_MILLIS + " default value is " + BaseObjectPoolConfig.DEFAULT_MAX_WAIT
                         + ".");
     }
@@ -238,32 +228,25 @@ public class BasicDataSourceFactory implements ObjectFactory {
         getOptional(properties, PROP_DEFAULT_TRANSACTION_ISOLATION).ifPresent(value -> {
             value = value.toUpperCase(Locale.ROOT);
             int level = PoolableConnectionFactory.UNKNOWN_TRANSACTION_ISOLATION;
-            switch (value) {
-                case "NONE":
-                    level = Connection.TRANSACTION_NONE;
-                    break;
-                case "READ_COMMITTED":
-                    level = Connection.TRANSACTION_READ_COMMITTED;
-                    break;
-                case "READ_UNCOMMITTED":
-                    level = Connection.TRANSACTION_READ_UNCOMMITTED;
-                    break;
-                case "REPEATABLE_READ":
-                    level = Connection.TRANSACTION_REPEATABLE_READ;
-                    break;
-                case "SERIALIZABLE":
-                    level = Connection.TRANSACTION_SERIALIZABLE;
-                    break;
-                default:
-                    try {
-                        level = Integer.parseInt(value);
-                    } catch (final NumberFormatException e) {
-                        System.err.println("Could not parse defaultTransactionIsolation: " + value);
-                        System.err.println("WARNING: defaultTransactionIsolation not set");
-                        System.err.println("using default value of database driver");
-                        level = PoolableConnectionFactory.UNKNOWN_TRANSACTION_ISOLATION;
-                    }
-                    break;
+            if ("NONE".equals(value)) {
+                level = Connection.TRANSACTION_NONE;
+            } else if ("READ_COMMITTED".equals(value)) {
+                level = Connection.TRANSACTION_READ_COMMITTED;
+            } else if ("READ_UNCOMMITTED".equals(value)) {
+                level = Connection.TRANSACTION_READ_UNCOMMITTED;
+            } else if ("REPEATABLE_READ".equals(value)) {
+                level = Connection.TRANSACTION_REPEATABLE_READ;
+            } else if ("SERIALIZABLE".equals(value)) {
+                level = Connection.TRANSACTION_SERIALIZABLE;
+            } else {
+                try {
+                    level = Integer.parseInt(value);
+                } catch (final NumberFormatException e) {
+                    System.err.println("Could not parse defaultTransactionIsolation: " + value);
+                    System.err.println("WARNING: defaultTransactionIsolation not set");
+                    System.err.println("using default value of database driver");
+                    level = PoolableConnectionFactory.UNKNOWN_TRANSACTION_ISOLATION;
+                }
             }
             dataSource.setDefaultTransactionIsolation(level);
         });
@@ -305,10 +288,9 @@ public class BasicDataSourceFactory implements ObjectFactory {
 
         final String value = properties.getProperty(PROP_CONNECTION_PROPERTIES);
         if (value != null) {
-            final Properties connectionProperties = getProperties(value);
-            for (final Object key : connectionProperties.keySet()) {
-                final String propertyName = Objects.toString(key);
-                dataSource.addConnectionProperty(propertyName, connectionProperties.getProperty(propertyName));
+            for (final Object key : getProperties(value).keySet()) {
+                final String propertyName = Objects.toString(key, null);
+                dataSource.addConnectionProperty(propertyName, getProperties(value).getProperty(propertyName));
             }
         }
 
@@ -321,7 +303,6 @@ public class BasicDataSourceFactory implements ObjectFactory {
         acceptDurationOfSeconds(properties, PROP_DEFAULT_QUERY_TIMEOUT, dataSource::setDefaultQueryTimeout);
         acceptBoolean(properties, PROP_FAST_FAIL_VALIDATION, dataSource::setFastFailValidation);
         getOptional(properties, PROP_DISCONNECTION_SQL_CODES).ifPresent(v -> dataSource.setDisconnectionSqlCodes(parseList(v, ',')));
-        getOptional(properties, PROP_DISCONNECTION_IGNORE_SQL_CODES).ifPresent(v -> dataSource.setDisconnectionIgnoreSqlCodes(parseList(v, ',')));
         acceptString(properties, PROP_CONNECTION_FACTORY_CLASS_NAME, dataSource::setConnectionFactoryClassName);
 
         // DBCP-215
@@ -350,7 +331,7 @@ public class BasicDataSourceFactory implements ObjectFactory {
         if (propText != null) {
             try {
                 p.load(new ByteArrayInputStream(propText.replace(';', '\n').getBytes(StandardCharsets.ISO_8859_1)));
-            } catch (final IOException e) {
+            } catch (IOException e) {
                 throw new SQLException(propText, e);
             }
         }
@@ -358,7 +339,7 @@ public class BasicDataSourceFactory implements ObjectFactory {
     }
 
     /**
-     * Parses list of property values from a delimited string
+     * Parse list of property values from a delimited string
      *
      * @param value
      *            delimited list of values
@@ -366,9 +347,9 @@ public class BasicDataSourceFactory implements ObjectFactory {
      *            character used to separate values in the list
      * @return String Collection of values
      */
-    private static List<String> parseList(final String value, final char delimiter) {
+    private static Collection<String> parseList(final String value, final char delimiter) {
         final StringTokenizer tokenizer = new StringTokenizer(value, Character.toString(delimiter));
-        final List<String> tokens = new ArrayList<>(tokenizer.countTokens());
+        final Collection<String> tokens = new ArrayList<>(tokenizer.countTokens());
         while (tokenizer.hasMoreTokens()) {
             tokens.add(tokenizer.nextToken());
         }
@@ -376,14 +357,7 @@ public class BasicDataSourceFactory implements ObjectFactory {
     }
 
     /**
-     * Constructs a new instance.
-     */
-    public BasicDataSourceFactory() {
-        // empty
-    }
-
-    /**
-     * Creates and return a new {@link BasicDataSource} instance. If no instance can be created, return
+     * Creates and return a new {@code BasicDataSource} instance. If no instance can be created, return
      * {@code null} instead.
      *
      * @param obj
@@ -446,18 +420,20 @@ public class BasicDataSourceFactory implements ObjectFactory {
      *            container for info messages
      */
     private void validatePropertyNames(final Reference ref, final Name name, final List<String> warnMessages,
-            final List<String> infoMessages) {
+        final List<String> infoMessages) {
         final String nameString = name != null ? "Name = " + name.toString() + " " : "";
-        NUPROP_WARNTEXT.forEach((propertyName, value) -> {
-            final RefAddr ra = ref.get(propertyName);
-            if (ra != null && !ALL_PROPERTY_NAMES.contains(ra.getType())) {
-                final StringBuilder stringBuilder = new StringBuilder(nameString);
-                final String propertyValue = Objects.toString(ra.getContent(), null);
-                stringBuilder.append(value).append(" You have set value of \"").append(propertyValue).append("\" for \"").append(propertyName)
+        if (NUPROP_WARNTEXT != null && !NUPROP_WARNTEXT.isEmpty()) {
+            NUPROP_WARNTEXT.forEach((propertyName, value) -> {
+                final RefAddr ra = ref.get(propertyName);
+                if (ra != null && !ALL_PROPERTY_NAMES.contains(ra.getType())) {
+                    final StringBuilder stringBuilder = new StringBuilder(nameString);
+                    final String propertyValue = Objects.toString(ra.getContent(), null);
+                    stringBuilder.append(value).append(" You have set value of \"").append(propertyValue).append("\" for \"").append(propertyName)
                         .append("\" property, which is being ignored.");
-                warnMessages.add(stringBuilder.toString());
-            }
-        });
+                    warnMessages.add(stringBuilder.toString());
+                }
+            });
+        }
 
         final Enumeration<RefAddr> allRefAddrs = ref.getAll();
         while (allRefAddrs.hasMoreElements()) {
@@ -469,7 +445,7 @@ public class BasicDataSourceFactory implements ObjectFactory {
                 final String propertyValue = Objects.toString(ra.getContent(), null);
                 final StringBuilder stringBuilder = new StringBuilder(nameString);
                 stringBuilder.append("Ignoring unknown property: ").append("value of \"").append(propertyValue).append("\" for \"").append(propertyName)
-                        .append("\" property");
+                    .append("\" property");
                 infoMessages.add(stringBuilder.toString());
             }
         }
