@@ -13,6 +13,7 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ *
  */
 package org.apache.tomcat.dbcp.dbcp2;
 
@@ -49,9 +50,7 @@ public final class Utils {
     @Deprecated
     public static final boolean IS_SECURITY_ENABLED = isSecurityEnabled();
 
-    /**
-     * Any SQL_STATE starting with this value is considered a fatal disconnect.
-     */
+    /** Any SQL_STATE starting with this value is considered a fatal disconnect */
     public static final String DISCONNECTION_SQL_CODE_PREFIX = "08";
 
     /**
@@ -82,27 +81,6 @@ public final class Utils {
         DISCONNECTION_SQL_CODES.add("JZ0C1"); // Sybase disconnect error
     }
 
-    /**
-     * Checks for conflicts between two collections.
-     * <p>
-     * If any overlap is found between the two provided collections, an {@link IllegalArgumentException} is thrown.
-     * </p>
-     *
-     * @param codes1 The first collection of SQL state codes.
-     * @param codes2 The second collection of SQL state codes.
-     * @throws IllegalArgumentException if any codes overlap between the two collections.
-     * @since 2.13.0
-     */
-    static void checkSqlCodes(final Collection<String> codes1, final Collection<String> codes2) {
-        if (codes1 != null && codes2 != null) {
-            final Set<String> test = new HashSet<>(codes1);
-            test.retainAll(codes2);
-            if (!test.isEmpty()) {
-                throw new IllegalArgumentException(test + " cannot be in both disconnectionSqlCodes and disconnectionIgnoreSqlCodes.");
-            }
-        }
-    }
-
     /**
      * Clones the given char[] if not null.
      *
@@ -137,7 +115,7 @@ public final class Utils {
      * @param exceptionHandler Consumes exception thrown closing this resource.
      * @since 2.10.0
      */
-    public static void close(final AutoCloseable autoCloseable, final Consumer<Exception> exceptionHandler) {
+    public static void close(AutoCloseable autoCloseable, final Consumer<Exception> exceptionHandler) {
         if (autoCloseable != null) {
             try {
                 autoCloseable.close();
@@ -202,7 +180,7 @@ public final class Utils {
      * <li>JZ0C0 (Sybase disconnect error)</li>
      * <li>JZ0C1 (Sybase disconnect error)</li>
      * </ul>
-     * @return A copy SQL codes of fatal connection errors.
+     * @return SQL codes of fatal connection errors.
      * @since 2.10.0
      */
     public static Set<String> getDisconnectionSqlCodes() {
@@ -235,17 +213,6 @@ public final class Utils {
         return mf.format(args, new StringBuffer(), null).toString();
     }
 
-    /**
-     * Checks if the given SQL state corresponds to a fatal connection error.
-     *
-     * @param sqlState the SQL state to check.
-     * @return true if the SQL state is a fatal connection error, false otherwise.
-     * @since 2.13.0
-     */
-    static boolean isDisconnectionSqlCode(final String sqlState) {
-        return DISCONNECTION_SQL_CODES.contains(sqlState);
-    }
-
     static boolean isEmpty(final Collection<?> collection) {
         return collection == null || collection.isEmpty();
     }
@@ -274,18 +241,11 @@ public final class Utils {
         return value == null ? null : String.valueOf(value);
     }
 
-    /**
-     * Throws a LifetimeExceededException if the given pooled object's lifetime has exceeded a maximum duration.
-     *
-     * @param p           The pooled object to test.
-     * @param maxDuration The maximum lifetime.
-     * @throws LifetimeExceededException Thrown if the given pooled object's lifetime has exceeded a maximum duration.
-     */
     public static void validateLifetime(final PooledObject<?> p, final Duration maxDuration) throws LifetimeExceededException {
         if (maxDuration.compareTo(Duration.ZERO) > 0) {
             final Duration lifetimeDuration = Duration.between(p.getCreateInstant(), Instant.now());
             if (lifetimeDuration.compareTo(maxDuration) > 0) {
-                throw new LifetimeExceededException(getMessage("connectionFactory.lifetimeExceeded", lifetimeDuration, maxDuration));
+                throw new LifetimeExceededException(Utils.getMessage("connectionFactory.lifetimeExceeded", lifetimeDuration, maxDuration));
             }
         }
     }
