@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      https://www.apache.org/licenses/LICENSE-2.0
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,12 +20,13 @@ import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.Objects;
 
-import javax.transaction.TransactionManager;
-import javax.transaction.TransactionSynchronizationRegistry;
 import javax.transaction.xa.XAException;
 import javax.transaction.xa.XAResource;
 import javax.transaction.xa.Xid;
 
+import jakarta.transaction.TransactionManager;
+import jakarta.transaction.TransactionSynchronizationRegistry;
+
 import org.apache.tomcat.dbcp.dbcp2.ConnectionFactory;
 
 /**
@@ -59,7 +60,7 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
         private boolean originalAutoCommit; // @GuardedBy("this")
 
         /**
-         * Constructs a new instance for a given connection.
+         * Construct a new instance for a given connection.
          *
          * @param localTransaction A connection.
          */
@@ -102,7 +103,7 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
                     connection.commit();
                 }
             } catch (final SQLException e) {
-                throw newXAException("Commit failed.", e);
+                throw (XAException) new XAException().initCause(e);
             } finally {
                 try {
                     connection.setAutoCommit(originalAutoCommit);
@@ -179,10 +180,6 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
             return this == xaResource;
         }
 
-        private XAException newXAException(final String message, final SQLException cause) {
-            return (XAException) new XAException(message).initCause(cause);
-        }
-
         /**
          * This method does nothing since the LocalXAConnection does not support two-phase-commit. This method will
          * return XAResource.XA_RDONLY if the connection isReadOnly(). This assumes that the physical connection is
@@ -204,18 +201,18 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
                     connection.setAutoCommit(originalAutoCommit);
 
                     // tell the transaction manager we are read only
-                    return XA_RDONLY;
+                    return XAResource.XA_RDONLY;
                 }
             } catch (final SQLException ignored) {
                 // no big deal
             }
 
             // this is a local (one phase) only connection, so we can't prepare
-            return XA_OK;
+            return XAResource.XA_OK;
         }
 
         /**
-         * Always returns a zero length Xid array. The LocalXAConnectionFactory cannot support recovery, so no xids
+         * Always returns a zero length Xid array. The LocalXAConnectionFactory can not support recovery, so no xids
          * will ever be found.
          *
          * @param flag
@@ -245,7 +242,7 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
             try {
                 connection.rollback();
             } catch (final SQLException e) {
-                throw newXAException("Rollback failed.", e);
+                throw (XAException) new XAException().initCause(e);
             } finally {
                 try {
                     connection.setAutoCommit(originalAutoCommit);
@@ -269,7 +266,7 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
         }
 
         /**
-         * Signals that a connection has been enrolled in a transaction. This method saves off the current auto
+         * Signals that a the connection has been enrolled in a transaction. This method saves off the current auto
          * commit flag, and then disables auto commit. The original auto commit setting is restored when the transaction
          * completes.
          *
@@ -283,29 +280,35 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
          */
         @Override
         public synchronized void start(final Xid xid, final int flag) throws XAException {
-            if (flag == TMNOFLAGS) {
+            if (flag == XAResource.TMNOFLAGS) {
                 // first time in this transaction
+
                 // make sure we aren't already in another tx
                 if (this.currentXid != null) {
                     throw new XAException("Already enlisted in another transaction with xid " + xid);
                 }
-                // save off the current auto commit flag, so it can be restored after the transaction completes
+
+                // save off the current auto commit flag so it can be restored after the transaction completes
                 try {
                     originalAutoCommit = connection.getAutoCommit();
                 } catch (final SQLException ignored) {
                     // no big deal, just assume it was off
                     originalAutoCommit = true;
                 }
+
                 // update the auto commit flag
                 try {
                     connection.setAutoCommit(false);
                 } catch (final SQLException e) {
-                    throw newXAException("Count not turn off auto commit for a XA transaction", e);
+                    throw (XAException) new XAException("Count not turn off auto commit for a XA transaction")
+                            .initCause(e);
                 }
+
                 this.currentXid = xid;
-            } else if (flag == TMRESUME) {
+            } else if (flag == XAResource.TMRESUME) {
                 if (!xid.equals(this.currentXid)) {
-                    throw new XAException("Attempting to resume in different transaction: expected " + this.currentXid + ", but was " + xid);
+                    throw new XAException("Attempting to resume in different transaction: expected " + this.currentXid
+                            + ", but was " + xid);
                 }
             } else {
                 throw new XAException("Unknown start flag " + flag);
@@ -359,15 +362,13 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
         // create a XAResource to manage the connection during XA transactions
         final XAResource xaResource = new LocalXAResource(connection);
 
-        // register the XA resource for the connection
+        // register the xa resource for the connection
         transactionRegistry.registerConnection(connection, xaResource);
 
         return connection;
     }
 
     /**
-     * Gets the connection factory.
-     *
      * @return The connection factory.
      * @since 2.6.0
      */
@@ -375,11 +376,6 @@ public class LocalXAConnectionFactory implements XAConnectionFactory {
         return connectionFactory;
     }
 
-    /**
-     * Gets the transaction registry.
-     *
-     * @return The transaction registry.
-     */
     @Override
     public TransactionRegistry getTransactionRegistry() {
         return transactionRegistry;
