@@ -26,24 +26,24 @@ import org.apache.tomcat.util.bcel.Const;
  *
  * <pre>
  * element_value {
- *    u1 tag;
- *    union {
- *        u2 const_value_index;
+ *     u1 tag;
+ *     union {
+ *         u2 const_value_index;
  *
- *        {   u2 type_name_index;
- *            u2 const_name_index;
- *        } enum_const_value;
+ *         {   u2 type_name_index;
+ *             u2 const_name_index;
+ *         } enum_const_value;
  *
- *        u2 class_info_index;
+ *         u2 class_info_index;
  *
- *        annotation annotation_value;
+ *         annotation annotation_value;
  *
- *        {   u2            num_values;
- *            element_value values[num_values];
- *        } array_value;
- *    } value;
- *}
- *</pre>
+ *         {   u2            num_values;
+ *             element_value values[num_values];
+ *         } array_value;
+ *     } value;
+ * }
+ * </pre>
  */
 public abstract class ElementValue {
 
@@ -119,7 +119,7 @@ public abstract class ElementValue {
             final int numArrayVals = input.readUnsignedShort();
             final ElementValue[] evalues = new ElementValue[numArrayVals];
             for (int j = 0; j < numArrayVals; j++) {
-                evalues[j] = ElementValue.readElementValue(input, cpool, arrayNesting);
+                evalues[j] = readElementValue(input, cpool, arrayNesting);
             }
             return new ArrayElementValue(ARRAY, evalues, cpool);
 
