@@ -19,9 +19,8 @@ package org.apache.tomcat.util.buf;
 import java.io.IOException;
 
 /**
- * Utilities to manipulate char chunks. While String is the easiest way to
- * manipulate chars ( search, substrings, etc), it is known to not be the most
- * efficient solution - Strings are designed as immutable and secure objects.
+ * Utilities to manipulate char chunks. While String is the easiest way to manipulate chars ( search, substrings, etc),
+ * it is known to not be the most efficient solution - Strings are designed as immutable and secure objects.
  *
  * @author dac@sun.com
  * @author James Todd [gonzo@sun.com]
@@ -35,7 +34,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
     /**
      * Input interface, used when the buffer is empty.
      */
-    public static interface CharInputChannel {
+    public interface CharInputChannel {
 
         /**
          * Read new characters.
@@ -44,25 +43,24 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
          *
          * @throws IOException If an I/O error occurs during reading
          */
-        public int realReadChars() throws IOException;
+        int realReadChars() throws IOException;
     }
 
     /**
-     * When we need more space we'll either grow the buffer ( up to the limit )
-     * or send it to a channel.
+     * When we need more space we'll either grow the buffer ( up to the limit ) or send it to a channel.
      */
-    public static interface CharOutputChannel {
+    public interface CharOutputChannel {
 
         /**
-         * Send the bytes ( usually the internal conversion buffer ). Expect 8k
-         * output if the buffer is full.
+         * Send the bytes ( usually the internal conversion buffer ). Expect 8k output if the buffer is full.
          *
          * @param buf characters that will be written
          * @param off offset in the characters array
          * @param len length that will be written
+         *
          * @throws IOException If an I/O occurs while writing the characters
          */
-        public void realWriteChars(char buf[], int off, int len) throws IOException;
+        void realWriteChars(char buf[], int off, int len) throws IOException;
     }
 
     // --------------------
@@ -112,7 +110,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
     /**
      * Sets the buffer to the specified subarray of characters.
      *
-     * @param c the characters
+     * @param c   the characters
      * @param off the start offset of the characters
      * @param len the length of the characters
      */
@@ -152,9 +150,8 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     /**
-     * When the buffer is full, write the data to the output channel. Also used
-     * when large amount of data is appended. If not set, the buffer will grow
-     * to the limit.
+     * When the buffer is full, write the data to the output channel. Also used when large amount of data is appended.
+     * If not set, the buffer will grow to the limit.
      *
      * @param out The output channel
      */
@@ -188,6 +185,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
      * @param src Char array
      * @param off Offset
      * @param len Length
+     *
      * @throws IOException Writing overflow data to the output channel failed
      */
     public void append(char src[], int off, int len) throws IOException {
@@ -223,9 +221,8 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
         if (len + end < 2 * limit) {
             /*
-             * If the request length exceeds the size of the output buffer,
-             * flush the output buffer and then write the data directly. We
-             * can't avoid 2 writes, but we can write more on the second
+             * If the request length exceeds the size of the output buffer, flush the output buffer and then write the
+             * data directly. We can't avoid 2 writes, but we can write more on the second
              */
             int avail = limit - end;
             System.arraycopy(src, off, buff, end, avail);
@@ -250,6 +247,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
      * Append a string to the buffer.
      *
      * @param s The string
+     *
      * @throws IOException Writing overflow data to the output channel failed
      */
     public void append(String s) throws IOException {
@@ -260,9 +258,10 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
     /**
      * Append a string to the buffer.
      *
-     * @param s The string
+     * @param s   The string
      * @param off Offset
      * @param len Length
+     *
      * @throws IOException Writing overflow data to the output channel failed
      */
     public void append(String s, int off, int len) throws IOException {
@@ -327,16 +326,16 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     /**
-     * Send the buffer to the sink. Called by append() when the limit is
-     * reached. You can also call it explicitly to force the data to be written.
+     * Send the buffer to the sink. Called by append() when the limit is reached. You can also call it explicitly to
+     * force the data to be written.
      *
      * @throws IOException Writing overflow data to the output channel failed
      */
     public void flushBuffer() throws IOException {
         // assert out!=null
         if (out == null) {
-            throw new IOException(sm.getString("chunk.overflow",
-                    Integer.valueOf(getLimit()), Integer.valueOf(buff.length)));
+            throw new IOException(
+                    sm.getString("chunk.overflow", Integer.valueOf(getLimit()), Integer.valueOf(buff.length)));
         }
         out.realWriteChars(buff, start, end - start);
         end = start;
@@ -344,8 +343,8 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     /**
-     * Make space for len chars. If len is small, allocate a reserve space too.
-     * Never grow bigger than the limit or {@link AbstractChunk#ARRAY_MAX_SIZE}.
+     * Make space for len chars. If len is small, allocate a reserve space too. Never grow bigger than the limit or
+     * {@link AbstractChunk#ARRAY_MAX_SIZE}.
      *
      * @param count The size
      */
@@ -370,7 +369,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
         }
 
         // limit < buf.length (the buffer is already big)
-        // or we already have space XXX
+        // or we already have space
         if (desiredSize <= buff.length) {
             return;
         }
@@ -426,8 +425,8 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
      * Compares the message bytes to the specified String object.
      *
      * @param s the String to compare
-     * @return <code>true</code> if the comparison succeeded, <code>false</code>
-     *         otherwise
+     *
+     * @return <code>true</code> if the comparison succeeded, <code>false</code> otherwise
      */
     public boolean equals(String s) {
         char[] c = buff;
@@ -449,8 +448,8 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
      * Compares the message bytes to the specified String object.
      *
      * @param s the String to compare
-     * @return <code>true</code> if the comparison succeeded, <code>false</code>
-     *         otherwise
+     *
+     * @return <code>true</code> if the comparison succeeded, <code>false</code> otherwise
      */
     public boolean equalsIgnoreCase(String s) {
         char[] c = buff;
@@ -496,8 +495,8 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     /**
-     * @return <code>true</code> if the message bytes starts with the specified
-     *         string.
+     * @return <code>true</code> if the message bytes starts with the specified string.
+     *
      * @param s The string
      */
     public boolean startsWith(String s) {
@@ -519,7 +518,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
     /**
      * Returns true if the buffer starts with the specified string.
      *
-     * @param s the string
+     * @param s   the string
      * @param pos The position
      *
      * @return <code>true</code> if the start matches
@@ -541,8 +540,8 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     /**
-     * @return <code>true</code> if the message bytes end with the specified
-     *         string.
+     * @return <code>true</code> if the message bytes end with the specified string.
+     *
      * @param s The string
      */
     public boolean endsWith(String s) {
@@ -573,14 +572,13 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     /**
-     * Returns the first instance of the given character in this CharChunk
-     * starting at the specified char. If the character is not found, -1 is
-     * returned. <br>
+     * Returns the first instance of the given character in this CharChunk starting at the specified char. If the
+     * character is not found, -1 is returned. <br>
      *
-     * @param c The character
+     * @param c        The character
      * @param starting The start position
-     * @return The position of the first instance of the character or -1 if the
-     *         character is not found.
+     *
+     * @return The position of the first instance of the character or -1 if the character is not found.
      */
     public int indexOf(char c, int starting) {
         int ret = indexOf(buff, start + starting, end, c);
@@ -589,15 +587,15 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     /**
-     * Returns the first instance of the given character in the given char array
-     * between the specified start and end. <br>
+     * Returns the first instance of the given character in the given char array between the specified start and end.
+     * <br>
      *
      * @param chars The array to search
      * @param start The point to start searching from in the array
-     * @param end The point to stop searching in the array
-     * @param s The character to search for
-     * @return The position of the first instance of the character or -1 if the
-     *         character is not found.
+     * @param end   The point to stop searching in the array
+     * @param s     The character to search for
+     *
+     * @return The position of the first instance of the character or -1 if the character is not found.
      */
     public static int indexOf(char chars[], int start, int end, char s) {
         int offset = start;
