@@ -26,12 +26,11 @@ import java.util.Locale;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * This class is used to represent a subarray of bytes in an HTTP message.
- * It represents all request/response elements. The byte/char conversions are
- * delayed and cached. Everything is recyclable.
- *
- * The object can represent a byte[], a char[], or a (sub) String. All
- * operations can be made in case sensitive mode or not.
+ * This class is used to represent a subarray of bytes in an HTTP message. It represents all request/response elements.
+ * The byte/char conversions are delayed and cached. Everything is recyclable.
+ * <p>
+ * The object can represent a byte[], a char[], or a (sub) String. All operations can be made in case sensitive mode or
+ * not.
  *
  * @author dac@eng.sun.com
  * @author James Todd [gonzo@eng.sun.com]
@@ -48,44 +47,40 @@ public final class MessageBytes implements Cloneable, Serializable {
 
     public static final int T_NULL = 0;
     /**
-     * getType() is T_STR if the the object used to create the MessageBytes
-     * was a String.
+     * getType() is T_STR if the the object used to create the MessageBytes was a String.
      */
-    public static final int T_STR  = 1;
+    public static final int T_STR = 1;
     /**
-     * getType() is T_BYTES if the the object used to create the MessageBytes
-     * was a byte[].
+     * getType() is T_BYTES if the the object used to create the MessageBytes was a byte[].
      */
     public static final int T_BYTES = 2;
     /**
-     * getType() is T_CHARS if the the object used to create the MessageBytes
-     * was a char[].
+     * getType() is T_CHARS if the the object used to create the MessageBytes was a char[].
      */
     public static final int T_CHARS = 3;
 
     public static final char[] EMPTY_CHAR_ARRAY = new char[0];
 
-    private int hashCode=0;
+    private int hashCode = 0;
     // did we compute the hashcode ?
-    private boolean hasHashCode=false;
+    private boolean hasHashCode = false;
 
     // Internal objects to represent array + offset, and specific methods
-    private final ByteChunk byteC=new ByteChunk();
-    private final CharChunk charC=new CharChunk();
+    private final ByteChunk byteC = new ByteChunk();
+    private final CharChunk charC = new CharChunk();
 
     // String
     private String strValue;
 
     /**
-     * Creates a new, uninitialized MessageBytes object.
-     * Use static newInstance() in order to allow
-     *   future hooks.
+     * Creates a new, uninitialized MessageBytes object. Use static newInstance() in order to allow future hooks.
      */
     private MessageBytes() {
     }
 
     /**
      * Construct a new MessageBytes instance.
+     *
      * @return the instance
      */
     public static MessageBytes newInstance() {
@@ -105,50 +100,51 @@ public final class MessageBytes implements Cloneable, Serializable {
      * Resets the message bytes to an uninitialized (NULL) state.
      */
     public void recycle() {
-        type=T_NULL;
+        type = T_NULL;
         byteC.recycle();
         charC.recycle();
 
-        strValue=null;
+        strValue = null;
 
-        hasHashCode=false;
-        hasLongValue=false;
+        hasHashCode = false;
+        hasLongValue = false;
     }
 
 
     /**
      * Sets the content to the specified subarray of bytes.
      *
-     * @param b the bytes
+     * @param b   the bytes
      * @param off the start offset of the bytes
      * @param len the length of the bytes
      */
     public void setBytes(byte[] b, int off, int len) {
-        byteC.setBytes( b, off, len );
-        type=T_BYTES;
-        hasHashCode=false;
-        hasLongValue=false;
+        byteC.setBytes(b, off, len);
+        type = T_BYTES;
+        hasHashCode = false;
+        hasLongValue = false;
     }
 
     /**
      * Sets the content to be a char[]
      *
-     * @param c the chars
+     * @param c   the chars
      * @param off the start offset of the chars
      * @param len the length of the chars
      */
-    public void setChars( char[] c, int off, int len ) {
-        charC.setChars( c, off, len );
-        type=T_CHARS;
-        hasHashCode=false;
-        hasLongValue=false;
+    public void setChars(char[] c, int off, int len) {
+        charC.setChars(c, off, len);
+        type = T_CHARS;
+        hasHashCode = false;
+        hasLongValue = false;
     }
 
     /**
      * Set the content to be a string
+     *
      * @param s The string
      */
-    public void setString( String s ) {
+    public void setString(String s) {
         strValue = s;
         hasHashCode = false;
         hasLongValue = false;
@@ -163,6 +159,7 @@ public final class MessageBytes implements Cloneable, Serializable {
 
     /**
      * Compute the string value.
+     *
      * @return the string
      */
     @Override
@@ -173,11 +170,9 @@ public final class MessageBytes implements Cloneable, Serializable {
                 // No conversion required
                 break;
             case T_BYTES:
-                type = T_STR;
                 strValue = byteC.toString();
                 break;
             case T_CHARS:
-                type = T_STR;
                 strValue = charC.toString();
                 break;
         }
@@ -185,10 +180,34 @@ public final class MessageBytes implements Cloneable, Serializable {
         return strValue;
     }
 
-    //----------------------------------------
+
     /**
-     * Return the type of the original content. Can be
-     * T_STR, T_BYTES, T_CHARS or T_NULL
+     * Convert to String (if not already of the String type) and then return the String value.
+     *
+     * @return The current value as a String
+     */
+    public String toStringType() {
+        switch (type) {
+            case T_NULL:
+            case T_STR:
+                // No conversion required
+                break;
+            case T_BYTES:
+                setString(byteC.toString());
+                break;
+            case T_CHARS:
+                setString(charC.toString());
+                break;
+        }
+
+        return strValue;
+    }
+
+
+    // ----------------------------------------
+    /**
+     * Return the type of the original content. Can be T_STR, T_BYTES, T_CHARS or T_NULL
+     *
      * @return the type
      */
     public int getType() {
@@ -196,8 +215,9 @@ public final class MessageBytes implements Cloneable, Serializable {
     }
 
     /**
-     * Returns the byte chunk, representing the byte[] and offset/length.
-     * Valid only if T_BYTES or after a conversion was made.
+     * Returns the byte chunk, representing the byte[] and offset/length. Valid only if T_BYTES or after a conversion
+     * was made.
+     *
      * @return the byte chunk
      */
     public ByteChunk getByteChunk() {
@@ -205,8 +225,9 @@ public final class MessageBytes implements Cloneable, Serializable {
     }
 
     /**
-     * Returns the char chunk, representing the char[] and offset/length.
-     * Valid only if T_CHARS or after a conversion was made.
+     * Returns the char chunk, representing the char[] and offset/length. Valid only if T_CHARS or after a conversion
+     * was made.
+     *
      * @return the char chunk
      */
     public CharChunk getCharChunk() {
@@ -214,8 +235,8 @@ public final class MessageBytes implements Cloneable, Serializable {
     }
 
     /**
-     * Returns the string value.
-     * Valid only if T_STR or after a conversion was made.
+     * Returns the string value. Valid only if T_STR or after a conversion was made.
+     *
      * @return the string
      */
     public String getString() {
@@ -231,6 +252,7 @@ public final class MessageBytes implements Cloneable, Serializable {
 
     /**
      * Set the Charset used for string&lt;-&gt;byte conversions.
+     *
      * @param charset The charset
      */
     public void setCharset(Charset charset) {
@@ -272,20 +294,16 @@ public final class MessageBytes implements Cloneable, Serializable {
         }
 
         byteC.setBytes(bb.array(), bb.arrayOffset(), bb.limit());
-        type = T_BYTES;
     }
 
 
     /**
      * Simple conversion of chars to bytes.
      *
-     * @throws IllegalArgumentException if any of the characters to convert are
-     *                                  above code point 0xFF.
+     * @throws IllegalArgumentException if any of the characters to convert are above code point 0xFF.
      */
     private void toBytesSimple(char[] chars, int start, int len) {
-        byteC.recycle();
-        byteC.allocate(len, byteC.getLimit());
-        byte[] bytes = byteC.getBuffer();
+        byte[] bytes = new byte[len];
 
         for (int i = 0; i < len; i++) {
             if (chars[i + start] > 255) {
@@ -296,17 +314,16 @@ public final class MessageBytes implements Cloneable, Serializable {
             }
         }
 
-        byteC.setEnd(len);
+        byteC.setBytes(bytes, 0, len);
         type = T_BYTES;
     }
 
 
     /**
      * Convert to char[] and fill the CharChunk.
-     *
-     * Note: The conversion from bytes is not optimised - it converts to String
-     *       first. However, Tomcat doesn't call this method to convert from
-     *       bytes so there is no benefit from optimising that path.
+     * <p>
+     * Note: The conversion from bytes is not optimised - it converts to String first. However, Tomcat doesn't call this
+     * method to convert from bytes so there is no benefit from optimising that path.
      */
     public void toChars() {
         switch (type) {
@@ -320,7 +337,6 @@ public final class MessageBytes implements Cloneable, Serializable {
                 toString();
                 //$FALL-THROUGH$
             case T_STR: {
-                type = T_CHARS;
                 char cc[] = strValue.toCharArray();
                 charC.setChars(cc, 0, cc.length);
             }
@@ -330,22 +346,23 @@ public final class MessageBytes implements Cloneable, Serializable {
 
     /**
      * Returns the length of the original buffer.
-     * Note that the length in bytes may be different from the length
-     * in chars.
+     * <p>
+     * Note: The length in bytes may be different from the length in chars.
+     *
      * @return the length
      */
     public int getLength() {
-        if(type==T_BYTES) {
+        if (type == T_BYTES) {
             return byteC.getLength();
         }
-        if(type==T_CHARS) {
+        if (type == T_CHARS) {
             return charC.getLength();
         }
-        if(type==T_STR) {
+        if (type == T_STR) {
             return strValue.length();
         }
         toString();
-        if( strValue==null ) {
+        if (strValue == null) {
             return 0;
         }
         return strValue.length();
@@ -355,43 +372,47 @@ public final class MessageBytes implements Cloneable, Serializable {
 
     /**
      * Compares the message bytes to the specified String object.
+     *
      * @param s the String to compare
+     *
      * @return <code>true</code> if the comparison succeeded, <code>false</code> otherwise
      */
     public boolean equals(String s) {
         switch (type) {
-        case T_STR:
-            if (strValue == null) {
-                return s == null;
-            }
-            return strValue.equals( s );
-        case T_CHARS:
-            return charC.equals( s );
-        case T_BYTES:
-            return byteC.equals( s );
-        default:
-            return false;
+            case T_STR:
+                if (strValue == null) {
+                    return s == null;
+                }
+                return strValue.equals(s);
+            case T_CHARS:
+                return charC.equals(s);
+            case T_BYTES:
+                return byteC.equals(s);
+            default:
+                return false;
         }
     }
 
     /**
      * Compares the message bytes to the specified String object.
+     *
      * @param s the String to compare
+     *
      * @return <code>true</code> if the comparison succeeded, <code>false</code> otherwise
      */
     public boolean equalsIgnoreCase(String s) {
         switch (type) {
-        case T_STR:
-            if (strValue == null) {
-                return s == null;
-            }
-            return strValue.equalsIgnoreCase( s );
-        case T_CHARS:
-            return charC.equalsIgnoreCase( s );
-        case T_BYTES:
-            return byteC.equalsIgnoreCase( s );
-        default:
-            return false;
+            case T_STR:
+                if (strValue == null) {
+                    return s == null;
+                }
+                return strValue.equalsIgnoreCase(s);
+            case T_CHARS:
+                return charC.equalsIgnoreCase(s);
+            case T_BYTES:
+                return byteC.equalsIgnoreCase(s);
+            default:
+                return false;
         }
     }
 
@@ -405,31 +426,30 @@ public final class MessageBytes implements Cloneable, Serializable {
 
     public boolean equals(MessageBytes mb) {
         switch (type) {
-        case T_STR:
-            return mb.equals( strValue );
+            case T_STR:
+                return mb.equals(strValue);
         }
 
-        if( mb.type != T_CHARS &&
-            mb.type!= T_BYTES ) {
+        if (mb.type != T_CHARS && mb.type != T_BYTES) {
             // it's a string or int/date string value
-            return equals( mb.toString() );
+            return equals(mb.toString());
         }
 
         // mb is either CHARS or BYTES.
         // this is either CHARS or BYTES
         // Deal with the 4 cases ( in fact 3, one is symmetric)
 
-        if( mb.type == T_CHARS && type==T_CHARS ) {
-            return charC.equals( mb.charC );
+        if (mb.type == T_CHARS && type == T_CHARS) {
+            return charC.equals(mb.charC);
         }
-        if( mb.type==T_BYTES && type== T_BYTES ) {
-            return byteC.equals( mb.byteC );
+        if (mb.type == T_BYTES && type == T_BYTES) {
+            return byteC.equals(mb.byteC);
         }
-        if( mb.type== T_CHARS && type== T_BYTES ) {
-            return byteC.equals( mb.charC );
+        if (mb.type == T_CHARS && type == T_BYTES) {
+            return byteC.equals(mb.charC);
         }
-        if( mb.type== T_BYTES && type== T_CHARS ) {
-            return mb.byteC.equals( charC );
+        if (mb.type == T_BYTES && type == T_CHARS) {
+            return mb.byteC.equals(charC);
         }
         // can't happen
         return true;
@@ -438,66 +458,66 @@ public final class MessageBytes implements Cloneable, Serializable {
 
     /**
      * @return <code>true</code> if the message bytes starts with the specified string.
-     * @param s the string
+     *
+     * @param s   the string
      * @param pos The start position
      */
     public boolean startsWithIgnoreCase(String s, int pos) {
         switch (type) {
-        case T_STR:
-            if( strValue==null ) {
-                return false;
-            }
-            if( strValue.length() < pos + s.length() ) {
-                return false;
-            }
-
-            for( int i=0; i<s.length(); i++ ) {
-                if( Ascii.toLower( s.charAt( i ) ) !=
-                    Ascii.toLower( strValue.charAt( pos + i ))) {
+            case T_STR:
+                if (strValue == null) {
                     return false;
                 }
-            }
-            return true;
-        case T_CHARS:
-            return charC.startsWithIgnoreCase( s, pos );
-        case T_BYTES:
-            return byteC.startsWithIgnoreCase( s, pos );
-        default:
-            return false;
+                if (strValue.length() < pos + s.length()) {
+                    return false;
+                }
+
+                for (int i = 0; i < s.length(); i++) {
+                    if (Ascii.toLower(s.charAt(i)) != Ascii.toLower(strValue.charAt(pos + i))) {
+                        return false;
+                    }
+                }
+                return true;
+            case T_CHARS:
+                return charC.startsWithIgnoreCase(s, pos);
+            case T_BYTES:
+                return byteC.startsWithIgnoreCase(s, pos);
+            default:
+                return false;
         }
     }
 
 
-    // -------------------- Hash code  --------------------
+    // -------------------- Hash code --------------------
     @Override
-    public  int hashCode() {
-        if( hasHashCode ) {
+    public int hashCode() {
+        if (hasHashCode) {
             return hashCode;
         }
         int code = 0;
 
-        code=hash();
-        hashCode=code;
-        hasHashCode=true;
+        code = hash();
+        hashCode = code;
+        hasHashCode = true;
         return code;
     }
 
     // normal hash.
     private int hash() {
-        int code=0;
+        int code = 0;
         switch (type) {
-        case T_STR:
-            // We need to use the same hash function
-            for (int i = 0; i < strValue.length(); i++) {
-                code = code * 37 + strValue.charAt( i );
-            }
-            return code;
-        case T_CHARS:
-            return charC.hash();
-        case T_BYTES:
-            return byteC.hash();
-        default:
-            return 0;
+            case T_STR:
+                // We need to use the same hash function
+                for (int i = 0; i < strValue.length(); i++) {
+                    code = code * 37 + strValue.charAt(i);
+                }
+                return code;
+            case T_CHARS:
+                return charC.hash();
+            case T_BYTES:
+                return byteC.hash();
+            default:
+                return 0;
         }
     }
 
@@ -505,59 +525,59 @@ public final class MessageBytes implements Cloneable, Serializable {
     // round of tune-up
     public int indexOf(String s, int starting) {
         toString();
-        return strValue.indexOf( s, starting );
+        return strValue.indexOf(s, starting);
     }
 
     // Inefficient initial implementation. Will be replaced on the next
     // round of tune-up
     public int indexOf(String s) {
-        return indexOf( s, 0 );
+        return indexOf(s, 0);
     }
 
     public int indexOfIgnoreCase(String s, int starting) {
         toString();
-        String upper=strValue.toUpperCase(Locale.ENGLISH);
-        String sU=s.toUpperCase(Locale.ENGLISH);
-        return upper.indexOf( sU, starting );
+        String upper = strValue.toUpperCase(Locale.ENGLISH);
+        String sU = s.toUpperCase(Locale.ENGLISH);
+        return upper.indexOf(sU, starting);
     }
 
     /**
      * Copy the src into this MessageBytes, allocating more space if needed.
+     *
      * @param src The source
+     *
      * @throws IOException Writing overflow data to the output channel failed
      */
-    public void duplicate( MessageBytes src ) throws IOException
-    {
-        switch( src.getType() ) {
-        case MessageBytes.T_BYTES:
-            type=T_BYTES;
-            ByteChunk bc=src.getByteChunk();
-            byteC.allocate( 2 * bc.getLength(), -1 );
-            byteC.append( bc );
-            break;
-        case MessageBytes.T_CHARS:
-            type=T_CHARS;
-            CharChunk cc=src.getCharChunk();
-            charC.allocate( 2 * cc.getLength(), -1 );
-            charC.append( cc );
-            break;
-        case MessageBytes.T_STR:
-            type=T_STR;
-            String sc=src.getString();
-            this.setString( sc );
-            break;
+    public void duplicate(MessageBytes src) throws IOException {
+        switch (src.getType()) {
+            case T_BYTES:
+                type = T_BYTES;
+                ByteChunk bc = src.getByteChunk();
+                byteC.allocate(2 * bc.getLength(), -1);
+                byteC.append(bc);
+                break;
+            case T_CHARS:
+                type = T_CHARS;
+                CharChunk cc = src.getCharChunk();
+                charC.allocate(2 * cc.getLength(), -1);
+                charC.append(cc);
+                break;
+            case T_STR:
+                type = T_STR;
+                String sc = src.getString();
+                this.setString(sc);
+                break;
         }
         setCharset(src.getCharset());
     }
 
-    // -------------------- Deprecated code --------------------
     // efficient long
-    // XXX used only for headers - shouldn't be stored here.
     private long longValue;
-    private boolean hasLongValue=false;
+    private boolean hasLongValue = false;
 
     /**
      * Set the buffer to the representation of a long.
+     *
      * @param l The long
      */
     public void setLong(long l) {
@@ -592,42 +612,43 @@ public final class MessageBytes implements Cloneable, Serializable {
             start++;
             end--;
         }
-        longValue=l;
-        hasHashCode=false;
-        hasLongValue=true;
-        type=T_BYTES;
+        longValue = l;
+        hasHashCode = false;
+        hasLongValue = true;
+        type = T_BYTES;
     }
 
-    // Used for headers conversion
     /**
-     * Convert the buffer to a long, cache the value.
+     * Convert the buffer to a long, cache the value. Used for headers conversion.
+     *
      * @return the long value
      */
     public long getLong() {
-        if( hasLongValue ) {
+        if (hasLongValue) {
             return longValue;
         }
 
         switch (type) {
-        case T_BYTES:
-            longValue=byteC.getLong();
-            break;
-        default:
-            longValue=Long.parseLong(toString());
+            case T_BYTES:
+                longValue = byteC.getLong();
+                break;
+            default:
+                longValue = Long.parseLong(toString());
         }
 
-        hasLongValue=true;
+        hasLongValue = true;
         return longValue;
 
-     }
+    }
 
     // -------------------- Future may be different --------------------
 
-    private static final MessageBytesFactory factory=new MessageBytesFactory();
+    private static final MessageBytesFactory factory = new MessageBytesFactory();
 
     private static class MessageBytesFactory {
         protected MessageBytesFactory() {
         }
+
         public MessageBytes newInstance() {
             return new MessageBytes();
         }
