@@ -18,9 +18,9 @@ package org.apache.tomcat.util.descriptor.tld;
 
 import java.lang.reflect.Method;
 
-import javax.servlet.jsp.tagext.TagAttributeInfo;
-import javax.servlet.jsp.tagext.TagVariableInfo;
-import javax.servlet.jsp.tagext.VariableInfo;
+import jakarta.servlet.jsp.tagext.TagAttributeInfo;
+import jakarta.servlet.jsp.tagext.TagVariableInfo;
+import jakarta.servlet.jsp.tagext.VariableInfo;
 
 import org.apache.tomcat.util.digester.Digester;
 import org.apache.tomcat.util.digester.Rule;
@@ -274,15 +274,15 @@ public class TldRuleSet implements RuleSet {
         public TagAttributeInfo toTagAttributeInfo() {
             if (fragment) {
                 // JSP8.5.2: for a fragment type is fixed and rexprvalue is true
-                type = "javax.servlet.jsp.tagext.JspFragment";
+                type = "jakarta.servlet.jsp.tagext.JspFragment";
                 requestTime = true;
             } else if (deferredValue) {
-                type = "javax.el.ValueExpression";
+                type = "jakarta.el.ValueExpression";
                 if (expectedTypeName == null) {
                     expectedTypeName = "java.lang.Object";
                 }
             } else if (deferredMethod) {
-                type = "javax.el.MethodExpression";
+                type = "jakarta.el.MethodExpression";
                 if (methodSignature == null) {
                     methodSignature = "java.lang.Object method()";
                 }
@@ -392,8 +392,9 @@ public class TldRuleSet implements RuleSet {
 
         @Override
         public void body(String namespace, String name, String text) throws Exception {
-            if(null != text)
+            if(null != text) {
                 text = text.trim();
+            }
             boolean value = "true".equalsIgnoreCase(text) || "yes".equalsIgnoreCase(text);
             setter.invoke(digester.peek(), Boolean.valueOf(value));
 
