@@ -17,9 +17,14 @@
 package org.apache.tomcat.util.descriptor.web;
 
 
+
 /**
- * Representation of a local EJB resource reference for a web application, as represented in a
- * <code>&lt;ejb-local-ref&gt;</code> element in the deployment descriptor.
+ * Representation of a local EJB resource reference for a web application, as
+ * represented in a <code>&lt;ejb-local-ref&gt;</code> element in the
+ * deployment descriptor.
+ *
+ * @author Craig R. McClanahan
+ * @author Peter Rossbach (pero@apache.org)
  */
 public class ContextLocalEjb extends ResourceBase {
 
@@ -42,7 +47,7 @@ public class ContextLocalEjb extends ResourceBase {
 
 
     /**
-     * The link to a J2EE EJB definition.
+     * The link to a Jakarta EE EJB definition.
      */
     private String link = null;
 
@@ -144,9 +149,12 @@ public class ContextLocalEjb extends ResourceBase {
             return false;
         }
         if (local == null) {
-            return other.local == null;
-        } else {
-            return local.equals(other.local);
+            if (other.local != null) {
+                return false;
+            }
+        } else if (!local.equals(other.local)) {
+            return false;
         }
+        return true;
     }
 }
