@@ -283,6 +283,8 @@ public class WebRuleSet implements RuleSet {
                                "setDeferredSyntax", 0);
         digester.addCallMethod(fullPrefix + "/jsp-config/jsp-property-group/el-ignored",
                                "setElIgnored", 0);
+        digester.addCallMethod(fullPrefix + "/jsp-config/jsp-property-group/error-on-el-not-found",
+                               "setErrorOnELNotFound", 0);
         digester.addCallMethod(fullPrefix + "/jsp-config/jsp-property-group/include-coda",
                                "addIncludeCoda", 0);
         digester.addCallMethod(fullPrefix + "/jsp-config/jsp-property-group/include-prelude",
@@ -441,6 +443,10 @@ public class WebRuleSet implements RuleSet {
                                "setCookieSecure", 0);
         digester.addCallMethod(fullPrefix + "/session-config/cookie-config/max-age",
                                "setCookieMaxAge", 0);
+        digester.addCallMethod(fullPrefix + "/session-config/cookie-config/attribute",
+                               "setCookieAttribute", 2);
+        digester.addCallParam(fullPrefix + "/session-config/cookie-config/attribute/attribute-name", 0);
+        digester.addCallParam(fullPrefix + "/session-config/cookie-config/attribute/attribute-value", 1);
         digester.addCallMethod(fullPrefix + "/session-config/tracking-mode",
                                "addSessionTrackingMode", 0);
 
@@ -795,9 +801,9 @@ final class SetAuthConstraintRule extends Rule {
         SecurityConstraint securityConstraint =
             (SecurityConstraint) digester.peek();
         securityConstraint.setAuthConstraint(true);
-        if (digester.getLogger().isTraceEnabled()) {
+        if (digester.getLogger().isDebugEnabled()) {
             digester.getLogger()
-               .trace("Calling SecurityConstraint.setAuthConstraint(true)");
+               .debug("Calling SecurityConstraint.setAuthConstraint(true)");
         }
 
         StringBuilder code = digester.getGeneratedCode();
@@ -826,8 +832,8 @@ final class SetDistributableRule extends Rule {
         throws Exception {
         WebXml webXml = (WebXml) digester.peek();
         webXml.setDistributable(true);
-        if (digester.getLogger().isTraceEnabled()) {
-            digester.getLogger().trace
+        if (digester.getLogger().isDebugEnabled()) {
+            digester.getLogger().debug
                (webXml.getClass().getName() + ".setDistributable(true)");
         }
 
@@ -856,8 +862,8 @@ final class SetDenyUncoveredHttpMethodsRule extends Rule {
         throws Exception {
         WebXml webXml = (WebXml) digester.peek();
         webXml.setDenyUncoveredHttpMethods(true);
-        if (digester.getLogger().isTraceEnabled()) {
-            digester.getLogger().trace(webXml.getClass().getName() +
+        if (digester.getLogger().isDebugEnabled()) {
+            digester.getLogger().debug(webXml.getClass().getName() +
                     ".setDenyUncoveredHttpMethods(true)");
         }
 
@@ -898,13 +904,14 @@ final class SetPublicIdRule extends Rule {
         try {
             m = top.getClass().getMethod(method, paramClasses);
         } catch (NoSuchMethodException e) {
-            digester.getLogger().error(sm.getString("webRuleSet.noMethod", method, top, top.getClass()));
+            digester.getLogger().error("Can't find method " + method + " in "
+                                       + top + " CLASS " + top.getClass());
             return;
         }
 
         m.invoke(top, (Object [])paramValues);
-        if (digester.getLogger().isTraceEnabled()) {
-            digester.getLogger().trace("" + top.getClass().getName() + "."
+        if (digester.getLogger().isDebugEnabled()) {
+            digester.getLogger().debug("" + top.getClass().getName() + "."
                                        + method + "(" + paramValues[0] + ")");
         }
 
@@ -936,8 +943,8 @@ final class ServletDefCreateRule extends Rule {
         throws Exception {
         ServletDef servletDef = new ServletDef();
         digester.push(servletDef);
-        if (digester.getLogger().isTraceEnabled()) {
-            digester.getLogger().trace("new " + servletDef.getClass().getName());
+        if (digester.getLogger().isDebugEnabled()) {
+            digester.getLogger().debug("new " + servletDef.getClass().getName());
         }
 
         StringBuilder code = digester.getGeneratedCode();
@@ -952,8 +959,8 @@ final class ServletDefCreateRule extends Rule {
     public void end(String namespace, String name)
         throws Exception {
         ServletDef servletDef = (ServletDef) digester.pop();
-        if (digester.getLogger().isTraceEnabled()) {
-            digester.getLogger().trace("pop " + servletDef.getClass().getName());
+        if (digester.getLogger().isDebugEnabled()) {
+            digester.getLogger().debug("pop " + servletDef.getClass().getName());
         }
 
         StringBuilder code = digester.getGeneratedCode();
@@ -1134,8 +1141,8 @@ final class IgnoreAnnotationsRule extends Rule {
         } else {
             value = null;
         }
-        if (digester.getLogger().isTraceEnabled()) {
-            digester.getLogger().trace
+        if (digester.getLogger().isDebugEnabled()) {
+            digester.getLogger().debug
                 (webXml.getClass().getName() + ".setMetadataComplete( " +
                         webXml.isMetadataComplete() + ")");
         }
@@ -1168,8 +1175,8 @@ final class VersionRule extends Rule {
         WebXml webXml = (WebXml) digester.peek(digester.getCount() - 1);
         webXml.setVersion(attributes.getValue("version"));
 
-        if (digester.getLogger().isTraceEnabled()) {
-            digester.getLogger().trace
+        if (digester.getLogger().isDebugEnabled()) {
+            digester.getLogger().debug
                 (webXml.getClass().getName() + ".setVersion( " +
                         webXml.getVersion() + ")");
         }
@@ -1250,8 +1257,8 @@ final class AbsoluteOrderingRule extends Rule {
             isAbsoluteOrderingSet = true;
             WebXml webXml = (WebXml) digester.peek();
             webXml.createAbsoluteOrdering();
-            if (digester.getLogger().isTraceEnabled()) {
-                digester.getLogger().trace(
+            if (digester.getLogger().isDebugEnabled()) {
+                digester.getLogger().debug(
                         webXml.getClass().getName() + ".setAbsoluteOrdering()");
             }
 
@@ -1491,8 +1498,8 @@ final class SetOverrideRule extends Rule {
     public void begin(String namespace, String name, Attributes attributes) throws Exception {
         ContextEnvironment envEntry = (ContextEnvironment) digester.peek();
         envEntry.setOverride(false);
-        if (digester.getLogger().isTraceEnabled()) {
-            digester.getLogger().trace(envEntry.getClass().getName() + ".setOverride(false)");
+        if (digester.getLogger().isDebugEnabled()) {
+            digester.getLogger().debug(envEntry.getClass().getName() + ".setOverride(false)");
         }
 
         StringBuilder code = digester.getGeneratedCode();
