@@ -14,32 +14,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
-
 package org.apache.tomcat.util.digester;
 
-
 import java.util.List;
 
-
 /**
  * Public interface defining a collection of Rule instances (and corresponding
  * matching patterns) plus an implementation of a matching policy that selects
  * the rules that match a particular pattern of nested elements discovered
  * during parsing.
  */
-
 public interface Rules {
 
-
     // ------------------------------------------------------------- Properties
 
-
     /**
      * @return the Digester instance with which this Rules instance is
      * associated.
      */
-    public Digester getDigester();
+    Digester getDigester();
 
 
     /**
@@ -47,49 +40,24 @@ public interface Rules {
      *
      * @param digester The newly associated Digester instance
      */
-    public void setDigester(Digester digester);
-
-
-    /**
-     * @return the namespace URI that will be applied to all subsequently
-     * added <code>Rule</code> objects.
-     *
-     * @deprecated Unused. Will be removed in Tomcat 9
-     */
-    @Deprecated
-    public String getNamespaceURI();
-
-
-    /**
-     * Set the namespace URI that will be applied to all subsequently
-     * added <code>Rule</code> objects.
-     *
-     * @param namespaceURI Namespace URI that must match on all
-     *  subsequently added rules, or <code>null</code> for matching
-     *  regardless of the current namespace URI
-     *
-     * @deprecated Unused. Will be removed in Tomcat 9
-     */
-    @Deprecated
-    public void setNamespaceURI(String namespaceURI);
+    void setDigester(Digester digester);
 
 
     // --------------------------------------------------------- Public Methods
 
-
     /**
      * Register a new Rule instance matching the specified pattern.
      *
      * @param pattern Nesting pattern to be matched for this Rule
      * @param rule Rule instance to be registered
      */
-    public void add(String pattern, Rule rule);
+    void add(String pattern, Rule rule);
 
 
     /**
      * Clear all existing Rule instance registrations.
      */
-    public void clear();
+    void clear();
 
 
     /**
@@ -104,7 +72,7 @@ public interface Rules {
      * @param pattern Nesting pattern to be matched
      * @return a rules list
      */
-    public List<Rule> match(String namespaceURI, String pattern);
+    List<Rule> match(String namespaceURI, String pattern);
 
 
     /**
@@ -115,7 +83,5 @@ public interface Rules {
      * method.
      * @return a rules list
      */
-    public List<Rule> rules();
-
-
+    List<Rule> rules();
 }
