@@ -85,8 +85,8 @@ public final class Parameters {
             charset = DEFAULT_BODY_CHARSET;
         }
         this.charset = charset;
-        if (log.isTraceEnabled()) {
-            log.trace("Set encoding to " + charset.name());
+        if (log.isDebugEnabled()) {
+            log.debug("Set encoding to " + charset.name());
         }
     }
 
@@ -96,8 +96,8 @@ public final class Parameters {
         }
         this.queryStringCharset = queryStringCharset;
 
-        if (log.isTraceEnabled()) {
-            log.trace("Set query string encoding to " + queryStringCharset.name());
+        if (log.isDebugEnabled()) {
+            log.debug("Set query string encoding to " + queryStringCharset.name());
         }
     }
 
@@ -157,7 +157,7 @@ public final class Parameters {
         handleQueryParameters();
         ArrayList<String> values = paramHashValues.get(name);
         if (values != null) {
-            if (values.isEmpty()) {
+            if (values.size() == 0) {
                 return "";
             }
             return values.get(0);
@@ -181,8 +181,8 @@ public final class Parameters {
             return;
         }
 
-        if (log.isTraceEnabled()) {
-            log.trace("Decoding query " + decodedQuery + " " + queryStringCharset.name());
+        if (log.isDebugEnabled()) {
+            log.debug("Decoding query " + decodedQuery + " " + queryStringCharset.name());
         }
 
         try {
@@ -227,14 +227,14 @@ public final class Parameters {
     private static final Charset DEFAULT_URI_CHARSET = StandardCharsets.UTF_8;
 
 
-    public void processParameters(byte[] bytes, int start, int len) {
+    public void processParameters(byte bytes[], int start, int len) {
         processParameters(bytes, start, len, charset);
     }
 
-    private void processParameters(byte[] bytes, int start, int len, Charset charset) {
+    private void processParameters(byte bytes[], int start, int len, Charset charset) {
 
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("parameters.bytes", new String(bytes, start, len, DEFAULT_BODY_CHARSET)));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("parameters.bytes", new String(bytes, start, len, DEFAULT_BODY_CHARSET)));
         }
 
         int decodeFailCount = 0;
@@ -478,7 +478,7 @@ public final class Parameters {
             data.toBytes();
         }
         ByteChunk bc = data.getByteChunk();
-        processParameters(bc.getBytes(), bc.getStart(), bc.getLength(), charset);
+        processParameters(bc.getBytes(), bc.getOffset(), bc.getLength(), charset);
     }
 
     /**
