@@ -56,7 +56,7 @@ import org.apache.tomcat.util.http.fileupload.util.Streams;
  * <p>Temporary files, which are created for file items, will be deleted when
  * the associated request is recycled.</p>
  *
- * @since FileUpload 1.1
+ * @since 1.1
  */
 public class DiskFileItem
     implements FileItem {
@@ -193,9 +193,7 @@ public class DiskFileItem
     public InputStream getInputStream()
         throws IOException {
         if (!isInMemory()) {
-            // Avoid JVM bug
-            // https://bz.apache.org/bugzilla/show_bug.cgi?id=65710
-            return new FileInputStream(dfos.getFile());
+            return Files.newInputStream(dfos.getFile().toPath());
         }
 
         if (cachedContent == null) {
@@ -291,7 +289,6 @@ public class DiskFileItem
      * or {@code null} if the data cannot be read
      *
      * @throws UncheckedIOException if an I/O error occurs
-     * @throws ArithmeticException if the file {@code size} overflows an int
      */
     @Override
     public byte[] get() throws UncheckedIOException {
@@ -302,7 +299,7 @@ public class DiskFileItem
             return cachedContent != null ? cachedContent.clone() : new byte[0];
         }
 
-        final byte[] fileData = new byte[Math.toIntExact(getSize())];
+        final byte[] fileData = new byte[(int) getSize()];
 
         try (InputStream fis = Files.newInputStream(dfos.getFile().toPath())) {
             IOUtils.readFully(fis, fileData);
@@ -532,21 +529,6 @@ public class DiskFileItem
 
     // ------------------------------------------------------ Protected methods
 
-    /**
-     * Removes the file contents from the temporary storage.
-     */
-    @Override
-    protected void finalize() {
-        if (dfos == null || dfos.isInMemory()) {
-            return;
-        }
-        final File outputFile = dfos.getFile();
-
-        if (outputFile != null && outputFile.exists()) {
-            outputFile.delete();
-        }
-    }
-
     /**
      * Creates and returns a {@link java.io.File File} representing a uniquely
      * named temporary file in the configured repository path. The lifetime of
