@@ -20,15 +20,16 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.nio.charset.StandardCharsets;
-import java.util.Base64;
 import java.util.HashMap;
 import java.util.Locale;
 import java.util.Map;
 
+import org.apache.tomcat.util.codec.binary.Base64;
+
 /**
  * Utility class to decode MIME texts.
  *
- * @since FileUpload 1.3
+ * @since 1.3
  */
 public final class MimeUtility {
 
@@ -75,6 +76,13 @@ public final class MimeUtility {
         MIME2JAVA.put("x-us-ascii", "ISO-8859-1");
     }
 
+    /**
+     * Hidden constructor, this class must not be instantiated.
+     */
+    private MimeUtility() {
+        // do nothing
+    }
+
     /**
      * Decode a string of text obtained from a mail header into
      * its proper form.  The text generally will consist of a
@@ -200,7 +208,7 @@ public final class MimeUtility {
         }
 
         // pull out the character set information (this is the MIME name at this point).
-        final String charset = word.substring(2, charsetPos).toLowerCase(Locale.ROOT);
+        final String charset = word.substring(2, charsetPos).toLowerCase(Locale.ENGLISH);
 
         // now pull out the encoding token the same way.
         final int encodingPos = word.indexOf('?', charsetPos + 1);
@@ -230,7 +238,7 @@ public final class MimeUtility {
             byte[] decodedData;
             // Base64 encoded?
             if (encoding.equals(BASE64_ENCODING_MARKER)) {
-                decodedData = Base64.getDecoder().decode(encodedText);
+                decodedData = Base64.decodeBase64(encodedText);
             } else if (encoding.equals(QUOTEDPRINTABLE_ENCODING_MARKER)) { // maybe quoted printable.
                 byte[] encodedData = encodedText.getBytes(StandardCharsets.US_ASCII);
                 QuotedPrintableDecoder.decode(encodedData, out);
@@ -259,7 +267,7 @@ public final class MimeUtility {
             return null;
         }
 
-        final String mappedCharset = MIME2JAVA.get(charset.toLowerCase(Locale.ROOT));
+        final String mappedCharset = MIME2JAVA.get(charset.toLowerCase(Locale.ENGLISH));
         // if there is no mapping, then the original name is used.  Many of the MIME character set
         // names map directly back into Java.  The reverse isn't necessarily true.
         if (mappedCharset == null) {
@@ -268,11 +276,4 @@ public final class MimeUtility {
         return mappedCharset;
     }
 
-    /**
-     * Hidden constructor, this class must not be instantiated.
-     */
-    private MimeUtility() {
-        // do nothing
-    }
-
 }
