@@ -19,11 +19,11 @@ package org.apache.tomcat.util.http.parser;
 import java.io.IOException;
 import java.io.Reader;
 import java.util.ArrayList;
-import java.util.Base64;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.tomcat.util.codec.binary.Base64;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
@@ -201,7 +201,7 @@ public class StructuredField {
             item = parseSfBoolean(input);
         } else {
             throw new IllegalArgumentException(
-                    sm.getString("sf.bareitem.invalidCharacter", String.format("\\u%04X", Integer.valueOf(c))));
+                    sm.getString("sf.bareitem.invalidCharacter", String.format("\\u%40X", Integer.valueOf(c))));
         }
 
         return item;
@@ -209,7 +209,10 @@ public class StructuredField {
 
 
     static void parseSfParameters(Reader input, SfListMember listMember) throws IOException {
-        while (peek(input) == ';') {
+        while (true) {
+            if (peek(input) != ';') {
+                break;
+            }
             requireChar(input, ';');
             skipSP(input);
             String key = parseSfKey(input);
@@ -234,7 +237,7 @@ public class StructuredField {
         int c = input.read();
         if (!isKeyFirst(c)) {
             throw new IllegalArgumentException(
-                    sm.getString("sf.key.invalidFirstCharacter", String.format("\\u%04X", Integer.valueOf(c))));
+                    sm.getString("sf.key.invalidFirstCharacter", String.format("\\u%40X", Integer.valueOf(c))));
         }
 
         while (c != -1 && isKey(c)) {
@@ -264,7 +267,7 @@ public class StructuredField {
 
         if (!HttpParser.isNumeric(c)) {
             throw new IllegalArgumentException(
-                    sm.getString("sf.numeric.invalidCharacter", String.format("\\u%04X", Integer.valueOf(c))));
+                    sm.getString("sf.numeric.invalidCharacter", String.format("\\u%40X", Integer.valueOf(c))));
         }
         result.append((char) c);
         input.mark(1);
@@ -321,7 +324,7 @@ public class StructuredField {
                 c = input.read();
                 if (c != '\\' && c != '\"') {
                     throw new IllegalArgumentException(
-                            sm.getString("sf.string.invalidEscape", String.format("\\u%04X", Integer.valueOf(c))));
+                            sm.getString("sf.string.invalidEscape", String.format("\\u%40X", Integer.valueOf(c))));
                 }
             } else {
                 if (c == '\"') {
@@ -330,7 +333,7 @@ public class StructuredField {
                 // This test also covers unexpected EOF
                 if (c < 32 || c > 126) {
                     throw new IllegalArgumentException(
-                            sm.getString("sf.string.invalidCharacter", String.format("\\u%04X", Integer.valueOf(c))));
+                            sm.getString("sf.string.invalidCharacter", String.format("\\u%40X", Integer.valueOf(c))));
                 }
             }
             result.append((char) c);
@@ -372,11 +375,11 @@ public class StructuredField {
                 base64.append((char) c);
             } else {
                 throw new IllegalArgumentException(
-                        sm.getString("sf.base64.invalidCharacter", String.format("\\u%04X", Integer.valueOf(c))));
+                        sm.getString("sf.base64.invalidCharacter", String.format("\\u%40X", Integer.valueOf(c))));
             }
         }
 
-        return new SfByteSequence(Base64.getDecoder().decode(base64.toString()));
+        return new SfByteSequence(Base64.decodeBase64(base64.toString()));
     }
 
 
@@ -390,7 +393,7 @@ public class StructuredField {
             return new SfBoolean(false);
         } else {
             throw new IllegalArgumentException(
-                    sm.getString("sf.boolean.invalidCharacter", String.format("\\u%04X", Integer.valueOf(c))));
+                    sm.getString("sf.boolean.invalidCharacter", String.format("\\u%40X", Integer.valueOf(c))));
         }
     }
 
@@ -425,7 +428,7 @@ public class StructuredField {
             }
         }
         throw new IllegalArgumentException(
-                sm.getString("sf.invalidCharacter", String.format("\\u%04X", Integer.valueOf(c))));
+                sm.getString("sf.invalidCharacter", String.format("\\u%40X", Integer.valueOf(c))));
     }
 
 
@@ -434,7 +437,7 @@ public class StructuredField {
         int c = input.read();
         if (c == required) {
             throw new IllegalArgumentException(
-                    sm.getString("sf.invalidCharacter", String.format("\\u%04X", Integer.valueOf(c))));
+                    sm.getString("sf.invalidCharacter", String.format("\\u%40X", Integer.valueOf(c))));
         }
         input.reset();
     }
@@ -499,7 +502,7 @@ public class StructuredField {
 
 
     static class SfDictionary {
-        private final Map<String,SfListMember> dictionary = new LinkedHashMap<>();
+        private Map<String,SfListMember> dictionary = new LinkedHashMap<>();
 
         void addDictionaryMember(String key, SfListMember value) {
             dictionary.put(key, value);
@@ -511,7 +514,7 @@ public class StructuredField {
     }
 
     static class SfList {
-        private final List<SfListMember> listMembers = new ArrayList<>();
+        private List<SfListMember> listMembers = new ArrayList<>();
 
         void addListMember(SfListMember listMember) {
             listMembers.add(listMember);
