@@ -28,10 +28,9 @@ import java.util.Set;
 import javax.net.ssl.SSLEngine;
 import javax.net.ssl.SSLParameters;
 
-import org.apache.tomcat.util.compat.JreCompat;
 import org.apache.tomcat.util.net.openssl.ciphers.Cipher;
 
-public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
+public abstract class AbstractJsseEndpoint<S,U> extends AbstractEndpoint<S,U> {
 
     private String sslImplementationName = null;
     private int sniParseLimit = 64 * 1024;
@@ -73,8 +72,8 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
 
             // Validate default SSLHostConfigName
             if (sslHostConfigs.get(getDefaultSSLHostConfigName()) == null) {
-                throw new IllegalArgumentException(
-                        sm.getString("endpoint.noSslHostConfig", getDefaultSSLHostConfigName(), getName()));
+                throw new IllegalArgumentException(sm.getString("endpoint.noSslHostConfig",
+                        getDefaultSSLHostConfigName(), getName()));
             }
 
         }
@@ -84,6 +83,13 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
     @Override
     protected void createSSLContext(SSLHostConfig sslHostConfig) throws IllegalArgumentException {
 
+        // HTTP/2 does not permit optional certificate authentication with any
+        // version of TLS.
+        if (sslHostConfig.getCertificateVerification().isOptional() &&
+                negotiableProtocols.contains("h2")) {
+            getLog().warn(sm.getString("sslHostConfig.certificateVerificationWithHttp2", sslHostConfig.getHostName()));
+        }
+
         boolean firstCertificate = true;
         for (SSLHostConfigCertificate certificate : sslHostConfig.getCertificates(true)) {
             SSLUtil sslUtil = sslImplementation.getSSLUtil(certificate);
@@ -93,24 +99,14 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
                 sslHostConfig.setEnabledCiphers(sslUtil.getEnabledCiphers());
             }
 
-            SSLContext sslContext = certificate.getSslContext();
-            SSLContext sslContextGenerated = certificate.getSslContextGenerated();
-            // Generate the SSLContext from configuration unless (e.g. embedded) an SSLContext has been provided.
-            // Need to handle both initial configuration and reload.
-            // Initial, SSLContext provided - sslContext will be non-null and sslContextGenerated will be null
-            // Initial, SSLContext not provided - sslContext null and sslContextGenerated will be null
-            // Reload, SSLContext provided - sslContext will be non-null and sslContextGenerated will be null
-            // Reload, SSLContext not provided - sslContext non-null and equal to sslContextGenerated
-            if (sslContext == null || sslContext == sslContextGenerated) {
-                try {
-                    sslContext = sslUtil.createSSLContext(negotiableProtocols);
-                } catch (Exception e) {
-                    throw new IllegalArgumentException(e.getMessage(), e);
-                }
-
-                certificate.setSslContextGenerated(sslContext);
+            SSLContext sslContext;
+            try {
+                sslContext = sslUtil.createSSLContext(negotiableProtocols);
+            } catch (Exception e) {
+                throw new IllegalArgumentException(e.getMessage(), e);
             }
 
+            certificate.setSslContext(sslContext);
             logCertificate(certificate);
         }
     }
@@ -124,7 +120,8 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
 
         SSLContext sslContext = certificate.getSslContext();
         if (sslContext == null) {
-            throw new IllegalStateException(sm.getString("endpoint.jsse.noSslContext", sniHostName));
+            throw new IllegalStateException(
+                    sm.getString("endpoint.jsse.noSslContext", sniHostName));
         }
 
         SSLEngine engine = sslContext.createSSLEngine();
@@ -134,8 +131,9 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
 
         SSLParameters sslParameters = engine.getSSLParameters();
         sslParameters.setUseCipherSuitesOrder(sslHostConfig.getHonorCipherOrder());
-        if (JreCompat.isAlpnSupported() && clientRequestedApplicationProtocols != null &&
-                clientRequestedApplicationProtocols.size() > 0 && negotiableProtocols.size() > 0) {
+        if (clientRequestedApplicationProtocols != null
+                && clientRequestedApplicationProtocols.size() > 0
+                && negotiableProtocols.size() > 0) {
             // Only try to negotiate if both client and server have at least
             // one protocol in common
             // Note: Tomcat does not explicitly negotiate http/1.1
@@ -144,21 +142,21 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
             commonProtocols.retainAll(clientRequestedApplicationProtocols);
             if (commonProtocols.size() > 0) {
                 String[] commonProtocolsArray = commonProtocols.toArray(new String[0]);
-                JreCompat.getInstance().setApplicationProtocols(sslParameters, commonProtocolsArray);
+                sslParameters.setApplicationProtocols(commonProtocolsArray);
             }
         }
         switch (sslHostConfig.getCertificateVerification()) {
-            case NONE:
-                sslParameters.setNeedClientAuth(false);
-                sslParameters.setWantClientAuth(false);
-                break;
-            case OPTIONAL:
-            case OPTIONAL_NO_CA:
-                sslParameters.setWantClientAuth(true);
-                break;
-            case REQUIRED:
-                sslParameters.setNeedClientAuth(true);
-                break;
+        case NONE:
+            sslParameters.setNeedClientAuth(false);
+            sslParameters.setWantClientAuth(false);
+            break;
+        case OPTIONAL:
+        case OPTIONAL_NO_CA:
+            sslParameters.setWantClientAuth(true);
+            break;
+        case REQUIRED:
+            sslParameters.setNeedClientAuth(true);
+            break;
         }
         // The getter (at least in OpenJDK and derivatives) returns a defensive copy
         engine.setSSLParameters(sslParameters);
@@ -167,7 +165,8 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
     }
 
 
-    private SSLHostConfigCertificate selectCertificate(SSLHostConfig sslHostConfig, List<Cipher> clientCiphers) {
+    private SSLHostConfigCertificate selectCertificate(
+            SSLHostConfig sslHostConfig, List<Cipher> clientCiphers) {
 
         Set<SSLHostConfigCertificate> certificates = sslHostConfig.getCertificates(true);
         if (certificates.size() == 1) {
@@ -199,35 +198,11 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
     }
 
 
-    @Override
-    public boolean isAlpnSupported() {
-        // ALPN requires TLS so if TLS is not enabled, ALPN cannot be supported
-        if (!isSSLEnabled()) {
-            return false;
-        }
-
-        // Depends on the SSLImplementation.
-        SSLImplementation sslImplementation;
-        try {
-            sslImplementation = SSLImplementation.getInstance(getSslImplementationName());
-        } catch (ClassNotFoundException e) {
-            // Ignore the exception. It will be logged when trying to start the
-            // end point.
-            return false;
-        }
-        return sslImplementation.isAlpnSupported();
-    }
-
-
     @Override
     public void unbind() throws Exception {
         for (SSLHostConfig sslHostConfig : sslHostConfigs.values()) {
-            for (SSLHostConfigCertificate certificate : sslHostConfig.getCertificates(true)) {
-                /*
-                 * Only remove any generated SSLContext. If the SSLContext was provided it is left in place in case the
-                 * endpoint is re-started.
-                 */
-                certificate.setSslContextGenerated(null);
+            for (SSLHostConfigCertificate certificate : sslHostConfig.getCertificates()) {
+                certificate.setSslContext(null);
             }
         }
     }
@@ -248,10 +223,4 @@ public abstract class AbstractJsseEndpoint<S, U> extends AbstractEndpoint<S,U> {
         }
         return null;
     }
-
-
-    @Override
-    protected void setDefaultSslHostConfig(SSLHostConfig sslHostConfig) {
-        // NO-OP for JSSE
-    }
 }
