@@ -26,20 +26,24 @@ import javax.net.ssl.X509ExtendedKeyManager;
 import javax.net.ssl.X509KeyManager;
 
 /**
- * X509KeyManager which allows selection of a specific key pair and certificate chain (identified by their keystore
- * alias name) to be used by the server to authenticate itself to SSL clients.
+ * X509KeyManager which allows selection of a specific key pair and certificate
+ * chain (identified by their keystore alias name) to be used by the server to
+ * authenticate itself to SSL clients.
+ *
+ * @author Jan Luehe
  */
 public final class JSSEKeyManager extends X509ExtendedKeyManager {
 
-    private final X509KeyManager delegate;
-    private final String serverKeyAlias;
+    private X509KeyManager delegate;
+    private String serverKeyAlias;
 
 
     /**
      * Constructor.
      *
-     * @param mgr            The X509KeyManager used as a delegate
-     * @param serverKeyAlias The alias name of the server's key pair and supporting certificate chain
+     * @param mgr The X509KeyManager used as a delegate
+     * @param serverKeyAlias The alias name of the server's key pair and
+     * supporting certificate chain
      */
     public JSSEKeyManager(X509KeyManager mgr, String serverKeyAlias) {
         super();
@@ -49,8 +53,9 @@ public final class JSSEKeyManager extends X509ExtendedKeyManager {
 
 
     /**
-     * Returns the server key alias that was provided in the constructor or the result from
-     * {@link X509KeyManager#chooseServerAlias(String, Principal[], Socket)} for the delegate if no alias is specified.
+     * Returns the server key alias that was provided in the constructor or the
+     * result from {@link X509KeyManager#chooseServerAlias(String, Principal[],
+     * Socket)} for the delegate if no alias is specified.
      */
     @Override
     public String chooseServerAlias(String keyType, Principal[] issuers, Socket socket) {
@@ -63,13 +68,14 @@ public final class JSSEKeyManager extends X509ExtendedKeyManager {
 
 
     /**
-     * Returns the server key alias that was provided in the constructor or the result from
-     * {@link X509ExtendedKeyManager#chooseEngineServerAlias(String, Principal[], SSLEngine)} for the delegate if no
-     * alias is specified.
+     * Returns the server key alias that was provided in the constructor or the
+     * result from {@link X509ExtendedKeyManager#chooseEngineServerAlias(String,
+     * Principal[], SSLEngine)} for the delegate if no alias is specified.
      */
     @Override
-    public String chooseEngineServerAlias(String keyType, Principal[] issuers, SSLEngine engine) {
-        if (serverKeyAlias != null) {
+    public String chooseEngineServerAlias(String keyType, Principal[] issuers,
+            SSLEngine engine) {
+        if (serverKeyAlias!=null) {
             return serverKeyAlias;
         }
 
@@ -78,7 +84,8 @@ public final class JSSEKeyManager extends X509ExtendedKeyManager {
 
 
     @Override
-    public String chooseClientAlias(String[] keyType, Principal[] issuers, Socket socket) {
+    public String chooseClientAlias(String[] keyType, Principal[] issuers,
+                                    Socket socket) {
         return delegate.chooseClientAlias(keyType, issuers, socket);
     }
 
@@ -108,7 +115,8 @@ public final class JSSEKeyManager extends X509ExtendedKeyManager {
 
 
     @Override
-    public String chooseEngineClientAlias(String[] keyType, Principal[] issuers, SSLEngine engine) {
+    public String chooseEngineClientAlias(String[] keyType, Principal[] issuers,
+            SSLEngine engine) {
         return delegate.chooseClientAlias(keyType, issuers, null);
     }
 }
