@@ -1733,7 +1733,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
      */
     public void allowCoreThreadTimeOut(boolean value) {
         if (value && keepAliveTime <= 0) {
-            throw new IllegalArgumentException("Core threads must have nonzero keep alive times");
+            throw new IllegalArgumentException(sm.getString("threadPoolExecutor.invalidKeepAlive"));
         }
         if (value != allowCoreThreadTimeOut) {
             allowCoreThreadTimeOut = value;
@@ -1793,10 +1793,10 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
      */
     public void setKeepAliveTime(long time, TimeUnit unit) {
         if (time < 0) {
-            throw new IllegalArgumentException();
+            throw new IllegalArgumentException(sm.getString("threadPoolExecutor.invalidKeepAlive"));
         }
         if (time == 0 && allowsCoreThreadTimeOut()) {
-            throw new IllegalArgumentException("Core threads must have nonzero keep alive times");
+            throw new IllegalArgumentException(sm.getString("threadPoolExecutor.invalidKeepAlive"));
         }
         long keepAliveTime = unit.toNanos(time);
         long delta = keepAliveTime - this.keepAliveTime;
@@ -2261,9 +2261,8 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
          */
         @Override
         public void rejectedExecution(Runnable r, ThreadPoolExecutor e) {
-            throw new RejectedExecutionException("Task " + r.toString() +
-                                                 " rejected from " +
-                                                 e.toString());
+            throw new RejectedExecutionException(
+                    sm.getString("threadPoolExecutor.taskRejected", r.toString(), e.toString()));
         }
     }
 
