@@ -27,29 +27,29 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
 
 import javax.naming.NamingException;
-import javax.websocket.ClientEndpointConfig;
-import javax.websocket.CloseReason;
-import javax.websocket.CloseReason.CloseCode;
-import javax.websocket.CloseReason.CloseCodes;
-import javax.websocket.DeploymentException;
-import javax.websocket.Endpoint;
-import javax.websocket.EndpointConfig;
-import javax.websocket.Extension;
-import javax.websocket.MessageHandler;
-import javax.websocket.MessageHandler.Partial;
-import javax.websocket.MessageHandler.Whole;
-import javax.websocket.PongMessage;
-import javax.websocket.RemoteEndpoint;
-import javax.websocket.SendResult;
-import javax.websocket.Session;
-import javax.websocket.WebSocketContainer;
-import javax.websocket.server.ServerEndpointConfig;
-import javax.websocket.server.ServerEndpointConfig.Configurator;
+
+import jakarta.websocket.ClientEndpointConfig;
+import jakarta.websocket.CloseReason;
+import jakarta.websocket.CloseReason.CloseCode;
+import jakarta.websocket.CloseReason.CloseCodes;
+import jakarta.websocket.DeploymentException;
+import jakarta.websocket.Endpoint;
+import jakarta.websocket.EndpointConfig;
+import jakarta.websocket.Extension;
+import jakarta.websocket.MessageHandler;
+import jakarta.websocket.MessageHandler.Partial;
+import jakarta.websocket.MessageHandler.Whole;
+import jakarta.websocket.PongMessage;
+import jakarta.websocket.RemoteEndpoint;
+import jakarta.websocket.SendResult;
+import jakarta.websocket.Session;
+import jakarta.websocket.WebSocketContainer;
+import jakarta.websocket.server.ServerEndpointConfig;
+import jakarta.websocket.server.ServerEndpointConfig.Configurator;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
@@ -72,7 +72,7 @@ public class WsSession implements Session {
 
     private static final boolean SEC_CONFIGURATOR_USES_IMPL_DEFAULT;
 
-    private static final AtomicLong ids = new AtomicLong(0);
+    private static AtomicLong ids = new AtomicLong(0);
 
     static {
         // Use fake end point and path. They are never used, they just need to
@@ -107,15 +107,14 @@ public class WsSession implements Session {
     // Expected to handle message types of <ByteBuffer> only
     private volatile MessageHandler binaryMessageHandler = null;
     private volatile MessageHandler.Whole<PongMessage> pongMessageHandler = null;
-    private final AtomicReference<State> state = new AtomicReference<>(State.OPEN);
+    private AtomicReference<State> state = new AtomicReference<>(State.OPEN);
     private final Map<String, Object> userProperties = new ConcurrentHashMap<>();
     private volatile int maxBinaryMessageBufferSize = Constants.DEFAULT_BUFFER_SIZE;
     private volatile int maxTextMessageBufferSize = Constants.DEFAULT_BUFFER_SIZE;
     private volatile long maxIdleTimeout = 0;
     private volatile long lastActiveRead = System.currentTimeMillis();
     private volatile long lastActiveWrite = System.currentTimeMillis();
-    private final Map<FutureToSendHandler, FutureToSendHandler> futures = new ConcurrentHashMap<>();
-    private volatile Long sessionCloseTimeoutExpiry;
+    private Map<FutureToSendHandler, FutureToSendHandler> futures = new ConcurrentHashMap<>();
 
 
     /**
@@ -170,8 +169,8 @@ public class WsSession implements Session {
 
         this.localEndpoint = clientEndpointHolder.getInstance(getInstanceManager());
 
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("wsSession.created", id));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("wsSession.created", id));
         }
     }
 
@@ -269,8 +268,8 @@ public class WsSession implements Session {
             this.localEndpoint = new PojoEndpointServer(pathParameters, endpointInstance);
         }
 
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("wsSession.created", id));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("wsSession.created", id));
         }
     }
 
@@ -279,92 +278,11 @@ public class WsSession implements Session {
         if (configurator.getClass().equals(DefaultServerEndpointConfigurator.class)) {
             return true;
         }
-        return SEC_CONFIGURATOR_USES_IMPL_DEFAULT &&
-            configurator.getClass().equals(Configurator.class);
-    }
-
-
-    /**
-     * Creates a new WebSocket session for communication between the two provided end points. The result of
-     * {@link Thread#getContextClassLoader()} at the time this constructor is called will be used when calling
-     * {@link Endpoint#onClose(Session, CloseReason)}.
-     *
-     * @param localEndpoint        The end point managed by this code
-     * @param wsRemoteEndpoint     The other / remote endpoint
-     * @param wsWebSocketContainer The container that created this session
-     * @param requestUri           The URI used to connect to this endpoint or <code>null</code> is this is a client
-     *                                 session
-     * @param requestParameterMap  The parameters associated with the request that initiated this session or
-     *                                 <code>null</code> if this is a client session
-     * @param queryString          The query string associated with the request that initiated this session or
-     *                                 <code>null</code> if this is a client session
-     * @param userPrincipal        The principal associated with the request that initiated this session or
-     *                                 <code>null</code> if this is a client session
-     * @param httpSessionId        The HTTP session ID associated with the request that initiated this session or
-     *                                 <code>null</code> if this is a client session
-     * @param negotiatedExtensions The agreed extensions to use for this session
-     * @param subProtocol          The agreed subprotocol to use for this session
-     * @param pathParameters       The path parameters associated with the request that initiated this session or
-     *                                 <code>null</code> if this is a client session
-     * @param secure               Was this session initiated over a secure connection?
-     * @param endpointConfig       The configuration information for the endpoint
-     *
-     * @throws DeploymentException if an invalid encode is specified
-     *
-     * @deprecated Unused. This will be removed in Tomcat 10.1
-     */
-    @Deprecated
-    public WsSession(Endpoint localEndpoint, WsRemoteEndpointImplBase wsRemoteEndpoint,
-            WsWebSocketContainer wsWebSocketContainer, URI requestUri, Map<String, List<String>> requestParameterMap,
-            String queryString, Principal userPrincipal, String httpSessionId, List<Extension> negotiatedExtensions,
-            String subProtocol, Map<String, String> pathParameters, boolean secure, EndpointConfig endpointConfig)
-            throws DeploymentException {
-        this.localEndpoint = localEndpoint;
-        this.wsRemoteEndpoint = wsRemoteEndpoint;
-        this.wsRemoteEndpoint.setSession(this);
-        this.remoteEndpointAsync = new WsRemoteEndpointAsync(wsRemoteEndpoint);
-        this.remoteEndpointBasic = new WsRemoteEndpointBasic(wsRemoteEndpoint);
-        this.webSocketContainer = wsWebSocketContainer;
-        applicationClassLoader = Thread.currentThread().getContextClassLoader();
-        wsRemoteEndpoint.setSendTimeout(wsWebSocketContainer.getDefaultAsyncSendTimeout());
-        this.maxBinaryMessageBufferSize = webSocketContainer.getDefaultMaxBinaryMessageBufferSize();
-        this.maxTextMessageBufferSize = webSocketContainer.getDefaultMaxTextMessageBufferSize();
-        this.maxIdleTimeout = webSocketContainer.getDefaultMaxSessionIdleTimeout();
-        this.requestUri = requestUri;
-        if (requestParameterMap == null) {
-            this.requestParameterMap = Collections.emptyMap();
-        } else {
-            this.requestParameterMap = requestParameterMap;
-        }
-        this.queryString = queryString;
-        this.userPrincipal = userPrincipal;
-        this.httpSessionId = httpSessionId;
-        this.negotiatedExtensions = negotiatedExtensions;
-        if (subProtocol == null) {
-            this.subProtocol = "";
-        } else {
-            this.subProtocol = subProtocol;
-        }
-        this.pathParameters = pathParameters;
-        this.secure = secure;
-        this.wsRemoteEndpoint.setEncoders(endpointConfig);
-        this.endpointConfig = endpointConfig;
-
-        this.userProperties.putAll(endpointConfig.getUserProperties());
-        this.id = Long.toHexString(ids.getAndIncrement());
-
-        InstanceManager instanceManager = getInstanceManager();
-        if (instanceManager != null) {
-            try {
-                instanceManager.newInstance(localEndpoint);
-            } catch (Exception e) {
-                throw new DeploymentException(sm.getString("wsSession.instanceNew"), e);
-            }
-        }
-
-        if (log.isDebugEnabled()) {
-            log.debug(sm.getString("wsSession.created", id));
+        if (SEC_CONFIGURATOR_USES_IMPL_DEFAULT &&
+                configurator.getClass().equals(ServerEndpointConfig.Configurator.class)) {
+            return true;
         }
+        return false;
     }
 
 
@@ -652,8 +570,8 @@ public class WsSession implements Session {
             return;
         }
 
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("wsSession.doClose", id));
+        if (log.isDebugEnabled()) {
+            log.debug(sm.getString("wsSession.doClose", id));
         }
 
         // Flush any batched messages not yet sent.
@@ -675,14 +593,7 @@ public class WsSession implements Session {
              */
             state.set(State.CLOSED);
             // ... and close the network connection.
-            closeConnection();
-        } else {
-            /*
-             * Set close timeout. If the client fails to send a close message response within the timeout, the session
-             * and the connection will be closed when the timeout expires.
-             */
-            sessionCloseTimeoutExpiry =
-                    Long.valueOf(System.nanoTime() + TimeUnit.MILLISECONDS.toNanos(getSessionCloseTimeout()));
+            wsRemoteEndpoint.close();
         }
 
         // Fail any uncompleted messages.
@@ -701,9 +612,6 @@ public class WsSession implements Session {
      * @param closeReason The reason contained within the received close message.
      */
     public void onClose(CloseReason closeReason) {
-        if (log.isTraceEnabled()) {
-            log.trace(sm.getString("wsSession.onClose.entry", closeReason, getId(), state));
-        }
         if (state.compareAndSet(State.OPEN, State.CLOSING)) {
             // Standard close.
 
@@ -724,11 +632,11 @@ public class WsSession implements Session {
             state.set(State.CLOSED);
 
             // Close the network connection.
-            closeConnection();
+            wsRemoteEndpoint.close();
         } else if (state.compareAndSet(State.OUTPUT_CLOSING, State.CLOSING)) {
             /*
-             * The local endpoint sent a close message at the same time as the remote endpoint. The local close is
-             * still being processed. Update the state so the local close process will also close the network
+             * The local endpoint sent a close message the the same time as the remote endpoint. The local close is
+             * still being processed. Update the state so the the local close process will also close the network
              * connection once it has finished sending a close message.
              */
         } else if (state.compareAndSet(State.OUTPUT_CLOSED, State.CLOSED)) {
@@ -736,71 +644,12 @@ public class WsSession implements Session {
              * The local endpoint sent the first close message. The remote endpoint has now responded with its own close
              * message so mark the session as fully closed and close the network connection.
              */
-            closeConnection();
+            wsRemoteEndpoint.close();
         }
         // CLOSING and CLOSED are NO-OPs
     }
 
 
-    private void closeConnection() {
-        /*
-         * Close the network connection.
-         */
-        wsRemoteEndpoint.close();
-        /*
-         * Don't unregister the session until the connection is fully closed since webSocketContainer is responsible for
-         * tracking the session close timeout.
-         */
-        webSocketContainer.unregisterSession(getSessionMapKey(), this);
-    }
-
-
-    /*
-     * Returns the session close timeout in milliseconds
-     */
-    protected long getSessionCloseTimeout() {
-        long result = 0;
-        Object obj = userProperties.get(Constants.SESSION_CLOSE_TIMEOUT_PROPERTY);
-        if (obj instanceof Long) {
-            result = ((Long) obj).intValue();
-        }
-        if (result <= 0) {
-            result = Constants.DEFAULT_SESSION_CLOSE_TIMEOUT;
-        }
-        return result;
-    }
-
-
-    /*
-     * Returns the session close timeout in milliseconds
-     */
-    private long getAbnormalSessionCloseSendTimeout() {
-        long result = 0;
-        Object obj = userProperties.get(Constants.ABNORMAL_SESSION_CLOSE_SEND_TIMEOUT_PROPERTY);
-        if (obj instanceof Long) {
-            result = ((Long) obj).longValue();
-        }
-        if (result <= 0) {
-            result = Constants.DEFAULT_ABNORMAL_SESSION_CLOSE_SEND_TIMEOUT;
-        }
-        return result;
-    }
-
-
-    protected void checkCloseTimeout() {
-        // Skip the check if no session close timeout has been set.
-        if (sessionCloseTimeoutExpiry != null) {
-            // Check if the timeout has expired.
-            if (System.nanoTime() - sessionCloseTimeoutExpiry.longValue() > 0) {
-                // Check if the session has been closed in another thread while the timeout was being processed.
-                if (state.compareAndSet(State.OUTPUT_CLOSED, State.CLOSED)) {
-                    closeConnection();
-                }
-            }
-        }
-    }
-
-
     private void fireEndpointOnClose(CloseReason closeReason) {
 
         // Fire the onClose event
@@ -861,31 +710,28 @@ public class WsSession implements Session {
         }
 
         String reason = closeReason.getReasonPhrase();
-        if (reason != null && !reason.isEmpty()) {
+        if (reason != null && reason.length() > 0) {
             appendCloseReasonWithTruncation(msg, reason);
         }
         msg.flip();
         try {
-            if (closeCode == CloseCodes.NORMAL_CLOSURE) {
-                wsRemoteEndpoint.sendMessageBlock(Constants.OPCODE_CLOSE, msg, true);
-            } else {
-                wsRemoteEndpoint.sendMessageBlock(Constants.OPCODE_CLOSE, msg, true,
-                        getAbnormalSessionCloseSendTimeout());
-            }
+            wsRemoteEndpoint.sendMessageBlock(Constants.OPCODE_CLOSE, msg, true);
         } catch (IOException | IllegalStateException e) {
             // Failed to send close message. Close the socket and let the caller
             // deal with the Exception
             if (log.isDebugEnabled()) {
                 log.debug(sm.getString("wsSession.sendCloseFail", id), e);
             }
-            closeConnection();
+            wsRemoteEndpoint.close();
             // Failure to send a close message is not unexpected in the case of
             // an abnormal closure (usually triggered by a failure to read/write
-            // from/to the client). In this case do not trigger the endpoint's
+            // from/to the client. In this case do not trigger the endpoint's
             // error handling
             if (closeCode != CloseCodes.CLOSED_ABNORMALLY) {
                 localEndpoint.onError(this, e);
             }
+        } finally {
+            webSocketContainer.unregisterSession(getSessionMapKey(), this);
         }
     }
 
@@ -910,7 +756,7 @@ public class WsSession implements Session {
         // Once the close code has been added there are a maximum of 123 bytes
         // left for the reason phrase. If it is truncated then care needs to be
         // taken to ensure the bytes are not truncated in the middle of a
-        // multibyte UTF-8 character.
+        // multi-byte UTF-8 character.
         byte[] reasonBytes = reason.getBytes(StandardCharsets.UTF_8);
 
         if (reasonBytes.length <= 123) {
@@ -938,11 +784,11 @@ public class WsSession implements Session {
      *
      * @param f2sh The handler
      */
-    void registerFuture(FutureToSendHandler f2sh) {
+    protected void registerFuture(FutureToSendHandler f2sh) {
         // Ideally, this code should sync on stateLock so that the correct
         // action is taken based on the current state of the connection.
         // However, a sync on stateLock can't be used here as it will create the
-        // possibility of a deadlock. See BZ 61183.
+        // possibility of a dead-lock. See BZ 61183.
         // Therefore, a slightly less efficient approach is used.
 
         // Always register the future.
@@ -989,7 +835,7 @@ public class WsSession implements Session {
      *
      * @param f2sh The handler
      */
-    void unregisterFuture(FutureToSendHandler f2sh) {
+    protected void unregisterFuture(FutureToSendHandler f2sh) {
         futures.remove(f2sh);
     }
 
@@ -1018,11 +864,6 @@ public class WsSession implements Session {
     @Override
     public Principal getUserPrincipal() {
         checkState();
-        return getUserPrincipalInternal();
-    }
-
-
-    public Principal getUserPrincipalInternal() {
         return userPrincipal;
     }
 
