@@ -21,10 +21,10 @@ import java.io.IOException;
 import java.util.List;
 import java.util.StringTokenizer;
 
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -465,7 +465,7 @@ public class TestFormAuthenticator extends TomcatBaseTest {
 
             // build the HTTP request while assembling the uri
             StringBuilder requestHead = new StringBuilder(128);
-            requestHead.append(method).append(" ");
+            requestHead.append(method).append(' ');
             if (isFullQualUri) {
                 requestHead.append(resourceUri);
             } else {
@@ -499,7 +499,7 @@ public class TestFormAuthenticator extends TomcatBaseTest {
                 if (sessionId != null) {
                     requestHead.append("Cookie: ")
                             .append(SESSION_COOKIE_NAME)
-                            .append("=").append(sessionId).append(CRLF);
+                            .append('=').append(sessionId).append(CRLF);
                 }
             }
 
