@@ -85,8 +85,6 @@ public class TestRequest extends TomcatBaseTest {
         client.doRequest(1, false); // 1 byte - too small should fail
         Assert.assertTrue(client.isResponse413());
 
-        client.reset();
-
         // Edge cases around actual content length
         client.reset();
         client.doRequest(6, false); // Too small should fail
@@ -162,7 +160,7 @@ public class TestRequest extends TomcatBaseTest {
 
         private boolean init;
 
-        public Bug37794Client(boolean createFilter) {
+        Bug37794Client(boolean createFilter) {
             this.createFilter = createFilter;
         }
 
@@ -531,7 +529,7 @@ public class TestRequest extends TomcatBaseTest {
             for(String name: parameters.keySet()) {
                 String[] values = req.getParameterValues(name);
 
-                java.util.Arrays.sort(values);
+                Arrays.sort(values);
 
                 for (String value : values) {
                     if (first) {
