@@ -26,10 +26,10 @@ import java.util.Map.Entry;
 import java.util.StringTokenizer;
 import java.util.TimeZone;
 
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -42,7 +42,6 @@ import org.apache.catalina.filters.ExpiresFilter.StartingPoint;
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
 import org.apache.tomcat.util.buf.ByteChunk;
-import org.apache.tomcat.util.buf.StringUtils;
 import org.apache.tomcat.util.collections.CaseInsensitiveKeyMap;
 import org.apache.tomcat.util.descriptor.web.FilterDef;
 import org.apache.tomcat.util.descriptor.web.FilterMap;
@@ -93,8 +92,8 @@ public class TestExpiresFilter extends TomcatBaseTest {
             Assert.assertEquals(1, expiresConfigurationDefault.getDurations().get(0).getAmount());
 
             // VERIFY TEXT/HTML
-            ExpiresConfiguration expiresConfigurationTextHtml =
-                    expiresFilter.getExpiresConfigurationByContentType().get("text/html");
+            ExpiresConfiguration expiresConfigurationTextHtml = expiresFilter.getExpiresConfigurationByContentType()
+                    .get("text/html");
             Assert.assertEquals(StartingPoint.ACCESS_TIME, expiresConfigurationTextHtml.getStartingPoint());
 
             Assert.assertEquals(3, expiresConfigurationTextHtml.getDurations().size());
@@ -112,8 +111,8 @@ public class TestExpiresFilter extends TomcatBaseTest {
             Assert.assertEquals(2, twoHours.getAmount());
 
             // VERIFY IMAGE/GIF
-            ExpiresConfiguration expiresConfigurationImageGif =
-                    expiresFilter.getExpiresConfigurationByContentType().get("image/gif");
+            ExpiresConfiguration expiresConfigurationImageGif = expiresFilter.getExpiresConfigurationByContentType()
+                    .get("image/gif");
             Assert.assertEquals(StartingPoint.LAST_MODIFICATION_TIME, expiresConfigurationImageGif.getStartingPoint());
 
             Assert.assertEquals(2, expiresConfigurationImageGif.getDurations().size());
@@ -127,8 +126,8 @@ public class TestExpiresFilter extends TomcatBaseTest {
             Assert.assertEquals(3, threeMinutes.getAmount());
 
             // VERIFY IMAGE/JPG
-            ExpiresConfiguration expiresConfigurationImageJpg =
-                    expiresFilter.getExpiresConfigurationByContentType().get("image/jpg");
+            ExpiresConfiguration expiresConfigurationImageJpg = expiresFilter.getExpiresConfigurationByContentType()
+                    .get("image/jpg");
             Assert.assertEquals(StartingPoint.ACCESS_TIME, expiresConfigurationImageJpg.getStartingPoint());
 
             Assert.assertEquals(1, expiresConfigurationImageJpg.getDurations().size());
@@ -138,8 +137,8 @@ public class TestExpiresFilter extends TomcatBaseTest {
             Assert.assertEquals(10000, tenThousandSeconds.getAmount());
 
             // VERIFY VIDEO/MPEG
-            ExpiresConfiguration expiresConfiguration =
-                    expiresFilter.getExpiresConfigurationByContentType().get("video/mpeg");
+            ExpiresConfiguration expiresConfiguration = expiresFilter.getExpiresConfigurationByContentType()
+                    .get("video/mpeg");
             Assert.assertEquals(StartingPoint.LAST_MODIFICATION_TIME, expiresConfiguration.getStartingPoint());
 
             Assert.assertEquals(1, expiresConfiguration.getDurations().size());
@@ -174,8 +173,8 @@ public class TestExpiresFilter extends TomcatBaseTest {
     @Test
     public void testParseExpiresConfigurationCombinedDuration() {
         ExpiresFilter expiresFilter = new ExpiresFilter();
-        ExpiresConfiguration actualConfiguration =
-                expiresFilter.parseExpiresConfiguration("access plus 1 month 15 days 2 hours");
+        ExpiresConfiguration actualConfiguration = expiresFilter
+                .parseExpiresConfiguration("access plus 1 month 15 days 2 hours");
 
         Assert.assertEquals(StartingPoint.ACCESS_TIME, actualConfiguration.getStartingPoint());
 
@@ -227,7 +226,7 @@ public class TestExpiresFilter extends TomcatBaseTest {
             }
         };
 
-        validate(servlet, null, null, HttpServletResponse.SC_NOT_MODIFIED);
+        validate(servlet, null, HttpServletResponse.SC_NOT_MODIFIED);
     }
 
     @Test
@@ -328,24 +327,6 @@ public class TestExpiresFilter extends TomcatBaseTest {
         validate(servlet, Integer.valueOf(1 * 60));
     }
 
-    @Test
-    public void testUseDefaultConfiguration3() throws Exception {
-        HttpServlet servlet = new HttpServlet() {
-            private static final long serialVersionUID = 1L;
-
-            @Override
-            protected void service(HttpServletRequest request, HttpServletResponse response)
-                    throws ServletException, IOException {
-                response.setContentType("image/jpeg");
-                response.addHeader("Cache-Control", "no-store");
-
-                response.getWriter().print("Hello world");
-            }
-        };
-
-        validate(servlet, null);
-    }
-
     @Test
     public void testUseMajorTypeExpiresConfiguration() throws Exception {
         HttpServlet servlet = new HttpServlet() {
@@ -363,11 +344,11 @@ public class TestExpiresFilter extends TomcatBaseTest {
     }
 
     protected void validate(HttpServlet servlet, Integer expectedMaxAgeInSeconds) throws Exception {
-        validate(servlet, expectedMaxAgeInSeconds, null, HttpServletResponse.SC_OK);
+        validate(servlet, expectedMaxAgeInSeconds, HttpServletResponse.SC_OK);
     }
 
-    protected void validate(HttpServlet servlet, Integer expectedMaxAgeInSeconds, Boolean expectedExpires,
-            int expectedResponseStatusCode) throws Exception {
+    protected void validate(HttpServlet servlet, Integer expectedMaxAgeInSeconds, int expectedResponseStatusCode)
+            throws Exception {
 
         // SETUP
 
@@ -402,14 +383,14 @@ public class TestExpiresFilter extends TomcatBaseTest {
 
             // TEST
             ByteChunk bc = new ByteChunk();
-            Map<String,List<String>> responseHeaders = new HashMap<>();
+            Map<String, List<String>> responseHeaders = new HashMap<>();
             int rc = getUrl("http://localhost:" + getPort() + "/test", bc, responseHeaders);
 
             // VALIDATE
             Assert.assertEquals(expectedResponseStatusCode, rc);
 
             StringBuilder msg = new StringBuilder();
-            for (Entry<String,List<String>> field : responseHeaders.entrySet()) {
+            for (Entry<String, List<String>> field : responseHeaders.entrySet()) {
                 for (String value : field.getValue()) {
                     msg.append((field.getKey() == null ? "" : field.getKey() + ": ") + value + "\n");
                 }
@@ -418,7 +399,7 @@ public class TestExpiresFilter extends TomcatBaseTest {
 
             Integer actualMaxAgeInSeconds;
 
-            String cacheControlHeader = StringUtils.join(responseHeaders.get("Cache-Control"));
+            String cacheControlHeader = getSingleHeader("Cache-Control", responseHeaders);
 
             if (cacheControlHeader == null) {
                 actualMaxAgeInSeconds = null;
@@ -439,30 +420,13 @@ public class TestExpiresFilter extends TomcatBaseTest {
             }
 
             if (expectedMaxAgeInSeconds == null) {
-                Assert.assertTrue(
-                        "actualMaxAgeInSeconds [" + actualMaxAgeInSeconds +
-                                "] should be null or 'no-store' should be set",
-                        actualMaxAgeInSeconds == null ||
-                                (cacheControlHeader != null && cacheControlHeader.contains("no-store")));
+                Assert.assertNull("actualMaxAgeInSeconds '" + actualMaxAgeInSeconds + "' should be null",
+                        actualMaxAgeInSeconds);
                 return;
             }
 
             Assert.assertNotNull(actualMaxAgeInSeconds);
 
-            if (expectedExpires != null) {
-                if (expectedExpires.booleanValue()) {
-                    // Expires is expected and should be greater than date
-                    Assert.assertNotNull(responseHeaders.get("Expires"));
-                    String expiresString = responseHeaders.get("Expires").get(0);
-                    long expiresDate = FastHttpDateFormat.parseDate(expiresString);
-                    Assert.assertTrue(
-                            "Expires header value [" + expiresString + "] does not specify a date in the future",
-                            expiresDate > System.currentTimeMillis());
-                } else {
-                    Assert.assertNull(responseHeaders.get("Expires"));
-                }
-            }
-
             String contentType = getSingleHeader("Content-Type", responseHeaders);
 
             int deltaInSeconds = Math.abs(actualMaxAgeInSeconds.intValue() - expectedMaxAgeInSeconds.intValue());
@@ -513,11 +477,11 @@ public class TestExpiresFilter extends TomcatBaseTest {
         tomcat.start();
 
         ByteChunk bc = new ByteChunk();
-        Map<String,List<String>> requestHeaders = new CaseInsensitiveKeyMap<>();
+        Map<String, List<String>> requestHeaders = new CaseInsensitiveKeyMap<>();
         List<String> ifModifiedSinceValues = new ArrayList<>();
         ifModifiedSinceValues.add(FastHttpDateFormat.getCurrentDate());
         requestHeaders.put("If-Modified-Since", ifModifiedSinceValues);
-        Map<String,List<String>> responseHeaders = new CaseInsensitiveKeyMap<>();
+        Map<String, List<String>> responseHeaders = new CaseInsensitiveKeyMap<>();
 
         int rc = getUrl("http://localhost:" + getPort() + "/test/bug6nnnn/bug69303.txt", bc, requestHeaders,
                 responseHeaders);
@@ -525,7 +489,7 @@ public class TestExpiresFilter extends TomcatBaseTest {
         Assert.assertEquals(HttpServletResponse.SC_NOT_MODIFIED, rc);
 
         StringBuilder msg = new StringBuilder();
-        for (Entry<String,List<String>> field : responseHeaders.entrySet()) {
+        for (Entry<String, List<String>> field : responseHeaders.entrySet()) {
             for (String value : field.getValue()) {
                 msg.append((field.getKey() == null ? "" : field.getKey() + ": ") + value + "\n");
             }
@@ -557,69 +521,4 @@ public class TestExpiresFilter extends TomcatBaseTest {
         Assert.assertNotNull(actualMaxAgeInSeconds);
         Assert.assertTrue(Math.abs(actualMaxAgeInSeconds.intValue() - 420) < 3);
     }
-
-
-    @Test
-    public void testBug69439CacheControlDirectiveConflict() throws Exception {
-        HttpServlet servlet = new HttpServlet() {
-            private static final long serialVersionUID = 1L;
-
-            @Override
-            protected void service(HttpServletRequest request, HttpServletResponse response)
-                    throws ServletException, IOException {
-                response.setContentType("image/jpeg");
-                response.addHeader("Cache-Control", "public");
-                response.addHeader("Cache-Control", "no-store");
-                response.addHeader("Cache-Control", "max-age=300");
-                response.getWriter().print("Hello world");
-            }
-        };
-        // rfc9111 - 4.2.1 - If directives conflict (e.g., both max-age and no-cache are present), the most restrictive
-        // directive should be honored.
-        // final effective Cache-Control: no-store
-        // skip ExpiresFilter
-        validate(servlet, null, Boolean.FALSE, HttpServletResponse.SC_OK);
-    }
-
-
-    @Test
-    public void testBug69439CacheControlMaxAgePredefined() throws Exception {
-        HttpServlet servlet = new HttpServlet() {
-            private static final long serialVersionUID = 1L;
-
-            @Override
-            protected void service(HttpServletRequest request, HttpServletResponse response)
-                    throws ServletException, IOException {
-                response.setContentType("image/jpeg");
-                response.addHeader("Cache-Control", "public");
-                response.addHeader("Cache-Control", "max-age=600");
-                response.getWriter().print("Hello world");
-            }
-        };
-        // rfc9111 - 4.2.1 - If directives conflict (e.g., both max-age and no-cache are present), the most restrictive
-        // directive should be honored.
-        // final effective Cache-Control: public, max-age=600
-        // skip ExpiresFilter
-        validate(servlet, Integer.valueOf(600), Boolean.FALSE, HttpServletResponse.SC_OK);
-    }
-
-
-    @Test
-    public void testBug69439CacheControlUndefined() throws Exception {
-        HttpServlet servlet = new HttpServlet() {
-            private static final long serialVersionUID = 1L;
-
-            @Override
-            protected void service(HttpServletRequest request, HttpServletResponse response)
-                    throws ServletException, IOException {
-                response.setContentType("image/jpeg");
-                response.getWriter().print("Hello world");
-            }
-        };
-        // rfc9111 - 4.2.1 - If directives conflict (e.g., both max-age and no-cache are present), the most restrictive
-        // directive should be honored.
-        // final effective Cache-Control: public, max-age=600
-        // apply ExpiresFilter
-        validate(servlet, Integer.valueOf(60), Boolean.TRUE, HttpServletResponse.SC_OK);
-    }
 }
