@@ -18,19 +18,18 @@ package org.apache.catalina.filters;
 
 import java.io.IOException;
 
-import javax.servlet.FilterChain;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpSession;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpSession;
 
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.tomcat.util.http.Method;
 import org.easymock.EasyMock;
 
 public class TestRestCsrfPreventionFilter {
@@ -39,6 +38,10 @@ public class TestRestCsrfPreventionFilter {
 
     private static final String INVALID_NONCE = "invalid-nonce";
 
+    private static final String GET_METHOD = "GET";
+
+    private static final String POST_METHOD = "POST";
+
     public static final String ACCEPTED_PATH1 = "/accepted/index1.jsp";
 
     public static final String ACCEPTED_PATH2 = "/accepted/index2.jsp";
@@ -71,45 +74,45 @@ public class TestRestCsrfPreventionFilter {
 
     @Test
     public void testGetRequestNoSessionNoNonce() throws Exception {
-        setRequestExpectations(Method.GET, null, null);
+        setRequestExpectations(GET_METHOD, null, null);
         filter.doFilter(request, response, filterChain);
         verifyContinueChain();
     }
 
     @Test
     public void testPostRequestNoSessionNoNonce() throws Exception {
-        setRequestExpectations(Method.POST, null, null);
+        setRequestExpectations(POST_METHOD, null, null);
         filter.doFilter(request, response, filterChain);
         verifyDenyResponse(HttpServletResponse.SC_FORBIDDEN);
     }
 
     @Test
     public void testPostRequestSessionNoNonce1() throws Exception {
-        setRequestExpectations(Method.POST, session, null);
+        setRequestExpectations(POST_METHOD, session, null);
         testPostRequestHeaderScenarios(null, true);
     }
 
     @Test
     public void testPostRequestSessionNoNonce2() throws Exception {
-        setRequestExpectations(Method.POST, session, null);
+        setRequestExpectations(POST_METHOD, session, null);
         testPostRequestHeaderScenarios(NONCE, true);
     }
 
     @Test
     public void testPostRequestSessionInvalidNonce() throws Exception {
-        setRequestExpectations(Method.POST, session, INVALID_NONCE);
+        setRequestExpectations(POST_METHOD, session, INVALID_NONCE);
         testPostRequestHeaderScenarios(NONCE, true);
     }
 
     @Test
     public void testPostRequestSessionValidNonce() throws Exception {
-        setRequestExpectations(Method.POST, session, NONCE);
+        setRequestExpectations(POST_METHOD, session, NONCE);
         testPostRequestHeaderScenarios(NONCE, false);
     }
 
     @Test
     public void testGetFetchRequestSessionNoNonce() throws Exception {
-        setRequestExpectations(Method.GET, session, Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE);
+        setRequestExpectations(GET_METHOD, session, Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE);
         EasyMock.expect(session.getAttribute(Constants.CSRF_REST_NONCE_SESSION_ATTR_NAME)).andReturn(null);
         session.setAttribute(Constants.CSRF_REST_NONCE_SESSION_ATTR_NAME, NONCE);
         EasyMock.expectLastCall();
@@ -121,13 +124,13 @@ public class TestRestCsrfPreventionFilter {
 
     @Test
     public void testPostFetchRequestSessionNoNonce() throws Exception {
-        setRequestExpectations(Method.POST, session, Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE);
+        setRequestExpectations(POST_METHOD, session, Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE);
         testPostRequestHeaderScenarios(null, true);
     }
 
     @Test
     public void testGetFetchRequestSessionNonce() throws Exception {
-        setRequestExpectations(Method.GET, session, Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE);
+        setRequestExpectations(GET_METHOD, session, Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE);
         EasyMock.expect(session.getAttribute(Constants.CSRF_REST_NONCE_SESSION_ATTR_NAME)).andReturn(NONCE);
         EasyMock.replay(session);
         filter.doFilter(request, response, filterChain);
@@ -137,13 +140,13 @@ public class TestRestCsrfPreventionFilter {
 
     @Test
     public void testPostFetchRequestSessionNonce() throws Exception {
-        setRequestExpectations(Method.POST, session, Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE);
+        setRequestExpectations(POST_METHOD, session, Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE);
         testPostRequestHeaderScenarios(NONCE, true);
     }
 
     @Test
     public void testPostRequestCustomDenyStatus() throws Exception {
-        setRequestExpectations(Method.POST, null, null);
+        setRequestExpectations(POST_METHOD, null, null);
         filter.setDenyStatus(HttpServletResponse.SC_BAD_REQUEST);
         filter.doFilter(request, response, filterChain);
         verifyDenyResponse(HttpServletResponse.SC_BAD_REQUEST);
@@ -151,74 +154,74 @@ public class TestRestCsrfPreventionFilter {
 
     @Test
     public void testPostRequestValidNonceAsParameterValidPath1() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { NONCE }, ACCEPTED_PATH1);
+        setRequestExpectations(POST_METHOD, session, null, new String[] { NONCE }, ACCEPTED_PATH1);
         testPostRequestParamsScenarios(NONCE, false, true);
     }
 
     @Test
     public void testPostRequestValidNonceAsParameterValidPath2() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { NONCE }, ACCEPTED_PATH2);
+        setRequestExpectations(POST_METHOD, session, null, new String[] { NONCE }, ACCEPTED_PATH2);
         testPostRequestParamsScenarios(NONCE, false, true);
     }
 
     @Test
     public void testPostRequestInvalidNonceAsParameterValidPath() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { INVALID_NONCE }, ACCEPTED_PATH1);
+        setRequestExpectations(POST_METHOD, session, null, new String[] { INVALID_NONCE }, ACCEPTED_PATH1);
         testPostRequestParamsScenarios(NONCE, true, true);
     }
 
     @Test
     public void testPostRequestValidNonceAsParameterInvalidPath() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { NONCE }, ACCEPTED_PATH1 + "blah");
+        setRequestExpectations(POST_METHOD, session, null, new String[] { NONCE }, ACCEPTED_PATH1 + "blah");
         testPostRequestParamsScenarios(NONCE, true, true);
     }
 
     @Test
     public void testPostRequestValidNonceAsParameterNoPath() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { NONCE }, ACCEPTED_PATH1);
+        setRequestExpectations(POST_METHOD, session, null, new String[] { NONCE }, ACCEPTED_PATH1);
         testPostRequestParamsScenarios(NONCE, true, false);
     }
 
     @Test
     public void testPostRequestValidNonceAsParameterNoNonceInSession() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { NONCE }, ACCEPTED_PATH1);
+        setRequestExpectations(POST_METHOD, session, null, new String[] { NONCE }, ACCEPTED_PATH1);
         testPostRequestParamsScenarios(null, true, true);
     }
 
     @Test
     public void testPostRequestValidNonceAsParameterInvalidNonceAsHeader() throws Exception {
-        setRequestExpectations(Method.POST, session, INVALID_NONCE, new String[] { NONCE }, ACCEPTED_PATH1);
+        setRequestExpectations(POST_METHOD, session, INVALID_NONCE, new String[] { NONCE }, ACCEPTED_PATH1);
         testPostRequestParamsScenarios(NONCE, true, true);
     }
 
     @Test
     public void testPostRequestNoNonceAsParameterAndHeaderValidPath() throws Exception {
-        setRequestExpectations(Method.POST, session, null, null, ACCEPTED_PATH1);
+        setRequestExpectations(POST_METHOD, session, null, null, ACCEPTED_PATH1);
         testPostRequestParamsScenarios(NONCE, true, true);
     }
 
     @Test
     public void testPostRequestMultipleValidNoncesAsParameterValidPath() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { NONCE, NONCE }, ACCEPTED_PATH1);
+        setRequestExpectations(POST_METHOD, session, null, new String[] { NONCE, NONCE }, ACCEPTED_PATH1);
         testPostRequestParamsScenarios(NONCE, false, true);
     }
 
     @Test
     public void testPostRequestMultipleNoncesAsParameterValidPath() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { NONCE, INVALID_NONCE }, ACCEPTED_PATH1);
+        setRequestExpectations(POST_METHOD, session, null, new String[] { NONCE, INVALID_NONCE }, ACCEPTED_PATH1);
         testPostRequestParamsScenarios(NONCE, true, true);
     }
 
     @Test
     public void testPostRequestMultipleInvalidNoncesAsParameterValidPath() throws Exception {
-        setRequestExpectations(Method.POST, session, null, new String[] { INVALID_NONCE, INVALID_NONCE },
+        setRequestExpectations(POST_METHOD, session, null, new String[] { INVALID_NONCE, INVALID_NONCE },
                 ACCEPTED_PATH1);
         testPostRequestParamsScenarios(NONCE, true, true);
     }
 
     @Test
     public void testGETRequestFetchNonceAsParameter() throws Exception {
-        setRequestExpectations(Method.GET, null, null, new String[] { Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE },
+        setRequestExpectations(GET_METHOD, null, null, new String[] { Constants.CSRF_REST_NONCE_HEADER_FETCH_VALUE },
                 ACCEPTED_PATH1);
         filter.setPathsAcceptingParams(ACCEPTED_PATHS);
         filter.doFilter(request, response, filterChain);
