@@ -32,6 +32,7 @@ import java.util.Map;
 import jakarta.servlet.AsyncContext;
 import jakarta.servlet.DispatcherType;
 import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.ServletConnection;
 import jakarta.servlet.ServletContext;
 import jakarta.servlet.ServletException;
 import jakarta.servlet.ServletInputStream;
@@ -72,8 +73,8 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     }
 
     @Override
-    public void setCharacterEncoding(String env)
-            throws UnsupportedEncodingException {
+    public void setCharacterEncoding(String env) throws UnsupportedEncodingException {
+        throw new RuntimeException("Not implemented");
     }
 
     @Override
@@ -111,7 +112,7 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     }
 
     @Override
-    public Map<String,String[]> getParameterMap() {
+    public Map<String, String[]> getParameterMap() {
         throw new RuntimeException("Not implemented");
     }
 
@@ -193,11 +194,6 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
-    @Override
-    public String getRealPath(String path) {
-        throw new RuntimeException("Not implemented");
-    }
-
     @Override
     public int getRemotePort() {
         throw new RuntimeException("Not implemented");
@@ -358,11 +354,6 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
-    @Override
-    public boolean isRequestedSessionIdFromUrl() {
-        throw new RuntimeException("Not implemented");
-    }
-
     @Override
     public long getContentLengthLong() {
         throw new RuntimeException("Not implemented");
@@ -379,8 +370,8 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     }
 
     @Override
-    public AsyncContext startAsync(ServletRequest servletRequest,
-            ServletResponse servletResponse) throws IllegalStateException {
+    public AsyncContext startAsync(ServletRequest servletRequest, ServletResponse servletResponse)
+            throws IllegalStateException {
         throw new RuntimeException("Not implemented");
     }
 
@@ -410,14 +401,12 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     }
 
     @Override
-    public boolean authenticate(HttpServletResponse response)
-            throws IOException, ServletException {
+    public boolean authenticate(HttpServletResponse response) throws IOException, ServletException {
         throw new RuntimeException("Not implemented");
     }
 
     @Override
-    public void login(String username, String password)
-            throws ServletException {
+    public void login(String username, String password) throws ServletException {
         throw new RuntimeException("Not implemented");
     }
 
@@ -437,8 +426,8 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     }
 
     @Override
-    public <T extends HttpUpgradeHandler> T upgrade(
-            Class<T> httpUpgradeHandlerClass) throws IOException, ServletException {
+    public <T extends HttpUpgradeHandler> T upgrade(Class<T> httpUpgradeHandlerClass)
+            throws IOException, ServletException {
         throw new RuntimeException("Not implemented");
     }
 
@@ -456,4 +445,19 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     public Map<String, String> getTrailerFields() {
         throw new RuntimeException("Not implemented");
     }
+
+    @Override
+    public String getRequestId() {
+        throw new RuntimeException("Not implemented");
+    }
+
+    @Override
+    public String getProtocolRequestId() {
+        throw new RuntimeException("Not implemented");
+    }
+
+    @Override
+    public ServletConnection getServletConnection() {
+        throw new RuntimeException("Not implemented");
+    }
 }
