@@ -24,7 +24,6 @@ import java.net.URLClassLoader;
 import org.junit.Assert;
 import org.junit.Test;
 
-import org.apache.catalina.Context;
 import org.apache.catalina.core.StandardContext;
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
@@ -82,13 +81,14 @@ public class TestWebappClassLoader extends TomcatBaseTest {
             "WEB-INF.lib",
             "org",
             "org.apache",
+            "jakarta",
             "javax",
             "com.mycorp"
         };
 
         String[] prefixesPermit = new String[]{
             "org.apache.tomcat.jdbc",
-            "javax.servlet.jsp.jstl",
+            "jakarta.servlet.jsp.jstl",
         };
 
         String[] prefixesDeny = new String[]{
@@ -99,11 +99,11 @@ public class TestWebappClassLoader extends TomcatBaseTest {
             "org.apache.juli",
             "org.apache.naming",
             "org.apache.tomcat",
-            "javax.annotation",
-            "javax.el",
-            "javax.servlet",
-            "javax.websocket",
-            "javax.security.auth.message"
+            "jakarta.annotation",
+            "jakarta.el",
+            "jakarta.servlet",
+            "jakarta.websocket",
+            "jakarta.security.auth.message"
         };
 
         try (WebappClassLoader loader = new WebappClassLoader()) {
@@ -172,48 +172,4 @@ public class TestWebappClassLoader extends TomcatBaseTest {
             }
         }
     }
-
-
-    /*
-     * See https://github.com/apache/tomcat/pull/816 for details.
-     */
-    @Test
-    public void testResourceName() throws Exception {
-
-        Tomcat tomcat = getTomcatInstance();
-        getProgrammaticRootContext();
-        tomcat.start();
-
-        // Add an external resource to the web application
-        WebappClassLoaderBase cl =
-                (WebappClassLoaderBase) ((Context) tomcat.getHost().findChildren()[0]).getLoader().getClassLoader();
-        File f = new File("test/conf");
-        cl.addURL(f.toURI().toURL());
-
-        /*
-         * External resources are loaded using URLClassLoader code so leading '/' characters are not permitted in
-         * resource names.
-         */
-        URL u1 = cl.getResource("/jaspic-test-01.xml");
-        Assert.assertNull(u1);
-
-        // Should now be visible if the correct name is used.
-        URL u2 = cl.getResource("jaspic-test-01.xml");
-        Assert.assertNotNull(u2);
-    }
-
-
-    @Test
-    public void testResourceNameEmptyString() throws Exception {
-        Tomcat tomcat = getTomcatInstance();
-        getProgrammaticRootContext();
-        tomcat.start();
-
-        // Add an external resource to the web application
-        WebappClassLoaderBase cl =
-                (WebappClassLoaderBase) ((Context) tomcat.getHost().findChildren()[0]).getLoader().getClassLoader();
-
-        URL u1 = cl.getResource("");
-        Assert.assertNotNull(u1);
-    }
 }
