@@ -72,7 +72,7 @@ public class TestEncryptInterceptor {
     @BeforeClass
     public static void setupClass() {
         Security.setProperty("jdk.tls.disabledAlgorithms", "");
-        Security.setProperty("crypto.policy", "unlimited"); // For Java 9+
+        Security.setProperty("crypto.policy", "unlimited");
     }
 
     @AfterClass
@@ -485,7 +485,7 @@ public class TestEncryptInterceptor {
     {
         private ChannelInterceptor dest;
 
-        public PipedInterceptor(ChannelInterceptor dest) {
+        PipedInterceptor(ChannelInterceptor dest) {
             if(null == dest) {
               throw new IllegalArgumentException("Destination must not be null");
             }
