@@ -26,11 +26,11 @@ import java.util.List;
 import java.util.Map;
 import java.util.regex.Pattern;
 
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpSession;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpSession;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -45,7 +45,6 @@ import org.apache.catalina.startup.TomcatBaseTest;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.buf.ByteChunk;
-import org.apache.tomcat.util.http.Method;
 import org.apache.tomcat.util.json.JSONParser;
 import org.apache.tomcat.util.json.ParseException;
 
@@ -106,11 +105,11 @@ public class TestAccessLogValve extends TomcatBaseTest {
         parameterSets.add(new Object[] {"pct-h", JSON_TYPE, "/", "%h", "\\{\"host\":\"" + LOCAL_IP_PATTERN + "\"\\}"});
         parameterSets.add(new Object[] {"pct-H", TEXT_TYPE, "/", "%H", "HTTP/1.1"});
         parameterSets.add(new Object[] {"pct-H", JSON_TYPE, "/", "%H", "\\{\"protocol\":\"HTTP/1.1\"\\}"});
-        parameterSets.add(new Object[] {"pct-I", TEXT_TYPE, "/", "%I", "http-(nio2?|apr)-" + LOCAL_IP_PATTERN + "-auto-\\d+-exec-\\d+"});
-        parameterSets.add(new Object[] {"pct-I", JSON_TYPE, "/", "%I", "\\{\"threadName\":\"http-(nio2?|apr)-" + LOCAL_IP_PATTERN + "-auto-\\d+-exec-\\d+\"\\}"});
+        parameterSets.add(new Object[] {"pct-I", TEXT_TYPE, "/", "%I", "http-nio2?-" + LOCAL_IP_PATTERN + "-auto-\\d+-exec-\\d+"});
+        parameterSets.add(new Object[] {"pct-I", JSON_TYPE, "/", "%I", "\\{\"threadName\":\"http-nio2?-" + LOCAL_IP_PATTERN + "-auto-\\d+-exec-\\d+\"\\}"});
         parameterSets.add(new Object[] {"pct-l", TEXT_TYPE, "/", "%l", "-"});
         parameterSets.add(new Object[] {"pct-l", JSON_TYPE, "/", "%l", "\\{\"logicalUserName\":\"-\"\\}"});
-        parameterSets.add(new Object[] {"pct-m", TEXT_TYPE, "/", "%m", Method.GET});
+        parameterSets.add(new Object[] {"pct-m", TEXT_TYPE, "/", "%m", "GET"});
         parameterSets.add(new Object[] {"pct-m", JSON_TYPE, "/", "%m", "\\{\"method\":\"GET\"\\}"});
         parameterSets.add(new Object[] {"pct-p", TEXT_TYPE, "/", "%p", "\\d+"});
         parameterSets.add(new Object[] {"pct-p", JSON_TYPE, "/", "%p", "\\{\"port\":\"\\d+\"\\}"});
@@ -124,8 +123,8 @@ public class TestAccessLogValve extends TomcatBaseTest {
         parameterSets.add(new Object[] {"pct-S", JSON_TYPE, "/", "%S", "\\{\"sessionId\":\"[A-F0-9]{32}\"\\}"});
         parameterSets.add(new Object[] {"pct-t", TEXT_TYPE, "/", "%t", DATE_PATTERN});
         parameterSets.add(new Object[] {"pct-t", JSON_TYPE, "/", "%t", "\\{\"time\":\"" + DATE_PATTERN + "\"\\}"});
-        parameterSets.add(new Object[] {"pct-T", TEXT_TYPE, "/", "%T", "\\d+\\.\\d+"});
-        parameterSets.add(new Object[] {"pct-T", JSON_TYPE, "/", "%T", "\\{\"elapsedTimeS\":\"\\d+\\.\\d+\"\\}"});
+        parameterSets.add(new Object[] {"pct-T", TEXT_TYPE, "/", "%T", "\\d+"});
+        parameterSets.add(new Object[] {"pct-T", JSON_TYPE, "/", "%T", "\\{\"elapsedTimeS\":\"\\d+\"\\}"});
         parameterSets.add(new Object[] {"pct-u", TEXT_TYPE, "/", "%u", "-"});
         parameterSets.add(new Object[] {"pct-u", JSON_TYPE, "/", "%u", "\\{\"user\":\"-\"\\}"});
         parameterSets.add(new Object[] {"pct-U", TEXT_TYPE, "/", "%U", "/"});
@@ -209,12 +208,18 @@ public class TestAccessLogValve extends TomcatBaseTest {
             this.writer = writer;
         }
 
+        /**
+         * Log the specified message to the log file, switching files if
+         * the date has changed since the previous log call.
+         *
+         * @param message Message to be logged
+         */
         @Override
         public void log(CharArrayWriter message) {
             try {
                 message.writeTo(writer);
-            } catch (IOException ioe) {
-                log.error("Could not write to writer", ioe);
+            } catch (IOException ex) {
+                log.error("Could not write to writer", ex);
             }
         }
     }
@@ -230,12 +235,18 @@ public class TestAccessLogValve extends TomcatBaseTest {
             this.writer = writer;
         }
 
+        /**
+         * Log the specified message to the log file, switching files if
+         * the date has changed since the previous log call.
+         *
+         * @param message Message to be logged
+         */
         @Override
         public void log(CharArrayWriter message) {
             try {
                 message.writeTo(writer);
-            } catch (IOException ioe) {
-                log.error("Could not write to writer", ioe);
+            } catch (IOException ex) {
+                log.error("Could not write to writer", ex);
             }
         }
     }
@@ -263,7 +274,7 @@ public class TestAccessLogValve extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        StandardContext ctx = (StandardContext) getProgrammaticRootContext();
+        StandardContext ctx = (StandardContext) tomcat.addContext("", null);
 
         // Map the test Servlet
         TesterServlet servlet = new TesterServlet();
