@@ -77,7 +77,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
         List<Object[]> parameterSets = new ArrayList<>();
 
         for (int loop = 0; loop < loopCount; loop++) {
-            for (Boolean useAsyncIO : TomcatBaseTest.booleans) {
+            for (Boolean useAsyncIO : booleans) {
                 parameterSets.add(new Object[] { Integer.valueOf(loop), useAsyncIO });
             }
         }
@@ -1118,13 +1118,6 @@ public abstract class Http2TestBase extends TomcatBaseTest {
         }
 
 
-        @Override
-        public void receivedEndOfStream(int streamId) {
-            lastStreamId = Integer.toString(streamId);
-            trace.append(lastStreamId + "-EndOfStream\n");
-        }
-
-
         @Override
         public HeaderEmitter headersStart(int streamId, boolean headersEndStream) {
             lastStreamId = Integer.toString(streamId);
@@ -1173,8 +1166,18 @@ public abstract class Http2TestBase extends TomcatBaseTest {
 
 
         @Override
-        public void headersEnd(int streamId) {
+        public void headersEnd(int streamId, boolean endOfStream) {
             trace.append(streamId + "-HeadersEnd\n");
+            if (endOfStream) {
+                receivedEndOfStream(streamId) ;
+            }
+        }
+
+
+        @Override
+        public void receivedEndOfStream(int streamId) {
+            lastStreamId = Integer.toString(streamId);
+            trace.append(lastStreamId + "-EndOfStream\n");
         }
 
 
