@@ -88,7 +88,7 @@ public class TestAsyncFlush extends Http2TestBase {
         parser.readFrame();
         // Body
 
-        while (output.getBytesRead() < targetSize ) {
+        while (output.getBytesRead() < targetSize) {
             if (output.getBytesRead() == totalWindow) {
                 sendWindowUpdate(3, ConnectionSettingsBase.DEFAULT_INITIAL_WINDOW_SIZE);
                 sendWindowUpdate(0, ConnectionSettingsBase.DEFAULT_INITIAL_WINDOW_SIZE);
@@ -113,8 +113,7 @@ public class TestAsyncFlush extends Http2TestBase {
         }
 
         @Override
-        protected void doGet(HttpServletRequest request, HttpServletResponse response)
-                throws IOException {
+        protected void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException {
 
             final AsyncContext asyncContext = request.startAsync();
 
