@@ -19,8 +19,6 @@ package org.apache.coyote.http2;
 import java.io.IOException;
 import java.io.InputStream;
 import java.nio.ByteBuffer;
-import java.util.logging.Level;
-import java.util.logging.LogManager;
 
 import jakarta.servlet.ServletException;
 import jakarta.servlet.http.HttpServletRequest;
@@ -40,72 +38,66 @@ public class TestCancelledUpload extends Http2TestBase {
     public void testCancelledRequest() throws Exception {
         http2Connect();
 
-        LogManager.getLogManager().getLogger("org.apache.coyote.http2").setLevel(Level.ALL);
-        try {
-            ((AbstractHttp11Protocol<?>) http2Protocol.getHttp11Protocol())
-                    .setAllowedTrailerHeaders(TRAILER_HEADER_NAME);
+        ((AbstractHttp11Protocol<?>) http2Protocol.getHttp11Protocol()).setAllowedTrailerHeaders(TRAILER_HEADER_NAME);
 
-            int bodySize = 8192;
-            int bodyCount = 20;
+        int bodySize = 8192;
+        int bodyCount = 20;
 
-            byte[] headersFrameHeader = new byte[9];
-            ByteBuffer headersPayload = ByteBuffer.allocate(128);
-            byte[] dataFrameHeader = new byte[9];
-            ByteBuffer dataPayload = ByteBuffer.allocate(bodySize);
-            byte[] trailerFrameHeader = new byte[9];
-            ByteBuffer trailerPayload = ByteBuffer.allocate(256);
+        byte[] headersFrameHeader = new byte[9];
+        ByteBuffer headersPayload = ByteBuffer.allocate(128);
+        byte[] dataFrameHeader = new byte[9];
+        ByteBuffer dataPayload = ByteBuffer.allocate(bodySize);
+        byte[] trailerFrameHeader = new byte[9];
+        ByteBuffer trailerPayload = ByteBuffer.allocate(256);
 
-            buildPostRequest(headersFrameHeader, headersPayload, false, dataFrameHeader, dataPayload, null,
-                    trailerFrameHeader, trailerPayload, 3);
+        buildPostRequest(headersFrameHeader, headersPayload, false, dataFrameHeader, dataPayload, null,
+                trailerFrameHeader, trailerPayload, 3);
 
-            // Write the headers
-            writeFrame(headersFrameHeader, headersPayload);
-            // Body
-            for (int i = 0; i < bodyCount; i++) {
-                writeFrame(dataFrameHeader, dataPayload);
-            }
-
-            // Trailers
-            writeFrame(trailerFrameHeader, trailerPayload);
-
-            // The Server will process the request on a separate thread to the
-            // incoming frames.
-            // The request processing thread will:
-            // - read up to 128 bytes of request body
-            // (and issue a window update for bytes read)
-            // - write a 403 response with no response body
-            // The connection processing thread will:
-            // - read the request body until the flow control window is exhausted
-            // - reset the stream if further DATA frames are received
-            parser.readFrame();
-
-            // Check for reset and exit if found
-            if (checkReset()) {
-                return;
-            }
-
-            // Not window update, not reset, must be the headers
-            Assert.assertEquals("3-HeadersStart\n" + "3-Header-[:status]-[403]\n" + "3-Header-[content-length]-[0]\n" +
-                    "3-Header-[date]-[Wed, 11 Nov 2015 19:18:42 GMT]\n" + "3-HeadersEnd\n", output.getTrace());
-            output.clearTrace();
-            parser.readFrame();
-
-            // Check for reset and exit if found
-            if (checkReset()) {
-                return;
-            }
-
-            // Not window update, not reset, must be the response body
-            Assert.assertEquals("3-Body-0\n" + "3-EndOfStream\n", output.getTrace());
-            output.clearTrace();
-            parser.readFrame();
-
-            Assert.assertTrue(checkReset());
-
-            // If there are any more frames after this, ignore them
-        } finally {
-            LogManager.getLogManager().getLogger("org.apache.coyote.http2").setLevel(Level.INFO);
+        // Write the headers
+        writeFrame(headersFrameHeader, headersPayload);
+        // Body
+        for (int i = 0; i < bodyCount; i++) {
+            writeFrame(dataFrameHeader, dataPayload);
         }
+
+        // Trailers
+        writeFrame(trailerFrameHeader, trailerPayload);
+
+        // The Server will process the request on a separate thread to the
+        // incoming frames.
+        // The request processing thread will:
+        // - read up to 128 bytes of request body
+        // (and issue a window update for bytes read)
+        // - write a 403 response with no response body
+        // The connection processing thread will:
+        // - read the request body until the flow control window is exhausted
+        // - reset the stream if further DATA frames are received
+        parser.readFrame();
+
+        // Check for reset and exit if found
+        if (checkReset()) {
+            return;
+        }
+
+        // Not window update, not reset, must be the headers
+        Assert.assertEquals("3-HeadersStart\n" + "3-Header-[:status]-[403]\n" + "3-Header-[content-length]-[0]\n" +
+                "3-Header-[date]-[Wed, 11 Nov 2015 19:18:42 GMT]\n" + "3-HeadersEnd\n", output.getTrace());
+        output.clearTrace();
+        parser.readFrame();
+
+        // Check for reset and exit if found
+        if (checkReset()) {
+            return;
+        }
+
+        // Not window update, not reset, must be the response body
+        Assert.assertEquals("3-Body-0\n" + "3-EndOfStream\n", output.getTrace());
+        output.clearTrace();
+        parser.readFrame();
+
+        Assert.assertTrue(checkReset());
+
+        // If there are any more frames after this, ignore them
     }
 
 
