@@ -43,8 +43,7 @@ public class TestHttp2Limits extends Http2TestBase {
     @Test
     public void testSettingsOverheadLimits() throws Exception {
         http2Connect();
-        String errMsg = sm.getString("upgradeHandler.tooMuchOverhead", "\\p{XDigit}++")
-            .replace("[", "\\[");
+        String errMsg = sm.getString("upgradeHandler.tooMuchOverhead", "\\p{XDigit}++").replace("[", "\\[");
         String overHeadMsgRegx = "0-Goaway-\\[1]-\\[11]-\\[" + errMsg + "]";
 
         for (int i = 0; i < 100; i++) {
@@ -100,8 +99,7 @@ public class TestHttp2Limits extends Http2TestBase {
     @Test
     public void testHeaderLimits20x32WithLimit10() throws Exception {
         // Check lower count limit is enforced
-        doTestHeaderLimits(20, 32, -1, 10, Constants.DEFAULT_MAX_HEADER_SIZE, 0,
-                FailureMode.STREAM_RESET);
+        doTestHeaderLimits(20, 32, -1, 10, Constants.DEFAULT_MAX_HEADER_SIZE, 0, FailureMode.STREAM_RESET);
     }
 
 
@@ -123,29 +121,28 @@ public class TestHttp2Limits extends Http2TestBase {
     @Test
     public void testHeaderLimits3x1024WithLimit2048() throws Exception {
         // Check lower size limit is enforced
-        doTestHeaderLimits(3, 1024, -1, Constants.DEFAULT_MAX_HEADER_COUNT, 2 * 1024, 0,
-                FailureMode.STREAM_RESET);
+        doTestHeaderLimits(3, 1024, -1, Constants.DEFAULT_MAX_HEADER_COUNT, 2 * 1024, 0, FailureMode.STREAM_RESET);
     }
 
 
     @Test
     public void testHeaderLimits1x12k() throws Exception {
         // Bug 60232
-        doTestHeaderLimits(1, 12*1024, FailureMode.STREAM_RESET);
+        doTestHeaderLimits(1, 12 * 1024, FailureMode.STREAM_RESET);
     }
 
 
     @Test
     public void testHeaderLimits1x12kin1kChunks() throws Exception {
         // Bug 60232
-        doTestHeaderLimits(1, 12*1024, 1024, FailureMode.STREAM_RESET);
+        doTestHeaderLimits(1, 12 * 1024, 1024, FailureMode.STREAM_RESET);
     }
 
 
     @Test
     public void testHeaderLimits1x12kin1kChunksThenNewRequest() throws Exception {
         // Bug 60232
-        doTestHeaderLimits(1, 12*1024, 1024, FailureMode.STREAM_RESET);
+        doTestHeaderLimits(1, 12 * 1024, 1024, FailureMode.STREAM_RESET);
 
         output.clearTrace();
         sendSimpleGetRequest(5);
@@ -158,7 +155,7 @@ public class TestHttp2Limits extends Http2TestBase {
     @Test
     public void testHeaderLimits1x32k() throws Exception {
         // Bug 60232
-        doTestHeaderLimits(1, 32*1024, FailureMode.CONNECTION_RESET);
+        doTestHeaderLimits(1, 32 * 1024, FailureMode.CONNECTION_RESET);
     }
 
 
@@ -168,54 +165,51 @@ public class TestHttp2Limits extends Http2TestBase {
         // 500ms per frame write delay to give server a chance to process the
         // stream reset and the connection reset before the request is fully
         // sent.
-        doTestHeaderLimits(1, 32*1024, 1024, 500, FailureMode.CONNECTION_RESET);
+        doTestHeaderLimits(1, 32 * 1024, 1024, 500, FailureMode.CONNECTION_RESET);
     }
 
 
     @Test
     public void testHeaderLimits1x128k() throws Exception {
         // Bug 60232
-        doTestHeaderLimits(1, 128*1024, FailureMode.CONNECTION_RESET);
+        doTestHeaderLimits(1, 128 * 1024, FailureMode.CONNECTION_RESET);
     }
 
 
     @Test
     public void testHeaderLimits1x512k() throws Exception {
         // Bug 60232
-        doTestHeaderLimits(1, 512*1024, FailureMode.CONNECTION_RESET);
+        doTestHeaderLimits(1, 512 * 1024, FailureMode.CONNECTION_RESET);
     }
 
 
     @Test
     public void testHeaderLimits10x512k() throws Exception {
         // Bug 60232
-        doTestHeaderLimits(10, 512*1024, FailureMode.CONNECTION_RESET);
+        doTestHeaderLimits(10, 512 * 1024, FailureMode.CONNECTION_RESET);
     }
 
 
-    private void doTestHeaderLimits(int headerCount, int headerSize, FailureMode failMode)
-            throws Exception {
+    private void doTestHeaderLimits(int headerCount, int headerSize, FailureMode failMode) throws Exception {
         doTestHeaderLimits(headerCount, headerSize, -1, failMode);
     }
 
 
-    private void doTestHeaderLimits(int headerCount, int headerSize, int maxHeaderPayloadSize,
-            FailureMode failMode) throws Exception {
+    private void doTestHeaderLimits(int headerCount, int headerSize, int maxHeaderPayloadSize, FailureMode failMode)
+            throws Exception {
         doTestHeaderLimits(headerCount, headerSize, maxHeaderPayloadSize, 0, failMode);
     }
 
 
-    private void doTestHeaderLimits(int headerCount, int headerSize, int maxHeaderPayloadSize,
-            int delayms, FailureMode failMode) throws Exception {
-        doTestHeaderLimits(headerCount, headerSize, maxHeaderPayloadSize,
-                Constants.DEFAULT_MAX_HEADER_COUNT, Constants.DEFAULT_MAX_HEADER_SIZE, delayms,
-                failMode);
+    private void doTestHeaderLimits(int headerCount, int headerSize, int maxHeaderPayloadSize, int delayms,
+            FailureMode failMode) throws Exception {
+        doTestHeaderLimits(headerCount, headerSize, maxHeaderPayloadSize, Constants.DEFAULT_MAX_HEADER_COUNT,
+                Constants.DEFAULT_MAX_HEADER_SIZE, delayms, failMode);
     }
 
 
-    private void doTestHeaderLimits(int headerCount, int headerSize, int maxHeaderPayloadSize,
-            int maxHeaderCount, int maxHeaderSize, int delayms, FailureMode failMode)
-            throws Exception {
+    private void doTestHeaderLimits(int headerCount, int headerSize, int maxHeaderPayloadSize, int maxHeaderCount,
+            int maxHeaderSize, int delayms, FailureMode failMode) throws Exception {
 
         // Build the custom headers
         List<String[]> customHeaders = new ArrayList<>();
@@ -228,7 +222,7 @@ public class TestHttp2Limits extends Http2TestBase {
         }
         String v = headerValue.toString();
         for (int i = 0; i < headerCount; i++) {
-            customHeaders.add(new String[] {"X-TomcatTest" + i, v});
+            customHeaders.add(new String[] { "X-TomcatTest" + i, v });
         }
 
         enableHttp2();
@@ -250,8 +244,8 @@ public class TestHttp2Limits extends Http2TestBase {
         byte[] frameHeader = new byte[9];
         // Assumes at least one custom header and that all headers are the same
         // length. These assumptions are valid for these tests.
-        ByteBuffer headersPayload = ByteBuffer.allocate(200 + (int) (customHeaders.size() *
-                customHeaders.iterator().next()[1].length() * 1.2));
+        ByteBuffer headersPayload = ByteBuffer
+                .allocate(200 + (int) (customHeaders.size() * customHeaders.iterator().next()[1].length() * 1.2));
 
         populateHeadersPayload(headersPayload, customHeaders, "/simple");
 
@@ -262,8 +256,7 @@ public class TestHttp2Limits extends Http2TestBase {
             while (left > 0) {
                 int thisTime = Math.min(left, maxHeaderPayloadSize);
                 populateFrameHeader(frameHeader, written, left, thisTime, 3);
-                writeFrame(frameHeader, headersPayload, headersPayload.limit() - left,
-                        thisTime, delayms);
+                writeFrame(frameHeader, headersPayload, headersPayload.limit() - left, thisTime, delayms);
                 left -= thisTime;
                 written += thisTime;
             }
@@ -272,49 +265,49 @@ public class TestHttp2Limits extends Http2TestBase {
         }
 
         switch (failMode) {
-        case NONE: {
-            // Expect a normal response
-            readSimpleGetResponse();
-            Assert.assertEquals(getSimpleResponseTrace(3), output.getTrace());
-            Assert.assertNull(e);
-            break;
-        }
-        case STREAM_RESET: {
-            // Expect a stream reset
-            parser.readFrame();
-            Assert.assertEquals("3-RST-[11]\n", output.getTrace());
-            Assert.assertNull(e);
-            break;
-        }
-        case CONNECTION_RESET: {
-            // This message uses i18n and needs to be used in a regular
-            // expression (since we don't know the connection ID). Generate the
-            // string as a regular expression and then replace '[' and ']' with
-            // the escaped values.
-            String limitMessage = sm.getString("http2Parser.headerLimitSize", "\\p{XDigit}++", "3");
-            limitMessage = limitMessage.replace("[", "\\[").replace("]", "\\]");
-            // Connection reset. Connection ID will vary so use a pattern
-            // On some platform / Connector combinations the TCP connection close
-            // will be processed before the client gets a chance to read the
-            // connection close frame which will trigger an
-            // IOException when we try to read the frame.
-            // Note: Some platforms will allow the read if if the write fails
-            //       above.
-            try {
+            case NONE: {
+                // Expect a normal response
+                readSimpleGetResponse();
+                Assert.assertEquals(getSimpleResponseTrace(3), output.getTrace());
+                Assert.assertNull(e);
+                break;
+            }
+            case STREAM_RESET: {
+                // Expect a stream reset
                 parser.readFrame();
-                MatcherAssert.assertThat(output.getTrace(), RegexMatcher.matchesRegex(
-                        "0-Goaway-\\[1\\]-\\[11\\]-\\[" + limitMessage + "\\]"));
-            } catch (IOException se) {
-                // Expected on some platforms
+                Assert.assertEquals("3-RST-[11]\n", output.getTrace());
+                Assert.assertNull(e);
+                break;
+            }
+            case CONNECTION_RESET: {
+                // This message uses i18n and needs to be used in a regular
+                // expression (since we don't know the connection ID). Generate the
+                // string as a regular expression and then replace '[' and ']' with
+                // the escaped values.
+                String limitMessage = sm.getString("http2Parser.headerLimitSize", "\\p{XDigit}++", "3");
+                limitMessage = limitMessage.replace("[", "\\[").replace("]", "\\]");
+                // Connection reset. Connection ID will vary so use a pattern
+                // On some platform / Connector combinations the TCP connection close
+                // will be processed before the client gets a chance to read the
+                // connection close frame which will trigger an
+                // IOException when we try to read the frame.
+                // Note: Some platforms will allow the read if if the write fails
+                // above.
+                try {
+                    parser.readFrame();
+                    MatcherAssert.assertThat(output.getTrace(),
+                            RegexMatcher.matchesRegex("0-Goaway-\\[1\\]-\\[11\\]-\\[" + limitMessage + "\\]"));
+                } catch (IOException se) {
+                    // Expected on some platforms
+                }
+                break;
             }
-            break;
-        }
         }
     }
 
 
-    private void populateHeadersPayload(ByteBuffer headersPayload, List<String[]> customHeaders,
-            String path) throws Exception {
+    private void populateHeadersPayload(ByteBuffer headersPayload, List<String[]> customHeaders, String path)
+            throws Exception {
         MimeHeaders headers = new MimeHeaders();
         headers.addValue(":method").setString("GET");
         headers.addValue(":scheme").setString("http");
@@ -333,8 +326,8 @@ public class TestHttp2Limits extends Http2TestBase {
     }
 
 
-    private void populateFrameHeader(byte[] frameHeader, int written, int left, int thisTime,
-            int streamId) throws Exception {
+    private void populateFrameHeader(byte[] frameHeader, int written, int left, int thisTime, int streamId)
+            throws Exception {
         ByteUtil.setThreeBytes(frameHeader, 0, thisTime);
         if (written == 0) {
             frameHeader[3] = FrameType.HEADERS.getIdByte();
@@ -394,8 +387,7 @@ public class TestHttp2Limits extends Http2TestBase {
     }
 
 
-    private void doTestCookieLimit(int cookieCount, int maxCookieCount, int failMode)
-            throws Exception {
+    private void doTestCookieLimit(int cookieCount, int maxCookieCount, int failMode) throws Exception {
 
         enableHttp2();
 
@@ -415,7 +407,7 @@ public class TestHttp2Limits extends Http2TestBase {
 
         List<String[]> customHeaders = new ArrayList<>();
         for (int i = 0; i < cookieCount; i++) {
-            customHeaders.add(new String[] {"Cookie", "a" + cookieCount + "=b" + cookieCount});
+            customHeaders.add(new String[] { "Cookie", "a" + cookieCount + "=b" + cookieCount });
         }
 
         populateHeadersPayload(headersPayload, customHeaders, "/cookie");
@@ -424,55 +416,53 @@ public class TestHttp2Limits extends Http2TestBase {
         writeFrame(frameHeader, headersPayload);
 
         switch (failMode) {
-        case 0: {
-            parser.readFrame();
-            parser.readFrame();
-            parser.readFrame();
-            System.out.println(output.getTrace());
-            Assert.assertEquals(getCookieResponseTrace(3, cookieCount), output.getTrace());
-            break;
-        }
-        case 1: {
-            // Check status is 400
-            parser.readFrame();
-            Assert.assertTrue(output.getTrace(), output.getTrace().startsWith(
-                    "3-HeadersStart\n3-Header-[:status]-[400]"));
-            output.clearTrace();
-            // Check EOS followed by error page body
-            parser.readFrame();
-            Assert.assertTrue(output.getTrace(), output.getTrace().startsWith("3-EndOfStream\n3-Body-<!doctype"));
-            break;
-        }
-        default: {
-            Assert.fail("Unknown failure mode specified");
-        }
+            case 0: {
+                parser.readFrame();
+                parser.readFrame();
+                parser.readFrame();
+                System.out.println(output.getTrace());
+                Assert.assertEquals(getCookieResponseTrace(3, cookieCount), output.getTrace());
+                break;
+            }
+            case 1: {
+                // Check status is 400
+                parser.readFrame();
+                Assert.assertTrue(output.getTrace(),
+                        output.getTrace().startsWith("3-HeadersStart\n3-Header-[:status]-[400]"));
+                output.clearTrace();
+                // Check EOS followed by error page body
+                parser.readFrame();
+                Assert.assertTrue(output.getTrace(), output.getTrace().startsWith("3-EndOfStream\n3-Body-<!doctype"));
+                break;
+            }
+            default: {
+                Assert.fail("Unknown failure mode specified");
+            }
         }
     }
 
 
     @Test
-    public void testPostWithTrailerHeadersDefaultLimit() throws Exception{
-        doTestPostWithTrailerHeaders(Constants.DEFAULT_MAX_TRAILER_COUNT,
-                Constants.DEFAULT_MAX_TRAILER_SIZE, FailureMode.NONE);
+    public void testPostWithTrailerHeadersDefaultLimit() throws Exception {
+        doTestPostWithTrailerHeaders(Constants.DEFAULT_MAX_TRAILER_COUNT, Constants.DEFAULT_MAX_TRAILER_SIZE,
+                FailureMode.NONE);
     }
 
 
     @Test
-    public void testPostWithTrailerHeadersCount0() throws Exception{
-        doTestPostWithTrailerHeaders(0, Constants.DEFAULT_MAX_TRAILER_SIZE,
-                FailureMode.STREAM_RESET);
+    public void testPostWithTrailerHeadersCount0() throws Exception {
+        doTestPostWithTrailerHeaders(0, Constants.DEFAULT_MAX_TRAILER_SIZE, FailureMode.STREAM_RESET);
     }
 
 
     @Test
-    public void testPostWithTrailerHeadersSize0() throws Exception{
-        doTestPostWithTrailerHeaders(Constants.DEFAULT_MAX_TRAILER_COUNT, 0,
-                FailureMode.CONNECTION_RESET);
+    public void testPostWithTrailerHeadersSize0() throws Exception {
+        doTestPostWithTrailerHeaders(Constants.DEFAULT_MAX_TRAILER_COUNT, 0, FailureMode.CONNECTION_RESET);
     }
 
 
-    private void doTestPostWithTrailerHeaders(int maxTrailerCount, int maxTrailerSize,
-            FailureMode failMode) throws Exception {
+    private void doTestPostWithTrailerHeaders(int maxTrailerCount, int maxTrailerSize, FailureMode failMode)
+            throws Exception {
         enableHttp2();
 
         ((AbstractHttp11Protocol<?>) http2Protocol.getHttp11Protocol()).setAllowedTrailerHeaders(TRAILER_HEADER_NAME);
@@ -494,8 +484,8 @@ public class TestHttp2Limits extends Http2TestBase {
         byte[] trailerFrameHeader = new byte[9];
         ByteBuffer trailerPayload = ByteBuffer.allocate(256);
 
-        buildPostRequest(headersFrameHeader, headersPayload, false, dataFrameHeader, dataPayload,
-                null, trailerFrameHeader, trailerPayload, 3);
+        buildPostRequest(headersFrameHeader, headersPayload, false, dataFrameHeader, dataPayload, null,
+                trailerFrameHeader, trailerPayload, 3);
 
         // Write the headers
         writeFrame(headersFrameHeader, headersPayload);
@@ -505,56 +495,48 @@ public class TestHttp2Limits extends Http2TestBase {
         writeFrame(trailerFrameHeader, trailerPayload);
 
         switch (failMode) {
-        case NONE: {
-            parser.readFrame();
-            parser.readFrame();
-            parser.readFrame();
-            parser.readFrame();
-
-            String len = Integer.toString(256 + TRAILER_HEADER_VALUE.length());
-
-            Assert.assertEquals("0-WindowSize-[256]\n" +
-                    "3-WindowSize-[256]\n" +
-                    "3-HeadersStart\n" +
-                    "3-Header-[:status]-[200]\n" +
-                    "3-Header-[content-length]-[" + len + "]\n" +
-                    "3-Header-[date]-["+ DEFAULT_DATE + "]\n" +
-                    "3-HeadersEnd\n" +
-                    "3-Body-" +
-                    len +
-                    "\n" +
-                    "3-EndOfStream\n",
-                    output.getTrace());
-            break;
-        }
-        case STREAM_RESET: {
-            // NIO2 can sometimes send window updates depending timing
-            skipWindowSizeFrames();
-
-            // Async I/O can sometimes result in a stream closed reset before
-            // the enhance your calm reset
-            if ("3-RST-[5]\n".equals(output.getTrace())) {
-                output.clearTrace();
+            case NONE: {
                 parser.readFrame();
+                parser.readFrame();
+                parser.readFrame();
+                parser.readFrame();
+
+                String len = Integer.toString(256 + TRAILER_HEADER_VALUE.length());
+
+                Assert.assertEquals("0-WindowSize-[256]\n" + "3-WindowSize-[256]\n" + "3-HeadersStart\n" +
+                        "3-Header-[:status]-[200]\n" + "3-Header-[content-length]-[" + len + "]\n" +
+                        "3-Header-[date]-[" + DEFAULT_DATE + "]\n" + "3-HeadersEnd\n" + "3-Body-" + len + "\n" +
+                        "3-EndOfStream\n", output.getTrace());
+                break;
             }
+            case STREAM_RESET: {
+                // NIO2 can sometimes send window updates depending timing
+                skipWindowSizeFrames();
 
-            Assert.assertEquals("3-RST-[11]\n", output.getTrace());
-            break;
-        }
-        case CONNECTION_RESET: {
-            // NIO2 can sometimes send window updates depending timing
-            skipWindowSizeFrames();
+                // Async I/O can sometimes result in a stream closed reset before
+                // the enhance your calm reset
+                if ("3-RST-[5]\n".equals(output.getTrace())) {
+                    output.clearTrace();
+                    parser.readFrame();
+                }
 
-            // This message uses i18n and needs to be used in a regular
-            // expression (since we don't know the connection ID). Generate the
-            // string as a regular expression and then replace '[' and ']' with
-            // the escaped values.
-            String limitMessage = sm.getString("http2Parser.headerLimitSize", "\\p{XDigit}++", "3");
-            limitMessage = limitMessage.replace("[", "\\[").replace("]", "\\]");
-            MatcherAssert.assertThat(output.getTrace(), RegexMatcher.matchesRegex(
-                    "0-Goaway-\\[3\\]-\\[11\\]-\\[" + limitMessage + "\\]"));
-            break;
-        }
+                Assert.assertEquals("3-RST-[11]\n", output.getTrace());
+                break;
+            }
+            case CONNECTION_RESET: {
+                // NIO2 can sometimes send window updates depending timing
+                skipWindowSizeFrames();
+
+                // This message uses i18n and needs to be used in a regular
+                // expression (since we don't know the connection ID). Generate the
+                // string as a regular expression and then replace '[' and ']' with
+                // the escaped values.
+                String limitMessage = sm.getString("http2Parser.headerLimitSize", "\\p{XDigit}++", "3");
+                limitMessage = limitMessage.replace("[", "\\[").replace("]", "\\]");
+                MatcherAssert.assertThat(output.getTrace(),
+                        RegexMatcher.matchesRegex("0-Goaway-\\[3\\]-\\[11\\]-\\[" + limitMessage + "\\]"));
+                break;
+            }
         }
     }
 
