@@ -26,20 +26,21 @@ import java.nio.charset.CodingErrorAction;
 import java.util.Date;
 import java.util.Scanner;
 
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.jsp.JspException;
-import javax.servlet.jsp.PageContext;
-import javax.servlet.jsp.tagext.BodyTagSupport;
-import javax.servlet.jsp.tagext.DynamicAttributes;
-import javax.servlet.jsp.tagext.JspIdConsumer;
-import javax.servlet.jsp.tagext.Tag;
-import javax.servlet.jsp.tagext.TagData;
-import javax.servlet.jsp.tagext.TagExtraInfo;
-import javax.servlet.jsp.tagext.TagSupport;
-import javax.servlet.jsp.tagext.TryCatchFinally;
-import javax.servlet.jsp.tagext.VariableInfo;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.jsp.JspException;
+import jakarta.servlet.jsp.PageContext;
+import jakarta.servlet.jsp.tagext.BodyTagSupport;
+import jakarta.servlet.jsp.tagext.DynamicAttributes;
+import jakarta.servlet.jsp.tagext.JspIdConsumer;
+import jakarta.servlet.jsp.tagext.Tag;
+import jakarta.servlet.jsp.tagext.TagData;
+import jakarta.servlet.jsp.tagext.TagExtraInfo;
+import jakarta.servlet.jsp.tagext.TagSupport;
+import jakarta.servlet.jsp.tagext.TryCatchFinally;
+import jakarta.servlet.jsp.tagext.VariableInfo;
 
 import org.junit.Assert;
+import org.junit.Ignore;
 import org.junit.Test;
 
 import org.apache.catalina.Context;
@@ -49,12 +50,9 @@ import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
 import org.apache.jasper.servlet.JasperInitializer;
 import org.apache.tomcat.util.buf.ByteChunk;
-import org.apache.tomcat.util.compat.JreCompat;
 
 public class TestGenerator extends TomcatBaseTest {
 
-    private static final String NEW_LINE = System.lineSeparator();
-
     @Test
     public void testBug45015a() throws Exception {
         getTomcatInstanceTestWebapp(false, true);
@@ -325,7 +323,7 @@ public class TestGenerator extends TomcatBaseTest {
             }
         }
         if (!removeBlankLines && blankLineCount == 0) {
-            Assert.fail("TrimSpaceOptions.EXTENDED not configured but blank lines have been removed");
+            Assert.fail("TrimSpaceOptions.EXTENDED not configured but balnk lines have been removed");
         } else if (removeBlankLines && blankLineCount > 0) {
             Assert.fail("TrimSpaceOptions.EXTENDED does not allow the line to be just a new line character");
         }
@@ -421,6 +419,11 @@ public class TestGenerator extends TomcatBaseTest {
         Assert.assertNotEquals(ids[0], ids[1]);
     }
 
+    @Test
+    public void testTryCatchFinally02() throws Exception {
+        doTestJsp("try-catch-finally-02.jsp");
+    }
+
     public static class JspIdTag extends TagSupport implements JspIdConsumer {
 
         private static final long serialVersionUID = 1L;
@@ -468,6 +471,21 @@ public class TestGenerator extends TomcatBaseTest {
         }
     }
 
+    public static class TryCatchFinallyTag extends TagSupport implements TryCatchFinally {
+
+        private static final long serialVersionUID = 1L;
+
+        @Override
+        public void doCatch(Throwable t) throws Throwable {
+            // NO-OP
+        }
+
+        @Override
+        public void doFinally() {
+            // NO-OP
+        }
+    }
+
     public static class TesterBodyTag extends BodyTagSupport {
 
         private static final long serialVersionUID = 1L;
@@ -528,25 +546,6 @@ public class TestGenerator extends TomcatBaseTest {
         }
     }
 
-    private static boolean tagTesterTagReleaseReleased = false;
-
-    public static class TesterTagRelease extends TesterTag {
-        private String data;
-
-        public String getData() {
-            return data;
-        }
-
-        public void setData(String data) {
-            this.data = data;
-        }
-
-        @Override
-        public void release() {
-            tagTesterTagReleaseReleased = true;
-        }
-    }
-
     public static class DataPropertyEditor extends PropertyEditorSupport {
     }
 
@@ -797,17 +796,13 @@ public class TestGenerator extends TomcatBaseTest {
         doTestJsp("usebean-04.jsp", HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
     }
 
+    @Ignore // Requires specific Java settings
     @Test
     public void testUseBean05() throws Exception {
         // Whether this test passes or fails depends on the Java version used
         // and the JRE settings.
-        // For the test to pass it requires --illegal-access=deny
-        // This is the default setting on Java 16 upwards
-        if (JreCompat.isJre16Available()) {
-            doTestJsp("usebean-05.jsp", HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
-        } else {
-            doTestJsp("usebean-05.jsp", HttpServletResponse.SC_OK);
-        }
+        // For the test to pass use --illegal-access=deny
+        doTestJsp("usebean-05.jsp", HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
     }
 
     @Test
@@ -827,7 +822,7 @@ public class TestGenerator extends TomcatBaseTest {
 
     @Test
     public void testCustomTag01() throws Exception {
-        doTestJsp("try-catch-finally.jsp");
+        doTestJsp("try-catch-finally-01.jsp");
     }
 
     @Test
@@ -968,112 +963,6 @@ public class TestGenerator extends TomcatBaseTest {
         Assert.assertEquals(body.toString(), HttpServletResponse.SC_OK, rc);
     }
 
-    @Test
-    public void testBug69508() throws Exception {
-        getTomcatInstanceTestWebapp(false, true);
-
-        ByteChunk body = new ByteChunk();
-        int rc = getUrl("http://localhost:" + getPort() + "/test/bug6nnnn/bug69508.jsp?init=InitCommand", body, null);
-
-        String text = body.toString();
-        Assert.assertEquals(text, HttpServletResponse.SC_OK, rc);
-        // include page URL with param cmd
-        Assert.assertTrue(text, text.contains("<p>cmd - someCommand</p>"));
-        Assert.assertTrue(text, text.contains("<p>param1 - value1</p>"));
-        Assert.assertTrue(text, text.contains("<p>cmd - someCommandAbs</p>"));
-        Assert.assertTrue(text, text.contains("<p>param1 - value1Abs</p>"));
-        // include page URL without param
-        Assert.assertTrue(text, text.contains("<p>param2 - value2</p>"));
-        Assert.assertTrue(text, text.contains("<p>param2 - value2Abs</p>"));
-
-        Assert.assertTrue(text, text.contains("<p>param3 - InitCommand</p>"));
-        Assert.assertTrue(text, text.contains("<p>param3 - InitCommandAbs</p>"));
-
-        Assert.assertTrue(text, text.contains("<p>param4 - value4</p>"));
-        Assert.assertTrue(text, text.contains("<p>param4 - value4Abs</p>"));
-
-        Assert.assertTrue(text, text.contains("<p>param5 - InitCommand</p>"));
-        Assert.assertTrue(text, text.contains("<p>param5 - InitCommandAbs</p>"));
-
-        Assert.assertTrue(text, text.contains("<p>param6 - value6</p>"));
-        Assert.assertTrue(text, text.contains("<p>param6 - value6Abs</p>"));
-    }
-
-    @Test
-    public void testTagReleaseWithPooling() throws Exception {
-        doTestTagRelease(true);
-    }
-
-    @Test
-    public void testTagReleaseWithoutPooling() throws Exception {
-        doTestTagRelease(false);
-    }
-
-    public void doTestTagRelease(boolean enablePooling) throws Exception {
-        tagTesterTagReleaseReleased = false;
-        Tomcat tomcat = getTomcatInstance();
-
-        File appDir = new File("test/webapp");
-        Context ctxt = tomcat.addContext("", appDir.getAbsolutePath());
-        ctxt.addServletContainerInitializer(new JasperInitializer(), null);
-
-        Tomcat.initWebappDefaults(ctxt);
-        Wrapper w = (Wrapper) ctxt.findChild("jsp");
-        w.addInitParameter("enablePooling", String.valueOf(enablePooling));
-
-        tomcat.start();
-
-        getUrl("http://localhost:" + getPort() + "/jsp/generator/release.jsp");
-        if (enablePooling) {
-            Assert.assertFalse(tagTesterTagReleaseReleased);
-        } else {
-            Assert.assertTrue(tagTesterTagReleaseReleased);
-        }
-    }
-
-    @Test
-    public void testNonstandardSets() throws Exception {
-        getTomcatInstanceTestWebapp(true, true);
-
-        // This should break all subsequent requests
-        ByteChunk body = new ByteChunk();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/set-01.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=testValue" + NEW_LINE
-                + "request value=null" + NEW_LINE
-                + "session value=null" + NEW_LINE
-                + "application value=null", body.toString());
-        body.recycle();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/set-02.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=testValue" + NEW_LINE
-                + "request value=null" + NEW_LINE
-                + "session value=null" + NEW_LINE
-                + "application value=null", body.toString());
-        body.recycle();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/set-03.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=null" + NEW_LINE
-                + "request value=testValue" + NEW_LINE
-                + "session value=null" + NEW_LINE
-                + "application value=null", body.toString());
-        body.recycle();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/set-04.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=null" + NEW_LINE
-                + "request value=null" + NEW_LINE
-                + "session value=testValue" + NEW_LINE
-                + "application value=null", body.toString());
-        body.recycle();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/set-05.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=null" + NEW_LINE
-                + "request value=null" + NEW_LINE
-                + "session value=null" + NEW_LINE
-                + "application value=testValue", body.toString());
-        body.recycle();
-    }
-
     private void doTestJsp(String jspName) throws Exception {
         doTestJsp(jspName, HttpServletResponse.SC_OK);
     }
@@ -1086,47 +975,4 @@ public class TestGenerator extends TomcatBaseTest {
 
         Assert.assertEquals(body.toString(), expectedResponseCode, rc);
     }
-
-    @Test
-    public void testNonstandardRemoves() throws Exception {
-        getTomcatInstanceTestWebapp(true, true);
-
-        // This should break all subsequent requests
-        ByteChunk body = new ByteChunk();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/remove-01.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=null" + NEW_LINE
-                + "request value=testValue" + NEW_LINE
-                + "session value=testValue" + NEW_LINE
-                + "application value=testValue", body.toString());
-        body.recycle();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/remove-02.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=testValue" + NEW_LINE
-                + "request value=null" + NEW_LINE
-                + "session value=testValue" + NEW_LINE
-                + "application value=testValue", body.toString());
-        body.recycle();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/remove-03.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=testValue" + NEW_LINE
-                + "request value=testValue" + NEW_LINE
-                + "session value=null" + NEW_LINE
-                + "application value=testValue", body.toString());
-        body.recycle();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/remove-04.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=testValue" + NEW_LINE
-                + "request value=testValue" + NEW_LINE
-                + "session value=testValue" + NEW_LINE
-                + "application value=null", body.toString());
-        body.recycle();
-        getUrl("http://localhost:" + getPort() + "/test/jsp/generator/nonstandard/remove-05.jsp", body, null);
-        Assert.assertEquals(NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE + NEW_LINE
-                + "pageContext value=null" + NEW_LINE
-                + "request value=null" + NEW_LINE
-                + "session value=null" + NEW_LINE
-                + "application value=null", body.toString());
-        body.recycle();
-    }
 }
