@@ -24,14 +24,16 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
 
 import javax.management.ObjectName;
-import javax.servlet.ServletContainerInitializer;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletRegistration.Dynamic;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletSecurityElement;
-import javax.servlet.descriptor.JspConfigDescriptor;
+
+import jakarta.servlet.ServletContainerInitializer;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletRegistration.Dynamic;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletSecurityElement;
+import jakarta.servlet.descriptor.JspConfigDescriptor;
 
 import org.apache.catalina.AccessLog;
 import org.apache.catalina.Authenticator;
@@ -363,11 +365,6 @@ public class TesterContext implements Context {
         // NO-OP
     }
 
-    @Override
-    public String getCharset(Locale locale) {
-        return null;
-    }
-
     @Override
     public URL getConfigFile() {
         return null;
@@ -738,9 +735,24 @@ public class TesterContext implements Context {
         // NO-OP
     }
 
+    private final Map<String,String> localEncodingMap = new ConcurrentHashMap<>();
+
     @Override
     public void addLocaleEncodingMappingParameter(String locale, String encoding) {
-        // NO-OP
+        localEncodingMap.put(locale, encoding);
+    }
+    @Override
+    public String getCharset(Locale locale) {
+        // Match full language_country_variant first, then language_country,
+        // then language only
+        String charset = localEncodingMap.get(locale.toString());
+        if (charset == null) {
+            charset = localEncodingMap.get(locale.getLanguage() + "_" + locale.getCountry());
+            if (charset == null) {
+                charset = localEncodingMap.get(locale.getLanguage());
+            }
+        }
+        return charset;
     }
 
     @Override
@@ -809,11 +821,6 @@ public class TesterContext implements Context {
         return null;
     }
 
-    @Override
-    public ErrorPage findErrorPage(String exceptionType) {
-        return null;
-    }
-
     @Override
     public ErrorPage findErrorPage(Throwable exceptionType) {
         return null;
@@ -874,16 +881,6 @@ public class TesterContext implements Context {
         return null;
     }
 
-    @Override
-    public String findStatusPage(int status) {
-        return null;
-    }
-
-    @Override
-    public int[] findStatusPages() {
-        return null;
-    }
-
     @Override
     public String[] findWatchedResources() {
         return null;
@@ -1290,14 +1287,34 @@ public class TesterContext implements Context {
     public boolean getCreateUploadTargets() { return false; }
 
     @Override
-    public boolean isParallelAnnotationScanning() { return false; }
+    public boolean getAlwaysAccessSession() { return false; }
+    @Override
+    public void setAlwaysAccessSession(boolean alwaysAccessSession) {}
+
+    @Override
+    public boolean getContextGetResourceRequiresSlash() { return false; }
+    @Override
+    public void setContextGetResourceRequiresSlash(boolean contextGetResourceRequiresSlash) {}
+
+    @Override
+    public boolean getDispatcherWrapsSameObject() { return false; }
+    @Override
+    public void setDispatcherWrapsSameObject(boolean dispatcherWrapsSameObject) {}
+
+    @Override
+    public boolean getParallelAnnotationScanning() { return false; }
     @Override
     public void setParallelAnnotationScanning(boolean parallelAnnotationScanning) {}
 
+    boolean useBloomFilterForArchives = false;
     @Override
-    public boolean getUseBloomFilterForArchives() { return false; }
+    public boolean getUseBloomFilterForArchives() {
+        return useBloomFilterForArchives;
+    }
 
     @Override
-    public void setUseBloomFilterForArchives(boolean useBloomFilterForArchives) {}
+    public void setUseBloomFilterForArchives(boolean useBloomFilterForArchives) {
+        this.useBloomFilterForArchives = useBloomFilterForArchives;
+    }
 
 }
