@@ -28,14 +28,13 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameter;
 
-import org.apache.catalina.Lifecycle;
-import org.apache.catalina.LifecycleEvent;
 import org.apache.catalina.connector.Connector;
-import org.apache.catalina.core.AprStatus;
+import org.apache.catalina.core.AprLifecycleListener;
+import org.apache.catalina.core.StandardServer;
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
+import org.apache.tomcat.jni.SSL;
 import org.apache.tomcat.util.buf.ByteChunk;
-import org.apache.tomcat.util.net.openssl.OpenSSLStatus;
 
 /**
  * The keys and certificates used in this file are all available in svn and were
@@ -53,11 +52,11 @@ public class TestClientCertTls13 extends TomcatBaseTest {
     public static Collection<Object[]> parameters() {
         List<Object[]> parameterSets = new ArrayList<>();
         parameterSets.add(new Object[] {
-                "JSSE", Boolean.FALSE, "org.apache.tomcat.util.net.jsse.JSSEImplementation", Boolean.FALSE});
+                "JSSE", Boolean.FALSE, "org.apache.tomcat.util.net.jsse.JSSEImplementation"});
         parameterSets.add(new Object[] {
-                "OpenSSL", Boolean.TRUE, "org.apache.tomcat.util.net.openssl.OpenSSLImplementation", Boolean.TRUE});
+                "OpenSSL", Boolean.TRUE, "org.apache.tomcat.util.net.openssl.OpenSSLImplementation"});
         parameterSets.add(new Object[] {
-                "OpenSSL-FFM", Boolean.TRUE, "org.apache.tomcat.util.net.openssl.panama.OpenSSLImplementation", Boolean.FALSE});
+                "OpenSSL-FFM", Boolean.FALSE, "org.apache.tomcat.util.net.openssl.panama.OpenSSLImplementation"});
 
         return parameterSets;
     }
@@ -66,14 +65,11 @@ public class TestClientCertTls13 extends TomcatBaseTest {
     public String connectorName;
 
     @Parameter(1)
-    public boolean useOpenSSL;
+    public boolean needApr;
 
     @Parameter(2)
     public String sslImplementationName;
 
-    @Parameter(3)
-    public boolean initSslImplementation;
-
 
     @Test
     public void testClientCertGet() throws Exception {
@@ -112,15 +108,15 @@ public class TestClientCertTls13 extends TomcatBaseTest {
         TesterSupport.configureClientSsl();
 
         Connector connector = tomcat.getConnector();
-        TesterSupport.configureSSLImplementation(tomcat, sslImplementationName, useOpenSSL);
+        TesterSupport.configureSSLImplementation(tomcat, sslImplementationName);
 
-        if (useOpenSSL) {
-            // getOpenSSLVersion() requires that the listener has been initialised
-            if (initSslImplementation) {
-                tomcat.getServer().findLifecycleListeners()[0].lifecycleEvent(
-                        new LifecycleEvent(tomcat.getServer(), Lifecycle.BEFORE_INIT_EVENT, null));
-            }
-            Assume.assumeTrue(AprStatus.getOpenSSLVersion() >= 0x1010100f || OpenSSLStatus.getVersion() >= 0x1010100f);
+        if (needApr) {
+            AprLifecycleListener listener = new AprLifecycleListener();
+            Assume.assumeTrue(AprLifecycleListener.isAprAvailable());
+            // Need at least OpenSSL 1.1.1 for TLSv1.3 support
+            Assume.assumeTrue(SSL.version() >= 0x1010100f);
+            StandardServer server = (StandardServer) tomcat.getServer();
+            server.addLifecycleListener(listener);
         }
 
         // Tests default to TLSv1.2 when client cert auth is used
