@@ -24,12 +24,15 @@ import java.util.List;
 import javax.net.ssl.SSLException;
 
 import org.junit.Assert;
+import org.junit.Assume;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameter;
 
 import org.apache.catalina.connector.Connector;
+import org.apache.catalina.core.AprLifecycleListener;
+import org.apache.catalina.core.StandardServer;
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
 import org.apache.coyote.ProtocolHandler;
@@ -52,7 +55,7 @@ public class TestCustomSslTrustManager extends TomcatBaseTest {
         parameterSets.add(new Object[] {
                 "OpenSSL", Boolean.TRUE, "org.apache.tomcat.util.net.openssl.OpenSSLImplementation"});
         parameterSets.add(new Object[] {
-                "OpenSSL-FFM", Boolean.TRUE, "org.apache.tomcat.util.net.openssl.panama.OpenSSLImplementation"});
+                "OpenSSL-FFM", Boolean.FALSE, "org.apache.tomcat.util.net.openssl.panama.OpenSSLImplementation"});
 
         return parameterSets;
     }
@@ -61,7 +64,7 @@ public class TestCustomSslTrustManager extends TomcatBaseTest {
     public String connectorName;
 
     @Parameter(1)
-    public boolean useOpenSSL;
+    public boolean needApr;
 
     @Parameter(2)
     public String sslImplementationName;
@@ -96,12 +99,14 @@ public class TestCustomSslTrustManager extends TomcatBaseTest {
         TesterSupport.configureClientCertContext(tomcat);
 
         Connector connector = tomcat.getConnector();
+        TesterSupport.configureSSLImplementation(tomcat, sslImplementationName);
 
-        // This test is only for JSSE based SSL connectors
-        if (connector.getProtocolHandlerClassName().contains("Apr")) {
-            return;
+        if (needApr) {
+            AprLifecycleListener listener = new AprLifecycleListener();
+            Assume.assumeTrue(AprLifecycleListener.isAprAvailable());
+            StandardServer server = (StandardServer) tomcat.getServer();
+            server.addLifecycleListener(listener);
         }
-        TesterSupport.configureSSLImplementation(tomcat, sslImplementationName, useOpenSSL);
 
         // Override the defaults
         ProtocolHandler handler = connector.getProtocolHandler();
