@@ -20,9 +20,9 @@ import java.io.IOException;
 import java.net.URI;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import javax.websocket.ContainerProvider;
-import javax.websocket.DeploymentException;
-import javax.websocket.WebSocketContainer;
+import jakarta.websocket.ContainerProvider;
+import jakarta.websocket.DeploymentException;
+import jakarta.websocket.WebSocketContainer;
 
 import org.junit.Assert;
 import org.junit.Ignore;
@@ -38,8 +38,7 @@ import org.apache.tomcat.websocket.TesterMessageCountClient.TesterProgrammaticEn
 public class TestConnectionLimit extends TomcatBaseTest {
 
     /*
-     * Simple test to see how many outgoing connections can be created on a
-     * single machine.
+     * Simple test to see how many outgoing connections can be created on a single machine.
      */
     @Test
     public void testSingleMachine() throws Exception {
@@ -54,8 +53,7 @@ public class TestConnectionLimit extends TomcatBaseTest {
 
         tomcat.start();
 
-        URI uri = new URI("ws://localhost:" + getPort() +
-                TesterEchoServer.Config.PATH_ASYNC);
+        URI uri = new URI("ws://localhost:" + getPort() + TesterEchoServer.Config.PATH_ASYNC);
         AtomicInteger counter = new AtomicInteger(0);
 
         int threadCount = 50;
@@ -87,15 +85,14 @@ public class TestConnectionLimit extends TomcatBaseTest {
 
         @Override
         public void run() {
-            WebSocketContainer wsContainer =
-                    ContainerProvider.getWebSocketContainer();
+            WebSocketContainer wsContainer = ContainerProvider.getWebSocketContainer();
 
             int count = 0;
 
             try {
                 while (true) {
                     wsContainer.connectToServer(TesterProgrammaticEndpoint.class,
-                            javax.websocket.ClientEndpointConfig.Builder.create().build(), uri);
+                            jakarta.websocket.ClientEndpointConfig.Builder.create().build(), uri);
                     count = counter.incrementAndGet();
                     if (count % 100 == 0) {
                         System.out.println(count + " and counting...");
