@@ -64,23 +64,19 @@ public class TestWebSocketFrameClient extends WebSocketBaseTest {
         WebSocketContainer wsContainer = ContainerProvider.getWebSocketContainer();
 
         // BZ 62596
-        ClientEndpointConfig clientEndpointConfig =
-                ClientEndpointConfig.Builder.create().configurator(new Configurator() {
+        ClientEndpointConfig clientEndpointConfig = ClientEndpointConfig.Builder.create()
+                .configurator(new Configurator() {
                     @Override
                     public void beforeRequest(Map<String, List<String>> headers) {
-                        headers.put("Dummy", Collections.singletonList(
-                                String.join("", Collections.nCopies(4000, "A"))));
+                        headers.put("Dummy",
+                                Collections.singletonList(String.join("", Collections.nCopies(4000, "A"))));
                         super.beforeRequest(headers);
                     }
                 }).build();
 
-        Session wsSession = wsContainer.connectToServer(
-                TesterProgrammaticEndpoint.class,
-                clientEndpointConfig,
-                new URI("ws://localhost:" + getPort() +
-                        TesterFirehoseServer.PATH));
-        CountDownLatch latch =
-                new CountDownLatch(TesterFirehoseServer.MESSAGE_COUNT);
+        Session wsSession = wsContainer.connectToServer(TesterProgrammaticEndpoint.class, clientEndpointConfig,
+                new URI("ws://localhost:" + getPort() + TesterFirehoseServer.PATH));
+        CountDownLatch latch = new CountDownLatch(TesterFirehoseServer.MESSAGE_COUNT);
         BasicText handler = new BasicText(latch);
         wsSession.addMessageHandler(handler);
         wsSession.getBasicRemote().sendText("Hello");
@@ -89,12 +85,10 @@ public class TestWebSocketFrameClient extends WebSocketBaseTest {
 
         // Ignore the latch result as the message count test below will tell us
         // if the right number of messages arrived
-        handler.getLatch().await(TesterFirehoseServer.WAIT_TIME_MILLIS,
-                TimeUnit.MILLISECONDS);
+        handler.getLatch().await(TesterFirehoseServer.WAIT_TIME_MILLIS, TimeUnit.MILLISECONDS);
 
         Queue<String> messages = handler.getMessages();
-        Assert.assertEquals(
-                TesterFirehoseServer.MESSAGE_COUNT, messages.size());
+        Assert.assertEquals(TesterFirehoseServer.MESSAGE_COUNT, messages.size());
         for (String message : messages) {
             Assert.assertEquals(TesterFirehoseServer.MESSAGE, message);
         }
@@ -115,15 +109,14 @@ public class TestWebSocketFrameClient extends WebSocketBaseTest {
 
         tomcat.start();
 
-        echoTester("",null);
-        echoTester("/",null);
+        echoTester("", null);
+        echoTester("/", null);
         // This will trigger a redirect so there will be 5 requests logged
-        echoTester("/foo",null);
-        echoTester("/foo/",null);
+        echoTester("/foo", null);
+        echoTester("/foo/", null);
     }
 
-    public void echoTester(String path, ClientEndpointConfig clientEndpointConfig)
-            throws Exception {
+    public void echoTester(String path, ClientEndpointConfig clientEndpointConfig) throws Exception {
         WebSocketContainer wsContainer = ContainerProvider.getWebSocketContainer();
 
         if (clientEndpointConfig == null) {
@@ -133,8 +126,8 @@ public class TestWebSocketFrameClient extends WebSocketBaseTest {
         // CI systems.
         clientEndpointConfig.getUserProperties().put(Constants.IO_TIMEOUT_MS_PROPERTY, "10000");
 
-        Session wsSession = wsContainer.connectToServer(TesterProgrammaticEndpoint.class,
-                clientEndpointConfig, new URI("ws://localhost:" + getPort() + path));
+        Session wsSession = wsContainer.connectToServer(TesterProgrammaticEndpoint.class, clientEndpointConfig,
+                new URI("ws://localhost:" + getPort() + path));
         CountDownLatch latch = new CountDownLatch(1);
         BasicText handler = new BasicText(latch);
         wsSession.addMessageHandler(handler);
@@ -220,7 +213,7 @@ public class TestWebSocketFrameClient extends WebSocketBaseTest {
 
         ClientEndpointConfig clientEndpointConfig = ClientEndpointConfig.Builder.create().build();
         clientEndpointConfig.getUserProperties().put(Constants.WS_AUTHENTICATION_USER_NAME, USER);
-        clientEndpointConfig.getUserProperties().put(Constants.WS_AUTHENTICATION_PASSWORD,PWD);
+        clientEndpointConfig.getUserProperties().put(Constants.WS_AUTHENTICATION_PASSWORD, PWD);
 
         echoTester(URI_PROTECTED, clientEndpointConfig);
     }
