@@ -62,7 +62,7 @@ public class TestWsWebSocketContainerSSL extends WebSocketBaseTest {
         parameterSets.add(new Object[] { "JSSE", Boolean.FALSE, "org.apache.tomcat.util.net.jsse.JSSEImplementation" });
         parameterSets.add(
                 new Object[] { "OpenSSL", Boolean.TRUE, "org.apache.tomcat.util.net.openssl.OpenSSLImplementation" });
-        parameterSets.add(new Object[] { "OpenSSL-Panama", Boolean.FALSE,
+        parameterSets.add(new Object[] { "OpenSSL-FFM", Boolean.FALSE,
                 "org.apache.tomcat.util.net.openssl.panama.OpenSSLImplementation" });
 
         return parameterSets;
