@@ -52,7 +52,8 @@ public class TestSlowClient extends WebSocketBaseTest {
         // WebSocket client
         WebSocketContainer wsContainer = ContainerProvider.getWebSocketContainer();
         Session wsSession = wsContainer.connectToServer(TesterProgrammaticEndpoint.class,
-                ClientEndpointConfig.Builder.create().build(), new URI("ws://localhost:" + getPort() + TesterFirehoseServer.PATH));
+                ClientEndpointConfig.Builder.create().build(),
+                new URI("ws://localhost:" + getPort() + TesterFirehoseServer.PATH));
         // Configure a handler designed to create a backlog causing the server
         // side write to time out.
         wsSession.addMessageHandler(new VerySlowHandler());
@@ -74,6 +75,11 @@ public class TestSlowClient extends WebSocketBaseTest {
         // BZ 64848 (non-container thread variant)
         // Confirm there are no waiting processors
         AbstractProtocol<?> protocol = (AbstractProtocol<?>) tomcat.getConnector().getProtocolHandler();
+        count = 0;
+        while (protocol.getWaitingProcessorCount() > 0 && count < 200) {
+            Thread.sleep(100);
+            count++;
+        }
         Assert.assertEquals(0, protocol.getWaitingProcessorCount());
     }
 
