@@ -19,17 +19,17 @@ import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.ResourceBundle;
 
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import util.HTMLFilter;
 
 /**
  * Example servlet showing request information.
  *
- * @author James Duncan Davidson <duncan@eng.sun.com>
+ * @author James Duncan Davidson &lt;duncan@eng.sun.com>
  */
 
 public class RequestInfoExample extends HttpServlet {
@@ -94,7 +94,7 @@ public class RequestInfoExample extends HttpServlet {
         out.println("</td></tr>");
 
         String cipherSuite=
-                (String)request.getAttribute("javax.servlet.request.cipher_suite");
+                (String)request.getAttribute("jakarta.servlet.request.cipher_suite");
         if(cipherSuite!=null){
             out.println("<tr><td>");
             out.println("SSLCipherSuite:");
